function P_(n,r){for(var i=0;i<r.length;i++){const l=r[i];if(typeof l!="string"&&!Array.isArray(l)){for(const u in l)if(u!=="default"&&!(u in n)){const c=Object.getOwnPropertyDescriptor(l,u);c&&Object.defineProperty(n,u,c.get?c:{enumerable:!0,get:()=>l[u]})}}}return Object.freeze(Object.defineProperty(n,Symbol.toStringTag,{value:"Module"}))}(function(){const r=document.createElement("link").relList;if(r&&r.supports&&r.supports("modulepreload"))return;for(const u of document.querySelectorAll('link[rel="modulepreload"]'))l(u);new MutationObserver(u=>{for(const c of u)if(c.type==="childList")for(const d of c.addedNodes)d.tagName==="LINK"&&d.rel==="modulepreload"&&l(d)}).observe(document,{childList:!0,subtree:!0});function i(u){const c={};return u.integrity&&(c.integrity=u.integrity),u.referrerPolicy&&(c.referrerPolicy=u.referrerPolicy),u.crossOrigin==="use-credentials"?c.credentials="include":u.crossOrigin==="anonymous"?c.credentials="omit":c.credentials="same-origin",c}function l(u){if(u.ep)return;u.ep=!0;const c=i(u);fetch(u.href,c)}})();var bs=typeof globalThis<"u"?globalThis:typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{};function _a(n){return n&&n.__esModule&&Object.prototype.hasOwnProperty.call(n,"default")?n.default:n}function Qr(n){if(Object.prototype.hasOwnProperty.call(n,"__esModule"))return n;var r=n.default;if(typeof r=="function"){var i=function l(){return this instanceof l?Reflect.construct(r,arguments,this.constructor):r.apply(this,arguments)};i.prototype=r.prototype}else i={};return Object.defineProperty(i,"__esModule",{value:!0}),Object.keys(n).forEach(function(l){var u=Object.getOwnPropertyDescriptor(n,l);Object.defineProperty(i,l,u.get?u:{enumerable:!0,get:function(){return n[l]}})}),i}var od={exports:{}},Wl={};/**
 * @license React
 * react-jsx-runtime.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var C0;function X_(){if(C0)return Wl;C0=1;var n=Symbol.for("react.transitional.element"),r=Symbol.for("react.fragment");function i(l,u,c){var d=null;if(c!==void 0&&(d=""+c),u.key!==void 0&&(d=""+u.key),"key"in u){c={};for(var p in u)p!=="key"&&(c[p]=u[p])}else c=u;return u=c.ref,{$$typeof:n,type:l,key:d,ref:u!==void 0?u:null,props:c}}return Wl.Fragment=r,Wl.jsx=i,Wl.jsxs=i,Wl}var N0;function Q_(){return N0||(N0=1,od.exports=X_()),od.exports}var T=Q_(),ud={exports:{}},$e={};/**
 * @license React
 * react.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var M0;function K_(){if(M0)return $e;M0=1;var n=Symbol.for("react.transitional.element"),r=Symbol.for("react.portal"),i=Symbol.for("react.fragment"),l=Symbol.for("react.strict_mode"),u=Symbol.for("react.profiler"),c=Symbol.for("react.consumer"),d=Symbol.for("react.context"),p=Symbol.for("react.forward_ref"),h=Symbol.for("react.suspense"),y=Symbol.for("react.memo"),m=Symbol.for("react.lazy"),g=Symbol.iterator;function S(N){return N===null||typeof N!="object"?null:(N=g&&N[g]||N["@@iterator"],typeof N=="function"?N:null)}var R={isMounted:function(){return!1},enqueueForceUpdate:function(){},enqueueReplaceState:function(){},enqueueSetState:function(){}},_=Object.assign,E={};function C(N,Z,le){this.props=N,this.context=Z,this.refs=E,this.updater=le||R}C.prototype.isReactComponent={},C.prototype.setState=function(N,Z){if(typeof N!="object"&&typeof N!="function"&&N!=null)throw Error("takes an object of state variables to update or a function which returns an object of state variables.");this.updater.enqueueSetState(this,N,Z,"setState")},C.prototype.forceUpdate=function(N){this.updater.enqueueForceUpdate(this,N,"forceUpdate")};function j(){}j.prototype=C.prototype;function M(N,Z,le){this.props=N,this.context=Z,this.refs=E,this.updater=le||R}var B=M.prototype=new j;B.constructor=M,_(B,C.prototype),B.isPureReactComponent=!0;var X=Array.isArray,A={H:null,A:null,T:null,S:null,V:null},$=Object.prototype.hasOwnProperty;function O(N,Z,le,re,z,F){return le=F.ref,{$$typeof:n,type:N,key:Z,ref:le!==void 0?le:null,props:F}}function q(N,Z){return O(N.type,Z,void 0,void 0,void 0,N.props)}function L(N){return typeof N=="object"&&N!==null&&N.$$typeof===n}function Y(N){var Z={"=":"=0",":":"=2"};return"$"+N.replace(/[=:]/g,function(le){return Z[le]})}var W=/\/+/g;function oe(N,Z){return typeof N=="object"&&N!==null&&N.key!=null?Y(""+N.key):Z.toString(36)}function ue(){}function he(N){switch(N.status){case"fulfilled":return N.value;case"rejected":throw N.reason;default:switch(typeof N.status=="string"?N.then(ue,ue):(N.status="pending",N.then(function(Z){N.status==="pending"&&(N.status="fulfilled",N.value=Z)},function(Z){N.status==="pending"&&(N.status="rejected",N.reason=Z)})),N.status){case"fulfilled":return N.value;case"rejected":throw N.reason}}throw N}function fe(N,Z,le,re,z){var F=typeof N;(F==="undefined"||F==="boolean")&&(N=null);var te=!1;if(N===null)te=!0;else switch(F){case"bigint":case"string":case"number":te=!0;break;case"object":switch(N.$$typeof){case n:case r:te=!0;break;case m:return te=N._init,fe(te(N._payload),Z,le,re,z)}}if(te)return z=z(N),te=re===""?"."+oe(N,0):re,X(z)?(le="",te!=null&&(le=te.replace(W,"$&/")+"/"),fe(z,Z,le,"",function(xe){return xe})):z!=null&&(L(z)&&(z=q(z,le+(z.key==null||N&&N.key===z.key?"":(""+z.key).replace(W,"$&/")+"/")+te)),Z.push(z)),1;te=0;var pe=re===""?".":re+":";if(X(N))for(var ce=0;ce<N.length;ce++)re=N[ce],F=pe+oe(re,ce),te+=fe(re,Z,le,F,z);else if(ce=S(N),typeof ce=="function")for(N=ce.call(N),ce=0;!(re=N.next()).done;)re=re.value,F=pe+oe(re,ce++),te+=fe(re,Z,le,F,z);else if(F==="object"){if(typeof N.then=="function")return fe(he(N),Z,le,re,z);throw Z=String(N),Error("Objects are not valid as a React child (found: "+(Z==="[object Object]"?"object with keys {"+Object.keys(N).join(", ")+"}":Z)+"). If you meant to render a collection of children, use an array instead.")}return te}function H(N,Z,le){if(N==null)return N;var re=[],z=0;return fe(N,re,"","",function(F){return Z.call(le,F,z++)}),re}function I(N){if(N._status===-1){var Z=N._result;Z=Z(),Z.then(function(le){(N._status===0||N._status===-1)&&(N._status=1,N._result=le)},function(le){(N._status===0||N._status===-1)&&(N._status=2,N._result=le)}),N._status===-1&&(N._status=0,N._result=Z)}if(N._status===1)return N._result.default;throw N._result}var ae=typeof reportError=="function"?reportError:function(N){if(typeof window=="object"&&typeof window.ErrorEvent=="function"){var Z=new window.ErrorEvent("error",{bubbles:!0,cancelable:!0,message:typeof N=="object"&&N!==null&&typeof N.message=="string"?String(N.message):String(N),error:N});if(!window.dispatchEvent(Z))return}else if(typeof process=="object"&&typeof process.emit=="function"){process.emit("uncaughtException",N);return}};function be(){}return $e.Children={map:H,forEach:function(N,Z,le){H(N,function(){Z.apply(this,arguments)},le)},count:function(N){var Z=0;return H(N,function(){Z++}),Z},toArray:function(N){return H(N,function(Z){return Z})||[]},only:function(N){if(!L(N))throw Error("React.Children.only expected to receive a single React element child.");return N}},$e.Component=C,$e.Fragment=i,$e.Profiler=u,$e.PureComponent=M,$e.StrictMode=l,$e.Suspense=h,$e.__CLIENT_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE=A,$e.__COMPILER_RUNTIME={__proto__:null,c:function(N){return A.H.useMemoCache(N)}},$e.cache=function(N){return function(){return N.apply(null,arguments)}},$e.cloneElement=function(N,Z,le){if(N==null)throw Error("The argument must be a React element, but you passed "+N+".");var re=_({},N.props),z=N.key,F=void 0;if(Z!=null)for(te in Z.ref!==void 0&&(F=void 0),Z.key!==void 0&&(z=""+Z.key),Z)!$.call(Z,te)||te==="key"||te==="__self"||te==="__source"||te==="ref"&&Z.ref===void 0||(re[te]=Z[te]);var te=arguments.length-2;if(te===1)re.children=le;else if(1<te){for(var pe=Array(te),ce=0;ce<te;ce++)pe[ce]=arguments[ce+2];re.children=pe}return O(N.type,z,void 0,void 0,F,re)},$e.createContext=function(N){return N={$$typeof:d,_currentValue:N,_currentValue2:N,_threadCount:0,Provider:null,Consumer:null},N.Provider=N,N.Consumer={$$typeof:c,_context:N},N},$e.createElement=function(N,Z,le){var re,z={},F=null;if(Z!=null)for(re in Z.key!==void 0&&(F=""+Z.key),Z)$.call(Z,re)&&re!=="key"&&re!=="__self"&&re!=="__source"&&(z[re]=Z[re]);var te=arguments.length-2;if(te===1)z.children=le;else if(1<te){for(var pe=Array(te),ce=0;ce<te;ce++)pe[ce]=arguments[ce+2];z.children=pe}if(N&&N.defaultProps)for(re in te=N.defaultProps,te)z[re]===void 0&&(z[re]=te[re]);return O(N,F,void 0,void 0,null,z)},$e.createRef=function(){return{current:null}},$e.forwardRef=function(N){return{$$typeof:p,render:N}},$e.isValidElement=L,$e.lazy=function(N){return{$$typeof:m,_payload:{_status:-1,_result:N},_init:I}},$e.memo=function(N,Z){return{$$typeof:y,type:N,compare:Z===void 0?null:Z}},$e.startTransition=function(N){var Z=A.T,le={};A.T=le;try{var re=N(),z=A.S;z!==null&&z(le,re),typeof re=="object"&&re!==null&&typeof re.then=="function"&&re.then(be,ae)}catch(F){ae(F)}finally{A.T=Z}},$e.unstable_useCacheRefresh=function(){return A.H.useCacheRefresh()},$e.use=function(N){return A.H.use(N)},$e.useActionState=function(N,Z,le){return A.H.useActionState(N,Z,le)},$e.useCallback=function(N,Z){return A.H.useCallback(N,Z)},$e.useContext=function(N){return A.H.useContext(N)},$e.useDebugValue=function(){},$e.useDeferredValue=function(N,Z){return A.H.useDeferredValue(N,Z)},$e.useEffect=function(N,Z,le){var re=A.H;if(typeof le=="function")throw Error("useEffect CRUD overload is not enabled in this build of React.");return re.useEffect(N,Z)},$e.useId=function(){return A.H.useId()},$e.useImperativeHandle=function(N,Z,le){return A.H.useImperativeHandle(N,Z,le)},$e.useInsertionEffect=function(N,Z){return A.H.useInsertionEffect(N,Z)},$e.useLayoutEffect=function(N,Z){return A.H.useLayoutEffect(N,Z)},$e.useMemo=function(N,Z){return A.H.useMemo(N,Z)},$e.useOptimistic=function(N,Z){return A.H.useOptimistic(N,Z)},$e.useReducer=function(N,Z,le){return A.H.useReducer(N,Z,le)},$e.useRef=function(N){return A.H.useRef(N)},$e.useState=function(N){return A.H.useState(N)},$e.useSyncExternalStore=function(N,Z,le){return A.H.useSyncExternalStore(N,Z,le)},$e.useTransition=function(){return A.H.useTransition()},$e.version="19.1.0",$e}var D0;function Qh(){return D0||(D0=1,ud.exports=K_()),ud.exports}var x=Qh();const Xe=_a(x),j0=P_({__proto__:null,default:Xe},[x]);var sd={exports:{}};/*!
	Copyright (c) 2018 Jed Watson.
	Licensed under the MIT License (MIT), see
	http://jedwatson.github.io/classnames
*/var B0;function F_(){return B0||(B0=1,function(n){(function(){var r={}.hasOwnProperty;function i(){for(var c="",d=0;d<arguments.length;d++){var p=arguments[d];p&&(c=u(c,l(p)))}return c}function l(c){if(typeof c=="string"||typeof c=="number")return c;if(typeof c!="object")return"";if(Array.isArray(c))return i.apply(null,c);if(c.toString!==Object.prototype.toString&&!c.toString.toString().includes("[native code]"))return c.toString();var d="";for(var p in c)r.call(c,p)&&c[p]&&(d=u(d,p));return d}function u(c,d){return d?c?c+" "+d:c+d:c}n.exports?(i.default=i,n.exports=i):window.classNames=i})()}(sd)),sd.exports}var Z_=F_();const Ae=_a(Z_);function ge(){return ge=Object.assign?Object.assign.bind():function(n){for(var r=1;r<arguments.length;r++){var i=arguments[r];for(var l in i)({}).hasOwnProperty.call(i,l)&&(n[l]=i[l])}return n},ge.apply(null,arguments)}function er(n,r){if(n==null)return{};var i={};for(var l in n)if({}.hasOwnProperty.call(n,l)){if(r.indexOf(l)!==-1)continue;i[l]=n[l]}return i}function $0(n){return"default"+n.charAt(0).toUpperCase()+n.substr(1)}function I_(n){var r=W_(n,"string");return typeof r=="symbol"?r:String(r)}function W_(n,r){if(typeof n!="object"||n===null)return n;var i=n[Symbol.toPrimitive];if(i!==void 0){var l=i.call(n,r);if(typeof l!="object")return l;throw new TypeError("@@toPrimitive must return a primitive value.")}return String(n)}function VS(n,r,i){var l=x.useRef(n!==void 0),u=x.useState(r),c=u[0],d=u[1],p=n!==void 0,h=l.current;return l.current=p,!p&&h&&c!==r&&d(r),[p?n:c,x.useCallback(function(y){for(var m=arguments.length,g=new Array(m>1?m-1:0),S=1;S<m;S++)g[S-1]=arguments[S];i&&i.apply(void 0,[y].concat(g)),d(y)},[i])]}function J_(n,r){return Object.keys(r).reduce(function(i,l){var u,c=i,d=c[$0(l)],p=c[l],h=er(c,[$0(l),l].map(I_)),y=r[l],m=VS(p,d,n[y]),g=m[0],S=m[1];return ge({},h,(u={},u[l]=g,u[y]=S,u))},n)}function bh(n,r){return bh=Object.setPrototypeOf?Object.setPrototypeOf.bind():function(i,l){return i.__proto__=l,i},bh(n,r)}function eA(n,r){n.prototype=Object.create(r.prototype),n.prototype.constructor=n,bh(n,r)}const tA=["xxl","xl","lg","md","sm","xs"],nA="xs",Ao=x.createContext({prefixes:{},breakpoints:tA,minBreakpoint:nA}),{Consumer:O5,Provider:T5}=Ao;function we(n,r){const{prefixes:i}=x.useContext(Ao);return n||i[r]||r}function PS(){const{breakpoints:n}=x.useContext(Ao);return n}function XS(){const{minBreakpoint:n}=x.useContext(Ao);return n}function QS(){const{dir:n}=x.useContext(Ao);return n==="rtl"}function Ro(n){return n&&n.ownerDocument||document}function rA(n){var r=Ro(n);return r&&r.defaultView||window}function aA(n,r){return rA(n).getComputedStyle(n,r)}var iA=/([A-Z])/g;function lA(n){return n.replace(iA,"-$1").toLowerCase()}var oA=/^ms-/;function Fu(n){return lA(n).replace(oA,"-ms-")}var uA=/^((translate|rotate|scale)(X|Y|Z|3d)?|matrix(3d)?|perspective|skew(X|Y)?)$/i;function sA(n){return!!(n&&uA.test(n))}function Gr(n,r){var i="",l="";if(typeof r=="string")return n.style.getPropertyValue(Fu(r))||aA(n).getPropertyValue(Fu(r));Object.keys(r).forEach(function(u){var c=r[u];!c&&c!==0?n.style.removeProperty(Fu(u)):sA(u)?l+=u+"("+c+") ":i+=Fu(u)+": "+c+";"}),l&&(i+="transform: "+l+";"),n.style.cssText+=";"+i}var cd={exports:{}},fd,q0;function cA(){if(q0)return fd;q0=1;var n="SECRET_DO_NOT_PASS_THIS_OR_YOU_WILL_BE_FIRED";return fd=n,fd}var dd,z0;function fA(){if(z0)return dd;z0=1;var n=cA();function r(){}function i(){}return i.resetWarningCache=r,dd=function(){function l(d,p,h,y,m,g){if(g!==n){var S=new Error("Calling PropTypes validators directly is not supported by the `prop-types` package. Use PropTypes.checkPropTypes() to call them. Read more at http://fb.me/use-check-prop-types");throw S.name="Invariant Violation",S}}l.isRequired=l;function u(){return l}var c={array:l,bigint:l,bool:l,func:l,number:l,object:l,string:l,symbol:l,any:l,arrayOf:u,element:l,elementType:l,instanceOf:u,node:l,objectOf:u,oneOf:u,oneOfType:u,shape:u,exact:u,checkPropTypes:i,resetWarningCache:r};return c.PropTypes=c,c},dd}var k0;function dA(){return k0||(k0=1,cd.exports=fA()()),cd.exports}var pA=dA();const dt=_a(pA);var pd={exports:{}},Jt={};/**
 * @license React
 * react-dom.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var L0;function hA(){if(L0)return Jt;L0=1;var n=Qh();function r(h){var y="https://react.dev/errors/"+h;if(1<arguments.length){y+="?args[]="+encodeURIComponent(arguments[1]);for(var m=2;m<arguments.length;m++)y+="&args[]="+encodeURIComponent(arguments[m])}return"Minified React error #"+h+"; visit "+y+" for the full message or use the non-minified dev environment for full errors and additional helpful warnings."}function i(){}var l={d:{f:i,r:function(){throw Error(r(522))},D:i,C:i,L:i,m:i,X:i,S:i,M:i},p:0,findDOMNode:null},u=Symbol.for("react.portal");function c(h,y,m){var g=3<arguments.length&&arguments[3]!==void 0?arguments[3]:null;return{$$typeof:u,key:g==null?null:""+g,children:h,containerInfo:y,implementation:m}}var d=n.__CLIENT_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE;function p(h,y){if(h==="font")return"";if(typeof y=="string")return y==="use-credentials"?y:""}return Jt.__DOM_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE=l,Jt.createPortal=function(h,y){var m=2<arguments.length&&arguments[2]!==void 0?arguments[2]:null;if(!y||y.nodeType!==1&&y.nodeType!==9&&y.nodeType!==11)throw Error(r(299));return c(h,y,null,m)},Jt.flushSync=function(h){var y=d.T,m=l.p;try{if(d.T=null,l.p=2,h)return h()}finally{d.T=y,l.p=m,l.d.f()}},Jt.preconnect=function(h,y){typeof h=="string"&&(y?(y=y.crossOrigin,y=typeof y=="string"?y==="use-credentials"?y:"":void 0):y=null,l.d.C(h,y))},Jt.prefetchDNS=function(h){typeof h=="string"&&l.d.D(h)},Jt.preinit=function(h,y){if(typeof h=="string"&&y&&typeof y.as=="string"){var m=y.as,g=p(m,y.crossOrigin),S=typeof y.integrity=="string"?y.integrity:void 0,R=typeof y.fetchPriority=="string"?y.fetchPriority:void 0;m==="style"?l.d.S(h,typeof y.precedence=="string"?y.precedence:void 0,{crossOrigin:g,integrity:S,fetchPriority:R}):m==="script"&&l.d.X(h,{crossOrigin:g,integrity:S,fetchPriority:R,nonce:typeof y.nonce=="string"?y.nonce:void 0})}},Jt.preinitModule=function(h,y){if(typeof h=="string")if(typeof y=="object"&&y!==null){if(y.as==null||y.as==="script"){var m=p(y.as,y.crossOrigin);l.d.M(h,{crossOrigin:m,integrity:typeof y.integrity=="string"?y.integrity:void 0,nonce:typeof y.nonce=="string"?y.nonce:void 0})}}else y==null&&l.d.M(h)},Jt.preload=function(h,y){if(typeof h=="string"&&typeof y=="object"&&y!==null&&typeof y.as=="string"){var m=y.as,g=p(m,y.crossOrigin);l.d.L(h,m,{crossOrigin:g,integrity:typeof y.integrity=="string"?y.integrity:void 0,nonce:typeof y.nonce=="string"?y.nonce:void 0,type:typeof y.type=="string"?y.type:void 0,fetchPriority:typeof y.fetchPriority=="string"?y.fetchPriority:void 0,referrerPolicy:typeof y.referrerPolicy=="string"?y.referrerPolicy:void 0,imageSrcSet:typeof y.imageSrcSet=="string"?y.imageSrcSet:void 0,imageSizes:typeof y.imageSizes=="string"?y.imageSizes:void 0,media:typeof y.media=="string"?y.media:void 0})}},Jt.preloadModule=function(h,y){if(typeof h=="string")if(y){var m=p(y.as,y.crossOrigin);l.d.m(h,{as:typeof y.as=="string"&&y.as!=="script"?y.as:void 0,crossOrigin:m,integrity:typeof y.integrity=="string"?y.integrity:void 0})}else l.d.m(h)},Jt.requestFormReset=function(h){l.d.r(h)},Jt.unstable_batchedUpdates=function(h,y){return h(y)},Jt.useFormState=function(h,y,m){return d.H.useFormState(h,y,m)},Jt.useFormStatus=function(){return d.H.useHostTransitionStatus()},Jt.version="19.1.0",Jt}var U0;function KS(){if(U0)return pd.exports;U0=1;function n(){if(!(typeof __REACT_DEVTOOLS_GLOBAL_HOOK__>"u"||typeof __REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE!="function"))try{__REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE(n)}catch{}}return n(),pd.exports=hA(),pd.exports}var yA=KS();const Qa=_a(yA),H0={disabled:!1},FS=Xe.createContext(null);var vA=function(r){return r.scrollTop},lo="unmounted",Sa="exited",Ln="entering",Lr="entered",Fi="exiting",Kr=function(n){eA(r,n);function r(l,u){var c;c=n.call(this,l,u)||this;var d=u,p=d&&!d.isMounting?l.enter:l.appear,h;return c.appearStatus=null,l.in?p?(h=Sa,c.appearStatus=Ln):h=Lr:l.unmountOnExit||l.mountOnEnter?h=lo:h=Sa,c.state={status:h},c.nextCallback=null,c}r.getDerivedStateFromProps=function(u,c){var d=u.in;return d&&c.status===lo?{status:Sa}:null};var i=r.prototype;return i.componentDidMount=function(){this.updateStatus(!0,this.appearStatus)},i.componentDidUpdate=function(u){var c=null;if(u!==this.props){var d=this.state.status;this.props.in?d!==Ln&&d!==Lr&&(c=Ln):(d===Ln||d===Lr)&&(c=Fi)}this.updateStatus(!1,c)},i.componentWillUnmount=function(){this.cancelNextCallback()},i.getTimeouts=function(){var u=this.props.timeout,c,d,p;return c=d=p=u,u!=null&&typeof u!="number"&&(c=u.exit,d=u.enter,p=u.appear!==void 0?u.appear:d),{exit:c,enter:d,appear:p}},i.updateStatus=function(u,c){if(u===void 0&&(u=!1),c!==null)if(this.cancelNextCallback(),c===Ln){if(this.props.unmountOnExit||this.props.mountOnEnter){var d=this.props.nodeRef?this.props.nodeRef.current:Qa.findDOMNode(this);d&&vA(d)}this.performEnter(u)}else this.performExit();else this.props.unmountOnExit&&this.state.status===Sa&&this.setState({status:lo})},i.performEnter=function(u){var c=this,d=this.props.enter,p=this.context?this.context.isMounting:u,h=this.props.nodeRef?[p]:[Qa.findDOMNode(this),p],y=h[0],m=h[1],g=this.getTimeouts(),S=p?g.appear:g.enter;if(!u&&!d||H0.disabled){this.safeSetState({status:Lr},function(){c.props.onEntered(y)});return}this.props.onEnter(y,m),this.safeSetState({status:Ln},function(){c.props.onEntering(y,m),c.onTransitionEnd(S,function(){c.safeSetState({status:Lr},function(){c.props.onEntered(y,m)})})})},i.performExit=function(){var u=this,c=this.props.exit,d=this.getTimeouts(),p=this.props.nodeRef?void 0:Qa.findDOMNode(this);if(!c||H0.disabled){this.safeSetState({status:Sa},function(){u.props.onExited(p)});return}this.props.onExit(p),this.safeSetState({status:Fi},function(){u.props.onExiting(p),u.onTransitionEnd(d.exit,function(){u.safeSetState({status:Sa},function(){u.props.onExited(p)})})})},i.cancelNextCallback=function(){this.nextCallback!==null&&(this.nextCallback.cancel(),this.nextCallback=null)},i.safeSetState=function(u,c){c=this.setNextCallback(c),this.setState(u,c)},i.setNextCallback=function(u){var c=this,d=!0;return this.nextCallback=function(p){d&&(d=!1,c.nextCallback=null,u(p))},this.nextCallback.cancel=function(){d=!1},this.nextCallback},i.onTransitionEnd=function(u,c){this.setNextCallback(c);var d=this.props.nodeRef?this.props.nodeRef.current:Qa.findDOMNode(this),p=u==null&&!this.props.addEndListener;if(!d||p){setTimeout(this.nextCallback,0);return}if(this.props.addEndListener){var h=this.props.nodeRef?[this.nextCallback]:[d,this.nextCallback],y=h[0],m=h[1];this.props.addEndListener(y,m)}u!=null&&setTimeout(this.nextCallback,u)},i.render=function(){var u=this.state.status;if(u===lo)return null;var c=this.props,d=c.children;c.in,c.mountOnEnter,c.unmountOnExit,c.appear,c.enter,c.exit,c.timeout,c.addEndListener,c.onEnter,c.onEntering,c.onEntered,c.onExit,c.onExiting,c.onExited,c.nodeRef;var p=er(c,["children","in","mountOnEnter","unmountOnExit","appear","enter","exit","timeout","addEndListener","onEnter","onEntering","onEntered","onExit","onExiting","onExited","nodeRef"]);return Xe.createElement(FS.Provider,{value:null},typeof d=="function"?d(u,p):Xe.cloneElement(Xe.Children.only(d),p))},r}(Xe.Component);Kr.contextType=FS;Kr.propTypes={};function $i(){}Kr.defaultProps={in:!1,mountOnEnter:!1,unmountOnExit:!1,appear:!1,enter:!0,exit:!0,onEnter:$i,onEntering:$i,onEntered:$i,onExit:$i,onExiting:$i,onExited:$i};Kr.UNMOUNTED=lo;Kr.EXITED=Sa;Kr.ENTERING=Ln;Kr.ENTERED=Lr;Kr.EXITING=Fi;function ZS(n){return n.code==="Escape"||n.keyCode===27}function mA(){const n=x.version.split(".");return{major:+n[0],minor:+n[1],patch:+n[2]}}function Za(n){if(!n||typeof n=="function")return null;const{major:r}=mA();return r>=19?n.props.ref:n.ref}const Cs=!!(typeof window<"u"&&window.document&&window.document.createElement);var Sh=!1,xh=!1;try{var hd={get passive(){return Sh=!0},get once(){return xh=Sh=!0}};Cs&&(window.addEventListener("test",hd,hd),window.removeEventListener("test",hd,!0))}catch{}function gA(n,r,i,l){if(l&&typeof l!="boolean"&&!xh){var u=l.once,c=l.capture,d=i;!xh&&u&&(d=i.__once||function p(h){this.removeEventListener(r,p,c),i.call(this,h)},i.__once=d),n.addEventListener(r,d,Sh?l:c)}n.addEventListener(r,i,l)}function bA(n,r,i,l){var u=l&&typeof l!="boolean"?l.capture:l;n.removeEventListener(r,i,u),i.__once&&n.removeEventListener(r,i.__once,u)}function Ur(n,r,i,l){return gA(n,r,i,l),function(){bA(n,r,i,l)}}function SA(n,r,i,l){if(l===void 0&&(l=!0),n){var u=document.createEvent("HTMLEvents");u.initEvent(r,i,l),n.dispatchEvent(u)}}function xA(n){var r=Gr(n,"transitionDuration")||"",i=r.indexOf("ms")===-1?1e3:1;return parseFloat(r)*i}function EA(n,r,i){i===void 0&&(i=5);var l=!1,u=setTimeout(function(){l||SA(n,"transitionend",!0)},r+i),c=Ur(n,"transitionend",function(){l=!0},{once:!0});return function(){clearTimeout(u),c()}}function OA(n,r,i,l){i==null&&(i=xA(n)||0);var u=EA(n,i,l),c=Ur(n,"transitionend",r);return function(){u(),c()}}function G0(n,r){const i=Gr(n,r)||"",l=i.indexOf("ms")===-1?1e3:1;return parseFloat(i)*l}function Kh(n,r){const i=G0(n,"transitionDuration"),l=G0(n,"transitionDelay"),u=OA(n,c=>{c.target===n&&(u(),r(c))},i+l)}function Jl(...n){return n.filter(r=>r!=null).reduce((r,i)=>{if(typeof i!="function")throw new Error("Invalid Argument Type, must only provide functions, undefined, or null.");return r===null?i:function(...u){r.apply(this,u),i.apply(this,u)}},null)}function IS(n){n.offsetHeight}const Y0=n=>!n||typeof n=="function"?n:r=>{n.current=r};function TA(n,r){const i=Y0(n),l=Y0(r);return u=>{i&&i(u),l&&l(u)}}function Fh(n,r){return x.useMemo(()=>TA(n,r),[n,r])}function Ss(n){return n&&"setState"in n?Qa.findDOMNode(n):n??null}const Ns=Xe.forwardRef(({onEnter:n,onEntering:r,onEntered:i,onExit:l,onExiting:u,onExited:c,addEndListener:d,children:p,childRef:h,...y},m)=>{const g=x.useRef(null),S=Fh(g,h),R=$=>{S(Ss($))},_=$=>O=>{$&&g.current&&$(g.current,O)},E=x.useCallback(_(n),[n]),C=x.useCallback(_(r),[r]),j=x.useCallback(_(i),[i]),M=x.useCallback(_(l),[l]),B=x.useCallback(_(u),[u]),X=x.useCallback(_(c),[c]),A=x.useCallback(_(d),[d]);return T.jsx(Kr,{ref:m,...y,onEnter:E,onEntered:j,onEntering:C,onExit:M,onExited:X,onExiting:B,addEndListener:A,nodeRef:g,children:typeof p=="function"?($,O)=>p($,{...O,ref:R}):Xe.cloneElement(p,{ref:R})})});Ns.displayName="TransitionWrapper";const _A={height:["marginTop","marginBottom"],width:["marginLeft","marginRight"]};function AA(n,r){const i=`offset${n[0].toUpperCase()}${n.slice(1)}`,l=r[i],u=_A[n];return l+parseInt(Gr(r,u[0]),10)+parseInt(Gr(r,u[1]),10)}const RA={[Sa]:"collapse",[Fi]:"collapsing",[Ln]:"collapsing",[Lr]:"collapse show"},wo=Xe.forwardRef(({onEnter:n,onEntering:r,onEntered:i,onExit:l,onExiting:u,className:c,children:d,dimension:p="height",in:h=!1,timeout:y=300,mountOnEnter:m=!1,unmountOnExit:g=!1,appear:S=!1,getDimensionValue:R=AA,..._},E)=>{const C=typeof p=="function"?p():p,j=x.useMemo(()=>Jl($=>{$.style[C]="0"},n),[C,n]),M=x.useMemo(()=>Jl($=>{const O=`scroll${C[0].toUpperCase()}${C.slice(1)}`;$.style[C]=`${$[O]}px`},r),[C,r]),B=x.useMemo(()=>Jl($=>{$.style[C]=null},i),[C,i]),X=x.useMemo(()=>Jl($=>{$.style[C]=`${R(C,$)}px`,IS($)},l),[l,R,C]),A=x.useMemo(()=>Jl($=>{$.style[C]=null},u),[C,u]);return T.jsx(Ns,{ref:E,addEndListener:Kh,..._,"aria-expanded":_.role?h:null,onEnter:j,onEntering:M,onEntered:B,onExit:X,onExiting:A,childRef:Za(d),in:h,timeout:y,mountOnEnter:m,unmountOnExit:g,appear:S,children:($,O)=>Xe.cloneElement(d,{...O,className:Ae(c,d.props.className,RA[$],C==="width"&&"collapse-horizontal")})})});wo.displayName="Collapse";function wA(n){const r=x.useRef(n);return x.useEffect(()=>{r.current=n},[n]),r}function nl(n){const r=wA(n);return x.useCallback(function(...i){return r.current&&r.current(...i)},[r])}const Zh=n=>x.forwardRef((r,i)=>T.jsx("div",{...r,ref:i,className:Ae(r.className,n)}));function V0(){return x.useState(null)}function CA(n){const r=x.useRef(n);return x.useEffect(()=>{r.current=n},[n]),r}function fr(n){const r=CA(n);return x.useCallback(function(...i){return r.current&&r.current(...i)},[r])}function WS(){const n=x.useRef(!0),r=x.useRef(()=>n.current);return x.useEffect(()=>(n.current=!0,()=>{n.current=!1}),[]),r.current}function NA(n){const r=x.useRef(null);return x.useEffect(()=>{r.current=n}),r.current}const MA=typeof global<"u"&&global.navigator&&global.navigator.product==="ReactNative",DA=typeof document<"u",P0=DA||MA?x.useLayoutEffect:x.useEffect,jA=["as","disabled"];function BA(n,r){if(n==null)return{};var i={};for(var l in n)if({}.hasOwnProperty.call(n,l)){if(r.indexOf(l)>=0)continue;i[l]=n[l]}return i}function $A(n){return!n||n.trim()==="#"}function JS({tagName:n,disabled:r,href:i,target:l,rel:u,role:c,onClick:d,tabIndex:p=0,type:h}){n||(i!=null||l!=null||u!=null?n="a":n="button");const y={tagName:n};if(n==="button")return[{type:h||"button",disabled:r},y];const m=S=>{if((r||n==="a"&&$A(i))&&S.preventDefault(),r){S.stopPropagation();return}d==null||d(S)},g=S=>{S.key===" "&&(S.preventDefault(),m(S))};return n==="a"&&(i||(i="#"),r&&(i=void 0)),[{role:c??"button",disabled:void 0,tabIndex:r?void 0:p,href:i,target:n==="a"?l:void 0,"aria-disabled":r||void 0,rel:n==="a"?u:void 0,onClick:m,onKeyDown:g},y]}const qA=x.forwardRef((n,r)=>{let{as:i,disabled:l}=n,u=BA(n,jA);const[c,{tagName:d}]=JS(Object.assign({tagName:i,disabled:l},u));return T.jsx(d,Object.assign({},u,c,{ref:r}))});qA.displayName="Button";const zA={[Ln]:"show",[Lr]:"show"},mo=x.forwardRef(({className:n,children:r,transitionClasses:i={},onEnter:l,...u},c)=>{const d={in:!1,timeout:300,mountOnEnter:!1,unmountOnExit:!1,appear:!1,...u},p=x.useCallback((h,y)=>{IS(h),l==null||l(h,y)},[l]);return T.jsx(Ns,{ref:c,addEndListener:Kh,...d,onEnter:p,childRef:Za(r),children:(h,y)=>x.cloneElement(r,{...y,className:Ae("fade",n,r.props.className,zA[h],i[h])})})});mo.displayName="Fade";const kA={"aria-label":dt.string,onClick:dt.func,variant:dt.oneOf(["white"])},Ms=x.forwardRef(({className:n,variant:r,"aria-label":i="Close",...l},u)=>T.jsx("button",{ref:u,type:"button",className:Ae("btn-close",r&&`btn-close-${r}`,n),"aria-label":i,...l}));Ms.displayName="CloseButton";Ms.propTypes=kA;const ex=x.forwardRef(({bsPrefix:n,bg:r="primary",pill:i=!1,text:l,className:u,as:c="span",...d},p)=>{const h=we(n,"badge");return T.jsx(c,{ref:p,...d,className:Ae(u,h,i&&"rounded-pill",l&&`text-${l}`,r&&`bg-${r}`)})});ex.displayName="Badge";const Co=x.forwardRef(({as:n,bsPrefix:r,variant:i="primary",size:l,active:u=!1,disabled:c=!1,className:d,...p},h)=>{const y=we(r,"btn"),[m,{tagName:g}]=JS({tagName:n,disabled:c,...p}),S=g;return T.jsx(S,{...m,...p,ref:h,disabled:c,className:Ae(d,y,u&&"active",i&&`${y}-${i}`,l&&`${y}-${l}`,p.href&&c&&"disabled")})});Co.displayName="Button";const Ih=x.forwardRef(({className:n,bsPrefix:r,as:i="div",...l},u)=>(r=we(r,"card-body"),T.jsx(i,{ref:u,className:Ae(n,r),...l})));Ih.displayName="CardBody";const tx=x.forwardRef(({className:n,bsPrefix:r,as:i="div",...l},u)=>(r=we(r,"card-footer"),T.jsx(i,{ref:u,className:Ae(n,r),...l})));tx.displayName="CardFooter";const nx=x.createContext(null);nx.displayName="CardHeaderContext";const rx=x.forwardRef(({bsPrefix:n,className:r,as:i="div",...l},u)=>{const c=we(n,"card-header"),d=x.useMemo(()=>({cardHeaderBsPrefix:c}),[c]);return T.jsx(nx.Provider,{value:d,children:T.jsx(i,{ref:u,...l,className:Ae(r,c)})})});rx.displayName="CardHeader";const ax=x.forwardRef(({bsPrefix:n,className:r,variant:i,as:l="img",...u},c)=>{const d=we(n,"card-img");return T.jsx(l,{ref:c,className:Ae(i?`${d}-${i}`:d,r),...u})});ax.displayName="CardImg";const ix=x.forwardRef(({className:n,bsPrefix:r,as:i="div",...l},u)=>(r=we(r,"card-img-overlay"),T.jsx(i,{ref:u,className:Ae(n,r),...l})));ix.displayName="CardImgOverlay";const lx=x.forwardRef(({className:n,bsPrefix:r,as:i="a",...l},u)=>(r=we(r,"card-link"),T.jsx(i,{ref:u,className:Ae(n,r),...l})));lx.displayName="CardLink";const LA=Zh("h6"),ox=x.forwardRef(({className:n,bsPrefix:r,as:i=LA,...l},u)=>(r=we(r,"card-subtitle"),T.jsx(i,{ref:u,className:Ae(n,r),...l})));ox.displayName="CardSubtitle";const ux=x.forwardRef(({className:n,bsPrefix:r,as:i="p",...l},u)=>(r=we(r,"card-text"),T.jsx(i,{ref:u,className:Ae(n,r),...l})));ux.displayName="CardText";const UA=Zh("h5"),sx=x.forwardRef(({className:n,bsPrefix:r,as:i=UA,...l},u)=>(r=we(r,"card-title"),T.jsx(i,{ref:u,className:Ae(n,r),...l})));sx.displayName="CardTitle";const cx=x.forwardRef(({bsPrefix:n,className:r,bg:i,text:l,border:u,body:c=!1,children:d,as:p="div",...h},y)=>{const m=we(n,"card");return T.jsx(p,{ref:y,...h,className:Ae(r,m,i&&`bg-${i}`,l&&`text-${l}`,u&&`border-${u}`),children:c?T.jsx(Ih,{children:d}):d})});cx.displayName="Card";const Xi=Object.assign(cx,{Img:ax,Title:sx,Subtitle:ox,Body:Ih,Link:lx,Text:ux,Header:rx,Footer:tx,ImgOverlay:ix});function HA(){const n=x.useRef(!0),r=x.useRef(()=>n.current);return x.useEffect(()=>(n.current=!0,()=>{n.current=!1}),[]),r.current}function GA(n){const r=x.useRef(n);return r.current=n,r}function YA(n){const r=GA(n);x.useEffect(()=>()=>r.current(),[])}const Eh=2**31-1;function fx(n,r,i){const l=i-Date.now();n.current=l<=Eh?setTimeout(r,l):setTimeout(()=>fx(n,r,i),Eh)}function dx(){const n=HA(),r=x.useRef();return YA(()=>clearTimeout(r.current)),x.useMemo(()=>{const i=()=>clearTimeout(r.current);function l(u,c=0){n()&&(i(),c<=Eh?r.current=setTimeout(u,c):fx(r,u,Date.now()+c))}return{set:l,clear:i,handleRef:r}},[])}function VA(n,r){return x.Children.toArray(n).some(i=>x.isValidElement(i)&&i.type===r)}function PA({as:n,bsPrefix:r,className:i,...l}){r=we(r,"col");const u=PS(),c=XS(),d=[],p=[];return u.forEach(h=>{const y=l[h];delete l[h];let m,g,S;typeof y=="object"&&y!=null?{span:m,offset:g,order:S}=y:m=y;const R=h!==c?`-${h}`:"";m&&d.push(m===!0?`${r}${R}`:`${r}${R}-${m}`),S!=null&&p.push(`order${R}-${S}`),g!=null&&p.push(`offset${R}-${g}`)}),[{...l,className:Ae(i,...d,...p)},{as:n,bsPrefix:r,spans:d}]}const ur=x.forwardRef((n,r)=>{const[{className:i,...l},{as:u="div",bsPrefix:c,spans:d}]=PA(n);return T.jsx(u,{...l,ref:r,className:Ae(i,!d.length&&c)})});ur.displayName="Col";const px=x.forwardRef(({bsPrefix:n,fluid:r=!1,as:i="div",className:l,...u},c)=>{const d=we(n,"container"),p=typeof r=="string"?`-${r}`:"-fluid";return T.jsx(i,{ref:c,...u,className:Ae(l,r?`${d}${p}`:d)})});px.displayName="Container";var XA=Function.prototype.bind.call(Function.prototype.call,[].slice);function qi(n,r){return XA(n.querySelectorAll(r))}var X0=Object.prototype.hasOwnProperty;function Q0(n,r,i){for(i of n.keys())if(co(i,r))return i}function co(n,r){var i,l,u;if(n===r)return!0;if(n&&r&&(i=n.constructor)===r.constructor){if(i===Date)return n.getTime()===r.getTime();if(i===RegExp)return n.toString()===r.toString();if(i===Array){if((l=n.length)===r.length)for(;l--&&co(n[l],r[l]););return l===-1}if(i===Set){if(n.size!==r.size)return!1;for(l of n)if(u=l,u&&typeof u=="object"&&(u=Q0(r,u),!u)||!r.has(u))return!1;return!0}if(i===Map){if(n.size!==r.size)return!1;for(l of n)if(u=l[0],u&&typeof u=="object"&&(u=Q0(r,u),!u)||!co(l[1],r.get(u)))return!1;return!0}if(i===ArrayBuffer)n=new Uint8Array(n),r=new Uint8Array(r);else if(i===DataView){if((l=n.byteLength)===r.byteLength)for(;l--&&n.getInt8(l)===r.getInt8(l););return l===-1}if(ArrayBuffer.isView(n)){if((l=n.byteLength)===r.byteLength)for(;l--&&n[l]===r[l];);return l===-1}if(!i||typeof n=="object"){l=0;for(i in n)if(X0.call(n,i)&&++l&&!X0.call(r,i)||!(i in r)||!co(n[i],r[i]))return!1;return Object.keys(r).length===l}}return n!==n&&r!==r}function QA(n){const r=WS();return[n[0],x.useCallback(i=>{if(r())return n[1](i)},[r,n[1]])]}var fn="top",Yn="bottom",Vn="right",dn="left",Wh="auto",No=[fn,Yn,Vn,dn],Zi="start",go="end",KA="clippingParents",hx="viewport",eo="popper",FA="reference",K0=No.reduce(function(n,r){return n.concat([r+"-"+Zi,r+"-"+go])},[]),yx=[].concat(No,[Wh]).reduce(function(n,r){return n.concat([r,r+"-"+Zi,r+"-"+go])},[]),ZA="beforeRead",IA="read",WA="afterRead",JA="beforeMain",eR="main",tR="afterMain",nR="beforeWrite",rR="write",aR="afterWrite",iR=[ZA,IA,WA,JA,eR,tR,nR,rR,aR];function dr(n){return n.split("-")[0]}function _n(n){if(n==null)return window;if(n.toString()!=="[object Window]"){var r=n.ownerDocument;return r&&r.defaultView||window}return n}function Fa(n){var r=_n(n).Element;return n instanceof r||n instanceof Element}function pr(n){var r=_n(n).HTMLElement;return n instanceof r||n instanceof HTMLElement}function Jh(n){if(typeof ShadowRoot>"u")return!1;var r=_n(n).ShadowRoot;return n instanceof r||n instanceof ShadowRoot}var Ka=Math.max,xs=Math.min,Ii=Math.round;function Oh(){var n=navigator.userAgentData;return n!=null&&n.brands&&Array.isArray(n.brands)?n.brands.map(function(r){return r.brand+"/"+r.version}).join(" "):navigator.userAgent}function vx(){return!/^((?!chrome|android).)*safari/i.test(Oh())}function Wi(n,r,i){r===void 0&&(r=!1),i===void 0&&(i=!1);var l=n.getBoundingClientRect(),u=1,c=1;r&&pr(n)&&(u=n.offsetWidth>0&&Ii(l.width)/n.offsetWidth||1,c=n.offsetHeight>0&&Ii(l.height)/n.offsetHeight||1);var d=Fa(n)?_n(n):window,p=d.visualViewport,h=!vx()&&i,y=(l.left+(h&&p?p.offsetLeft:0))/u,m=(l.top+(h&&p?p.offsetTop:0))/c,g=l.width/u,S=l.height/c;return{width:g,height:S,top:m,right:y+g,bottom:m+S,left:y,x:y,y:m}}function ey(n){var r=Wi(n),i=n.offsetWidth,l=n.offsetHeight;return Math.abs(r.width-i)<=1&&(i=r.width),Math.abs(r.height-l)<=1&&(l=r.height),{x:n.offsetLeft,y:n.offsetTop,width:i,height:l}}function mx(n,r){var i=r.getRootNode&&r.getRootNode();if(n.contains(r))return!0;if(i&&Jh(i)){var l=r;do{if(l&&n.isSameNode(l))return!0;l=l.parentNode||l.host}while(l)}return!1}function Ta(n){return n?(n.nodeName||"").toLowerCase():null}function Vr(n){return _n(n).getComputedStyle(n)}function lR(n){return["table","td","th"].indexOf(Ta(n))>=0}function Aa(n){return((Fa(n)?n.ownerDocument:n.document)||window.document).documentElement}function Ds(n){return Ta(n)==="html"?n:n.assignedSlot||n.parentNode||(Jh(n)?n.host:null)||Aa(n)}function F0(n){return!pr(n)||Vr(n).position==="fixed"?null:n.offsetParent}function oR(n){var r=/firefox/i.test(Oh()),i=/Trident/i.test(Oh());if(i&&pr(n)){var l=Vr(n);if(l.position==="fixed")return null}var u=Ds(n);for(Jh(u)&&(u=u.host);pr(u)&&["html","body"].indexOf(Ta(u))<0;){var c=Vr(u);if(c.transform!=="none"||c.perspective!=="none"||c.contain==="paint"||["transform","perspective"].indexOf(c.willChange)!==-1||r&&c.willChange==="filter"||r&&c.filter&&c.filter!=="none")return u;u=u.parentNode}return null}function Mo(n){for(var r=_n(n),i=F0(n);i&&lR(i)&&Vr(i).position==="static";)i=F0(i);return i&&(Ta(i)==="html"||Ta(i)==="body"&&Vr(i).position==="static")?r:i||oR(n)||r}function ty(n){return["top","bottom"].indexOf(n)>=0?"x":"y"}function fo(n,r,i){return Ka(n,xs(r,i))}function uR(n,r,i){var l=fo(n,r,i);return l>i?i:l}function gx(){return{top:0,right:0,bottom:0,left:0}}function bx(n){return Object.assign({},gx(),n)}function Sx(n,r){return r.reduce(function(i,l){return i[l]=n,i},{})}var sR=function(r,i){return r=typeof r=="function"?r(Object.assign({},i.rects,{placement:i.placement})):r,bx(typeof r!="number"?r:Sx(r,No))};function cR(n){var r,i=n.state,l=n.name,u=n.options,c=i.elements.arrow,d=i.modifiersData.popperOffsets,p=dr(i.placement),h=ty(p),y=[dn,Vn].indexOf(p)>=0,m=y?"height":"width";if(!(!c||!d)){var g=sR(u.padding,i),S=ey(c),R=h==="y"?fn:dn,_=h==="y"?Yn:Vn,E=i.rects.reference[m]+i.rects.reference[h]-d[h]-i.rects.popper[m],C=d[h]-i.rects.reference[h],j=Mo(c),M=j?h==="y"?j.clientHeight||0:j.clientWidth||0:0,B=E/2-C/2,X=g[R],A=M-S[m]-g[_],$=M/2-S[m]/2+B,O=fo(X,$,A),q=h;i.modifiersData[l]=(r={},r[q]=O,r.centerOffset=O-$,r)}}function fR(n){var r=n.state,i=n.options,l=i.element,u=l===void 0?"[data-popper-arrow]":l;u!=null&&(typeof u=="string"&&(u=r.elements.popper.querySelector(u),!u)||mx(r.elements.popper,u)&&(r.elements.arrow=u))}const dR={name:"arrow",enabled:!0,phase:"main",fn:cR,effect:fR,requires:["popperOffsets"],requiresIfExists:["preventOverflow"]};function Ji(n){return n.split("-")[1]}var pR={top:"auto",right:"auto",bottom:"auto",left:"auto"};function hR(n,r){var i=n.x,l=n.y,u=r.devicePixelRatio||1;return{x:Ii(i*u)/u||0,y:Ii(l*u)/u||0}}function Z0(n){var r,i=n.popper,l=n.popperRect,u=n.placement,c=n.variation,d=n.offsets,p=n.position,h=n.gpuAcceleration,y=n.adaptive,m=n.roundOffsets,g=n.isFixed,S=d.x,R=S===void 0?0:S,_=d.y,E=_===void 0?0:_,C=typeof m=="function"?m({x:R,y:E}):{x:R,y:E};R=C.x,E=C.y;var j=d.hasOwnProperty("x"),M=d.hasOwnProperty("y"),B=dn,X=fn,A=window;if(y){var $=Mo(i),O="clientHeight",q="clientWidth";if($===_n(i)&&($=Aa(i),Vr($).position!=="static"&&p==="absolute"&&(O="scrollHeight",q="scrollWidth")),$=$,u===fn||(u===dn||u===Vn)&&c===go){X=Yn;var L=g&&$===A&&A.visualViewport?A.visualViewport.height:$[O];E-=L-l.height,E*=h?1:-1}if(u===dn||(u===fn||u===Yn)&&c===go){B=Vn;var Y=g&&$===A&&A.visualViewport?A.visualViewport.width:$[q];R-=Y-l.width,R*=h?1:-1}}var W=Object.assign({position:p},y&&pR),oe=m===!0?hR({x:R,y:E},_n(i)):{x:R,y:E};if(R=oe.x,E=oe.y,h){var ue;return Object.assign({},W,(ue={},ue[X]=M?"0":"",ue[B]=j?"0":"",ue.transform=(A.devicePixelRatio||1)<=1?"translate("+R+"px, "+E+"px)":"translate3d("+R+"px, "+E+"px, 0)",ue))}return Object.assign({},W,(r={},r[X]=M?E+"px":"",r[B]=j?R+"px":"",r.transform="",r))}function yR(n){var r=n.state,i=n.options,l=i.gpuAcceleration,u=l===void 0?!0:l,c=i.adaptive,d=c===void 0?!0:c,p=i.roundOffsets,h=p===void 0?!0:p,y={placement:dr(r.placement),variation:Ji(r.placement),popper:r.elements.popper,popperRect:r.rects.popper,gpuAcceleration:u,isFixed:r.options.strategy==="fixed"};r.modifiersData.popperOffsets!=null&&(r.styles.popper=Object.assign({},r.styles.popper,Z0(Object.assign({},y,{offsets:r.modifiersData.popperOffsets,position:r.options.strategy,adaptive:d,roundOffsets:h})))),r.modifiersData.arrow!=null&&(r.styles.arrow=Object.assign({},r.styles.arrow,Z0(Object.assign({},y,{offsets:r.modifiersData.arrow,position:"absolute",adaptive:!1,roundOffsets:h})))),r.attributes.popper=Object.assign({},r.attributes.popper,{"data-popper-placement":r.placement})}const vR={name:"computeStyles",enabled:!0,phase:"beforeWrite",fn:yR,data:{}};var Zu={passive:!0};function mR(n){var r=n.state,i=n.instance,l=n.options,u=l.scroll,c=u===void 0?!0:u,d=l.resize,p=d===void 0?!0:d,h=_n(r.elements.popper),y=[].concat(r.scrollParents.reference,r.scrollParents.popper);return c&&y.forEach(function(m){m.addEventListener("scroll",i.update,Zu)}),p&&h.addEventListener("resize",i.update,Zu),function(){c&&y.forEach(function(m){m.removeEventListener("scroll",i.update,Zu)}),p&&h.removeEventListener("resize",i.update,Zu)}}const gR={name:"eventListeners",enabled:!0,phase:"write",fn:function(){},effect:mR,data:{}};var bR={left:"right",right:"left",bottom:"top",top:"bottom"};function us(n){return n.replace(/left|right|bottom|top/g,function(r){return bR[r]})}var SR={start:"end",end:"start"};function I0(n){return n.replace(/start|end/g,function(r){return SR[r]})}function ny(n){var r=_n(n),i=r.pageXOffset,l=r.pageYOffset;return{scrollLeft:i,scrollTop:l}}function ry(n){return Wi(Aa(n)).left+ny(n).scrollLeft}function xR(n,r){var i=_n(n),l=Aa(n),u=i.visualViewport,c=l.clientWidth,d=l.clientHeight,p=0,h=0;if(u){c=u.width,d=u.height;var y=vx();(y||!y&&r==="fixed")&&(p=u.offsetLeft,h=u.offsetTop)}return{width:c,height:d,x:p+ry(n),y:h}}function ER(n){var r,i=Aa(n),l=ny(n),u=(r=n.ownerDocument)==null?void 0:r.body,c=Ka(i.scrollWidth,i.clientWidth,u?u.scrollWidth:0,u?u.clientWidth:0),d=Ka(i.scrollHeight,i.clientHeight,u?u.scrollHeight:0,u?u.clientHeight:0),p=-l.scrollLeft+ry(n),h=-l.scrollTop;return Vr(u||i).direction==="rtl"&&(p+=Ka(i.clientWidth,u?u.clientWidth:0)-c),{width:c,height:d,x:p,y:h}}function ay(n){var r=Vr(n),i=r.overflow,l=r.overflowX,u=r.overflowY;return/auto|scroll|overlay|hidden/.test(i+u+l)}function xx(n){return["html","body","#document"].indexOf(Ta(n))>=0?n.ownerDocument.body:pr(n)&&ay(n)?n:xx(Ds(n))}function po(n,r){var i;r===void 0&&(r=[]);var l=xx(n),u=l===((i=n.ownerDocument)==null?void 0:i.body),c=_n(l),d=u?[c].concat(c.visualViewport||[],ay(l)?l:[]):l,p=r.concat(d);return u?p:p.concat(po(Ds(d)))}function Th(n){return Object.assign({},n,{left:n.x,top:n.y,right:n.x+n.width,bottom:n.y+n.height})}function OR(n,r){var i=Wi(n,!1,r==="fixed");return i.top=i.top+n.clientTop,i.left=i.left+n.clientLeft,i.bottom=i.top+n.clientHeight,i.right=i.left+n.clientWidth,i.width=n.clientWidth,i.height=n.clientHeight,i.x=i.left,i.y=i.top,i}function W0(n,r,i){return r===hx?Th(xR(n,i)):Fa(r)?OR(r,i):Th(ER(Aa(n)))}function TR(n){var r=po(Ds(n)),i=["absolute","fixed"].indexOf(Vr(n).position)>=0,l=i&&pr(n)?Mo(n):n;return Fa(l)?r.filter(function(u){return Fa(u)&&mx(u,l)&&Ta(u)!=="body"}):[]}function _R(n,r,i,l){var u=r==="clippingParents"?TR(n):[].concat(r),c=[].concat(u,[i]),d=c[0],p=c.reduce(function(h,y){var m=W0(n,y,l);return h.top=Ka(m.top,h.top),h.right=xs(m.right,h.right),h.bottom=xs(m.bottom,h.bottom),h.left=Ka(m.left,h.left),h},W0(n,d,l));return p.width=p.right-p.left,p.height=p.bottom-p.top,p.x=p.left,p.y=p.top,p}function Ex(n){var r=n.reference,i=n.element,l=n.placement,u=l?dr(l):null,c=l?Ji(l):null,d=r.x+r.width/2-i.width/2,p=r.y+r.height/2-i.height/2,h;switch(u){case fn:h={x:d,y:r.y-i.height};break;case Yn:h={x:d,y:r.y+r.height};break;case Vn:h={x:r.x+r.width,y:p};break;case dn:h={x:r.x-i.width,y:p};break;default:h={x:r.x,y:r.y}}var y=u?ty(u):null;if(y!=null){var m=y==="y"?"height":"width";switch(c){case Zi:h[y]=h[y]-(r[m]/2-i[m]/2);break;case go:h[y]=h[y]+(r[m]/2-i[m]/2);break}}return h}function bo(n,r){r===void 0&&(r={});var i=r,l=i.placement,u=l===void 0?n.placement:l,c=i.strategy,d=c===void 0?n.strategy:c,p=i.boundary,h=p===void 0?KA:p,y=i.rootBoundary,m=y===void 0?hx:y,g=i.elementContext,S=g===void 0?eo:g,R=i.altBoundary,_=R===void 0?!1:R,E=i.padding,C=E===void 0?0:E,j=bx(typeof C!="number"?C:Sx(C,No)),M=S===eo?FA:eo,B=n.rects.popper,X=n.elements[_?M:S],A=_R(Fa(X)?X:X.contextElement||Aa(n.elements.popper),h,m,d),$=Wi(n.elements.reference),O=Ex({reference:$,element:B,placement:u}),q=Th(Object.assign({},B,O)),L=S===eo?q:$,Y={top:A.top-L.top+j.top,bottom:L.bottom-A.bottom+j.bottom,left:A.left-L.left+j.left,right:L.right-A.right+j.right},W=n.modifiersData.offset;if(S===eo&&W){var oe=W[u];Object.keys(Y).forEach(function(ue){var he=[Vn,Yn].indexOf(ue)>=0?1:-1,fe=[fn,Yn].indexOf(ue)>=0?"y":"x";Y[ue]+=oe[fe]*he})}return Y}function AR(n,r){r===void 0&&(r={});var i=r,l=i.placement,u=i.boundary,c=i.rootBoundary,d=i.padding,p=i.flipVariations,h=i.allowedAutoPlacements,y=h===void 0?yx:h,m=Ji(l),g=m?p?K0:K0.filter(function(_){return Ji(_)===m}):No,S=g.filter(function(_){return y.indexOf(_)>=0});S.length===0&&(S=g);var R=S.reduce(function(_,E){return _[E]=bo(n,{placement:E,boundary:u,rootBoundary:c,padding:d})[dr(E)],_},{});return Object.keys(R).sort(function(_,E){return R[_]-R[E]})}function RR(n){if(dr(n)===Wh)return[];var r=us(n);return[I0(n),r,I0(r)]}function wR(n){var r=n.state,i=n.options,l=n.name;if(!r.modifiersData[l]._skip){for(var u=i.mainAxis,c=u===void 0?!0:u,d=i.altAxis,p=d===void 0?!0:d,h=i.fallbackPlacements,y=i.padding,m=i.boundary,g=i.rootBoundary,S=i.altBoundary,R=i.flipVariations,_=R===void 0?!0:R,E=i.allowedAutoPlacements,C=r.options.placement,j=dr(C),M=j===C,B=h||(M||!_?[us(C)]:RR(C)),X=[C].concat(B).reduce(function(z,F){return z.concat(dr(F)===Wh?AR(r,{placement:F,boundary:m,rootBoundary:g,padding:y,flipVariations:_,allowedAutoPlacements:E}):F)},[]),A=r.rects.reference,$=r.rects.popper,O=new Map,q=!0,L=X[0],Y=0;Y<X.length;Y++){var W=X[Y],oe=dr(W),ue=Ji(W)===Zi,he=[fn,Yn].indexOf(oe)>=0,fe=he?"width":"height",H=bo(r,{placement:W,boundary:m,rootBoundary:g,altBoundary:S,padding:y}),I=he?ue?Vn:dn:ue?Yn:fn;A[fe]>$[fe]&&(I=us(I));var ae=us(I),be=[];if(c&&be.push(H[oe]<=0),p&&be.push(H[I]<=0,H[ae]<=0),be.every(function(z){return z})){L=W,q=!1;break}O.set(W,be)}if(q)for(var N=_?3:1,Z=function(F){var te=X.find(function(pe){var ce=O.get(pe);if(ce)return ce.slice(0,F).every(function(xe){return xe})});if(te)return L=te,"break"},le=N;le>0;le--){var re=Z(le);if(re==="break")break}r.placement!==L&&(r.modifiersData[l]._skip=!0,r.placement=L,r.reset=!0)}}const CR={name:"flip",enabled:!0,phase:"main",fn:wR,requiresIfExists:["offset"],data:{_skip:!1}};function J0(n,r,i){return i===void 0&&(i={x:0,y:0}),{top:n.top-r.height-i.y,right:n.right-r.width+i.x,bottom:n.bottom-r.height+i.y,left:n.left-r.width-i.x}}function eb(n){return[fn,Vn,Yn,dn].some(function(r){return n[r]>=0})}function NR(n){var r=n.state,i=n.name,l=r.rects.reference,u=r.rects.popper,c=r.modifiersData.preventOverflow,d=bo(r,{elementContext:"reference"}),p=bo(r,{altBoundary:!0}),h=J0(d,l),y=J0(p,u,c),m=eb(h),g=eb(y);r.modifiersData[i]={referenceClippingOffsets:h,popperEscapeOffsets:y,isReferenceHidden:m,hasPopperEscaped:g},r.attributes.popper=Object.assign({},r.attributes.popper,{"data-popper-reference-hidden":m,"data-popper-escaped":g})}const MR={name:"hide",enabled:!0,phase:"main",requiresIfExists:["preventOverflow"],fn:NR};function DR(n,r,i){var l=dr(n),u=[dn,fn].indexOf(l)>=0?-1:1,c=typeof i=="function"?i(Object.assign({},r,{placement:n})):i,d=c[0],p=c[1];return d=d||0,p=(p||0)*u,[dn,Vn].indexOf(l)>=0?{x:p,y:d}:{x:d,y:p}}function jR(n){var r=n.state,i=n.options,l=n.name,u=i.offset,c=u===void 0?[0,0]:u,d=yx.reduce(function(m,g){return m[g]=DR(g,r.rects,c),m},{}),p=d[r.placement],h=p.x,y=p.y;r.modifiersData.popperOffsets!=null&&(r.modifiersData.popperOffsets.x+=h,r.modifiersData.popperOffsets.y+=y),r.modifiersData[l]=d}const BR={name:"offset",enabled:!0,phase:"main",requires:["popperOffsets"],fn:jR};function $R(n){var r=n.state,i=n.name;r.modifiersData[i]=Ex({reference:r.rects.reference,element:r.rects.popper,placement:r.placement})}const qR={name:"popperOffsets",enabled:!0,phase:"read",fn:$R,data:{}};function zR(n){return n==="x"?"y":"x"}function kR(n){var r=n.state,i=n.options,l=n.name,u=i.mainAxis,c=u===void 0?!0:u,d=i.altAxis,p=d===void 0?!1:d,h=i.boundary,y=i.rootBoundary,m=i.altBoundary,g=i.padding,S=i.tether,R=S===void 0?!0:S,_=i.tetherOffset,E=_===void 0?0:_,C=bo(r,{boundary:h,rootBoundary:y,padding:g,altBoundary:m}),j=dr(r.placement),M=Ji(r.placement),B=!M,X=ty(j),A=zR(X),$=r.modifiersData.popperOffsets,O=r.rects.reference,q=r.rects.popper,L=typeof E=="function"?E(Object.assign({},r.rects,{placement:r.placement})):E,Y=typeof L=="number"?{mainAxis:L,altAxis:L}:Object.assign({mainAxis:0,altAxis:0},L),W=r.modifiersData.offset?r.modifiersData.offset[r.placement]:null,oe={x:0,y:0};if($){if(c){var ue,he=X==="y"?fn:dn,fe=X==="y"?Yn:Vn,H=X==="y"?"height":"width",I=$[X],ae=I+C[he],be=I-C[fe],N=R?-q[H]/2:0,Z=M===Zi?O[H]:q[H],le=M===Zi?-q[H]:-O[H],re=r.elements.arrow,z=R&&re?ey(re):{width:0,height:0},F=r.modifiersData["arrow#persistent"]?r.modifiersData["arrow#persistent"].padding:gx(),te=F[he],pe=F[fe],ce=fo(0,O[H],z[H]),xe=B?O[H]/2-N-ce-te-Y.mainAxis:Z-ce-te-Y.mainAxis,me=B?-O[H]/2+N+ce+pe+Y.mainAxis:le+ce+pe+Y.mainAxis,Ee=r.elements.arrow&&Mo(r.elements.arrow),de=Ee?X==="y"?Ee.clientTop||0:Ee.clientLeft||0:0,ve=(ue=W==null?void 0:W[X])!=null?ue:0,Oe=I+xe-ve-de,ye=I+me-ve,je=fo(R?xs(ae,Oe):ae,I,R?Ka(be,ye):be);$[X]=je,oe[X]=je-I}if(p){var Me,Fe=X==="x"?fn:dn,Ht=X==="x"?Yn:Vn,ze=$[A],Ze=A==="y"?"height":"width",Gt=ze+C[Fe],$t=ze-C[Ht],qt=[fn,dn].indexOf(j)!==-1,An=(Me=W==null?void 0:W[A])!=null?Me:0,_t=qt?Gt:ze-O[Ze]-q[Ze]-An+Y.altAxis,rt=qt?ze+O[Ze]+q[Ze]-An-Y.altAxis:$t,ie=R&&qt?uR(_t,ze,rt):fo(R?_t:Gt,ze,R?rt:$t);$[A]=ie,oe[A]=ie-ze}r.modifiersData[l]=oe}}const LR={name:"preventOverflow",enabled:!0,phase:"main",fn:kR,requiresIfExists:["offset"]};function UR(n){return{scrollLeft:n.scrollLeft,scrollTop:n.scrollTop}}function HR(n){return n===_n(n)||!pr(n)?ny(n):UR(n)}function GR(n){var r=n.getBoundingClientRect(),i=Ii(r.width)/n.offsetWidth||1,l=Ii(r.height)/n.offsetHeight||1;return i!==1||l!==1}function YR(n,r,i){i===void 0&&(i=!1);var l=pr(r),u=pr(r)&&GR(r),c=Aa(r),d=Wi(n,u,i),p={scrollLeft:0,scrollTop:0},h={x:0,y:0};return(l||!l&&!i)&&((Ta(r)!=="body"||ay(c))&&(p=HR(r)),pr(r)?(h=Wi(r,!0),h.x+=r.clientLeft,h.y+=r.clientTop):c&&(h.x=ry(c))),{x:d.left+p.scrollLeft-h.x,y:d.top+p.scrollTop-h.y,width:d.width,height:d.height}}function VR(n){var r=new Map,i=new Set,l=[];n.forEach(function(c){r.set(c.name,c)});function u(c){i.add(c.name);var d=[].concat(c.requires||[],c.requiresIfExists||[]);d.forEach(function(p){if(!i.has(p)){var h=r.get(p);h&&u(h)}}),l.push(c)}return n.forEach(function(c){i.has(c.name)||u(c)}),l}function PR(n){var r=VR(n);return iR.reduce(function(i,l){return i.concat(r.filter(function(u){return u.phase===l}))},[])}function XR(n){var r;return function(){return r||(r=new Promise(function(i){Promise.resolve().then(function(){r=void 0,i(n())})})),r}}function QR(n){var r=n.reduce(function(i,l){var u=i[l.name];return i[l.name]=u?Object.assign({},u,l,{options:Object.assign({},u.options,l.options),data:Object.assign({},u.data,l.data)}):l,i},{});return Object.keys(r).map(function(i){return r[i]})}var tb={placement:"bottom",modifiers:[],strategy:"absolute"};function nb(){for(var n=arguments.length,r=new Array(n),i=0;i<n;i++)r[i]=arguments[i];return!r.some(function(l){return!(l&&typeof l.getBoundingClientRect=="function")})}function KR(n){n===void 0&&(n={});var r=n,i=r.defaultModifiers,l=i===void 0?[]:i,u=r.defaultOptions,c=u===void 0?tb:u;return function(p,h,y){y===void 0&&(y=c);var m={placement:"bottom",orderedModifiers:[],options:Object.assign({},tb,c),modifiersData:{},elements:{reference:p,popper:h},attributes:{},styles:{}},g=[],S=!1,R={state:m,setOptions:function(j){var M=typeof j=="function"?j(m.options):j;E(),m.options=Object.assign({},c,m.options,M),m.scrollParents={reference:Fa(p)?po(p):p.contextElement?po(p.contextElement):[],popper:po(h)};var B=PR(QR([].concat(l,m.options.modifiers)));return m.orderedModifiers=B.filter(function(X){return X.enabled}),_(),R.update()},forceUpdate:function(){if(!S){var j=m.elements,M=j.reference,B=j.popper;if(nb(M,B)){m.rects={reference:YR(M,Mo(B),m.options.strategy==="fixed"),popper:ey(B)},m.reset=!1,m.placement=m.options.placement,m.orderedModifiers.forEach(function(Y){return m.modifiersData[Y.name]=Object.assign({},Y.data)});for(var X=0;X<m.orderedModifiers.length;X++){if(m.reset===!0){m.reset=!1,X=-1;continue}var A=m.orderedModifiers[X],$=A.fn,O=A.options,q=O===void 0?{}:O,L=A.name;typeof $=="function"&&(m=$({state:m,options:q,name:L,instance:R})||m)}}}},update:XR(function(){return new Promise(function(C){R.forceUpdate(),C(m)})}),destroy:function(){E(),S=!0}};if(!nb(p,h))return R;R.setOptions(y).then(function(C){!S&&y.onFirstUpdate&&y.onFirstUpdate(C)});function _(){m.orderedModifiers.forEach(function(C){var j=C.name,M=C.options,B=M===void 0?{}:M,X=C.effect;if(typeof X=="function"){var A=X({state:m,name:j,instance:R,options:B}),$=function(){};g.push(A||$)}})}function E(){g.forEach(function(C){return C()}),g=[]}return R}}const FR=KR({defaultModifiers:[MR,qR,vR,gR,BR,CR,LR,dR]}),ZR=["enabled","placement","strategy","modifiers"];function IR(n,r){if(n==null)return{};var i={};for(var l in n)if({}.hasOwnProperty.call(n,l)){if(r.indexOf(l)>=0)continue;i[l]=n[l]}return i}const WR={name:"applyStyles",enabled:!1,phase:"afterWrite",fn:()=>{}},JR={name:"ariaDescribedBy",enabled:!0,phase:"afterWrite",effect:({state:n})=>()=>{const{reference:r,popper:i}=n.elements;if("removeAttribute"in r){const l=(r.getAttribute("aria-describedby")||"").split(",").filter(u=>u.trim()!==i.id);l.length?r.setAttribute("aria-describedby",l.join(",")):r.removeAttribute("aria-describedby")}},fn:({state:n})=>{var r;const{popper:i,reference:l}=n.elements,u=(r=i.getAttribute("role"))==null?void 0:r.toLowerCase();if(i.id&&u==="tooltip"&&"setAttribute"in l){const c=l.getAttribute("aria-describedby");if(c&&c.split(",").indexOf(i.id)!==-1)return;l.setAttribute("aria-describedby",c?`${c},${i.id}`:i.id)}}},ew=[];function tw(n,r,i={}){let{enabled:l=!0,placement:u="bottom",strategy:c="absolute",modifiers:d=ew}=i,p=IR(i,ZR);const h=x.useRef(d),y=x.useRef(),m=x.useCallback(()=>{var C;(C=y.current)==null||C.update()},[]),g=x.useCallback(()=>{var C;(C=y.current)==null||C.forceUpdate()},[]),[S,R]=QA(x.useState({placement:u,update:m,forceUpdate:g,attributes:{},styles:{popper:{},arrow:{}}})),_=x.useMemo(()=>({name:"updateStateModifier",enabled:!0,phase:"write",requires:["computeStyles"],fn:({state:C})=>{const j={},M={};Object.keys(C.elements).forEach(B=>{j[B]=C.styles[B],M[B]=C.attributes[B]}),R({state:C,styles:j,attributes:M,update:m,forceUpdate:g,placement:C.placement})}}),[m,g,R]),E=x.useMemo(()=>(co(h.current,d)||(h.current=d),h.current),[d]);return x.useEffect(()=>{!y.current||!l||y.current.setOptions({placement:u,strategy:c,modifiers:[...E,_,WR]})},[c,u,_,l,E]),x.useEffect(()=>{if(!(!l||n==null||r==null))return y.current=FR(n,r,Object.assign({},p,{placement:u,strategy:c,modifiers:[...E,JR,_]})),()=>{y.current!=null&&(y.current.destroy(),y.current=void 0,R(C=>Object.assign({},C,{attributes:{},styles:{popper:{}}})))}},[l,n,r]),S}function So(n,r){if(n.contains)return n.contains(r);if(n.compareDocumentPosition)return n===r||!!(n.compareDocumentPosition(r)&16)}var yd,rb;function nw(){if(rb)return yd;rb=1;var n=function(){};return yd=n,yd}var rw=nw();const aw=_a(rw),ab=()=>{};function iw(n){return n.button===0}function lw(n){return!!(n.metaKey||n.altKey||n.ctrlKey||n.shiftKey)}const ss=n=>n&&("current"in n?n.current:n),ib={click:"mousedown",mouseup:"mousedown",pointerup:"pointerdown"};function ow(n,r=ab,{disabled:i,clickTrigger:l="click"}={}){const u=x.useRef(!1),c=x.useRef(!1),d=x.useCallback(y=>{const m=ss(n);aw(!!m,"ClickOutside captured a close event but does not have a ref to compare it to. useClickOutside(), should be passed a ref that resolves to a DOM node"),u.current=!m||lw(y)||!iw(y)||!!So(m,y.target)||c.current,c.current=!1},[n]),p=fr(y=>{const m=ss(n);m&&So(m,y.target)?c.current=!0:c.current=!1}),h=fr(y=>{u.current||r(y)});x.useEffect(()=>{var y,m;if(i||n==null)return;const g=Ro(ss(n)),S=g.defaultView||window;let R=(y=S.event)!=null?y:(m=S.parent)==null?void 0:m.event,_=null;ib[l]&&(_=Ur(g,ib[l],p,!0));const E=Ur(g,l,d,!0),C=Ur(g,l,M=>{if(M===R){R=void 0;return}h(M)});let j=[];return"ontouchstart"in g.documentElement&&(j=[].slice.call(g.body.children).map(M=>Ur(M,"mousemove",ab))),()=>{_==null||_(),E(),C(),j.forEach(M=>M())}},[n,i,l,d,p,h])}function uw(n){const r={};return Array.isArray(n)?(n==null||n.forEach(i=>{r[i.name]=i}),r):n||r}function sw(n={}){return Array.isArray(n)?n:Object.keys(n).map(r=>(n[r].name=r,n[r]))}function cw({enabled:n,enableEvents:r,placement:i,flip:l,offset:u,fixed:c,containerPadding:d,arrowElement:p,popperConfig:h={}}){var y,m,g,S;const R=uw(h.modifiers);return Object.assign({},h,{placement:i,enabled:n,strategy:c?"fixed":h.strategy,modifiers:sw(Object.assign({},R,{eventListeners:{enabled:r,options:(y=R.eventListeners)==null?void 0:y.options},preventOverflow:Object.assign({},R.preventOverflow,{options:Object.assign({padding:d},(m=R.preventOverflow)==null?void 0:m.options)}),offset:{options:Object.assign({offset:u},(g=R.offset)==null?void 0:g.options)},arrow:Object.assign({},R.arrow,{enabled:!!p,options:Object.assign({},(S=R.arrow)==null?void 0:S.options,{element:p})}),flip:Object.assign({enabled:!!l},R.flip)}))})}const fw=x.createContext(null),dw="data-rr-ui-";function pw(n){return`${dw}${n}`}const Ox=x.createContext(Cs?window:void 0);Ox.Provider;function iy(){return x.useContext(Ox)}const hw=typeof global<"u"&&global.navigator&&global.navigator.product==="ReactNative",yw=typeof document<"u",Tx=yw||hw?x.useLayoutEffect:x.useEffect,_x=x.createContext(null);_x.displayName="InputGroupContext";const Do=x.createContext(null);Do.displayName="NavbarContext";dt.string,dt.bool,dt.bool,dt.bool,dt.bool;const Ax=x.forwardRef(({bsPrefix:n,className:r,fluid:i=!1,rounded:l=!1,roundedCircle:u=!1,thumbnail:c=!1,...d},p)=>(n=we(n,"img"),T.jsx("img",{ref:p,...d,className:Ae(r,i&&`${n}-fluid`,l&&"rounded",u&&"rounded-circle",c&&`${n}-thumbnail`)})));Ax.displayName="Image";const vw={type:dt.string,tooltip:dt.bool,as:dt.elementType},js=x.forwardRef(({as:n="div",className:r,type:i="valid",tooltip:l=!1,...u},c)=>T.jsx(n,{...u,ref:c,className:Ae(r,`${i}-${l?"tooltip":"feedback"}`)}));js.displayName="Feedback";js.propTypes=vw;const Pr=x.createContext({}),jo=x.forwardRef(({id:n,bsPrefix:r,className:i,type:l="checkbox",isValid:u=!1,isInvalid:c=!1,as:d="input",...p},h)=>{const{controlId:y}=x.useContext(Pr);return r=we(r,"form-check-input"),T.jsx(d,{...p,ref:h,type:l,id:n||y,className:Ae(i,r,u&&"is-valid",c&&"is-invalid")})});jo.displayName="FormCheckInput";const Es=x.forwardRef(({bsPrefix:n,className:r,htmlFor:i,...l},u)=>{const{controlId:c}=x.useContext(Pr);return n=we(n,"form-check-label"),T.jsx("label",{...l,ref:u,htmlFor:i||c,className:Ae(r,n)})});Es.displayName="FormCheckLabel";const Rx=x.forwardRef(({id:n,bsPrefix:r,bsSwitchPrefix:i,inline:l=!1,reverse:u=!1,disabled:c=!1,isValid:d=!1,isInvalid:p=!1,feedbackTooltip:h=!1,feedback:y,feedbackType:m,className:g,style:S,title:R="",type:_="checkbox",label:E,children:C,as:j="input",...M},B)=>{r=we(r,"form-check"),i=we(i,"form-switch");const{controlId:X}=x.useContext(Pr),A=x.useMemo(()=>({controlId:n||X}),[X,n]),$=!C&&E!=null&&E!==!1||VA(C,Es),O=T.jsx(jo,{...M,type:_==="switch"?"checkbox":_,ref:B,isValid:d,isInvalid:p,disabled:c,as:j});return T.jsx(Pr.Provider,{value:A,children:T.jsx("div",{style:S,className:Ae(g,$&&r,l&&`${r}-inline`,u&&`${r}-reverse`,_==="switch"&&i),children:C||T.jsxs(T.Fragment,{children:[O,$&&T.jsx(Es,{title:R,children:E}),y&&T.jsx(js,{type:m,tooltip:h,children:y})]})})})});Rx.displayName="FormCheck";const Os=Object.assign(Rx,{Input:jo,Label:Es}),wx=x.forwardRef(({bsPrefix:n,type:r,size:i,htmlSize:l,id:u,className:c,isValid:d=!1,isInvalid:p=!1,plaintext:h,readOnly:y,as:m="input",...g},S)=>{const{controlId:R}=x.useContext(Pr);return n=we(n,"form-control"),T.jsx(m,{...g,type:r,size:l,ref:S,readOnly:y,id:u||R,className:Ae(c,h?`${n}-plaintext`:n,i&&`${n}-${i}`,r==="color"&&`${n}-color`,d&&"is-valid",p&&"is-invalid")})});wx.displayName="FormControl";const mw=Object.assign(wx,{Feedback:js}),Cx=x.forwardRef(({className:n,bsPrefix:r,as:i="div",...l},u)=>(r=we(r,"form-floating"),T.jsx(i,{ref:u,className:Ae(n,r),...l})));Cx.displayName="FormFloating";const ly=x.forwardRef(({controlId:n,as:r="div",...i},l)=>{const u=x.useMemo(()=>({controlId:n}),[n]);return T.jsx(Pr.Provider,{value:u,children:T.jsx(r,{...i,ref:l})})});ly.displayName="FormGroup";const Nx=x.forwardRef(({as:n="label",bsPrefix:r,column:i=!1,visuallyHidden:l=!1,className:u,htmlFor:c,...d},p)=>{const{controlId:h}=x.useContext(Pr);r=we(r,"form-label");let y="col-form-label";typeof i=="string"&&(y=`${y} ${y}-${i}`);const m=Ae(u,r,l&&"visually-hidden",i&&y);return c=c||h,i?T.jsx(ur,{ref:p,as:"label",className:m,htmlFor:c,...d}):T.jsx(n,{ref:p,className:m,htmlFor:c,...d})});Nx.displayName="FormLabel";const Mx=x.forwardRef(({bsPrefix:n,className:r,id:i,...l},u)=>{const{controlId:c}=x.useContext(Pr);return n=we(n,"form-range"),T.jsx("input",{...l,type:"range",ref:u,className:Ae(r,n),id:i||c})});Mx.displayName="FormRange";const Dx=x.forwardRef(({bsPrefix:n,size:r,htmlSize:i,className:l,isValid:u=!1,isInvalid:c=!1,id:d,...p},h)=>{const{controlId:y}=x.useContext(Pr);return n=we(n,"form-select"),T.jsx("select",{...p,size:i,ref:h,className:Ae(l,n,r&&`${n}-${r}`,u&&"is-valid",c&&"is-invalid"),id:d||y})});Dx.displayName="FormSelect";const jx=x.forwardRef(({bsPrefix:n,className:r,as:i="small",muted:l,...u},c)=>(n=we(n,"form-text"),T.jsx(i,{...u,ref:c,className:Ae(r,n,l&&"text-muted")})));jx.displayName="FormText";const Bx=x.forwardRef((n,r)=>T.jsx(Os,{...n,ref:r,type:"switch"}));Bx.displayName="Switch";const gw=Object.assign(Bx,{Input:Os.Input,Label:Os.Label}),$x=x.forwardRef(({bsPrefix:n,className:r,children:i,controlId:l,label:u,...c},d)=>(n=we(n,"form-floating"),T.jsxs(ly,{ref:d,className:Ae(r,n),controlId:l,...c,children:[i,T.jsx("label",{htmlFor:l,children:u})]})));$x.displayName="FloatingLabel";const bw={_ref:dt.any,validated:dt.bool,as:dt.elementType},oy=x.forwardRef(({className:n,validated:r,as:i="form",...l},u)=>T.jsx(i,{...l,ref:u,className:Ae(n,r&&"was-validated")}));oy.displayName="Form";oy.propTypes=bw;const an=Object.assign(oy,{Group:ly,Control:mw,Floating:Cx,Check:Os,Switch:gw,Label:Nx,Text:jx,Range:Mx,Select:Dx,FloatingLabel:$x}),Bs=x.forwardRef(({className:n,bsPrefix:r,as:i="span",...l},u)=>(r=we(r,"input-group-text"),T.jsx(i,{ref:u,className:Ae(n,r),...l})));Bs.displayName="InputGroupText";const Sw=n=>T.jsx(Bs,{children:T.jsx(jo,{type:"checkbox",...n})}),xw=n=>T.jsx(Bs,{children:T.jsx(jo,{type:"radio",...n})}),qx=x.forwardRef(({bsPrefix:n,size:r,hasValidation:i,className:l,as:u="div",...c},d)=>{n=we(n,"input-group");const p=x.useMemo(()=>({}),[]);return T.jsx(_x.Provider,{value:p,children:T.jsx(u,{ref:d,...c,className:Ae(l,n,r&&`${n}-${r}`,i&&"has-validation")})})});qx.displayName="InputGroup";const Yr=Object.assign(qx,{Text:Bs,Radio:xw,Checkbox:Sw}),lb=n=>!n||typeof n=="function"?n:r=>{n.current=r};function Ew(n,r){const i=lb(n),l=lb(r);return u=>{i&&i(u),l&&l(u)}}function $s(n,r){return x.useMemo(()=>Ew(n,r),[n,r])}function vd(n){n===void 0&&(n=Ro());try{var r=n.activeElement;return!r||!r.nodeName?null:r}catch{return n.body}}function Ow(n){const r=x.useRef(n);return r.current=n,r}function Tw(n){const r=Ow(n);x.useEffect(()=>()=>r.current(),[])}function _w(n=document){const r=n.defaultView;return Math.abs(r.innerWidth-n.documentElement.clientWidth)}const ob=pw("modal-open");class uy{constructor({ownerDocument:r,handleContainerOverflow:i=!0,isRTL:l=!1}={}){this.handleContainerOverflow=i,this.isRTL=l,this.modals=[],this.ownerDocument=r}getScrollbarWidth(){return _w(this.ownerDocument)}getElement(){return(this.ownerDocument||document).body}setModalAttributes(r){}removeModalAttributes(r){}setContainerStyle(r){const i={overflow:"hidden"},l=this.isRTL?"paddingLeft":"paddingRight",u=this.getElement();r.style={overflow:u.style.overflow,[l]:u.style[l]},r.scrollBarWidth&&(i[l]=`${parseInt(Gr(u,l)||"0",10)+r.scrollBarWidth}px`),u.setAttribute(ob,""),Gr(u,i)}reset(){[...this.modals].forEach(r=>this.remove(r))}removeContainerStyle(r){const i=this.getElement();i.removeAttribute(ob),Object.assign(i.style,r.style)}add(r){let i=this.modals.indexOf(r);return i!==-1||(i=this.modals.length,this.modals.push(r),this.setModalAttributes(r),i!==0)||(this.state={scrollBarWidth:this.getScrollbarWidth(),style:{}},this.handleContainerOverflow&&this.setContainerStyle(this.state)),i}remove(r){const i=this.modals.indexOf(r);i!==-1&&(this.modals.splice(i,1),!this.modals.length&&this.handleContainerOverflow&&this.removeContainerStyle(this.state),this.removeModalAttributes(r))}isTopModal(r){return!!this.modals.length&&this.modals[this.modals.length-1]===r}}const md=(n,r)=>Cs?n==null?(r||Ro()).body:(typeof n=="function"&&(n=n()),n&&"current"in n&&(n=n.current),n&&("nodeType"in n||n.getBoundingClientRect)?n:null):null;function _h(n,r){const i=iy(),[l,u]=x.useState(()=>md(n,i==null?void 0:i.document));if(!l){const c=md(n);c&&u(c)}return x.useEffect(()=>{},[r,l]),x.useEffect(()=>{const c=md(n);c!==l&&u(c)},[n,l]),l}function Aw({children:n,in:r,onExited:i,mountOnEnter:l,unmountOnExit:u}){const c=x.useRef(null),d=x.useRef(r),p=fr(i);x.useEffect(()=>{r?d.current=!0:p(c.current)},[r,p]);const h=$s(c,Za(n)),y=x.cloneElement(n,{ref:h});return r?y:u||!d.current&&l?null:y}const Rw=["onEnter","onEntering","onEntered","onExit","onExiting","onExited","addEndListener","children"];function ww(n,r){if(n==null)return{};var i={};for(var l in n)if({}.hasOwnProperty.call(n,l)){if(r.indexOf(l)>=0)continue;i[l]=n[l]}return i}function Cw(n){let{onEnter:r,onEntering:i,onEntered:l,onExit:u,onExiting:c,onExited:d,addEndListener:p,children:h}=n,y=ww(n,Rw);const m=x.useRef(null),g=$s(m,Za(h)),S=X=>A=>{X&&m.current&&X(m.current,A)},R=x.useCallback(S(r),[r]),_=x.useCallback(S(i),[i]),E=x.useCallback(S(l),[l]),C=x.useCallback(S(u),[u]),j=x.useCallback(S(c),[c]),M=x.useCallback(S(d),[d]),B=x.useCallback(S(p),[p]);return Object.assign({},y,{nodeRef:m},r&&{onEnter:R},i&&{onEntering:_},l&&{onEntered:E},u&&{onExit:C},c&&{onExiting:j},d&&{onExited:M},p&&{addEndListener:B},{children:typeof h=="function"?(X,A)=>h(X,Object.assign({},A,{ref:g})):x.cloneElement(h,{ref:g})})}const Nw=["component"];function Mw(n,r){if(n==null)return{};var i={};for(var l in n)if({}.hasOwnProperty.call(n,l)){if(r.indexOf(l)>=0)continue;i[l]=n[l]}return i}const Dw=x.forwardRef((n,r)=>{let{component:i}=n,l=Mw(n,Nw);const u=Cw(l);return T.jsx(i,Object.assign({ref:r},u))});function jw({in:n,onTransition:r}){const i=x.useRef(null),l=x.useRef(!0),u=fr(r);return P0(()=>{if(!i.current)return;let c=!1;return u({in:n,element:i.current,initial:l.current,isStale:()=>c}),()=>{c=!0}},[n,u]),P0(()=>(l.current=!1,()=>{l.current=!0}),[]),i}function Bw({children:n,in:r,onExited:i,onEntered:l,transition:u}){const[c,d]=x.useState(!r);r&&c&&d(!1);const p=jw({in:!!r,onTransition:y=>{const m=()=>{y.isStale()||(y.in?l==null||l(y.element,y.initial):(d(!0),i==null||i(y.element)))};Promise.resolve(u(y)).then(m,g=>{throw y.in||d(!0),g})}}),h=$s(p,Za(n));return c&&!r?null:x.cloneElement(n,{ref:h})}function Ah(n,r,i){return n?T.jsx(Dw,Object.assign({},i,{component:n})):r?T.jsx(Bw,Object.assign({},i,{transition:r})):T.jsx(Aw,Object.assign({},i))}const $w=["show","role","className","style","children","backdrop","keyboard","onBackdropClick","onEscapeKeyDown","transition","runTransition","backdropTransition","runBackdropTransition","autoFocus","enforceFocus","restoreFocus","restoreFocusOptions","renderDialog","renderBackdrop","manager","container","onShow","onHide","onExit","onExited","onExiting","onEnter","onEntering","onEntered"];function qw(n,r){if(n==null)return{};var i={};for(var l in n)if({}.hasOwnProperty.call(n,l)){if(r.indexOf(l)>=0)continue;i[l]=n[l]}return i}let gd;function zw(n){return gd||(gd=new uy({ownerDocument:n==null?void 0:n.document})),gd}function kw(n){const r=iy(),i=n||zw(r),l=x.useRef({dialog:null,backdrop:null});return Object.assign(l.current,{add:()=>i.add(l.current),remove:()=>i.remove(l.current),isTopModal:()=>i.isTopModal(l.current),setDialogRef:x.useCallback(u=>{l.current.dialog=u},[]),setBackdropRef:x.useCallback(u=>{l.current.backdrop=u},[])})}const zx=x.forwardRef((n,r)=>{let{show:i=!1,role:l="dialog",className:u,style:c,children:d,backdrop:p=!0,keyboard:h=!0,onBackdropClick:y,onEscapeKeyDown:m,transition:g,runTransition:S,backdropTransition:R,runBackdropTransition:_,autoFocus:E=!0,enforceFocus:C=!0,restoreFocus:j=!0,restoreFocusOptions:M,renderDialog:B,renderBackdrop:X=ye=>T.jsx("div",Object.assign({},ye)),manager:A,container:$,onShow:O,onHide:q=()=>{},onExit:L,onExited:Y,onExiting:W,onEnter:oe,onEntering:ue,onEntered:he}=n,fe=qw(n,$w);const H=iy(),I=_h($),ae=kw(A),be=WS(),N=NA(i),[Z,le]=x.useState(!i),re=x.useRef(null);x.useImperativeHandle(r,()=>ae,[ae]),Cs&&!N&&i&&(re.current=vd(H==null?void 0:H.document)),i&&Z&&le(!1);const z=fr(()=>{if(ae.add(),me.current=Ur(document,"keydown",ce),xe.current=Ur(document,"focus",()=>setTimeout(te),!0),O&&O(),E){var ye,je;const Me=vd((ye=(je=ae.dialog)==null?void 0:je.ownerDocument)!=null?ye:H==null?void 0:H.document);ae.dialog&&Me&&!So(ae.dialog,Me)&&(re.current=Me,ae.dialog.focus())}}),F=fr(()=>{if(ae.remove(),me.current==null||me.current(),xe.current==null||xe.current(),j){var ye;(ye=re.current)==null||ye.focus==null||ye.focus(M),re.current=null}});x.useEffect(()=>{!i||!I||z()},[i,I,z]),x.useEffect(()=>{Z&&F()},[Z,F]),Tw(()=>{F()});const te=fr(()=>{if(!C||!be()||!ae.isTopModal())return;const ye=vd(H==null?void 0:H.document);ae.dialog&&ye&&!So(ae.dialog,ye)&&ae.dialog.focus()}),pe=fr(ye=>{ye.target===ye.currentTarget&&(y==null||y(ye),p===!0&&q())}),ce=fr(ye=>{h&&ZS(ye)&&ae.isTopModal()&&(m==null||m(ye),ye.defaultPrevented||q())}),xe=x.useRef(),me=x.useRef(),Ee=(...ye)=>{le(!0),Y==null||Y(...ye)};if(!I)return null;const de=Object.assign({role:l,ref:ae.setDialogRef,"aria-modal":l==="dialog"?!0:void 0},fe,{style:c,className:u,tabIndex:-1});let ve=B?B(de):T.jsx("div",Object.assign({},de,{children:x.cloneElement(d,{role:"document"})}));ve=Ah(g,S,{unmountOnExit:!0,mountOnEnter:!0,appear:!0,in:!!i,onExit:L,onExiting:W,onExited:Ee,onEnter:oe,onEntering:ue,onEntered:he,children:ve});let Oe=null;return p&&(Oe=X({ref:ae.setBackdropRef,onClick:pe}),Oe=Ah(R,_,{in:!!i,appear:!0,mountOnEnter:!0,unmountOnExit:!0,children:Oe})),T.jsx(T.Fragment,{children:Qa.createPortal(T.jsxs(T.Fragment,{children:[Oe,ve]}),I)})});zx.displayName="Modal";const Lw=Object.assign(zx,{Manager:uy});function Rh(n,r){return n.classList?!!r&&n.classList.contains(r):(" "+(n.className.baseVal||n.className)+" ").indexOf(" "+r+" ")!==-1}function Uw(n,r){n.classList?n.classList.add(r):Rh(n,r)||(typeof n.className=="string"?n.className=n.className+" "+r:n.setAttribute("class",(n.className&&n.className.baseVal||"")+" "+r))}function ub(n,r){return n.replace(new RegExp("(^|\\s)"+r+"(?:\\s|$)","g"),"$1").replace(/\s+/g," ").replace(/^\s*|\s*$/g,"")}function Hw(n,r){n.classList?n.classList.remove(r):typeof n.className=="string"?n.className=ub(n.className,r):n.setAttribute("class",ub(n.className&&n.className.baseVal||"",r))}const zi={FIXED_CONTENT:".fixed-top, .fixed-bottom, .is-fixed, .sticky-top",STICKY_CONTENT:".sticky-top",NAVBAR_TOGGLER:".navbar-toggler"};class kx extends uy{adjustAndStore(r,i,l){const u=i.style[r];i.dataset[r]=u,Gr(i,{[r]:`${parseFloat(Gr(i,r))+l}px`})}restore(r,i){const l=i.dataset[r];l!==void 0&&(delete i.dataset[r],Gr(i,{[r]:l}))}setContainerStyle(r){super.setContainerStyle(r);const i=this.getElement();if(Uw(i,"modal-open"),!r.scrollBarWidth)return;const l=this.isRTL?"paddingLeft":"paddingRight",u=this.isRTL?"marginLeft":"marginRight";qi(i,zi.FIXED_CONTENT).forEach(c=>this.adjustAndStore(l,c,r.scrollBarWidth)),qi(i,zi.STICKY_CONTENT).forEach(c=>this.adjustAndStore(u,c,-r.scrollBarWidth)),qi(i,zi.NAVBAR_TOGGLER).forEach(c=>this.adjustAndStore(u,c,r.scrollBarWidth))}removeContainerStyle(r){super.removeContainerStyle(r);const i=this.getElement();Hw(i,"modal-open");const l=this.isRTL?"paddingLeft":"paddingRight",u=this.isRTL?"marginLeft":"marginRight";qi(i,zi.FIXED_CONTENT).forEach(c=>this.restore(l,c)),qi(i,zi.STICKY_CONTENT).forEach(c=>this.restore(u,c)),qi(i,zi.NAVBAR_TOGGLER).forEach(c=>this.restore(u,c))}}let bd;function Gw(n){return bd||(bd=new kx(n)),bd}const Lx=x.createContext({onHide(){}}),Ux=x.forwardRef(({closeLabel:n="Close",closeVariant:r,closeButton:i=!1,onHide:l,children:u,...c},d)=>{const p=x.useContext(Lx),h=nl(()=>{p==null||p.onHide(),l==null||l()});return T.jsxs("div",{ref:d,...c,children:[u,i&&T.jsx(Ms,{"aria-label":n,variant:r,onClick:h})]})});Ux.displayName="AbstractModalHeader";const Hx=x.forwardRef(({bsPrefix:n,className:r,as:i,...l},u)=>{n=we(n,"navbar-brand");const c=i||(l.href?"a":"span");return T.jsx(c,{...l,ref:u,className:Ae(r,n)})});Hx.displayName="NavbarBrand";const Gx=x.forwardRef(({children:n,bsPrefix:r,...i},l)=>{r=we(r,"navbar-collapse");const u=x.useContext(Do);return T.jsx(wo,{in:!!(u&&u.expanded),...i,children:T.jsx("div",{ref:l,className:r,children:n})})});Gx.displayName="NavbarCollapse";const Yx=x.forwardRef(({bsPrefix:n,className:r,children:i,label:l="Toggle navigation",as:u="button",onClick:c,...d},p)=>{n=we(n,"navbar-toggler");const{onToggle:h,expanded:y}=x.useContext(Do)||{},m=nl(g=>{c&&c(g),h&&h()});return u==="button"&&(d.type="button"),T.jsx(u,{...d,ref:p,onClick:m,"aria-label":l,className:Ae(r,n,!y&&"collapsed"),children:i||T.jsx("span",{className:`${n}-icon`})})});Yx.displayName="NavbarToggle";const wh=new WeakMap,sb=(n,r)=>{if(!n||!r)return;const i=wh.get(r)||new Map;wh.set(r,i);let l=i.get(n);return l||(l=r.matchMedia(n),l.refCount=0,i.set(l.media,l)),l};function Yw(n,r=typeof window>"u"?void 0:window){const i=sb(n,r),[l,u]=x.useState(()=>i?i.matches:!1);return Tx(()=>{let c=sb(n,r);if(!c)return u(!1);let d=wh.get(r);const p=()=>{u(c.matches)};return c.refCount++,c.addListener(p),p(),()=>{c.removeListener(p),c.refCount--,c.refCount<=0&&(d==null||d.delete(c.media)),c=void 0}},[n]),l}function Vw(n){const r=Object.keys(n);function i(p,h){return p===h?h:p?`${p} and ${h}`:h}function l(p){return r[Math.min(r.indexOf(p)+1,r.length-1)]}function u(p){const h=l(p);let y=n[h];return typeof y=="number"?y=`${y-.2}px`:y=`calc(${y} - 0.2px)`,`(max-width: ${y})`}function c(p){let h=n[p];return typeof h=="number"&&(h=`${h}px`),`(min-width: ${h})`}function d(p,h,y){let m;typeof p=="object"?(m=p,y=h,h=!0):(h=h||!0,m={[p]:h});let g=x.useMemo(()=>Object.entries(m).reduce((S,[R,_])=>((_==="up"||_===!0)&&(S=i(S,c(R))),(_==="down"||_===!0)&&(S=i(S,u(R))),S),""),[JSON.stringify(m)]);return Yw(g,y)}return d}const Pw=Vw({xs:0,sm:576,md:768,lg:992,xl:1200,xxl:1400}),Vx=x.forwardRef(({className:n,bsPrefix:r,as:i="div",...l},u)=>(r=we(r,"offcanvas-body"),T.jsx(i,{ref:u,className:Ae(n,r),...l})));Vx.displayName="OffcanvasBody";const Xw={[Ln]:"show",[Lr]:"show"},Px=x.forwardRef(({bsPrefix:n,className:r,children:i,in:l=!1,mountOnEnter:u=!1,unmountOnExit:c=!1,appear:d=!1,...p},h)=>(n=we(n,"offcanvas"),T.jsx(Ns,{ref:h,addEndListener:Kh,in:l,mountOnEnter:u,unmountOnExit:c,appear:d,...p,childRef:Za(i),children:(y,m)=>x.cloneElement(i,{...m,className:Ae(r,i.props.className,(y===Ln||y===Fi)&&`${n}-toggling`,Xw[y])})})));Px.displayName="OffcanvasToggling";const Xx=x.forwardRef(({bsPrefix:n,className:r,closeLabel:i="Close",closeButton:l=!1,...u},c)=>(n=we(n,"offcanvas-header"),T.jsx(Ux,{ref:c,...u,className:Ae(r,n),closeLabel:i,closeButton:l})));Xx.displayName="OffcanvasHeader";const Qw=Zh("h5"),Qx=x.forwardRef(({className:n,bsPrefix:r,as:i=Qw,...l},u)=>(r=we(r,"offcanvas-title"),T.jsx(i,{ref:u,className:Ae(n,r),...l})));Qx.displayName="OffcanvasTitle";function Kw(n){return T.jsx(Px,{...n})}function Fw(n){return T.jsx(mo,{...n})}const Kx=x.forwardRef(({bsPrefix:n,className:r,children:i,"aria-labelledby":l,placement:u="start",responsive:c,show:d=!1,backdrop:p=!0,keyboard:h=!0,scroll:y=!1,onEscapeKeyDown:m,onShow:g,onHide:S,container:R,autoFocus:_=!0,enforceFocus:E=!0,restoreFocus:C=!0,restoreFocusOptions:j,onEntered:M,onExit:B,onExiting:X,onEnter:A,onEntering:$,onExited:O,backdropClassName:q,manager:L,renderStaticNode:Y=!1,...W},oe)=>{const ue=x.useRef();n=we(n,"offcanvas");const[he,fe]=x.useState(!1),H=nl(S),I=Pw(c||"xs","up");x.useEffect(()=>{fe(c?d&&!I:d)},[d,c,I]);const ae=x.useMemo(()=>({onHide:H}),[H]);function be(){return L||(y?(ue.current||(ue.current=new kx({handleContainerOverflow:!1})),ue.current):Gw())}const N=(z,...F)=>{z&&(z.style.visibility="visible"),A==null||A(z,...F)},Z=(z,...F)=>{z&&(z.style.visibility=""),O==null||O(...F)},le=x.useCallback(z=>T.jsx("div",{...z,className:Ae(`${n}-backdrop`,q)}),[q,n]),re=z=>T.jsx("div",{...z,...W,className:Ae(r,c?`${n}-${c}`:n,`${n}-${u}`),"aria-labelledby":l,children:i});return T.jsxs(T.Fragment,{children:[!he&&(c||Y)&&re({}),T.jsx(Lx.Provider,{value:ae,children:T.jsx(Lw,{show:he,ref:oe,backdrop:p,container:R,keyboard:h,autoFocus:_,enforceFocus:E&&!y,restoreFocus:C,restoreFocusOptions:j,onEscapeKeyDown:m,onShow:g,onHide:H,onEnter:N,onEntering:$,onEntered:M,onExit:B,onExiting:X,onExited:Z,manager:be(),transition:Kw,backdropTransition:Fw,renderBackdrop:le,renderDialog:re})})]})});Kx.displayName="Offcanvas";const oo=Object.assign(Kx,{Body:Vx,Header:Xx,Title:Qx}),Fx=x.forwardRef(({onHide:n,...r},i)=>{const l=x.useContext(Do),u=nl(()=>{l==null||l.onToggle==null||l.onToggle(),n==null||n()});return T.jsx(oo,{ref:i,show:!!(l!=null&&l.expanded),...r,renderStaticNode:!0,onHide:u})});Fx.displayName="NavbarOffcanvas";const Zx=x.forwardRef(({className:n,bsPrefix:r,as:i="span",...l},u)=>(r=we(r,"navbar-text"),T.jsx(i,{ref:u,className:Ae(n,r),...l})));Zx.displayName="NavbarText";const Ix=x.forwardRef((n,r)=>{const{bsPrefix:i,expand:l=!0,variant:u="light",bg:c,fixed:d,sticky:p,className:h,as:y="nav",expanded:m,onToggle:g,onSelect:S,collapseOnSelect:R=!1,..._}=J_(n,{expanded:"onToggle"}),E=we(i,"navbar"),C=x.useCallback((...B)=>{S==null||S(...B),R&&m&&(g==null||g(!1))},[S,R,m,g]);_.role===void 0&&y!=="nav"&&(_.role="navigation");let j=`${E}-expand`;typeof l=="string"&&(j=`${j}-${l}`);const M=x.useMemo(()=>({onToggle:()=>g==null?void 0:g(!m),bsPrefix:E,expanded:!!m,expand:l}),[E,m,l,g]);return T.jsx(Do.Provider,{value:M,children:T.jsx(fw.Provider,{value:C,children:T.jsx(y,{ref:r,..._,className:Ae(h,E,l&&j,u&&`${E}-${u}`,c&&`bg-${c}`,p&&`sticky-${p}`,d&&`fixed-${d}`)})})})});Ix.displayName="Navbar";const Sd=Object.assign(Ix,{Brand:Hx,Collapse:Gx,Offcanvas:Fx,Text:Zx,Toggle:Yx}),Zw=()=>{};function Iw(n,r,{disabled:i,clickTrigger:l}={}){const u=r||Zw;ow(n,u,{disabled:i,clickTrigger:l});const c=fr(d=>{ZS(d)&&u(d)});x.useEffect(()=>{if(i||n==null)return;const d=Ro(ss(n));let p=(d.defaultView||window).event;const h=Ur(d,"keyup",y=>{if(y===p){p=void 0;return}c(y)});return()=>{h()}},[n,i,c])}const Wx=x.forwardRef((n,r)=>{const{flip:i,offset:l,placement:u,containerPadding:c,popperConfig:d={},transition:p,runTransition:h}=n,[y,m]=V0(),[g,S]=V0(),R=$s(m,r),_=_h(n.container),E=_h(n.target),[C,j]=x.useState(!n.show),M=tw(E,y,cw({placement:u,enableEvents:!!n.show,containerPadding:c||5,flip:i,offset:l,arrowElement:g,popperConfig:d}));n.show&&C&&j(!1);const B=(...W)=>{j(!0),n.onExited&&n.onExited(...W)},X=n.show||!C;if(Iw(y,n.onHide,{disabled:!n.rootClose||n.rootCloseDisabled,clickTrigger:n.rootCloseEvent}),!X)return null;const{onExit:A,onExiting:$,onEnter:O,onEntering:q,onEntered:L}=n;let Y=n.children(Object.assign({},M.attributes.popper,{style:M.styles.popper,ref:R}),{popper:M,placement:u,show:!!n.show,arrowProps:Object.assign({},M.attributes.arrow,{style:M.styles.arrow,ref:S})});return Y=Ah(p,h,{in:!!n.show,appear:!0,mountOnEnter:!0,unmountOnExit:!0,children:Y,onExit:A,onExiting:$,onExited:B,onEnter:O,onEntering:q,onEntered:L}),_?Qa.createPortal(Y,_):null});Wx.displayName="Overlay";const Jx=x.forwardRef(({className:n,bsPrefix:r,as:i="div",...l},u)=>(r=we(r,"popover-header"),T.jsx(i,{ref:u,className:Ae(n,r),...l})));Jx.displayName="PopoverHeader";const sy=x.forwardRef(({className:n,bsPrefix:r,as:i="div",...l},u)=>(r=we(r,"popover-body"),T.jsx(i,{ref:u,className:Ae(n,r),...l})));sy.displayName="PopoverBody";function eE(n,r){let i=n;return n==="left"?i=r?"end":"start":n==="right"&&(i=r?"start":"end"),i}function tE(n="absolute"){return{position:n,top:"0",left:"0",opacity:"0",pointerEvents:"none"}}const nE=x.forwardRef(({bsPrefix:n,placement:r="right",className:i,style:l,children:u,body:c,arrowProps:d,hasDoneInitialMeasure:p,popper:h,show:y,...m},g)=>{const S=we(n,"popover"),R=QS(),[_]=(r==null?void 0:r.split("-"))||[],E=eE(_,R);let C=l;return y&&!p&&(C={...l,...tE(h==null?void 0:h.strategy)}),T.jsxs("div",{ref:g,role:"tooltip",style:C,"x-placement":_,className:Ae(i,S,_&&`bs-popover-${E}`),...m,children:[T.jsx("div",{className:"popover-arrow",...d}),c?T.jsx(sy,{children:u}):u]})});nE.displayName="Popover";const Ww=Object.assign(nE,{Header:Jx,Body:sy,POPPER_OFFSET:[0,8]}),rE=x.forwardRef(({bsPrefix:n,placement:r="right",className:i,style:l,children:u,arrowProps:c,hasDoneInitialMeasure:d,popper:p,show:h,...y},m)=>{n=we(n,"tooltip");const g=QS(),[S]=(r==null?void 0:r.split("-"))||[],R=eE(S,g);let _=l;return h&&!d&&(_={...l,...tE(p==null?void 0:p.strategy)}),T.jsxs("div",{ref:m,style:_,role:"tooltip","x-placement":S,className:Ae(i,n,`bs-tooltip-${R}`),...y,children:[T.jsx("div",{className:"tooltip-arrow",...c}),T.jsx("div",{className:`${n}-inner`,children:u})]})});rE.displayName="Tooltip";const aE=Object.assign(rE,{TOOLTIP_OFFSET:[0,6]});function Jw(n){const r=x.useRef(null),i=we(void 0,"popover"),l=we(void 0,"tooltip"),u=x.useMemo(()=>({name:"offset",options:{offset:()=>{if(n)return n;if(r.current){if(Rh(r.current,i))return Ww.POPPER_OFFSET;if(Rh(r.current,l))return aE.TOOLTIP_OFFSET}return[0,0]}}}),[n,i,l]);return[r,[u]]}function e2(n,r){const{ref:i}=n,{ref:l}=r;n.ref=i.__wrapped||(i.__wrapped=u=>i(Ss(u))),r.ref=l.__wrapped||(l.__wrapped=u=>l(Ss(u)))}const iE=x.forwardRef(({children:n,transition:r=mo,popperConfig:i={},rootClose:l=!1,placement:u="top",show:c=!1,...d},p)=>{const h=x.useRef({}),[y,m]=x.useState(null),[g,S]=Jw(d.offset),R=Fh(p,g),_=r===!0?mo:r||void 0,E=nl(C=>{m(C),i==null||i.onFirstUpdate==null||i.onFirstUpdate(C)});return Tx(()=>{y&&d.target&&(h.current.scheduleUpdate==null||h.current.scheduleUpdate())},[y,d.target]),x.useEffect(()=>{c||m(null)},[c]),T.jsx(Wx,{...d,ref:R,popperConfig:{...i,modifiers:S.concat(i.modifiers||[]),onFirstUpdate:E},transition:_,rootClose:l,placement:u,show:c,children:(C,{arrowProps:j,popper:M,show:B})=>{var X;e2(C,j);const A=M==null?void 0:M.placement,$=Object.assign(h.current,{state:M==null?void 0:M.state,scheduleUpdate:M==null?void 0:M.update,placement:A,outOfBoundaries:(M==null||(X=M.state)==null||(X=X.modifiersData.hide)==null?void 0:X.isReferenceHidden)||!1,strategy:i.strategy}),O=!!y;return typeof n=="function"?n({...C,placement:A,show:B,...!r&&B&&{className:"show"},popper:$,arrowProps:j,hasDoneInitialMeasure:O}):x.cloneElement(n,{...C,placement:A,arrowProps:j,popper:$,hasDoneInitialMeasure:O,className:Ae(n.props.className,!r&&B&&"show"),style:{...n.props.style,...C.style}})}})});iE.displayName="Overlay";function t2(n){return n&&typeof n=="object"?n:{show:n,hide:n}}function cb(n,r,i){const[l]=r,u=l.currentTarget,c=l.relatedTarget||l.nativeEvent[i];(!c||c!==u)&&!So(u,c)&&n(...r)}dt.oneOf(["click","hover","focus"]);const n2=({trigger:n=["hover","focus"],overlay:r,children:i,popperConfig:l={},show:u,defaultShow:c=!1,onToggle:d,delay:p,placement:h,flip:y=h&&h.indexOf("auto")!==-1,...m})=>{const g=x.useRef(null),S=Fh(g,Za(i)),R=dx(),_=x.useRef(""),[E,C]=VS(u,c,d),j=t2(p),{onFocus:M,onBlur:B,onClick:X}=typeof i!="function"?x.Children.only(i).props:{},A=fe=>{S(Ss(fe))},$=x.useCallback(()=>{if(R.clear(),_.current="show",!j.show){C(!0);return}R.set(()=>{_.current==="show"&&C(!0)},j.show)},[j.show,C,R]),O=x.useCallback(()=>{if(R.clear(),_.current="hide",!j.hide){C(!1);return}R.set(()=>{_.current==="hide"&&C(!1)},j.hide)},[j.hide,C,R]),q=x.useCallback((...fe)=>{$(),M==null||M(...fe)},[$,M]),L=x.useCallback((...fe)=>{O(),B==null||B(...fe)},[O,B]),Y=x.useCallback((...fe)=>{C(!E),X==null||X(...fe)},[X,C,E]),W=x.useCallback((...fe)=>{cb($,fe,"fromElement")},[$]),oe=x.useCallback((...fe)=>{cb(O,fe,"toElement")},[O]),ue=n==null?[]:[].concat(n),he={ref:A};return ue.indexOf("click")!==-1&&(he.onClick=Y),ue.indexOf("focus")!==-1&&(he.onFocus=q,he.onBlur=L),ue.indexOf("hover")!==-1&&(he.onMouseOver=W,he.onMouseOut=oe),T.jsxs(T.Fragment,{children:[typeof i=="function"?i(he):x.cloneElement(i,he),T.jsx(iE,{...m,show:E,onHide:O,flip:y,placement:h,popperConfig:l,target:g.current,children:r})]})},Ts=x.forwardRef(({bsPrefix:n,className:r,as:i="div",...l},u)=>{const c=we(n,"row"),d=PS(),p=XS(),h=`${c}-cols`,y=[];return d.forEach(m=>{const g=l[m];delete l[m];let S;g!=null&&typeof g=="object"?{cols:S}=g:S=g;const R=m!==p?`-${m}`:"";S!=null&&y.push(`${h}${R}-${S}`)}),T.jsx(i,{ref:u,...l,className:Ae(r,c,...y)})});Ts.displayName="Row";const lE=x.forwardRef(({bsPrefix:n,variant:r,animation:i="border",size:l,as:u="div",className:c,...d},p)=>{n=we(n,"spinner");const h=`${n}-${i}`;return T.jsx(u,{ref:p,...d,className:Ae(c,h,l&&`${h}-${l}`,r&&`text-${r}`)})});lE.displayName="Spinner";const r2={[Ln]:"showing",[Fi]:"showing show"},oE=x.forwardRef((n,r)=>T.jsx(mo,{...n,ref:r,transitionClasses:r2}));oE.displayName="ToastFade";const uE=x.createContext({onClose(){}}),sE=x.forwardRef(({bsPrefix:n,closeLabel:r="Close",closeVariant:i,closeButton:l=!0,className:u,children:c,...d},p)=>{n=we(n,"toast-header");const h=x.useContext(uE),y=nl(m=>{h==null||h.onClose==null||h.onClose(m)});return T.jsxs("div",{ref:p,...d,className:Ae(n,u),children:[c,l&&T.jsx(Ms,{"aria-label":r,variant:i,onClick:y,"data-dismiss":"toast"})]})});sE.displayName="ToastHeader";const cE=x.forwardRef(({className:n,bsPrefix:r,as:i="div",...l},u)=>(r=we(r,"toast-body"),T.jsx(i,{ref:u,className:Ae(n,r),...l})));cE.displayName="ToastBody";const fE=x.forwardRef(({bsPrefix:n,className:r,transition:i=oE,show:l=!0,animation:u=!0,delay:c=5e3,autohide:d=!1,onClose:p,onEntered:h,onExit:y,onExiting:m,onEnter:g,onEntering:S,onExited:R,bg:_,...E},C)=>{n=we(n,"toast");const j=x.useRef(c),M=x.useRef(p);x.useEffect(()=>{j.current=c,M.current=p},[c,p]);const B=dx(),X=!!(d&&l),A=x.useCallback(()=>{X&&(M.current==null||M.current())},[X]);x.useEffect(()=>{B.set(A,j.current)},[B,A]);const $=x.useMemo(()=>({onClose:p}),[p]),O=!!(i&&u),q=T.jsx("div",{...E,ref:C,className:Ae(n,r,_&&`bg-${_}`,!O&&(l?"show":"hide")),role:"alert","aria-live":"assertive","aria-atomic":"true"});return T.jsx(uE.Provider,{value:$,children:O&&i?T.jsx(i,{in:l,onEnter:g,onEntering:S,onEntered:h,onExit:y,onExiting:m,onExited:R,unmountOnExit:!0,children:q}):q})});fE.displayName="Toast";const ho=Object.assign(fE,{Body:cE,Header:sE}),a2={"top-start":"top-0 start-0","top-center":"top-0 start-50 translate-middle-x","top-end":"top-0 end-0","middle-start":"top-50 start-0 translate-middle-y","middle-center":"top-50 start-50 translate-middle","middle-end":"top-50 end-0 translate-middle-y","bottom-start":"bottom-0 start-0","bottom-center":"bottom-0 start-50 translate-middle-x","bottom-end":"bottom-0 end-0"},cy=x.forwardRef(({bsPrefix:n,position:r,containerPosition:i,className:l,as:u="div",...c},d)=>(n=we(n,"toast-container"),T.jsx(u,{ref:d,...c,className:Ae(n,r&&a2[r],i&&`position-${i}`,l)})));cy.displayName="ToastContainer";const i2=()=>{},fy=x.forwardRef(({bsPrefix:n,name:r,className:i,checked:l,type:u,onChange:c,value:d,disabled:p,id:h,inputRef:y,...m},g)=>(n=we(n,"btn-check"),T.jsxs(T.Fragment,{children:[T.jsx("input",{className:n,name:r,type:u,value:d,ref:y,autoComplete:"off",checked:!!l,disabled:!!p,onChange:c||i2,id:h}),T.jsx(Co,{...m,ref:g,className:Ae(i,p&&"disabled"),type:void 0,role:void 0,as:"label",htmlFor:h})]})));fy.displayName="ToggleButton";const mr=Object.create(null);mr.open="0";mr.close="1";mr.ping="2";mr.pong="3";mr.message="4";mr.upgrade="5";mr.noop="6";const cs=Object.create(null);Object.keys(mr).forEach(n=>{cs[mr[n]]=n});const Ch={type:"error",data:"parser error"},dE=typeof Blob=="function"||typeof Blob<"u"&&Object.prototype.toString.call(Blob)==="[object BlobConstructor]",pE=typeof ArrayBuffer=="function",hE=n=>typeof ArrayBuffer.isView=="function"?ArrayBuffer.isView(n):n&&n.buffer instanceof ArrayBuffer,dy=({type:n,data:r},i,l)=>dE&&r instanceof Blob?i?l(r):fb(r,l):pE&&(r instanceof ArrayBuffer||hE(r))?i?l(r):fb(new Blob([r]),l):l(mr[n]+(r||"")),fb=(n,r)=>{const i=new FileReader;return i.onload=function(){const l=i.result.split(",")[1];r("b"+(l||""))},i.readAsDataURL(n)};function db(n){return n instanceof Uint8Array?n:n instanceof ArrayBuffer?new Uint8Array(n):new Uint8Array(n.buffer,n.byteOffset,n.byteLength)}let xd;function l2(n,r){if(dE&&n.data instanceof Blob)return n.data.arrayBuffer().then(db).then(r);if(pE&&(n.data instanceof ArrayBuffer||hE(n.data)))return r(db(n.data));dy(n,!1,i=>{xd||(xd=new TextEncoder),r(xd.encode(i))})}const pb="ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/",uo=typeof Uint8Array>"u"?[]:new Uint8Array(256);for(let n=0;n<pb.length;n++)uo[pb.charCodeAt(n)]=n;const o2=n=>{let r=n.length*.75,i=n.length,l,u=0,c,d,p,h;n[n.length-1]==="="&&(r--,n[n.length-2]==="="&&r--);const y=new ArrayBuffer(r),m=new Uint8Array(y);for(l=0;l<i;l+=4)c=uo[n.charCodeAt(l)],d=uo[n.charCodeAt(l+1)],p=uo[n.charCodeAt(l+2)],h=uo[n.charCodeAt(l+3)],m[u++]=c<<2|d>>4,m[u++]=(d&15)<<4|p>>2,m[u++]=(p&3)<<6|h&63;return y},u2=typeof ArrayBuffer=="function",py=(n,r)=>{if(typeof n!="string")return{type:"message",data:yE(n,r)};const i=n.charAt(0);return i==="b"?{type:"message",data:s2(n.substring(1),r)}:cs[i]?n.length>1?{type:cs[i],data:n.substring(1)}:{type:cs[i]}:Ch},s2=(n,r)=>{if(u2){const i=o2(n);return yE(i,r)}else return{base64:!0,data:n}},yE=(n,r)=>{switch(r){case"blob":return n instanceof Blob?n:new Blob([n]);case"arraybuffer":default:return n instanceof ArrayBuffer?n:n.buffer}},vE="",c2=(n,r)=>{const i=n.length,l=new Array(i);let u=0;n.forEach((c,d)=>{dy(c,!1,p=>{l[d]=p,++u===i&&r(l.join(vE))})})},f2=(n,r)=>{const i=n.split(vE),l=[];for(let u=0;u<i.length;u++){const c=py(i[u],r);if(l.push(c),c.type==="error")break}return l};function d2(){return new TransformStream({transform(n,r){l2(n,i=>{const l=i.length;let u;if(l<126)u=new Uint8Array(1),new DataView(u.buffer).setUint8(0,l);else if(l<65536){u=new Uint8Array(3);const c=new DataView(u.buffer);c.setUint8(0,126),c.setUint16(1,l)}else{u=new Uint8Array(9);const c=new DataView(u.buffer);c.setUint8(0,127),c.setBigUint64(1,BigInt(l))}n.data&&typeof n.data!="string"&&(u[0]|=128),r.enqueue(u),r.enqueue(i)})}})}let Ed;function Iu(n){return n.reduce((r,i)=>r+i.length,0)}function Wu(n,r){if(n[0].length===r)return n.shift();const i=new Uint8Array(r);let l=0;for(let u=0;u<r;u++)i[u]=n[0][l++],l===n[0].length&&(n.shift(),l=0);return n.length&&l<n[0].length&&(n[0]=n[0].slice(l)),i}function p2(n,r){Ed||(Ed=new TextDecoder);const i=[];let l=0,u=-1,c=!1;return new TransformStream({transform(d,p){for(i.push(d);;){if(l===0){if(Iu(i)<1)break;const h=Wu(i,1);c=(h[0]&128)===128,u=h[0]&127,u<126?l=3:u===126?l=1:l=2}else if(l===1){if(Iu(i)<2)break;const h=Wu(i,2);u=new DataView(h.buffer,h.byteOffset,h.length).getUint16(0),l=3}else if(l===2){if(Iu(i)<8)break;const h=Wu(i,8),y=new DataView(h.buffer,h.byteOffset,h.length),m=y.getUint32(0);if(m>Math.pow(2,21)-1){p.enqueue(Ch);break}u=m*Math.pow(2,32)+y.getUint32(4),l=3}else{if(Iu(i)<u)break;const h=Wu(i,u);p.enqueue(py(c?h:Ed.decode(h),r)),l=0}if(u===0||u>n){p.enqueue(Ch);break}}}})}const mE=4;function Bt(n){if(n)return h2(n)}function h2(n){for(var r in Bt.prototype)n[r]=Bt.prototype[r];return n}Bt.prototype.on=Bt.prototype.addEventListener=function(n,r){return this._callbacks=this._callbacks||{},(this._callbacks["$"+n]=this._callbacks["$"+n]||[]).push(r),this};Bt.prototype.once=function(n,r){function i(){this.off(n,i),r.apply(this,arguments)}return i.fn=r,this.on(n,i),this};Bt.prototype.off=Bt.prototype.removeListener=Bt.prototype.removeAllListeners=Bt.prototype.removeEventListener=function(n,r){if(this._callbacks=this._callbacks||{},arguments.length==0)return this._callbacks={},this;var i=this._callbacks["$"+n];if(!i)return this;if(arguments.length==1)return delete this._callbacks["$"+n],this;for(var l,u=0;u<i.length;u++)if(l=i[u],l===r||l.fn===r){i.splice(u,1);break}return i.length===0&&delete this._callbacks["$"+n],this};Bt.prototype.emit=function(n){this._callbacks=this._callbacks||{};for(var r=new Array(arguments.length-1),i=this._callbacks["$"+n],l=1;l<arguments.length;l++)r[l-1]=arguments[l];if(i){i=i.slice(0);for(var l=0,u=i.length;l<u;++l)i[l].apply(this,r)}return this};Bt.prototype.emitReserved=Bt.prototype.emit;Bt.prototype.listeners=function(n){return this._callbacks=this._callbacks||{},this._callbacks["$"+n]||[]};Bt.prototype.hasListeners=function(n){return!!this.listeners(n).length};const qs=typeof Promise=="function"&&typeof Promise.resolve=="function"?r=>Promise.resolve().then(r):(r,i)=>i(r,0),Un=typeof self<"u"?self:typeof window<"u"?window:Function("return this")(),y2="arraybuffer";function gE(n,...r){return r.reduce((i,l)=>(n.hasOwnProperty(l)&&(i[l]=n[l]),i),{})}const v2=Un.setTimeout,m2=Un.clearTimeout;function zs(n,r){r.useNativeTimers?(n.setTimeoutFn=v2.bind(Un),n.clearTimeoutFn=m2.bind(Un)):(n.setTimeoutFn=Un.setTimeout.bind(Un),n.clearTimeoutFn=Un.clearTimeout.bind(Un))}const g2=1.33;function b2(n){return typeof n=="string"?S2(n):Math.ceil((n.byteLength||n.size)*g2)}function S2(n){let r=0,i=0;for(let l=0,u=n.length;l<u;l++)r=n.charCodeAt(l),r<128?i+=1:r<2048?i+=2:r<55296||r>=57344?i+=3:(l++,i+=4);return i}function bE(){return Date.now().toString(36).substring(3)+Math.random().toString(36).substring(2,5)}function x2(n){let r="";for(let i in n)n.hasOwnProperty(i)&&(r.length&&(r+="&"),r+=encodeURIComponent(i)+"="+encodeURIComponent(n[i]));return r}function E2(n){let r={},i=n.split("&");for(let l=0,u=i.length;l<u;l++){let c=i[l].split("=");r[decodeURIComponent(c[0])]=decodeURIComponent(c[1])}return r}class O2 extends Error{constructor(r,i,l){super(r),this.description=i,this.context=l,this.type="TransportError"}}class hy extends Bt{constructor(r){super(),this.writable=!1,zs(this,r),this.opts=r,this.query=r.query,this.socket=r.socket,this.supportsBinary=!r.forceBase64}onError(r,i,l){return super.emitReserved("error",new O2(r,i,l)),this}open(){return this.readyState="opening",this.doOpen(),this}close(){return(this.readyState==="opening"||this.readyState==="open")&&(this.doClose(),this.onClose()),this}send(r){this.readyState==="open"&&this.write(r)}onOpen(){this.readyState="open",this.writable=!0,super.emitReserved("open")}onData(r){const i=py(r,this.socket.binaryType);this.onPacket(i)}onPacket(r){super.emitReserved("packet",r)}onClose(r){this.readyState="closed",super.emitReserved("close",r)}pause(r){}createUri(r,i={}){return r+"://"+this._hostname()+this._port()+this.opts.path+this._query(i)}_hostname(){const r=this.opts.hostname;return r.indexOf(":")===-1?r:"["+r+"]"}_port(){return this.opts.port&&(this.opts.secure&&+(this.opts.port!==443)||!this.opts.secure&&Number(this.opts.port)!==80)?":"+this.opts.port:""}_query(r){const i=x2(r);return i.length?"?"+i:""}}class T2 extends hy{constructor(){super(...arguments),this._polling=!1}get name(){return"polling"}doOpen(){this._poll()}pause(r){this.readyState="pausing";const i=()=>{this.readyState="paused",r()};if(this._polling||!this.writable){let l=0;this._polling&&(l++,this.once("pollComplete",function(){--l||i()})),this.writable||(l++,this.once("drain",function(){--l||i()}))}else i()}_poll(){this._polling=!0,this.doPoll(),this.emitReserved("poll")}onData(r){const i=l=>{if(this.readyState==="opening"&&l.type==="open"&&this.onOpen(),l.type==="close")return this.onClose({description:"transport closed by the server"}),!1;this.onPacket(l)};f2(r,this.socket.binaryType).forEach(i),this.readyState!=="closed"&&(this._polling=!1,this.emitReserved("pollComplete"),this.readyState==="open"&&this._poll())}doClose(){const r=()=>{this.write([{type:"close"}])};this.readyState==="open"?r():this.once("open",r)}write(r){this.writable=!1,c2(r,i=>{this.doWrite(i,()=>{this.writable=!0,this.emitReserved("drain")})})}uri(){const r=this.opts.secure?"https":"http",i=this.query||{};return this.opts.timestampRequests!==!1&&(i[this.opts.timestampParam]=bE()),!this.supportsBinary&&!i.sid&&(i.b64=1),this.createUri(r,i)}}let SE=!1;try{SE=typeof XMLHttpRequest<"u"&&"withCredentials"in new XMLHttpRequest}catch{}const _2=SE;function A2(){}class R2 extends T2{constructor(r){if(super(r),typeof location<"u"){const i=location.protocol==="https:";let l=location.port;l||(l=i?"443":"80"),this.xd=typeof location<"u"&&r.hostname!==location.hostname||l!==r.port}}doWrite(r,i){const l=this.request({method:"POST",data:r});l.on("success",i),l.on("error",(u,c)=>{this.onError("xhr post error",u,c)})}doPoll(){const r=this.request();r.on("data",this.onData.bind(this)),r.on("error",(i,l)=>{this.onError("xhr poll error",i,l)}),this.pollXhr=r}}class hr extends Bt{constructor(r,i,l){super(),this.createRequest=r,zs(this,l),this._opts=l,this._method=l.method||"GET",this._uri=i,this._data=l.data!==void 0?l.data:null,this._create()}_create(){var r;const i=gE(this._opts,"agent","pfx","key","passphrase","cert","ca","ciphers","rejectUnauthorized","autoUnref");i.xdomain=!!this._opts.xd;const l=this._xhr=this.createRequest(i);try{l.open(this._method,this._uri,!0);try{if(this._opts.extraHeaders){l.setDisableHeaderCheck&&l.setDisableHeaderCheck(!0);for(let u in this._opts.extraHeaders)this._opts.extraHeaders.hasOwnProperty(u)&&l.setRequestHeader(u,this._opts.extraHeaders[u])}}catch{}if(this._method==="POST")try{l.setRequestHeader("Content-type","text/plain;charset=UTF-8")}catch{}try{l.setRequestHeader("Accept","*/*")}catch{}(r=this._opts.cookieJar)===null||r===void 0||r.addCookies(l),"withCredentials"in l&&(l.withCredentials=this._opts.withCredentials),this._opts.requestTimeout&&(l.timeout=this._opts.requestTimeout),l.onreadystatechange=()=>{var u;l.readyState===3&&((u=this._opts.cookieJar)===null||u===void 0||u.parseCookies(l.getResponseHeader("set-cookie"))),l.readyState===4&&(l.status===200||l.status===1223?this._onLoad():this.setTimeoutFn(()=>{this._onError(typeof l.status=="number"?l.status:0)},0))},l.send(this._data)}catch(u){this.setTimeoutFn(()=>{this._onError(u)},0);return}typeof document<"u"&&(this._index=hr.requestsCount++,hr.requests[this._index]=this)}_onError(r){this.emitReserved("error",r,this._xhr),this._cleanup(!0)}_cleanup(r){if(!(typeof this._xhr>"u"||this._xhr===null)){if(this._xhr.onreadystatechange=A2,r)try{this._xhr.abort()}catch{}typeof document<"u"&&delete hr.requests[this._index],this._xhr=null}}_onLoad(){const r=this._xhr.responseText;r!==null&&(this.emitReserved("data",r),this.emitReserved("success"),this._cleanup())}abort(){this._cleanup()}}hr.requestsCount=0;hr.requests={};if(typeof document<"u"){if(typeof attachEvent=="function")attachEvent("onunload",hb);else if(typeof addEventListener=="function"){const n="onpagehide"in Un?"pagehide":"unload";addEventListener(n,hb,!1)}}function hb(){for(let n in hr.requests)hr.requests.hasOwnProperty(n)&&hr.requests[n].abort()}const w2=function(){const n=xE({xdomain:!1});return n&&n.responseType!==null}();class C2 extends R2{constructor(r){super(r);const i=r&&r.forceBase64;this.supportsBinary=w2&&!i}request(r={}){return Object.assign(r,{xd:this.xd},this.opts),new hr(xE,this.uri(),r)}}function xE(n){const r=n.xdomain;try{if(typeof XMLHttpRequest<"u"&&(!r||_2))return new XMLHttpRequest}catch{}if(!r)try{return new Un[["Active"].concat("Object").join("X")]("Microsoft.XMLHTTP")}catch{}}const EE=typeof navigator<"u"&&typeof navigator.product=="string"&&navigator.product.toLowerCase()==="reactnative";class N2 extends hy{get name(){return"websocket"}doOpen(){const r=this.uri(),i=this.opts.protocols,l=EE?{}:gE(this.opts,"agent","perMessageDeflate","pfx","key","passphrase","cert","ca","ciphers","rejectUnauthorized","localAddress","protocolVersion","origin","maxPayload","family","checkServerIdentity");this.opts.extraHeaders&&(l.headers=this.opts.extraHeaders);try{this.ws=this.createSocket(r,i,l)}catch(u){return this.emitReserved("error",u)}this.ws.binaryType=this.socket.binaryType,this.addEventListeners()}addEventListeners(){this.ws.onopen=()=>{this.opts.autoUnref&&this.ws._socket.unref(),this.onOpen()},this.ws.onclose=r=>this.onClose({description:"websocket connection closed",context:r}),this.ws.onmessage=r=>this.onData(r.data),this.ws.onerror=r=>this.onError("websocket error",r)}write(r){this.writable=!1;for(let i=0;i<r.length;i++){const l=r[i],u=i===r.length-1;dy(l,this.supportsBinary,c=>{try{this.doWrite(l,c)}catch{}u&&qs(()=>{this.writable=!0,this.emitReserved("drain")},this.setTimeoutFn)})}}doClose(){typeof this.ws<"u"&&(this.ws.onerror=()=>{},this.ws.close(),this.ws=null)}uri(){const r=this.opts.secure?"wss":"ws",i=this.query||{};return this.opts.timestampRequests&&(i[this.opts.timestampParam]=bE()),this.supportsBinary||(i.b64=1),this.createUri(r,i)}}const Od=Un.WebSocket||Un.MozWebSocket;class M2 extends N2{createSocket(r,i,l){return EE?new Od(r,i,l):i?new Od(r,i):new Od(r)}doWrite(r,i){this.ws.send(i)}}class D2 extends hy{get name(){return"webtransport"}doOpen(){try{this._transport=new WebTransport(this.createUri("https"),this.opts.transportOptions[this.name])}catch(r){return this.emitReserved("error",r)}this._transport.closed.then(()=>{this.onClose()}).catch(r=>{this.onError("webtransport error",r)}),this._transport.ready.then(()=>{this._transport.createBidirectionalStream().then(r=>{const i=p2(Number.MAX_SAFE_INTEGER,this.socket.binaryType),l=r.readable.pipeThrough(i).getReader(),u=d2();u.readable.pipeTo(r.writable),this._writer=u.writable.getWriter();const c=()=>{l.read().then(({done:p,value:h})=>{p||(this.onPacket(h),c())}).catch(p=>{})};c();const d={type:"open"};this.query.sid&&(d.data=`{"sid":"${this.query.sid}"}`),this._writer.write(d).then(()=>this.onOpen())})})}write(r){this.writable=!1;for(let i=0;i<r.length;i++){const l=r[i],u=i===r.length-1;this._writer.write(l).then(()=>{u&&qs(()=>{this.writable=!0,this.emitReserved("drain")},this.setTimeoutFn)})}}doClose(){var r;(r=this._transport)===null||r===void 0||r.close()}}const j2={websocket:M2,webtransport:D2,polling:C2},B2=/^(?:(?![^:@\/?#]+:[^:@\/]*@)(http|https|ws|wss):\/\/)?((?:(([^:@\/?#]*)(?::([^:@\/?#]*))?)?@)?((?:[a-f0-9]{0,4}:){2,7}[a-f0-9]{0,4}|[^:\/?#]*)(?::(\d*))?)(((\/(?:[^?#](?![^?#\/]*\.[^?#\/.]+(?:[?#]|$)))*\/?)?([^?#\/]*))(?:\?([^#]*))?(?:#(.*))?)/,$2=["source","protocol","authority","userInfo","user","password","host","port","relative","path","directory","file","query","anchor"];function Nh(n){if(n.length>8e3)throw"URI too long";const r=n,i=n.indexOf("["),l=n.indexOf("]");i!=-1&&l!=-1&&(n=n.substring(0,i)+n.substring(i,l).replace(/:/g,";")+n.substring(l,n.length));let u=B2.exec(n||""),c={},d=14;for(;d--;)c[$2[d]]=u[d]||"";return i!=-1&&l!=-1&&(c.source=r,c.host=c.host.substring(1,c.host.length-1).replace(/;/g,":"),c.authority=c.authority.replace("[","").replace("]","").replace(/;/g,":"),c.ipv6uri=!0),c.pathNames=q2(c,c.path),c.queryKey=z2(c,c.query),c}function q2(n,r){const i=/\/{2,9}/g,l=r.replace(i,"/").split("/");return(r.slice(0,1)=="/"||r.length===0)&&l.splice(0,1),r.slice(-1)=="/"&&l.splice(l.length-1,1),l}function z2(n,r){const i={};return r.replace(/(?:^|&)([^&=]*)=?([^&]*)/g,function(l,u,c){u&&(i[u]=c)}),i}const Mh=typeof addEventListener=="function"&&typeof removeEventListener=="function",fs=[];Mh&&addEventListener("offline",()=>{fs.forEach(n=>n())},!1);class Ea extends Bt{constructor(r,i){if(super(),this.binaryType=y2,this.writeBuffer=[],this._prevBufferLen=0,this._pingInterval=-1,this._pingTimeout=-1,this._maxPayload=-1,this._pingTimeoutTime=1/0,r&&typeof r=="object"&&(i=r,r=null),r){const l=Nh(r);i.hostname=l.host,i.secure=l.protocol==="https"||l.protocol==="wss",i.port=l.port,l.query&&(i.query=l.query)}else i.host&&(i.hostname=Nh(i.host).host);zs(this,i),this.secure=i.secure!=null?i.secure:typeof location<"u"&&location.protocol==="https:",i.hostname&&!i.port&&(i.port=this.secure?"443":"80"),this.hostname=i.hostname||(typeof location<"u"?location.hostname:"localhost"),this.port=i.port||(typeof location<"u"&&location.port?location.port:this.secure?"443":"80"),this.transports=[],this._transportsByName={},i.transports.forEach(l=>{const u=l.prototype.name;this.transports.push(u),this._transportsByName[u]=l}),this.opts=Object.assign({path:"/engine.io",agent:!1,withCredentials:!1,upgrade:!0,timestampParam:"t",rememberUpgrade:!1,addTrailingSlash:!0,rejectUnauthorized:!0,perMessageDeflate:{threshold:1024},transportOptions:{},closeOnBeforeunload:!1},i),this.opts.path=this.opts.path.replace(/\/$/,"")+(this.opts.addTrailingSlash?"/":""),typeof this.opts.query=="string"&&(this.opts.query=E2(this.opts.query)),Mh&&(this.opts.closeOnBeforeunload&&(this._beforeunloadEventListener=()=>{this.transport&&(this.transport.removeAllListeners(),this.transport.close())},addEventListener("beforeunload",this._beforeunloadEventListener,!1)),this.hostname!=="localhost"&&(this._offlineEventListener=()=>{this._onClose("transport close",{description:"network connection lost"})},fs.push(this._offlineEventListener))),this.opts.withCredentials&&(this._cookieJar=void 0),this._open()}createTransport(r){const i=Object.assign({},this.opts.query);i.EIO=mE,i.transport=r,this.id&&(i.sid=this.id);const l=Object.assign({},this.opts,{query:i,socket:this,hostname:this.hostname,secure:this.secure,port:this.port},this.opts.transportOptions[r]);return new this._transportsByName[r](l)}_open(){if(this.transports.length===0){this.setTimeoutFn(()=>{this.emitReserved("error","No transports available")},0);return}const r=this.opts.rememberUpgrade&&Ea.priorWebsocketSuccess&&this.transports.indexOf("websocket")!==-1?"websocket":this.transports[0];this.readyState="opening";const i=this.createTransport(r);i.open(),this.setTransport(i)}setTransport(r){this.transport&&this.transport.removeAllListeners(),this.transport=r,r.on("drain",this._onDrain.bind(this)).on("packet",this._onPacket.bind(this)).on("error",this._onError.bind(this)).on("close",i=>this._onClose("transport close",i))}onOpen(){this.readyState="open",Ea.priorWebsocketSuccess=this.transport.name==="websocket",this.emitReserved("open"),this.flush()}_onPacket(r){if(this.readyState==="opening"||this.readyState==="open"||this.readyState==="closing")switch(this.emitReserved("packet",r),this.emitReserved("heartbeat"),r.type){case"open":this.onHandshake(JSON.parse(r.data));break;case"ping":this._sendPacket("pong"),this.emitReserved("ping"),this.emitReserved("pong"),this._resetPingTimeout();break;case"error":const i=new Error("server error");i.code=r.data,this._onError(i);break;case"message":this.emitReserved("data",r.data),this.emitReserved("message",r.data);break}}onHandshake(r){this.emitReserved("handshake",r),this.id=r.sid,this.transport.query.sid=r.sid,this._pingInterval=r.pingInterval,this._pingTimeout=r.pingTimeout,this._maxPayload=r.maxPayload,this.onOpen(),this.readyState!=="closed"&&this._resetPingTimeout()}_resetPingTimeout(){this.clearTimeoutFn(this._pingTimeoutTimer);const r=this._pingInterval+this._pingTimeout;this._pingTimeoutTime=Date.now()+r,this._pingTimeoutTimer=this.setTimeoutFn(()=>{this._onClose("ping timeout")},r),this.opts.autoUnref&&this._pingTimeoutTimer.unref()}_onDrain(){this.writeBuffer.splice(0,this._prevBufferLen),this._prevBufferLen=0,this.writeBuffer.length===0?this.emitReserved("drain"):this.flush()}flush(){if(this.readyState!=="closed"&&this.transport.writable&&!this.upgrading&&this.writeBuffer.length){const r=this._getWritablePackets();this.transport.send(r),this._prevBufferLen=r.length,this.emitReserved("flush")}}_getWritablePackets(){if(!(this._maxPayload&&this.transport.name==="polling"&&this.writeBuffer.length>1))return this.writeBuffer;let i=1;for(let l=0;l<this.writeBuffer.length;l++){const u=this.writeBuffer[l].data;if(u&&(i+=b2(u)),l>0&&i>this._maxPayload)return this.writeBuffer.slice(0,l);i+=2}return this.writeBuffer}_hasPingExpired(){if(!this._pingTimeoutTime)return!0;const r=Date.now()>this._pingTimeoutTime;return r&&(this._pingTimeoutTime=0,qs(()=>{this._onClose("ping timeout")},this.setTimeoutFn)),r}write(r,i,l){return this._sendPacket("message",r,i,l),this}send(r,i,l){return this._sendPacket("message",r,i,l),this}_sendPacket(r,i,l,u){if(typeof i=="function"&&(u=i,i=void 0),typeof l=="function"&&(u=l,l=null),this.readyState==="closing"||this.readyState==="closed")return;l=l||{},l.compress=l.compress!==!1;const c={type:r,data:i,options:l};this.emitReserved("packetCreate",c),this.writeBuffer.push(c),u&&this.once("flush",u),this.flush()}close(){const r=()=>{this._onClose("forced close"),this.transport.close()},i=()=>{this.off("upgrade",i),this.off("upgradeError",i),r()},l=()=>{this.once("upgrade",i),this.once("upgradeError",i)};return(this.readyState==="opening"||this.readyState==="open")&&(this.readyState="closing",this.writeBuffer.length?this.once("drain",()=>{this.upgrading?l():r()}):this.upgrading?l():r()),this}_onError(r){if(Ea.priorWebsocketSuccess=!1,this.opts.tryAllTransports&&this.transports.length>1&&this.readyState==="opening")return this.transports.shift(),this._open();this.emitReserved("error",r),this._onClose("transport error",r)}_onClose(r,i){if(this.readyState==="opening"||this.readyState==="open"||this.readyState==="closing"){if(this.clearTimeoutFn(this._pingTimeoutTimer),this.transport.removeAllListeners("close"),this.transport.close(),this.transport.removeAllListeners(),Mh&&(this._beforeunloadEventListener&&removeEventListener("beforeunload",this._beforeunloadEventListener,!1),this._offlineEventListener)){const l=fs.indexOf(this._offlineEventListener);l!==-1&&fs.splice(l,1)}this.readyState="closed",this.id=null,this.emitReserved("close",r,i),this.writeBuffer=[],this._prevBufferLen=0}}}Ea.protocol=mE;class k2 extends Ea{constructor(){super(...arguments),this._upgrades=[]}onOpen(){if(super.onOpen(),this.readyState==="open"&&this.opts.upgrade)for(let r=0;r<this._upgrades.length;r++)this._probe(this._upgrades[r])}_probe(r){let i=this.createTransport(r),l=!1;Ea.priorWebsocketSuccess=!1;const u=()=>{l||(i.send([{type:"ping",data:"probe"}]),i.once("packet",g=>{if(!l)if(g.type==="pong"&&g.data==="probe"){if(this.upgrading=!0,this.emitReserved("upgrading",i),!i)return;Ea.priorWebsocketSuccess=i.name==="websocket",this.transport.pause(()=>{l||this.readyState!=="closed"&&(m(),this.setTransport(i),i.send([{type:"upgrade"}]),this.emitReserved("upgrade",i),i=null,this.upgrading=!1,this.flush())})}else{const S=new Error("probe error");S.transport=i.name,this.emitReserved("upgradeError",S)}}))};function c(){l||(l=!0,m(),i.close(),i=null)}const d=g=>{const S=new Error("probe error: "+g);S.transport=i.name,c(),this.emitReserved("upgradeError",S)};function p(){d("transport closed")}function h(){d("socket closed")}function y(g){i&&g.name!==i.name&&c()}const m=()=>{i.removeListener("open",u),i.removeListener("error",d),i.removeListener("close",p),this.off("close",h),this.off("upgrading",y)};i.once("open",u),i.once("error",d),i.once("close",p),this.once("close",h),this.once("upgrading",y),this._upgrades.indexOf("webtransport")!==-1&&r!=="webtransport"?this.setTimeoutFn(()=>{l||i.open()},200):i.open()}onHandshake(r){this._upgrades=this._filterUpgrades(r.upgrades),super.onHandshake(r)}_filterUpgrades(r){const i=[];for(let l=0;l<r.length;l++)~this.transports.indexOf(r[l])&&i.push(r[l]);return i}}let L2=class extends k2{constructor(r,i={}){const l=typeof r=="object"?r:i;(!l.transports||l.transports&&typeof l.transports[0]=="string")&&(l.transports=(l.transports||["polling","websocket","webtransport"]).map(u=>j2[u]).filter(u=>!!u)),super(r,l)}};function U2(n,r="",i){let l=n;i=i||typeof location<"u"&&location,n==null&&(n=i.protocol+"//"+i.host),typeof n=="string"&&(n.charAt(0)==="/"&&(n.charAt(1)==="/"?n=i.protocol+n:n=i.host+n),/^(https?|wss?):\/\//.test(n)||(typeof i<"u"?n=i.protocol+"//"+n:n="https://"+n),l=Nh(n)),l.port||(/^(http|ws)$/.test(l.protocol)?l.port="80":/^(http|ws)s$/.test(l.protocol)&&(l.port="443")),l.path=l.path||"/";const c=l.host.indexOf(":")!==-1?"["+l.host+"]":l.host;return l.id=l.protocol+"://"+c+":"+l.port+r,l.href=l.protocol+"://"+c+(i&&i.port===l.port?"":":"+l.port),l}const H2=typeof ArrayBuffer=="function",G2=n=>typeof ArrayBuffer.isView=="function"?ArrayBuffer.isView(n):n.buffer instanceof ArrayBuffer,OE=Object.prototype.toString,Y2=typeof Blob=="function"||typeof Blob<"u"&&OE.call(Blob)==="[object BlobConstructor]",V2=typeof File=="function"||typeof File<"u"&&OE.call(File)==="[object FileConstructor]";function yy(n){return H2&&(n instanceof ArrayBuffer||G2(n))||Y2&&n instanceof Blob||V2&&n instanceof File}function ds(n,r){if(!n||typeof n!="object")return!1;if(Array.isArray(n)){for(let i=0,l=n.length;i<l;i++)if(ds(n[i]))return!0;return!1}if(yy(n))return!0;if(n.toJSON&&typeof n.toJSON=="function"&&arguments.length===1)return ds(n.toJSON(),!0);for(const i in n)if(Object.prototype.hasOwnProperty.call(n,i)&&ds(n[i]))return!0;return!1}function P2(n){const r=[],i=n.data,l=n;return l.data=Dh(i,r),l.attachments=r.length,{packet:l,buffers:r}}function Dh(n,r){if(!n)return n;if(yy(n)){const i={_placeholder:!0,num:r.length};return r.push(n),i}else if(Array.isArray(n)){const i=new Array(n.length);for(let l=0;l<n.length;l++)i[l]=Dh(n[l],r);return i}else if(typeof n=="object"&&!(n instanceof Date)){const i={};for(const l in n)Object.prototype.hasOwnProperty.call(n,l)&&(i[l]=Dh(n[l],r));return i}return n}function X2(n,r){return n.data=jh(n.data,r),delete n.attachments,n}function jh(n,r){if(!n)return n;if(n&&n._placeholder===!0){if(typeof n.num=="number"&&n.num>=0&&n.num<r.length)return r[n.num];throw new Error("illegal attachments")}else if(Array.isArray(n))for(let i=0;i<n.length;i++)n[i]=jh(n[i],r);else if(typeof n=="object")for(const i in n)Object.prototype.hasOwnProperty.call(n,i)&&(n[i]=jh(n[i],r));return n}const Q2=["connect","connect_error","disconnect","disconnecting","newListener","removeListener"],K2=5;var Ve;(function(n){n[n.CONNECT=0]="CONNECT",n[n.DISCONNECT=1]="DISCONNECT",n[n.EVENT=2]="EVENT",n[n.ACK=3]="ACK",n[n.CONNECT_ERROR=4]="CONNECT_ERROR",n[n.BINARY_EVENT=5]="BINARY_EVENT",n[n.BINARY_ACK=6]="BINARY_ACK"})(Ve||(Ve={}));class F2{constructor(r){this.replacer=r}encode(r){return(r.type===Ve.EVENT||r.type===Ve.ACK)&&ds(r)?this.encodeAsBinary({type:r.type===Ve.EVENT?Ve.BINARY_EVENT:Ve.BINARY_ACK,nsp:r.nsp,data:r.data,id:r.id}):[this.encodeAsString(r)]}encodeAsString(r){let i=""+r.type;return(r.type===Ve.BINARY_EVENT||r.type===Ve.BINARY_ACK)&&(i+=r.attachments+"-"),r.nsp&&r.nsp!=="/"&&(i+=r.nsp+","),r.id!=null&&(i+=r.id),r.data!=null&&(i+=JSON.stringify(r.data,this.replacer)),i}encodeAsBinary(r){const i=P2(r),l=this.encodeAsString(i.packet),u=i.buffers;return u.unshift(l),u}}function yb(n){return Object.prototype.toString.call(n)==="[object Object]"}class vy extends Bt{constructor(r){super(),this.reviver=r}add(r){let i;if(typeof r=="string"){if(this.reconstructor)throw new Error("got plaintext data when reconstructing a packet");i=this.decodeString(r);const l=i.type===Ve.BINARY_EVENT;l||i.type===Ve.BINARY_ACK?(i.type=l?Ve.EVENT:Ve.ACK,this.reconstructor=new Z2(i),i.attachments===0&&super.emitReserved("decoded",i)):super.emitReserved("decoded",i)}else if(yy(r)||r.base64)if(this.reconstructor)i=this.reconstructor.takeBinaryData(r),i&&(this.reconstructor=null,super.emitReserved("decoded",i));else throw new Error("got binary data when not reconstructing a packet");else throw new Error("Unknown type: "+r)}decodeString(r){let i=0;const l={type:Number(r.charAt(0))};if(Ve[l.type]===void 0)throw new Error("unknown packet type "+l.type);if(l.type===Ve.BINARY_EVENT||l.type===Ve.BINARY_ACK){const c=i+1;for(;r.charAt(++i)!=="-"&&i!=r.length;);const d=r.substring(c,i);if(d!=Number(d)||r.charAt(i)!=="-")throw new Error("Illegal attachments");l.attachments=Number(d)}if(r.charAt(i+1)==="/"){const c=i+1;for(;++i&&!(r.charAt(i)===","||i===r.length););l.nsp=r.substring(c,i)}else l.nsp="/";const u=r.charAt(i+1);if(u!==""&&Number(u)==u){const c=i+1;for(;++i;){const d=r.charAt(i);if(d==null||Number(d)!=d){--i;break}if(i===r.length)break}l.id=Number(r.substring(c,i+1))}if(r.charAt(++i)){const c=this.tryParse(r.substr(i));if(vy.isPayloadValid(l.type,c))l.data=c;else throw new Error("invalid payload")}return l}tryParse(r){try{return JSON.parse(r,this.reviver)}catch{return!1}}static isPayloadValid(r,i){switch(r){case Ve.CONNECT:return yb(i);case Ve.DISCONNECT:return i===void 0;case Ve.CONNECT_ERROR:return typeof i=="string"||yb(i);case Ve.EVENT:case Ve.BINARY_EVENT:return Array.isArray(i)&&(typeof i[0]=="number"||typeof i[0]=="string"&&Q2.indexOf(i[0])===-1);case Ve.ACK:case Ve.BINARY_ACK:return Array.isArray(i)}}destroy(){this.reconstructor&&(this.reconstructor.finishedReconstruction(),this.reconstructor=null)}}class Z2{constructor(r){this.packet=r,this.buffers=[],this.reconPack=r}takeBinaryData(r){if(this.buffers.push(r),this.buffers.length===this.reconPack.attachments){const i=X2(this.reconPack,this.buffers);return this.finishedReconstruction(),i}return null}finishedReconstruction(){this.reconPack=null,this.buffers=[]}}const I2=Object.freeze(Object.defineProperty({__proto__:null,Decoder:vy,Encoder:F2,get PacketType(){return Ve},protocol:K2},Symbol.toStringTag,{value:"Module"}));function Wn(n,r,i){return n.on(r,i),function(){n.off(r,i)}}const W2=Object.freeze({connect:1,connect_error:1,disconnect:1,disconnecting:1,newListener:1,removeListener:1});class TE extends Bt{constructor(r,i,l){super(),this.connected=!1,this.recovered=!1,this.receiveBuffer=[],this.sendBuffer=[],this._queue=[],this._queueSeq=0,this.ids=0,this.acks={},this.flags={},this.io=r,this.nsp=i,l&&l.auth&&(this.auth=l.auth),this._opts=Object.assign({},l),this.io._autoConnect&&this.open()}get disconnected(){return!this.connected}subEvents(){if(this.subs)return;const r=this.io;this.subs=[Wn(r,"open",this.onopen.bind(this)),Wn(r,"packet",this.onpacket.bind(this)),Wn(r,"error",this.onerror.bind(this)),Wn(r,"close",this.onclose.bind(this))]}get active(){return!!this.subs}connect(){return this.connected?this:(this.subEvents(),this.io._reconnecting||this.io.open(),this.io._readyState==="open"&&this.onopen(),this)}open(){return this.connect()}send(...r){return r.unshift("message"),this.emit.apply(this,r),this}emit(r,...i){var l,u,c;if(W2.hasOwnProperty(r))throw new Error('"'+r.toString()+'" is a reserved event name');if(i.unshift(r),this._opts.retries&&!this.flags.fromQueue&&!this.flags.volatile)return this._addToQueue(i),this;const d={type:Ve.EVENT,data:i};if(d.options={},d.options.compress=this.flags.compress!==!1,typeof i[i.length-1]=="function"){const m=this.ids++,g=i.pop();this._registerAckCallback(m,g),d.id=m}const p=(u=(l=this.io.engine)===null||l===void 0?void 0:l.transport)===null||u===void 0?void 0:u.writable,h=this.connected&&!(!((c=this.io.engine)===null||c===void 0)&&c._hasPingExpired());return this.flags.volatile&&!p||(h?(this.notifyOutgoingListeners(d),this.packet(d)):this.sendBuffer.push(d)),this.flags={},this}_registerAckCallback(r,i){var l;const u=(l=this.flags.timeout)!==null&&l!==void 0?l:this._opts.ackTimeout;if(u===void 0){this.acks[r]=i;return}const c=this.io.setTimeoutFn(()=>{delete this.acks[r];for(let p=0;p<this.sendBuffer.length;p++)this.sendBuffer[p].id===r&&this.sendBuffer.splice(p,1);i.call(this,new Error("operation has timed out"))},u),d=(...p)=>{this.io.clearTimeoutFn(c),i.apply(this,p)};d.withError=!0,this.acks[r]=d}emitWithAck(r,...i){return new Promise((l,u)=>{const c=(d,p)=>d?u(d):l(p);c.withError=!0,i.push(c),this.emit(r,...i)})}_addToQueue(r){let i;typeof r[r.length-1]=="function"&&(i=r.pop());const l={id:this._queueSeq++,tryCount:0,pending:!1,args:r,flags:Object.assign({fromQueue:!0},this.flags)};r.push((u,...c)=>l!==this._queue[0]?void 0:(u!==null?l.tryCount>this._opts.retries&&(this._queue.shift(),i&&i(u)):(this._queue.shift(),i&&i(null,...c)),l.pending=!1,this._drainQueue())),this._queue.push(l),this._drainQueue()}_drainQueue(r=!1){if(!this.connected||this._queue.length===0)return;const i=this._queue[0];i.pending&&!r||(i.pending=!0,i.tryCount++,this.flags=i.flags,this.emit.apply(this,i.args))}packet(r){r.nsp=this.nsp,this.io._packet(r)}onopen(){typeof this.auth=="function"?this.auth(r=>{this._sendConnectPacket(r)}):this._sendConnectPacket(this.auth)}_sendConnectPacket(r){this.packet({type:Ve.CONNECT,data:this._pid?Object.assign({pid:this._pid,offset:this._lastOffset},r):r})}onerror(r){this.connected||this.emitReserved("connect_error",r)}onclose(r,i){this.connected=!1,delete this.id,this.emitReserved("disconnect",r,i),this._clearAcks()}_clearAcks(){Object.keys(this.acks).forEach(r=>{if(!this.sendBuffer.some(l=>String(l.id)===r)){const l=this.acks[r];delete this.acks[r],l.withError&&l.call(this,new Error("socket has been disconnected"))}})}onpacket(r){if(r.nsp===this.nsp)switch(r.type){case Ve.CONNECT:r.data&&r.data.sid?this.onconnect(r.data.sid,r.data.pid):this.emitReserved("connect_error",new Error("It seems you are trying to reach a Socket.IO server in v2.x with a v3.x client, but they are not compatible (more information here: https://socket.io/docs/v3/migrating-from-2-x-to-3-0/)"));break;case Ve.EVENT:case Ve.BINARY_EVENT:this.onevent(r);break;case Ve.ACK:case Ve.BINARY_ACK:this.onack(r);break;case Ve.DISCONNECT:this.ondisconnect();break;case Ve.CONNECT_ERROR:this.destroy();const l=new Error(r.data.message);l.data=r.data.data,this.emitReserved("connect_error",l);break}}onevent(r){const i=r.data||[];r.id!=null&&i.push(this.ack(r.id)),this.connected?this.emitEvent(i):this.receiveBuffer.push(Object.freeze(i))}emitEvent(r){if(this._anyListeners&&this._anyListeners.length){const i=this._anyListeners.slice();for(const l of i)l.apply(this,r)}super.emit.apply(this,r),this._pid&&r.length&&typeof r[r.length-1]=="string"&&(this._lastOffset=r[r.length-1])}ack(r){const i=this;let l=!1;return function(...u){l||(l=!0,i.packet({type:Ve.ACK,id:r,data:u}))}}onack(r){const i=this.acks[r.id];typeof i=="function"&&(delete this.acks[r.id],i.withError&&r.data.unshift(null),i.apply(this,r.data))}onconnect(r,i){this.id=r,this.recovered=i&&this._pid===i,this._pid=i,this.connected=!0,this.emitBuffered(),this.emitReserved("connect"),this._drainQueue(!0)}emitBuffered(){this.receiveBuffer.forEach(r=>this.emitEvent(r)),this.receiveBuffer=[],this.sendBuffer.forEach(r=>{this.notifyOutgoingListeners(r),this.packet(r)}),this.sendBuffer=[]}ondisconnect(){this.destroy(),this.onclose("io server disconnect")}destroy(){this.subs&&(this.subs.forEach(r=>r()),this.subs=void 0),this.io._destroy(this)}disconnect(){return this.connected&&this.packet({type:Ve.DISCONNECT}),this.destroy(),this.connected&&this.onclose("io client disconnect"),this}close(){return this.disconnect()}compress(r){return this.flags.compress=r,this}get volatile(){return this.flags.volatile=!0,this}timeout(r){return this.flags.timeout=r,this}onAny(r){return this._anyListeners=this._anyListeners||[],this._anyListeners.push(r),this}prependAny(r){return this._anyListeners=this._anyListeners||[],this._anyListeners.unshift(r),this}offAny(r){if(!this._anyListeners)return this;if(r){const i=this._anyListeners;for(let l=0;l<i.length;l++)if(r===i[l])return i.splice(l,1),this}else this._anyListeners=[];return this}listenersAny(){return this._anyListeners||[]}onAnyOutgoing(r){return this._anyOutgoingListeners=this._anyOutgoingListeners||[],this._anyOutgoingListeners.push(r),this}prependAnyOutgoing(r){return this._anyOutgoingListeners=this._anyOutgoingListeners||[],this._anyOutgoingListeners.unshift(r),this}offAnyOutgoing(r){if(!this._anyOutgoingListeners)return this;if(r){const i=this._anyOutgoingListeners;for(let l=0;l<i.length;l++)if(r===i[l])return i.splice(l,1),this}else this._anyOutgoingListeners=[];return this}listenersAnyOutgoing(){return this._anyOutgoingListeners||[]}notifyOutgoingListeners(r){if(this._anyOutgoingListeners&&this._anyOutgoingListeners.length){const i=this._anyOutgoingListeners.slice();for(const l of i)l.apply(this,r.data)}}}function rl(n){n=n||{},this.ms=n.min||100,this.max=n.max||1e4,this.factor=n.factor||2,this.jitter=n.jitter>0&&n.jitter<=1?n.jitter:0,this.attempts=0}rl.prototype.duration=function(){var n=this.ms*Math.pow(this.factor,this.attempts++);if(this.jitter){var r=Math.random(),i=Math.floor(r*this.jitter*n);n=(Math.floor(r*10)&1)==0?n-i:n+i}return Math.min(n,this.max)|0};rl.prototype.reset=function(){this.attempts=0};rl.prototype.setMin=function(n){this.ms=n};rl.prototype.setMax=function(n){this.max=n};rl.prototype.setJitter=function(n){this.jitter=n};class Bh extends Bt{constructor(r,i){var l;super(),this.nsps={},this.subs=[],r&&typeof r=="object"&&(i=r,r=void 0),i=i||{},i.path=i.path||"/socket.io",this.opts=i,zs(this,i),this.reconnection(i.reconnection!==!1),this.reconnectionAttempts(i.reconnectionAttempts||1/0),this.reconnectionDelay(i.reconnectionDelay||1e3),this.reconnectionDelayMax(i.reconnectionDelayMax||5e3),this.randomizationFactor((l=i.randomizationFactor)!==null&&l!==void 0?l:.5),this.backoff=new rl({min:this.reconnectionDelay(),max:this.reconnectionDelayMax(),jitter:this.randomizationFactor()}),this.timeout(i.timeout==null?2e4:i.timeout),this._readyState="closed",this.uri=r;const u=i.parser||I2;this.encoder=new u.Encoder,this.decoder=new u.Decoder,this._autoConnect=i.autoConnect!==!1,this._autoConnect&&this.open()}reconnection(r){return arguments.length?(this._reconnection=!!r,r||(this.skipReconnect=!0),this):this._reconnection}reconnectionAttempts(r){return r===void 0?this._reconnectionAttempts:(this._reconnectionAttempts=r,this)}reconnectionDelay(r){var i;return r===void 0?this._reconnectionDelay:(this._reconnectionDelay=r,(i=this.backoff)===null||i===void 0||i.setMin(r),this)}randomizationFactor(r){var i;return r===void 0?this._randomizationFactor:(this._randomizationFactor=r,(i=this.backoff)===null||i===void 0||i.setJitter(r),this)}reconnectionDelayMax(r){var i;return r===void 0?this._reconnectionDelayMax:(this._reconnectionDelayMax=r,(i=this.backoff)===null||i===void 0||i.setMax(r),this)}timeout(r){return arguments.length?(this._timeout=r,this):this._timeout}maybeReconnectOnOpen(){!this._reconnecting&&this._reconnection&&this.backoff.attempts===0&&this.reconnect()}open(r){if(~this._readyState.indexOf("open"))return this;this.engine=new L2(this.uri,this.opts);const i=this.engine,l=this;this._readyState="opening",this.skipReconnect=!1;const u=Wn(i,"open",function(){l.onopen(),r&&r()}),c=p=>{this.cleanup(),this._readyState="closed",this.emitReserved("error",p),r?r(p):this.maybeReconnectOnOpen()},d=Wn(i,"error",c);if(this._timeout!==!1){const p=this._timeout,h=this.setTimeoutFn(()=>{u(),c(new Error("timeout")),i.close()},p);this.opts.autoUnref&&h.unref(),this.subs.push(()=>{this.clearTimeoutFn(h)})}return this.subs.push(u),this.subs.push(d),this}connect(r){return this.open(r)}onopen(){this.cleanup(),this._readyState="open",this.emitReserved("open");const r=this.engine;this.subs.push(Wn(r,"ping",this.onping.bind(this)),Wn(r,"data",this.ondata.bind(this)),Wn(r,"error",this.onerror.bind(this)),Wn(r,"close",this.onclose.bind(this)),Wn(this.decoder,"decoded",this.ondecoded.bind(this)))}onping(){this.emitReserved("ping")}ondata(r){try{this.decoder.add(r)}catch(i){this.onclose("parse error",i)}}ondecoded(r){qs(()=>{this.emitReserved("packet",r)},this.setTimeoutFn)}onerror(r){this.emitReserved("error",r)}socket(r,i){let l=this.nsps[r];return l?this._autoConnect&&!l.active&&l.connect():(l=new TE(this,r,i),this.nsps[r]=l),l}_destroy(r){const i=Object.keys(this.nsps);for(const l of i)if(this.nsps[l].active)return;this._close()}_packet(r){const i=this.encoder.encode(r);for(let l=0;l<i.length;l++)this.engine.write(i[l],r.options)}cleanup(){this.subs.forEach(r=>r()),this.subs.length=0,this.decoder.destroy()}_close(){this.skipReconnect=!0,this._reconnecting=!1,this.onclose("forced close")}disconnect(){return this._close()}onclose(r,i){var l;this.cleanup(),(l=this.engine)===null||l===void 0||l.close(),this.backoff.reset(),this._readyState="closed",this.emitReserved("close",r,i),this._reconnection&&!this.skipReconnect&&this.reconnect()}reconnect(){if(this._reconnecting||this.skipReconnect)return this;const r=this;if(this.backoff.attempts>=this._reconnectionAttempts)this.backoff.reset(),this.emitReserved("reconnect_failed"),this._reconnecting=!1;else{const i=this.backoff.duration();this._reconnecting=!0;const l=this.setTimeoutFn(()=>{r.skipReconnect||(this.emitReserved("reconnect_attempt",r.backoff.attempts),!r.skipReconnect&&r.open(u=>{u?(r._reconnecting=!1,r.reconnect(),this.emitReserved("reconnect_error",u)):r.onreconnect()}))},i);this.opts.autoUnref&&l.unref(),this.subs.push(()=>{this.clearTimeoutFn(l)})}}onreconnect(){const r=this.backoff.attempts;this._reconnecting=!1,this.backoff.reset(),this.emitReserved("reconnect",r)}}const to={};function ps(n,r){typeof n=="object"&&(r=n,n=void 0),r=r||{};const i=U2(n,r.path||"/socket.io"),l=i.source,u=i.id,c=i.path,d=to[u]&&c in to[u].nsps,p=r.forceNew||r["force new connection"]||r.multiplex===!1||d;let h;return p?h=new Bh(l,r):(to[u]||(to[u]=new Bh(l,r)),h=to[u]),i.query&&!r.query&&(r.query=i.queryKey),h.socket(i.path,r)}Object.assign(ps,{Manager:Bh,Socket:TE,io:ps,connect:ps});const _E=(n,r)=>{if(typeof n=="number")return{full_access_path:r,doc:null,readonly:!1,type:Number.isInteger(n)?"int":"float",value:n};if(typeof n=="boolean")return{full_access_path:r,doc:null,readonly:!1,type:"bool",value:n};if(typeof n=="string")return{full_access_path:r,doc:null,readonly:!1,type:"str",value:n};if(n===null)return{full_access_path:r,doc:null,readonly:!1,type:"None",value:null};throw new Error("Unsupported type for serialization")},J2=(n,r="")=>{const l=n.map((u,c)=>{(typeof u=="number"||typeof u=="boolean"||typeof u=="string"||u===null)&&_E(u,`${r}[${c}]`)});return{full_access_path:r,type:"list",value:l,readonly:!1,doc:null}},eC=(n,r="")=>{const l=Object.entries(n).reduce((u,[c,d])=>{const p=`${r}["${c}"]`;return(typeof d=="number"||typeof d=="boolean"||typeof d=="string"||d===null)&&(u[c]=_E(d,p)),u},{});return{full_access_path:r,type:"dict",value:l,readonly:!1,doc:null}},AE=window.location.hostname,RE=window.location.port,wE=window.__FORWARDED_PREFIX__||"",so=window.__FORWARDED_PROTO__||"http",Pi=`${AE}:${RE}${wE}`,tC=so==="http"?"ws":"wss",nC=`${tC}://${AE}:${RE}/`,kr=ps(nC,{path:`${wE}/ws/socket.io`,transports:["websocket"]}),rC=(n,r)=>{r?kr.emit("update_value",{access_path:n.full_access_path,value:n},r):kr.emit("update_value",{access_path:n.full_access_path,value:n})},CE=(n,r=[],i={},l)=>{const u=J2(r),c=eC(i);kr.emit("trigger_method",{access_path:n,args:u,kwargs:c})},NE=Xe.memo(n=>{const{showNotification:r,notifications:i,removeNotificationById:l}=n;return T.jsx(cy,{className:"navbarOffset toastContainer",position:"top-end",children:i.map(u=>u.levelname==="ERROR"||u.levelname==="CRITICAL"||r&&["WARNING","INFO","DEBUG"].includes(u.levelname)?T.jsxs(ho,{className:u.levelname.toLowerCase()+"Toast",onClose:()=>l(u.id),onClick:()=>l(u.id),onMouseLeave:()=>{u.levelname!=="ERROR"&&l(u.id)},show:!0,autohide:u.levelname==="WARNING"||u.levelname==="INFO"||u.levelname==="DEBUG",delay:u.levelname==="WARNING"||u.levelname==="INFO"||u.levelname==="DEBUG"?2e3:void 0,children:[T.jsxs(ho.Header,{closeButton:!1,className:u.levelname.toLowerCase()+"Toast text-right",children:[T.jsx("strong",{className:"me-auto",children:u.levelname}),T.jsx("small",{children:u.timeStamp})]}),T.jsx(ho.Body,{children:u.message})]},u.id):null)})});NE.displayName="Notifications";const $h=Xe.memo(({connectionStatus:n})=>{const[r,i]=x.useState(!0);x.useEffect(()=>{i(!0)},[n]);const l=()=>i(!1),u=()=>{switch(n){case"connecting":return{message:"Connecting...",bg:"info",delay:void 0};case"connected":return{message:"Connected",bg:"success",delay:1e3};case"disconnected":return{message:"Disconnected",bg:"danger",delay:void 0};case"reconnecting":return{message:"Reconnecting...",bg:"info",delay:void 0};default:return{message:"",bg:"info",delay:void 0}}},{message:c,bg:d,delay:p}=u();return T.jsx(cy,{position:"bottom-center",className:"toastContainer",children:T.jsx(ho,{show:r,onClose:l,delay:p,autohide:p!==void 0,bg:d,children:T.jsxs(ho.Body,{className:"d-flex justify-content-between",children:[c,T.jsx(Co,{variant:"close",size:"sm",onClick:l})]})})})});$h.displayName="ConnectionToast";function ME(n){const r=/\w+|\[\d+\.\d+\]|\[\d+\]|\["[^"]*"\]|\['[^']*'\]/g;return n.match(r)??[]}function aC(n){if(n.startsWith("[")&&n.endsWith("]")&&(n=n.slice(1,-1)),n.startsWith("'")&&n.endsWith("'")||n.startsWith('"')&&n.endsWith('"'))return n.slice(1,-1);const r=parseFloat(n);return isNaN(r)?n:r}function iC(n,r,i){if(r in n)return n[r];if(Array.isArray(n)){if(i&&r===n.length)return n.push(mb()),n[r];throw new Error(`Index out of bounds: ${r}`)}else{if(i)return n[r]=mb(),n[r];throw new Error(`Key not found: ${r}`)}}function vb(n,r,i=!1){const l=aC(r);try{return iC(n,l,i)}catch(u){throw u instanceof RangeError?new Error(`Index '${l}': ${u.message}`):u instanceof Error?new Error(`Key '${l}': ${u.message}`):u}}function lC(n,r,i){const l=ME(r),u=JSON.parse(JSON.stringify(n));let c=u;try{for(let h=0;h<l.length-1;h++){const y=l[h];c=vb(c,y,!1).value}const d=l[l.length-1],p=vb(c,d,!0);return Object.assign(p,i),u}catch{}return{}}function mb(){return{full_access_path:"",value:null,type:"None",doc:null,readonly:!1}}const my=x.createContext({}),tr=Xe.memo(n=>{const{docString:r}=n;if(!r)return null;const i=T.jsx(aE,{id:"tooltip",children:r});return T.jsx(n2,{placement:"bottom",overlay:i,children:T.jsx(ex,{pill:!0,className:"tooltip-trigger",bg:"light",text:"dark",children:"?"})})});tr.displayName="DocStringComponent";function gr(){const n=x.useRef(0);return x.useEffect(()=>{n.current+=1}),n.current}const DE=Xe.memo(n=>{const{value:r,fullAccessPath:i,readOnly:l,docString:u,addNotification:c,changeCallback:d=()=>{},displayName:p,id:h}=n;gr(),x.useEffect(()=>{c(`${i} changed to ${r}.`)},[n.value]);const y=m=>{d({type:"bool",value:m,full_access_path:i,readonly:l,doc:u})};return T.jsxs("div",{className:"component buttonComponent",id:h,children:[!1,T.jsxs(fy,{id:`toggle-check-${h}`,type:"checkbox",variant:r?"success":"secondary",checked:r,value:p,disabled:l,onChange:m=>y(m.currentTarget.checked),children:[p,T.jsx(tr,{docString:u})]})]})});DE.displayName="ButtonComponent";const oC=(n,r,i)=>{const l=r.split("."),u=l[0].length,c=l[1]?l[1].length:0,d=i>u;let p=0;d?p=Math.pow(10,u+1-i):p=Math.pow(10,u-i);const y=(parseFloat(r)+(n==="ArrowUp"?p:-p)).toFixed(c),m=y.split(".")[0].length;return m>u?i+=1:m<u&&(i-=1),{value:y,selectionStart:i}},uC=(n,r,i)=>i>r?{value:n.slice(0,r)+n.slice(i),selectionStart:r}:r>0?{value:n.slice(0,r-1)+n.slice(r),selectionStart:r-1}:{value:n,selectionStart:r},sC=(n,r,i)=>i>r?{value:n.slice(0,r)+n.slice(i),selectionStart:r}:r<n.length?{value:n.slice(0,r)+n.slice(r+1),selectionStart:r}:{value:n,selectionStart:r},gb=(n,r,i,l)=>{let u=r;return n==="."&&r.includes(".")?{value:r,selectionStart:i}:n==="-"?(i===0&&l>i?(u="-"+r.slice(l),i=1):i===0&&!r.startsWith("-")?(u="-"+r,i=1):(i===0||i===1)&&r.startsWith("-")&&(u=r.slice(1),i=0),{value:u,selectionStart:i}):(l>i?u=r.slice(0,i)+n+r.slice(l):u=r.slice(0,i)+n+r.slice(i),{value:u,selectionStart:i+1})},cC=(n,r)=>Math.max(0,n-r),fC=(n,r,i)=>Math.min(i,n+r),_s=Xe.memo(n=>{const{fullAccessPath:r,value:i,readOnly:l,type:u,docString:c,isInstantUpdate:d,unit:p,addNotification:h,changeCallback:y=()=>{},displayName:m,id:g}=n,S=x.useRef(null),[R,_]=x.useState(i.toString());gr();const E=j=>{const{key:M,target:B}=j,X=B,{value:A}=X,$=A.length,O=X.selectionEnd??0;let q=X.selectionStart??0;if(M==="F1"||M==="F5"||M==="F12"||M==="Tab")return;if(M==="ArrowLeft"||M==="ArrowRight"){if(O>q&&!j.shiftKey){const W=M==="ArrowLeft"?q:O;S.current=W}else{const W=M==="ArrowLeft"?cC(q,1):fC(O,1,$);S.current=W}return}j.preventDefault();let L=A;if(j.ctrlKey&&M==="a"){X.setSelectionRange(0,A.length);return}else if(M>="0"&&M<="9"||M==="-")({value:L,selectionStart:q}=gb(M,A,q,O));else if(M==="."&&(u==="float"||u==="Quantity"))({value:L,selectionStart:q}=gb(M,A,q,O));else if(M==="ArrowUp"||M==="ArrowDown")({value:L,selectionStart:q}=oC(M,A,q));else if(M==="Backspace")({value:L,selectionStart:q}=uC(A,q,O));else if(M==="Delete")({value:L,selectionStart:q}=sC(A,q,O));else if(M==="Enter"&&!d){let Y;u==="Quantity"?Y={type:"Quantity",value:{magnitude:Number(L),unit:p},full_access_path:r,readonly:l,doc:c}:Y={type:u,value:Number(L),full_access_path:r,readonly:l,doc:c},y(Y);return}else return;if(d){let Y;u==="Quantity"?Y={type:"Quantity",value:{magnitude:Number(L),unit:p},full_access_path:r,readonly:l,doc:c}:Y={type:u,value:Number(L),full_access_path:r,readonly:l,doc:c},y(Y)}_(L),S.current=q},C=()=>{if(!d){let j;u==="Quantity"?j={type:"Quantity",value:{magnitude:Number(R),unit:p},full_access_path:r,readonly:l,doc:c}:j={type:u,value:Number(R),full_access_path:r,readonly:l,doc:c},y(j)}};return x.useEffect(()=>{const j=u==="int"?parseInt(R):parseFloat(R);i!==j&&_(i.toString());let M=`${r} changed to ${n.value}`;p===void 0?M+=".":M+=` ${p}.`,h(M)},[i]),x.useEffect(()=>{const j=document.getElementsByName(g)[0];j&&S.current!==null&&j.setSelectionRange(S.current,S.current)}),T.jsxs("div",{className:"component numberComponent",id:g,children:[!1,T.jsxs(Yr,{children:[m&&T.jsxs(Yr.Text,{children:[m,T.jsx(tr,{docString:c})]}),T.jsx(an.Control,{type:"text",value:R,disabled:l,onChange:()=>{},name:g,onKeyDown:E,onBlur:C,className:d&&!l?"instantUpdate":""}),p&&T.jsx(Yr.Text,{children:p})]})]})});_s.displayName="NumberComponent";const xo={black:"#000",white:"#fff"},ki={300:"#e57373",400:"#ef5350",500:"#f44336",700:"#d32f2f",800:"#c62828"},Li={50:"#f3e5f5",200:"#ce93d8",300:"#ba68c8",400:"#ab47bc",500:"#9c27b0",700:"#7b1fa2"},Ui={50:"#e3f2fd",200:"#90caf9",400:"#42a5f5",700:"#1976d2",800:"#1565c0"},Hi={300:"#4fc3f7",400:"#29b6f6",500:"#03a9f4",700:"#0288d1",900:"#01579b"},Gi={300:"#81c784",400:"#66bb6a",500:"#4caf50",700:"#388e3c",800:"#2e7d32",900:"#1b5e20"},no={300:"#ffb74d",400:"#ffa726",500:"#ff9800",700:"#f57c00",900:"#e65100"},dC={50:"#fafafa",100:"#f5f5f5",200:"#eeeeee",300:"#e0e0e0",400:"#bdbdbd",500:"#9e9e9e",600:"#757575",700:"#616161",800:"#424242",900:"#212121",A100:"#f5f5f5",A200:"#eeeeee",A400:"#bdbdbd",A700:"#616161"};function Eo(n){let r="https://mui.com/production-error/?code="+n;for(let i=1;i<arguments.length;i+=1)r+="&args[]="+encodeURIComponent(arguments[i]);return"Minified MUI error #"+n+"; visit "+r+" for the full message."}const pC=Object.freeze(Object.defineProperty({__proto__:null,default:Eo},Symbol.toStringTag,{value:"Module"})),hC="$$material";function yC(n){if(n.sheet)return n.sheet;for(var r=0;r<document.styleSheets.length;r++)if(document.styleSheets[r].ownerNode===n)return document.styleSheets[r]}function vC(n){var r=document.createElement("style");return r.setAttribute("data-emotion",n.key),n.nonce!==void 0&&r.setAttribute("nonce",n.nonce),r.appendChild(document.createTextNode("")),r.setAttribute("data-s",""),r}var mC=function(){function n(i){var l=this;this._insertTag=function(u){var c;l.tags.length===0?l.insertionPoint?c=l.insertionPoint.nextSibling:l.prepend?c=l.container.firstChild:c=l.before:c=l.tags[l.tags.length-1].nextSibling,l.container.insertBefore(u,c),l.tags.push(u)},this.isSpeedy=i.speedy===void 0?!0:i.speedy,this.tags=[],this.ctr=0,this.nonce=i.nonce,this.key=i.key,this.container=i.container,this.prepend=i.prepend,this.insertionPoint=i.insertionPoint,this.before=null}var r=n.prototype;return r.hydrate=function(l){l.forEach(this._insertTag)},r.insert=function(l){this.ctr%(this.isSpeedy?65e3:1)===0&&this._insertTag(vC(this));var u=this.tags[this.tags.length-1];if(this.isSpeedy){var c=yC(u);try{c.insertRule(l,c.cssRules.length)}catch{}}else u.appendChild(document.createTextNode(l));this.ctr++},r.flush=function(){this.tags.forEach(function(l){var u;return(u=l.parentNode)==null?void 0:u.removeChild(l)}),this.tags=[],this.ctr=0},n}(),en="-ms-",As="-moz-",et="-webkit-",jE="comm",gy="rule",by="decl",gC="@import",BE="@keyframes",bC="@layer",SC=Math.abs,ks=String.fromCharCode,xC=Object.assign;function EC(n,r){return It(n,0)^45?(((r<<2^It(n,0))<<2^It(n,1))<<2^It(n,2))<<2^It(n,3):0}function $E(n){return n.trim()}function OC(n,r){return(n=r.exec(n))?n[0]:n}function tt(n,r,i){return n.replace(r,i)}function qh(n,r){return n.indexOf(r)}function It(n,r){return n.charCodeAt(r)|0}function Oo(n,r,i){return n.slice(r,i)}function sr(n){return n.length}function Sy(n){return n.length}function Ju(n,r){return r.push(n),n}function TC(n,r){return n.map(r).join("")}var Ls=1,el=1,qE=0,pn=0,jt=0,al="";function Us(n,r,i,l,u,c,d){return{value:n,root:r,parent:i,type:l,props:u,children:c,line:Ls,column:el,length:d,return:""}}function ro(n,r){return xC(Us("",null,null,"",null,null,0),n,{length:-n.length},r)}function _C(){return jt}function AC(){return jt=pn>0?It(al,--pn):0,el--,jt===10&&(el=1,Ls--),jt}function Tn(){return jt=pn<qE?It(al,pn++):0,el++,jt===10&&(el=1,Ls++),jt}function yr(){return It(al,pn)}function hs(){return pn}function Bo(n,r){return Oo(al,n,r)}function To(n){switch(n){case 0:case 9:case 10:case 13:case 32:return 5;case 33:case 43:case 44:case 47:case 62:case 64:case 126:case 59:case 123:case 125:return 4;case 58:return 3;case 34:case 39:case 40:case 91:return 2;case 41:case 93:return 1}return 0}function zE(n){return Ls=el=1,qE=sr(al=n),pn=0,[]}function kE(n){return al="",n}function ys(n){return $E(Bo(pn-1,zh(n===91?n+2:n===40?n+1:n)))}function RC(n){for(;(jt=yr())&&jt<33;)Tn();return To(n)>2||To(jt)>3?"":" "}function wC(n,r){for(;--r&&Tn()&&!(jt<48||jt>102||jt>57&&jt<65||jt>70&&jt<97););return Bo(n,hs()+(r<6&&yr()==32&&Tn()==32))}function zh(n){for(;Tn();)switch(jt){case n:return pn;case 34:case 39:n!==34&&n!==39&&zh(jt);break;case 40:n===41&&zh(n);break;case 92:Tn();break}return pn}function CC(n,r){for(;Tn()&&n+jt!==57;)if(n+jt===84&&yr()===47)break;return"/*"+Bo(r,pn-1)+"*"+ks(n===47?n:Tn())}function NC(n){for(;!To(yr());)Tn();return Bo(n,pn)}function MC(n){return kE(vs("",null,null,null,[""],n=zE(n),0,[0],n))}function vs(n,r,i,l,u,c,d,p,h){for(var y=0,m=0,g=d,S=0,R=0,_=0,E=1,C=1,j=1,M=0,B="",X=u,A=c,$=l,O=B;C;)switch(_=M,M=Tn()){case 40:if(_!=108&&It(O,g-1)==58){qh(O+=tt(ys(M),"&","&\f"),"&\f")!=-1&&(j=-1);break}case 34:case 39:case 91:O+=ys(M);break;case 9:case 10:case 13:case 32:O+=RC(_);break;case 92:O+=wC(hs()-1,7);continue;case 47:switch(yr()){case 42:case 47:Ju(DC(CC(Tn(),hs()),r,i),h);break;default:O+="/"}break;case 123*E:p[y++]=sr(O)*j;case 125*E:case 59:case 0:switch(M){case 0:case 125:C=0;case 59+m:j==-1&&(O=tt(O,/\f/g,"")),R>0&&sr(O)-g&&Ju(R>32?Sb(O+";",l,i,g-1):Sb(tt(O," ","")+";",l,i,g-2),h);break;case 59:O+=";";default:if(Ju($=bb(O,r,i,y,m,u,p,B,X=[],A=[],g),c),M===123)if(m===0)vs(O,r,$,$,X,c,g,p,A);else switch(S===99&&It(O,3)===110?100:S){case 100:case 108:case 109:case 115:vs(n,$,$,l&&Ju(bb(n,$,$,0,0,u,p,B,u,X=[],g),A),u,A,g,p,l?X:A);break;default:vs(O,$,$,$,[""],A,0,p,A)}}y=m=R=0,E=j=1,B=O="",g=d;break;case 58:g=1+sr(O),R=_;default:if(E<1){if(M==123)--E;else if(M==125&&E++==0&&AC()==125)continue}switch(O+=ks(M),M*E){case 38:j=m>0?1:(O+="\f",-1);break;case 44:p[y++]=(sr(O)-1)*j,j=1;break;case 64:yr()===45&&(O+=ys(Tn())),S=yr(),m=g=sr(B=O+=NC(hs())),M++;break;case 45:_===45&&sr(O)==2&&(E=0)}}return c}function bb(n,r,i,l,u,c,d,p,h,y,m){for(var g=u-1,S=u===0?c:[""],R=Sy(S),_=0,E=0,C=0;_<l;++_)for(var j=0,M=Oo(n,g+1,g=SC(E=d[_])),B=n;j<R;++j)(B=$E(E>0?S[j]+" "+M:tt(M,/&\f/g,S[j])))&&(h[C++]=B);return Us(n,r,i,u===0?gy:p,h,y,m)}function DC(n,r,i){return Us(n,r,i,jE,ks(_C()),Oo(n,2,-2),0)}function Sb(n,r,i,l){return Us(n,r,i,by,Oo(n,0,l),Oo(n,l+1,-1),l)}function Qi(n,r){for(var i="",l=Sy(n),u=0;u<l;u++)i+=r(n[u],u,n,r)||"";return i}function jC(n,r,i,l){switch(n.type){case bC:if(n.children.length)break;case gC:case by:return n.return=n.return||n.value;case jE:return"";case BE:return n.return=n.value+"{"+Qi(n.children,l)+"}";case gy:n.value=n.props.join(",")}return sr(i=Qi(n.children,l))?n.return=n.value+"{"+i+"}":""}function BC(n){var r=Sy(n);return function(i,l,u,c){for(var d="",p=0;p<r;p++)d+=n[p](i,l,u,c)||"";return d}}function $C(n){return function(r){r.root||(r=r.return)&&n(r)}}function LE(n){var r=Object.create(null);return function(i){return r[i]===void 0&&(r[i]=n(i)),r[i]}}var qC=function(r,i,l){for(var u=0,c=0;u=c,c=yr(),u===38&&c===12&&(i[l]=1),!To(c);)Tn();return Bo(r,pn)},zC=function(r,i){var l=-1,u=44;do switch(To(u)){case 0:u===38&&yr()===12&&(i[l]=1),r[l]+=qC(pn-1,i,l);break;case 2:r[l]+=ys(u);break;case 4:if(u===44){r[++l]=yr()===58?"&\f":"",i[l]=r[l].length;break}default:r[l]+=ks(u)}while(u=Tn());return r},kC=function(r,i){return kE(zC(zE(r),i))},xb=new WeakMap,LC=function(r){if(!(r.type!=="rule"||!r.parent||r.length<1)){for(var i=r.value,l=r.parent,u=r.column===l.column&&r.line===l.line;l.type!=="rule";)if(l=l.parent,!l)return;if(!(r.props.length===1&&i.charCodeAt(0)!==58&&!xb.get(l))&&!u){xb.set(r,!0);for(var c=[],d=kC(i,c),p=l.props,h=0,y=0;h<d.length;h++)for(var m=0;m<p.length;m++,y++)r.props[y]=c[h]?d[h].replace(/&\f/g,p[m]):p[m]+" "+d[h]}}},UC=function(r){if(r.type==="decl"){var i=r.value;i.charCodeAt(0)===108&&i.charCodeAt(2)===98&&(r.return="",r.value="")}};function UE(n,r){switch(EC(n,r)){case 5103:return et+"print-"+n+n;case 5737:case 4201:case 3177:case 3433:case 1641:case 4457:case 2921:case 5572:case 6356:case 5844:case 3191:case 6645:case 3005:case 6391:case 5879:case 5623:case 6135:case 4599:case 4855:case 4215:case 6389:case 5109:case 5365:case 5621:case 3829:return et+n+n;case 5349:case 4246:case 4810:case 6968:case 2756:return et+n+As+n+en+n+n;case 6828:case 4268:return et+n+en+n+n;case 6165:return et+n+en+"flex-"+n+n;case 5187:return et+n+tt(n,/(\w+).+(:[^]+)/,et+"box-$1$2"+en+"flex-$1$2")+n;case 5443:return et+n+en+"flex-item-"+tt(n,/flex-|-self/,"")+n;case 4675:return et+n+en+"flex-line-pack"+tt(n,/align-content|flex-|-self/,"")+n;case 5548:return et+n+en+tt(n,"shrink","negative")+n;case 5292:return et+n+en+tt(n,"basis","preferred-size")+n;case 6060:return et+"box-"+tt(n,"-grow","")+et+n+en+tt(n,"grow","positive")+n;case 4554:return et+tt(n,/([^-])(transform)/g,"$1"+et+"$2")+n;case 6187:return tt(tt(tt(n,/(zoom-|grab)/,et+"$1"),/(image-set)/,et+"$1"),n,"")+n;case 5495:case 3959:return tt(n,/(image-set\([^]*)/,et+"$1$`$1");case 4968:return tt(tt(n,/(.+:)(flex-)?(.*)/,et+"box-pack:$3"+en+"flex-pack:$3"),/s.+-b[^;]+/,"justify")+et+n+n;case 4095:case 3583:case 4068:case 2532:return tt(n,/(.+)-inline(.+)/,et+"$1$2")+n;case 8116:case 7059:case 5753:case 5535:case 5445:case 5701:case 4933:case 4677:case 5533:case 5789:case 5021:case 4765:if(sr(n)-1-r>6)switch(It(n,r+1)){case 109:if(It(n,r+4)!==45)break;case 102:return tt(n,/(.+:)(.+)-([^]+)/,"$1"+et+"$2-$3$1"+As+(It(n,r+3)==108?"$3":"$2-$3"))+n;case 115:return~qh(n,"stretch")?UE(tt(n,"stretch","fill-available"),r)+n:n}break;case 4949:if(It(n,r+1)!==115)break;case 6444:switch(It(n,sr(n)-3-(~qh(n,"!important")&&10))){case 107:return tt(n,":",":"+et)+n;case 101:return tt(n,/(.+:)([^;!]+)(;|!.+)?/,"$1"+et+(It(n,14)===45?"inline-":"")+"box$3$1"+et+"$2$3$1"+en+"$2box$3")+n}break;case 5936:switch(It(n,r+11)){case 114:return et+n+en+tt(n,/[svh]\w+-[tblr]{2}/,"tb")+n;case 108:return et+n+en+tt(n,/[svh]\w+-[tblr]{2}/,"tb-rl")+n;case 45:return et+n+en+tt(n,/[svh]\w+-[tblr]{2}/,"lr")+n}return et+n+en+n+n}return n}var HC=function(r,i,l,u){if(r.length>-1&&!r.return)switch(r.type){case by:r.return=UE(r.value,r.length);break;case BE:return Qi([ro(r,{value:tt(r.value,"@","@"+et)})],u);case gy:if(r.length)return TC(r.props,function(c){switch(OC(c,/(::plac\w+|:read-\w+)/)){case":read-only":case":read-write":return Qi([ro(r,{props:[tt(c,/:(read-\w+)/,":"+As+"$1")]})],u);case"::placeholder":return Qi([ro(r,{props:[tt(c,/:(plac\w+)/,":"+et+"input-$1")]}),ro(r,{props:[tt(c,/:(plac\w+)/,":"+As+"$1")]}),ro(r,{props:[tt(c,/:(plac\w+)/,en+"input-$1")]})],u)}return""})}},GC=[HC],HE=function(r){var i=r.key;if(i==="css"){var l=document.querySelectorAll("style[data-emotion]:not([data-s])");Array.prototype.forEach.call(l,function(E){var C=E.getAttribute("data-emotion");C.indexOf(" ")!==-1&&(document.head.appendChild(E),E.setAttribute("data-s",""))})}var u=r.stylisPlugins||GC,c={},d,p=[];d=r.container||document.head,Array.prototype.forEach.call(document.querySelectorAll('style[data-emotion^="'+i+' "]'),function(E){for(var C=E.getAttribute("data-emotion").split(" "),j=1;j<C.length;j++)c[C[j]]=!0;p.push(E)});var h,y=[LC,UC];{var m,g=[jC,$C(function(E){m.insert(E)})],S=BC(y.concat(u,g)),R=function(C){return Qi(MC(C),S)};h=function(C,j,M,B){m=M,R(C?C+"{"+j.styles+"}":j.styles),B&&(_.inserted[j.name]=!0)}}var _={key:i,sheet:new mC({key:i,container:d,nonce:r.nonce,speedy:r.speedy,prepend:r.prepend,insertionPoint:r.insertionPoint}),nonce:r.nonce,inserted:c,registered:{},insert:h};return _.sheet.hydrate(p),_},Td={exports:{}},nt={};/** @license React v16.13.1
 * react-is.production.min.js
 *
 * Copyright (c) Facebook, Inc. and its affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var Eb;function YC(){if(Eb)return nt;Eb=1;var n=typeof Symbol=="function"&&Symbol.for,r=n?Symbol.for("react.element"):60103,i=n?Symbol.for("react.portal"):60106,l=n?Symbol.for("react.fragment"):60107,u=n?Symbol.for("react.strict_mode"):60108,c=n?Symbol.for("react.profiler"):60114,d=n?Symbol.for("react.provider"):60109,p=n?Symbol.for("react.context"):60110,h=n?Symbol.for("react.async_mode"):60111,y=n?Symbol.for("react.concurrent_mode"):60111,m=n?Symbol.for("react.forward_ref"):60112,g=n?Symbol.for("react.suspense"):60113,S=n?Symbol.for("react.suspense_list"):60120,R=n?Symbol.for("react.memo"):60115,_=n?Symbol.for("react.lazy"):60116,E=n?Symbol.for("react.block"):60121,C=n?Symbol.for("react.fundamental"):60117,j=n?Symbol.for("react.responder"):60118,M=n?Symbol.for("react.scope"):60119;function B(A){if(typeof A=="object"&&A!==null){var $=A.$$typeof;switch($){case r:switch(A=A.type,A){case h:case y:case l:case c:case u:case g:return A;default:switch(A=A&&A.$$typeof,A){case p:case m:case _:case R:case d:return A;default:return $}}case i:return $}}}function X(A){return B(A)===y}return nt.AsyncMode=h,nt.ConcurrentMode=y,nt.ContextConsumer=p,nt.ContextProvider=d,nt.Element=r,nt.ForwardRef=m,nt.Fragment=l,nt.Lazy=_,nt.Memo=R,nt.Portal=i,nt.Profiler=c,nt.StrictMode=u,nt.Suspense=g,nt.isAsyncMode=function(A){return X(A)||B(A)===h},nt.isConcurrentMode=X,nt.isContextConsumer=function(A){return B(A)===p},nt.isContextProvider=function(A){return B(A)===d},nt.isElement=function(A){return typeof A=="object"&&A!==null&&A.$$typeof===r},nt.isForwardRef=function(A){return B(A)===m},nt.isFragment=function(A){return B(A)===l},nt.isLazy=function(A){return B(A)===_},nt.isMemo=function(A){return B(A)===R},nt.isPortal=function(A){return B(A)===i},nt.isProfiler=function(A){return B(A)===c},nt.isStrictMode=function(A){return B(A)===u},nt.isSuspense=function(A){return B(A)===g},nt.isValidElementType=function(A){return typeof A=="string"||typeof A=="function"||A===l||A===y||A===c||A===u||A===g||A===S||typeof A=="object"&&A!==null&&(A.$$typeof===_||A.$$typeof===R||A.$$typeof===d||A.$$typeof===p||A.$$typeof===m||A.$$typeof===C||A.$$typeof===j||A.$$typeof===M||A.$$typeof===E)},nt.typeOf=B,nt}var Ob;function VC(){return Ob||(Ob=1,Td.exports=YC()),Td.exports}var _d,Tb;function PC(){if(Tb)return _d;Tb=1;var n=VC(),r={childContextTypes:!0,contextType:!0,contextTypes:!0,defaultProps:!0,displayName:!0,getDefaultProps:!0,getDerivedStateFromError:!0,getDerivedStateFromProps:!0,mixins:!0,propTypes:!0,type:!0},i={name:!0,length:!0,prototype:!0,caller:!0,callee:!0,arguments:!0,arity:!0},l={$$typeof:!0,render:!0,defaultProps:!0,displayName:!0,propTypes:!0},u={$$typeof:!0,compare:!0,defaultProps:!0,displayName:!0,propTypes:!0,type:!0},c={};c[n.ForwardRef]=l,c[n.Memo]=u;function d(_){return n.isMemo(_)?u:c[_.$$typeof]||r}var p=Object.defineProperty,h=Object.getOwnPropertyNames,y=Object.getOwnPropertySymbols,m=Object.getOwnPropertyDescriptor,g=Object.getPrototypeOf,S=Object.prototype;function R(_,E,C){if(typeof E!="string"){if(S){var j=g(E);j&&j!==S&&R(_,j,C)}var M=h(E);y&&(M=M.concat(y(E)));for(var B=d(_),X=d(E),A=0;A<M.length;++A){var $=M[A];if(!i[$]&&!(C&&C[$])&&!(X&&X[$])&&!(B&&B[$])){var O=m(E,$);try{p(_,$,O)}catch{}}}}return _}return _d=R,_d}PC();var XC=!0;function GE(n,r,i){var l="";return i.split(" ").forEach(function(u){n[u]!==void 0?r.push(n[u]+";"):u&&(l+=u+" ")}),l}var xy=function(r,i,l){var u=r.key+"-"+i.name;(l===!1||XC===!1)&&r.registered[u]===void 0&&(r.registered[u]=i.styles)},Ey=function(r,i,l){xy(r,i,l);var u=r.key+"-"+i.name;if(r.inserted[i.name]===void 0){var c=i;do r.insert(i===c?"."+u:"",c,r.sheet,!0),c=c.next;while(c!==void 0)}};function QC(n){for(var r=0,i,l=0,u=n.length;u>=4;++l,u-=4)i=n.charCodeAt(l)&255|(n.charCodeAt(++l)&255)<<8|(n.charCodeAt(++l)&255)<<16|(n.charCodeAt(++l)&255)<<24,i=(i&65535)*1540483477+((i>>>16)*59797<<16),i^=i>>>24,r=(i&65535)*1540483477+((i>>>16)*59797<<16)^(r&65535)*1540483477+((r>>>16)*59797<<16);switch(u){case 3:r^=(n.charCodeAt(l+2)&255)<<16;case 2:r^=(n.charCodeAt(l+1)&255)<<8;case 1:r^=n.charCodeAt(l)&255,r=(r&65535)*1540483477+((r>>>16)*59797<<16)}return r^=r>>>13,r=(r&65535)*1540483477+((r>>>16)*59797<<16),((r^r>>>15)>>>0).toString(36)}var KC={animationIterationCount:1,aspectRatio:1,borderImageOutset:1,borderImageSlice:1,borderImageWidth:1,boxFlex:1,boxFlexGroup:1,boxOrdinalGroup:1,columnCount:1,columns:1,flex:1,flexGrow:1,flexPositive:1,flexShrink:1,flexNegative:1,flexOrder:1,gridRow:1,gridRowEnd:1,gridRowSpan:1,gridRowStart:1,gridColumn:1,gridColumnEnd:1,gridColumnSpan:1,gridColumnStart:1,msGridRow:1,msGridRowSpan:1,msGridColumn:1,msGridColumnSpan:1,fontWeight:1,lineHeight:1,opacity:1,order:1,orphans:1,scale:1,tabSize:1,widows:1,zIndex:1,zoom:1,WebkitLineClamp:1,fillOpacity:1,floodOpacity:1,stopOpacity:1,strokeDasharray:1,strokeDashoffset:1,strokeMiterlimit:1,strokeOpacity:1,strokeWidth:1},FC=/[A-Z]|^ms/g,ZC=/_EMO_([^_]+?)_([^]*?)_EMO_/g,YE=function(r){return r.charCodeAt(1)===45},_b=function(r){return r!=null&&typeof r!="boolean"},Ad=LE(function(n){return YE(n)?n:n.replace(FC,"-$&").toLowerCase()}),Ab=function(r,i){switch(r){case"animation":case"animationName":if(typeof i=="string")return i.replace(ZC,function(l,u,c){return cr={name:u,styles:c,next:cr},u})}return KC[r]!==1&&!YE(r)&&typeof i=="number"&&i!==0?i+"px":i};function _o(n,r,i){if(i==null)return"";var l=i;if(l.__emotion_styles!==void 0)return l;switch(typeof i){case"boolean":return"";case"object":{var u=i;if(u.anim===1)return cr={name:u.name,styles:u.styles,next:cr},u.name;var c=i;if(c.styles!==void 0){var d=c.next;if(d!==void 0)for(;d!==void 0;)cr={name:d.name,styles:d.styles,next:cr},d=d.next;var p=c.styles+";";return p}return IC(n,r,i)}case"function":{if(n!==void 0){var h=cr,y=i(n);return cr=h,_o(n,r,y)}break}}var m=i;if(r==null)return m;var g=r[m];return g!==void 0?g:m}function IC(n,r,i){var l="";if(Array.isArray(i))for(var u=0;u<i.length;u++)l+=_o(n,r,i[u])+";";else for(var c in i){var d=i[c];if(typeof d!="object"){var p=d;r!=null&&r[p]!==void 0?l+=c+"{"+r[p]+"}":_b(p)&&(l+=Ad(c)+":"+Ab(c,p)+";")}else if(Array.isArray(d)&&typeof d[0]=="string"&&(r==null||r[d[0]]===void 0))for(var h=0;h<d.length;h++)_b(d[h])&&(l+=Ad(c)+":"+Ab(c,d[h])+";");else{var y=_o(n,r,d);switch(c){case"animation":case"animationName":{l+=Ad(c)+":"+y+";";break}default:l+=c+"{"+y+"}"}}}return l}var Rb=/label:\s*([^\s;{]+)\s*(;|$)/g,cr;function Hs(n,r,i){if(n.length===1&&typeof n[0]=="object"&&n[0]!==null&&n[0].styles!==void 0)return n[0];var l=!0,u="";cr=void 0;var c=n[0];if(c==null||c.raw===void 0)l=!1,u+=_o(i,r,c);else{var d=c;u+=d[0]}for(var p=1;p<n.length;p++)if(u+=_o(i,r,n[p]),l){var h=c;u+=h[p]}Rb.lastIndex=0;for(var y="",m;(m=Rb.exec(u))!==null;)y+="-"+m[1];var g=QC(u)+y;return{name:g,styles:u,next:cr}}var WC=function(r){return r()},VE=j0.useInsertionEffect?j0.useInsertionEffect:!1,PE=VE||WC,wb=VE||x.useLayoutEffect,XE=x.createContext(typeof HTMLElement<"u"?HE({key:"css"}):null),JC=XE.Provider,Oy=function(r){return x.forwardRef(function(i,l){var u=x.useContext(XE);return r(i,u,l)})},Gs=x.createContext({}),Ty={}.hasOwnProperty,kh="__EMOTION_TYPE_PLEASE_DO_NOT_USE__",eN=function(r,i){var l={};for(var u in i)Ty.call(i,u)&&(l[u]=i[u]);return l[kh]=r,l},tN=function(r){var i=r.cache,l=r.serialized,u=r.isStringTag;return xy(i,l,u),PE(function(){return Ey(i,l,u)}),null},nN=Oy(function(n,r,i){var l=n.css;typeof l=="string"&&r.registered[l]!==void 0&&(l=r.registered[l]);var u=n[kh],c=[l],d="";typeof n.className=="string"?d=GE(r.registered,c,n.className):n.className!=null&&(d=n.className+" ");var p=Hs(c,void 0,x.useContext(Gs));d+=r.key+"-"+p.name;var h={};for(var y in n)Ty.call(n,y)&&y!=="css"&&y!==kh&&(h[y]=n[y]);return h.className=d,i&&(h.ref=i),x.createElement(x.Fragment,null,x.createElement(tN,{cache:r,serialized:p,isStringTag:typeof u=="string"}),x.createElement(u,h))}),rN=nN,Cb=function(r,i){var l=arguments;if(i==null||!Ty.call(i,"css"))return x.createElement.apply(void 0,l);var u=l.length,c=new Array(u);c[0]=rN,c[1]=eN(r,i);for(var d=2;d<u;d++)c[d]=l[d];return x.createElement.apply(null,c)};(function(n){var r;r||(r=n.JSX||(n.JSX={}))})(Cb||(Cb={}));var aN=Oy(function(n,r){var i=n.styles,l=Hs([i],void 0,x.useContext(Gs)),u=x.useRef();return wb(function(){var c=r.key+"-global",d=new r.sheet.constructor({key:c,nonce:r.sheet.nonce,container:r.sheet.container,speedy:r.sheet.isSpeedy}),p=!1,h=document.querySelector('style[data-emotion="'+c+" "+l.name+'"]');return r.sheet.tags.length&&(d.before=r.sheet.tags[0]),h!==null&&(p=!0,h.setAttribute("data-emotion",c),d.hydrate([h])),u.current=[d,p],function(){d.flush()}},[r]),wb(function(){var c=u.current,d=c[0],p=c[1];if(p){c[1]=!1;return}if(l.next!==void 0&&Ey(r,l.next,!0),d.tags.length){var h=d.tags[d.tags.length-1].nextElementSibling;d.before=h,d.flush()}r.insert("",l,d,!1)},[r,l.name]),null});function QE(){for(var n=arguments.length,r=new Array(n),i=0;i<n;i++)r[i]=arguments[i];return Hs(r)}function iN(){var n=QE.apply(void 0,arguments),r="animation-"+n.name;return{name:r,styles:"@keyframes "+r+"{"+n.styles+"}",anim:1,toString:function(){return"_EMO_"+this.name+"_"+this.styles+"_EMO_"}}}var lN=/^((children|dangerouslySetInnerHTML|key|ref|autoFocus|defaultValue|defaultChecked|innerHTML|suppressContentEditableWarning|suppressHydrationWarning|valueLink|abbr|accept|acceptCharset|accessKey|action|allow|allowUserMedia|allowPaymentRequest|allowFullScreen|allowTransparency|alt|async|autoComplete|autoPlay|capture|cellPadding|cellSpacing|challenge|charSet|checked|cite|classID|className|cols|colSpan|content|contentEditable|contextMenu|controls|controlsList|coords|crossOrigin|data|dateTime|decoding|default|defer|dir|disabled|disablePictureInPicture|disableRemotePlayback|download|draggable|encType|enterKeyHint|fetchpriority|fetchPriority|form|formAction|formEncType|formMethod|formNoValidate|formTarget|frameBorder|headers|height|hidden|high|href|hrefLang|htmlFor|httpEquiv|id|inputMode|integrity|is|keyParams|keyType|kind|label|lang|list|loading|loop|low|marginHeight|marginWidth|max|maxLength|media|mediaGroup|method|min|minLength|multiple|muted|name|nonce|noValidate|open|optimum|pattern|placeholder|playsInline|poster|preload|profile|radioGroup|readOnly|referrerPolicy|rel|required|reversed|role|rows|rowSpan|sandbox|scope|scoped|scrolling|seamless|selected|shape|size|sizes|slot|span|spellCheck|src|srcDoc|srcLang|srcSet|start|step|style|summary|tabIndex|target|title|translate|type|useMap|value|width|wmode|wrap|about|datatype|inlist|prefix|property|resource|typeof|vocab|autoCapitalize|autoCorrect|autoSave|color|incremental|fallback|inert|itemProp|itemScope|itemType|itemID|itemRef|on|option|results|security|unselectable|accentHeight|accumulate|additive|alignmentBaseline|allowReorder|alphabetic|amplitude|arabicForm|ascent|attributeName|attributeType|autoReverse|azimuth|baseFrequency|baselineShift|baseProfile|bbox|begin|bias|by|calcMode|capHeight|clip|clipPathUnits|clipPath|clipRule|colorInterpolation|colorInterpolationFilters|colorProfile|colorRendering|contentScriptType|contentStyleType|cursor|cx|cy|d|decelerate|descent|diffuseConstant|direction|display|divisor|dominantBaseline|dur|dx|dy|edgeMode|elevation|enableBackground|end|exponent|externalResourcesRequired|fill|fillOpacity|fillRule|filter|filterRes|filterUnits|floodColor|floodOpacity|focusable|fontFamily|fontSize|fontSizeAdjust|fontStretch|fontStyle|fontVariant|fontWeight|format|from|fr|fx|fy|g1|g2|glyphName|glyphOrientationHorizontal|glyphOrientationVertical|glyphRef|gradientTransform|gradientUnits|hanging|horizAdvX|horizOriginX|ideographic|imageRendering|in|in2|intercept|k|k1|k2|k3|k4|kernelMatrix|kernelUnitLength|kerning|keyPoints|keySplines|keyTimes|lengthAdjust|letterSpacing|lightingColor|limitingConeAngle|local|markerEnd|markerMid|markerStart|markerHeight|markerUnits|markerWidth|mask|maskContentUnits|maskUnits|mathematical|mode|numOctaves|offset|opacity|operator|order|orient|orientation|origin|overflow|overlinePosition|overlineThickness|panose1|paintOrder|pathLength|patternContentUnits|patternTransform|patternUnits|pointerEvents|points|pointsAtX|pointsAtY|pointsAtZ|preserveAlpha|preserveAspectRatio|primitiveUnits|r|radius|refX|refY|renderingIntent|repeatCount|repeatDur|requiredExtensions|requiredFeatures|restart|result|rotate|rx|ry|scale|seed|shapeRendering|slope|spacing|specularConstant|specularExponent|speed|spreadMethod|startOffset|stdDeviation|stemh|stemv|stitchTiles|stopColor|stopOpacity|strikethroughPosition|strikethroughThickness|string|stroke|strokeDasharray|strokeDashoffset|strokeLinecap|strokeLinejoin|strokeMiterlimit|strokeOpacity|strokeWidth|surfaceScale|systemLanguage|tableValues|targetX|targetY|textAnchor|textDecoration|textRendering|textLength|to|transform|u1|u2|underlinePosition|underlineThickness|unicode|unicodeBidi|unicodeRange|unitsPerEm|vAlphabetic|vHanging|vIdeographic|vMathematical|values|vectorEffect|version|vertAdvY|vertOriginX|vertOriginY|viewBox|viewTarget|visibility|widths|wordSpacing|writingMode|x|xHeight|x1|x2|xChannelSelector|xlinkActuate|xlinkArcrole|xlinkHref|xlinkRole|xlinkShow|xlinkTitle|xlinkType|xmlBase|xmlns|xmlnsXlink|xmlLang|xmlSpace|y|y1|y2|yChannelSelector|z|zoomAndPan|for|class|autofocus)|(([Dd][Aa][Tt][Aa]|[Aa][Rr][Ii][Aa]|x)-.*))$/,oN=LE(function(n){return lN.test(n)||n.charCodeAt(0)===111&&n.charCodeAt(1)===110&&n.charCodeAt(2)<91}),uN=oN,sN=function(r){return r!=="theme"},Nb=function(r){return typeof r=="string"&&r.charCodeAt(0)>96?uN:sN},Mb=function(r,i,l){var u;if(i){var c=i.shouldForwardProp;u=r.__emotion_forwardProp&&c?function(d){return r.__emotion_forwardProp(d)&&c(d)}:c}return typeof u!="function"&&l&&(u=r.__emotion_forwardProp),u},cN=function(r){var i=r.cache,l=r.serialized,u=r.isStringTag;return xy(i,l,u),PE(function(){return Ey(i,l,u)}),null},fN=function n(r,i){var l=r.__emotion_real===r,u=l&&r.__emotion_base||r,c,d;i!==void 0&&(c=i.label,d=i.target);var p=Mb(r,i,l),h=p||Nb(u),y=!h("as");return function(){var m=arguments,g=l&&r.__emotion_styles!==void 0?r.__emotion_styles.slice(0):[];if(c!==void 0&&g.push("label:"+c+";"),m[0]==null||m[0].raw===void 0)g.push.apply(g,m);else{var S=m[0];g.push(S[0]);for(var R=m.length,_=1;_<R;_++)g.push(m[_],S[_])}var E=Oy(function(C,j,M){var B=y&&C.as||u,X="",A=[],$=C;if(C.theme==null){$={};for(var O in C)$[O]=C[O];$.theme=x.useContext(Gs)}typeof C.className=="string"?X=GE(j.registered,A,C.className):C.className!=null&&(X=C.className+" ");var q=Hs(g.concat(A),j.registered,$);X+=j.key+"-"+q.name,d!==void 0&&(X+=" "+d);var L=y&&p===void 0?Nb(B):h,Y={};for(var W in C)y&&W==="as"||L(W)&&(Y[W]=C[W]);return Y.className=X,M&&(Y.ref=M),x.createElement(x.Fragment,null,x.createElement(cN,{cache:j,serialized:q,isStringTag:typeof B=="string"}),x.createElement(B,Y))});return E.displayName=c!==void 0?c:"Styled("+(typeof u=="string"?u:u.displayName||u.name||"Component")+")",E.defaultProps=r.defaultProps,E.__emotion_real=E,E.__emotion_base=u,E.__emotion_styles=g,E.__emotion_forwardProp=p,Object.defineProperty(E,"toString",{value:function(){return"."+d}}),E.withComponent=function(C,j){var M=n(C,ge({},i,j,{shouldForwardProp:Mb(E,j,!0)}));return M.apply(void 0,g)},E}},dN=["a","abbr","address","area","article","aside","audio","b","base","bdi","bdo","big","blockquote","body","br","button","canvas","caption","cite","code","col","colgroup","data","datalist","dd","del","details","dfn","dialog","div","dl","dt","em","embed","fieldset","figcaption","figure","footer","form","h1","h2","h3","h4","h5","h6","head","header","hgroup","hr","html","i","iframe","img","input","ins","kbd","keygen","label","legend","li","link","main","map","mark","marquee","menu","menuitem","meta","meter","nav","noscript","object","ol","optgroup","option","output","p","param","picture","pre","progress","q","rp","rt","ruby","s","samp","script","section","select","small","source","span","strong","style","sub","summary","sup","table","tbody","td","textarea","tfoot","th","thead","time","title","tr","track","u","ul","var","video","wbr","circle","clipPath","defs","ellipse","foreignObject","g","image","line","linearGradient","mask","path","pattern","polygon","polyline","radialGradient","rect","stop","svg","text","tspan"],Lh=fN.bind(null);dN.forEach(function(n){Lh[n]=Lh(n)});let Uh;typeof document=="object"&&(Uh=HE({key:"css",prepend:!0}));function pN(n){const{injectFirst:r,children:i}=n;return r&&Uh?T.jsx(JC,{value:Uh,children:i}):i}function hN(n){return n==null||Object.keys(n).length===0}function yN(n){const{styles:r,defaultTheme:i={}}=n,l=typeof r=="function"?u=>r(hN(u)?i:u):r;return T.jsx(aN,{styles:l})}function vN(n,r){return Lh(n,r)}const mN=(n,r)=>{Array.isArray(n.__emotion_styles)&&(n.__emotion_styles=r(n.__emotion_styles))},gN=Object.freeze(Object.defineProperty({__proto__:null,GlobalStyles:yN,StyledEngineProvider:pN,ThemeContext:Gs,css:QE,default:vN,internal_processStyles:mN,keyframes:iN},Symbol.toStringTag,{value:"Module"}));function xa(n){if(typeof n!="object"||n===null)return!1;const r=Object.getPrototypeOf(n);return(r===null||r===Object.prototype||Object.getPrototypeOf(r)===null)&&!(Symbol.toStringTag in n)&&!(Symbol.iterator in n)}function KE(n){if(x.isValidElement(n)||!xa(n))return n;const r={};return Object.keys(n).forEach(i=>{r[i]=KE(n[i])}),r}function vr(n,r,i={clone:!0}){const l=i.clone?ge({},n):n;return xa(n)&&xa(r)&&Object.keys(r).forEach(u=>{x.isValidElement(r[u])?l[u]=r[u]:xa(r[u])&&Object.prototype.hasOwnProperty.call(n,u)&&xa(n[u])?l[u]=vr(n[u],r[u],i):i.clone?l[u]=xa(r[u])?KE(r[u]):r[u]:l[u]=r[u]}),l}const bN=Object.freeze(Object.defineProperty({__proto__:null,default:vr,isPlainObject:xa},Symbol.toStringTag,{value:"Module"})),SN=["values","unit","step"],xN=n=>{const r=Object.keys(n).map(i=>({key:i,val:n[i]}))||[];return r.sort((i,l)=>i.val-l.val),r.reduce((i,l)=>ge({},i,{[l.key]:l.val}),{})};function FE(n){const{values:r={xs:0,sm:600,md:900,lg:1200,xl:1536},unit:i="px",step:l=5}=n,u=er(n,SN),c=xN(r),d=Object.keys(c);function p(S){return`@media (min-width:${typeof r[S]=="number"?r[S]:S}${i})`}function h(S){return`@media (max-width:${(typeof r[S]=="number"?r[S]:S)-l/100}${i})`}function y(S,R){const _=d.indexOf(R);return`@media (min-width:${typeof r[S]=="number"?r[S]:S}${i}) and (max-width:${(_!==-1&&typeof r[d[_]]=="number"?r[d[_]]:R)-l/100}${i})`}function m(S){return d.indexOf(S)+1<d.length?y(S,d[d.indexOf(S)+1]):p(S)}function g(S){const R=d.indexOf(S);return R===0?p(d[1]):R===d.length-1?h(d[R]):y(S,d[d.indexOf(S)+1]).replace("@media","@media not all and")}return ge({keys:d,values:c,up:p,down:h,between:y,only:m,not:g,unit:i},u)}const EN={borderRadius:4};function yo(n,r){return r?vr(n,r,{clone:!1}):n}const _y={xs:0,sm:600,md:900,lg:1200,xl:1536},Db={keys:["xs","sm","md","lg","xl"],up:n=>`@media (min-width:${_y[n]}px)`};function Xr(n,r,i){const l=n.theme||{};if(Array.isArray(r)){const c=l.breakpoints||Db;return r.reduce((d,p,h)=>(d[c.up(c.keys[h])]=i(r[h]),d),{})}if(typeof r=="object"){const c=l.breakpoints||Db;return Object.keys(r).reduce((d,p)=>{if(Object.keys(c.values||_y).indexOf(p)!==-1){const h=c.up(p);d[h]=i(r[p],p)}else{const h=p;d[h]=r[h]}return d},{})}return i(r)}function ON(n={}){var r;return((r=n.keys)==null?void 0:r.reduce((l,u)=>{const c=n.up(u);return l[c]={},l},{}))||{}}function TN(n,r){return n.reduce((i,l)=>{const u=i[l];return(!u||Object.keys(u).length===0)&&delete i[l],i},r)}function Jn(n){if(typeof n!="string")throw new Error(Eo(7));return n.charAt(0).toUpperCase()+n.slice(1)}const _N=Object.freeze(Object.defineProperty({__proto__:null,default:Jn},Symbol.toStringTag,{value:"Module"}));function Ys(n,r,i=!0){if(!r||typeof r!="string")return null;if(n&&n.vars&&i){const l=`vars.${r}`.split(".").reduce((u,c)=>u&&u[c]?u[c]:null,n);if(l!=null)return l}return r.split(".").reduce((l,u)=>l&&l[u]!=null?l[u]:null,n)}function Rs(n,r,i,l=i){let u;return typeof n=="function"?u=n(i):Array.isArray(n)?u=n[i]||l:u=Ys(n,i)||l,r&&(u=r(u,l,n)),u}function Ct(n){const{prop:r,cssProperty:i=n.prop,themeKey:l,transform:u}=n,c=d=>{if(d[r]==null)return null;const p=d[r],h=d.theme,y=Ys(h,l)||{};return Xr(d,p,g=>{let S=Rs(y,u,g);return g===S&&typeof g=="string"&&(S=Rs(y,u,`${r}${g==="default"?"":Jn(g)}`,g)),i===!1?S:{[i]:S}})};return c.propTypes={},c.filterProps=[r],c}function AN(n){const r={};return i=>(r[i]===void 0&&(r[i]=n(i)),r[i])}const RN={m:"margin",p:"padding"},wN={t:"Top",r:"Right",b:"Bottom",l:"Left",x:["Left","Right"],y:["Top","Bottom"]},jb={marginX:"mx",marginY:"my",paddingX:"px",paddingY:"py"},CN=AN(n=>{if(n.length>2)if(jb[n])n=jb[n];else return[n];const[r,i]=n.split(""),l=RN[r],u=wN[i]||"";return Array.isArray(u)?u.map(c=>l+c):[l+u]}),Ay=["m","mt","mr","mb","ml","mx","my","margin","marginTop","marginRight","marginBottom","marginLeft","marginX","marginY","marginInline","marginInlineStart","marginInlineEnd","marginBlock","marginBlockStart","marginBlockEnd"],Ry=["p","pt","pr","pb","pl","px","py","padding","paddingTop","paddingRight","paddingBottom","paddingLeft","paddingX","paddingY","paddingInline","paddingInlineStart","paddingInlineEnd","paddingBlock","paddingBlockStart","paddingBlockEnd"];[...Ay,...Ry];function $o(n,r,i,l){var u;const c=(u=Ys(n,r,!1))!=null?u:i;return typeof c=="number"?d=>typeof d=="string"?d:c*d:Array.isArray(c)?d=>typeof d=="string"?d:c[d]:typeof c=="function"?c:()=>{}}function ZE(n){return $o(n,"spacing",8)}function qo(n,r){if(typeof r=="string"||r==null)return r;const i=Math.abs(r),l=n(i);return r>=0?l:typeof l=="number"?-l:`-${l}`}function NN(n,r){return i=>n.reduce((l,u)=>(l[u]=qo(r,i),l),{})}function MN(n,r,i,l){if(r.indexOf(i)===-1)return null;const u=CN(i),c=NN(u,l),d=n[i];return Xr(n,d,c)}function IE(n,r){const i=ZE(n.theme);return Object.keys(n).map(l=>MN(n,r,l,i)).reduce(yo,{})}function Ot(n){return IE(n,Ay)}Ot.propTypes={};Ot.filterProps=Ay;function Tt(n){return IE(n,Ry)}Tt.propTypes={};Tt.filterProps=Ry;function DN(n=8){if(n.mui)return n;const r=ZE({spacing:n}),i=(...l)=>(l.length===0?[1]:l).map(c=>{const d=r(c);return typeof d=="number"?`${d}px`:d}).join(" ");return i.mui=!0,i}function Vs(...n){const r=n.reduce((l,u)=>(u.filterProps.forEach(c=>{l[c]=u}),l),{}),i=l=>Object.keys(l).reduce((u,c)=>r[c]?yo(u,r[c](l)):u,{});return i.propTypes={},i.filterProps=n.reduce((l,u)=>l.concat(u.filterProps),[]),i}function Hn(n){return typeof n!="number"?n:`${n}px solid`}function Pn(n,r){return Ct({prop:n,themeKey:"borders",transform:r})}const jN=Pn("border",Hn),BN=Pn("borderTop",Hn),$N=Pn("borderRight",Hn),qN=Pn("borderBottom",Hn),zN=Pn("borderLeft",Hn),kN=Pn("borderColor"),LN=Pn("borderTopColor"),UN=Pn("borderRightColor"),HN=Pn("borderBottomColor"),GN=Pn("borderLeftColor"),YN=Pn("outline",Hn),VN=Pn("outlineColor"),Ps=n=>{if(n.borderRadius!==void 0&&n.borderRadius!==null){const r=$o(n.theme,"shape.borderRadius",4),i=l=>({borderRadius:qo(r,l)});return Xr(n,n.borderRadius,i)}return null};Ps.propTypes={};Ps.filterProps=["borderRadius"];Vs(jN,BN,$N,qN,zN,kN,LN,UN,HN,GN,Ps,YN,VN);const Xs=n=>{if(n.gap!==void 0&&n.gap!==null){const r=$o(n.theme,"spacing",8),i=l=>({gap:qo(r,l)});return Xr(n,n.gap,i)}return null};Xs.propTypes={};Xs.filterProps=["gap"];const Qs=n=>{if(n.columnGap!==void 0&&n.columnGap!==null){const r=$o(n.theme,"spacing",8),i=l=>({columnGap:qo(r,l)});return Xr(n,n.columnGap,i)}return null};Qs.propTypes={};Qs.filterProps=["columnGap"];const Ks=n=>{if(n.rowGap!==void 0&&n.rowGap!==null){const r=$o(n.theme,"spacing",8),i=l=>({rowGap:qo(r,l)});return Xr(n,n.rowGap,i)}return null};Ks.propTypes={};Ks.filterProps=["rowGap"];const PN=Ct({prop:"gridColumn"}),XN=Ct({prop:"gridRow"}),QN=Ct({prop:"gridAutoFlow"}),KN=Ct({prop:"gridAutoColumns"}),FN=Ct({prop:"gridAutoRows"}),ZN=Ct({prop:"gridTemplateColumns"}),IN=Ct({prop:"gridTemplateRows"}),WN=Ct({prop:"gridTemplateAreas"}),JN=Ct({prop:"gridArea"});Vs(Xs,Qs,Ks,PN,XN,QN,KN,FN,ZN,IN,WN,JN);function Ki(n,r){return r==="grey"?r:n}const e3=Ct({prop:"color",themeKey:"palette",transform:Ki}),t3=Ct({prop:"bgcolor",cssProperty:"backgroundColor",themeKey:"palette",transform:Ki}),n3=Ct({prop:"backgroundColor",themeKey:"palette",transform:Ki});Vs(e3,t3,n3);function On(n){return n<=1&&n!==0?`${n*100}%`:n}const r3=Ct({prop:"width",transform:On}),wy=n=>{if(n.maxWidth!==void 0&&n.maxWidth!==null){const r=i=>{var l,u;const c=((l=n.theme)==null||(l=l.breakpoints)==null||(l=l.values)==null?void 0:l[i])||_y[i];return c?((u=n.theme)==null||(u=u.breakpoints)==null?void 0:u.unit)!=="px"?{maxWidth:`${c}${n.theme.breakpoints.unit}`}:{maxWidth:c}:{maxWidth:On(i)}};return Xr(n,n.maxWidth,r)}return null};wy.filterProps=["maxWidth"];const a3=Ct({prop:"minWidth",transform:On}),i3=Ct({prop:"height",transform:On}),l3=Ct({prop:"maxHeight",transform:On}),o3=Ct({prop:"minHeight",transform:On});Ct({prop:"size",cssProperty:"width",transform:On});Ct({prop:"size",cssProperty:"height",transform:On});const u3=Ct({prop:"boxSizing"});Vs(r3,wy,a3,i3,l3,o3,u3);const zo={border:{themeKey:"borders",transform:Hn},borderTop:{themeKey:"borders",transform:Hn},borderRight:{themeKey:"borders",transform:Hn},borderBottom:{themeKey:"borders",transform:Hn},borderLeft:{themeKey:"borders",transform:Hn},borderColor:{themeKey:"palette"},borderTopColor:{themeKey:"palette"},borderRightColor:{themeKey:"palette"},borderBottomColor:{themeKey:"palette"},borderLeftColor:{themeKey:"palette"},outline:{themeKey:"borders",transform:Hn},outlineColor:{themeKey:"palette"},borderRadius:{themeKey:"shape.borderRadius",style:Ps},color:{themeKey:"palette",transform:Ki},bgcolor:{themeKey:"palette",cssProperty:"backgroundColor",transform:Ki},backgroundColor:{themeKey:"palette",transform:Ki},p:{style:Tt},pt:{style:Tt},pr:{style:Tt},pb:{style:Tt},pl:{style:Tt},px:{style:Tt},py:{style:Tt},padding:{style:Tt},paddingTop:{style:Tt},paddingRight:{style:Tt},paddingBottom:{style:Tt},paddingLeft:{style:Tt},paddingX:{style:Tt},paddingY:{style:Tt},paddingInline:{style:Tt},paddingInlineStart:{style:Tt},paddingInlineEnd:{style:Tt},paddingBlock:{style:Tt},paddingBlockStart:{style:Tt},paddingBlockEnd:{style:Tt},m:{style:Ot},mt:{style:Ot},mr:{style:Ot},mb:{style:Ot},ml:{style:Ot},mx:{style:Ot},my:{style:Ot},margin:{style:Ot},marginTop:{style:Ot},marginRight:{style:Ot},marginBottom:{style:Ot},marginLeft:{style:Ot},marginX:{style:Ot},marginY:{style:Ot},marginInline:{style:Ot},marginInlineStart:{style:Ot},marginInlineEnd:{style:Ot},marginBlock:{style:Ot},marginBlockStart:{style:Ot},marginBlockEnd:{style:Ot},displayPrint:{cssProperty:!1,transform:n=>({"@media print":{display:n}})},display:{},overflow:{},textOverflow:{},visibility:{},whiteSpace:{},flexBasis:{},flexDirection:{},flexWrap:{},justifyContent:{},alignItems:{},alignContent:{},order:{},flex:{},flexGrow:{},flexShrink:{},alignSelf:{},justifyItems:{},justifySelf:{},gap:{style:Xs},rowGap:{style:Ks},columnGap:{style:Qs},gridColumn:{},gridRow:{},gridAutoFlow:{},gridAutoColumns:{},gridAutoRows:{},gridTemplateColumns:{},gridTemplateRows:{},gridTemplateAreas:{},gridArea:{},position:{},zIndex:{themeKey:"zIndex"},top:{},right:{},bottom:{},left:{},boxShadow:{themeKey:"shadows"},width:{transform:On},maxWidth:{style:wy},minWidth:{transform:On},height:{transform:On},maxHeight:{transform:On},minHeight:{transform:On},boxSizing:{},fontFamily:{themeKey:"typography"},fontSize:{themeKey:"typography"},fontStyle:{themeKey:"typography"},fontWeight:{themeKey:"typography"},letterSpacing:{},textTransform:{},lineHeight:{},textAlign:{},typography:{cssProperty:!1,themeKey:"typography"}};function s3(...n){const r=n.reduce((l,u)=>l.concat(Object.keys(u)),[]),i=new Set(r);return n.every(l=>i.size===Object.keys(l).length)}function c3(n,r){return typeof n=="function"?n(r):n}function WE(){function n(i,l,u,c){const d={[i]:l,theme:u},p=c[i];if(!p)return{[i]:l};const{cssProperty:h=i,themeKey:y,transform:m,style:g}=p;if(l==null)return null;if(y==="typography"&&l==="inherit")return{[i]:l};const S=Ys(u,y)||{};return g?g(d):Xr(d,l,_=>{let E=Rs(S,m,_);return _===E&&typeof _=="string"&&(E=Rs(S,m,`${i}${_==="default"?"":Jn(_)}`,_)),h===!1?E:{[h]:E}})}function r(i){var l;const{sx:u,theme:c={}}=i||{};if(!u)return null;const d=(l=c.unstable_sxConfig)!=null?l:zo;function p(h){let y=h;if(typeof h=="function")y=h(c);else if(typeof h!="object")return h;if(!y)return null;const m=ON(c.breakpoints),g=Object.keys(m);let S=m;return Object.keys(y).forEach(R=>{const _=c3(y[R],c);if(_!=null)if(typeof _=="object")if(d[R])S=yo(S,n(R,_,c,d));else{const E=Xr({theme:c},_,C=>({[R]:C}));s3(E,_)?S[R]=r({sx:_,theme:c}):S=yo(S,E)}else S=yo(S,n(R,_,c,d))}),TN(g,S)}return Array.isArray(u)?u.map(p):p(u)}return r}const Fs=WE();Fs.filterProps=["sx"];function JE(n,r){const i=this;return i.vars&&typeof i.getColorSchemeSelector=="function"?{[i.getColorSchemeSelector(n).replace(/(\[[^\]]+\])/,"*:where($1)")]:r}:i.palette.mode===n?r:{}}const f3=["breakpoints","palette","spacing","shape"];function eO(n={},...r){const{breakpoints:i={},palette:l={},spacing:u,shape:c={}}=n,d=er(n,f3),p=FE(i),h=DN(u);let y=vr({breakpoints:p,direction:"ltr",components:{},palette:ge({mode:"light"},l),spacing:h,shape:ge({},EN,c)},d);return y.applyStyles=JE,y=r.reduce((m,g)=>vr(m,g),y),y.unstable_sxConfig=ge({},zo,d==null?void 0:d.unstable_sxConfig),y.unstable_sx=function(g){return Fs({sx:g,theme:this})},y}const d3=Object.freeze(Object.defineProperty({__proto__:null,default:eO,private_createBreakpoints:FE,unstable_applyStyles:JE},Symbol.toStringTag,{value:"Module"})),p3=["sx"],h3=n=>{var r,i;const l={systemProps:{},otherProps:{}},u=(r=n==null||(i=n.theme)==null?void 0:i.unstable_sxConfig)!=null?r:zo;return Object.keys(n).forEach(c=>{u[c]?l.systemProps[c]=n[c]:l.otherProps[c]=n[c]}),l};function y3(n){const{sx:r}=n,i=er(n,p3),{systemProps:l,otherProps:u}=h3(i);let c;return Array.isArray(r)?c=[l,...r]:typeof r=="function"?c=(...d)=>{const p=r(...d);return xa(p)?ge({},l,p):l}:c=ge({},l,r),ge({},u,{sx:c})}const v3=Object.freeze(Object.defineProperty({__proto__:null,default:Fs,extendSxProp:y3,unstable_createStyleFunctionSx:WE,unstable_defaultSxConfig:zo},Symbol.toStringTag,{value:"Module"})),Bb=n=>n,m3=()=>{let n=Bb;return{configure(r){n=r},generate(r){return n(r)},reset(){n=Bb}}},g3=m3();function tO(n){var r,i,l="";if(typeof n=="string"||typeof n=="number")l+=n;else if(typeof n=="object")if(Array.isArray(n)){var u=n.length;for(r=0;r<u;r++)n[r]&&(i=tO(n[r]))&&(l&&(l+=" "),l+=i)}else for(i in n)n[i]&&(l&&(l+=" "),l+=i);return l}function Oa(){for(var n,r,i=0,l="",u=arguments.length;i<u;i++)(n=arguments[i])&&(r=tO(n))&&(l&&(l+=" "),l+=r);return l}const b3={active:"active",checked:"checked",completed:"completed",disabled:"disabled",error:"error",expanded:"expanded",focused:"focused",focusVisible:"focusVisible",open:"open",readOnly:"readOnly",required:"required",selected:"selected"};function nO(n,r,i="Mui"){const l=b3[r];return l?`${i}-${l}`:`${g3.generate(n)}-${r}`}function S3(n,r,i="Mui"){const l={};return r.forEach(u=>{l[u]=nO(n,u,i)}),l}var Rd={exports:{}},st={};/**
 * @license React
 * react-is.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var $b;function x3(){if($b)return st;$b=1;var n=Symbol.for("react.transitional.element"),r=Symbol.for("react.portal"),i=Symbol.for("react.fragment"),l=Symbol.for("react.strict_mode"),u=Symbol.for("react.profiler"),c=Symbol.for("react.consumer"),d=Symbol.for("react.context"),p=Symbol.for("react.forward_ref"),h=Symbol.for("react.suspense"),y=Symbol.for("react.suspense_list"),m=Symbol.for("react.memo"),g=Symbol.for("react.lazy"),S=Symbol.for("react.view_transition"),R=Symbol.for("react.client.reference");function _(E){if(typeof E=="object"&&E!==null){var C=E.$$typeof;switch(C){case n:switch(E=E.type,E){case i:case u:case l:case h:case y:case S:return E;default:switch(E=E&&E.$$typeof,E){case d:case p:case g:case m:return E;case c:return E;default:return C}}case r:return C}}}return st.ContextConsumer=c,st.ContextProvider=d,st.Element=n,st.ForwardRef=p,st.Fragment=i,st.Lazy=g,st.Memo=m,st.Portal=r,st.Profiler=u,st.StrictMode=l,st.Suspense=h,st.SuspenseList=y,st.isContextConsumer=function(E){return _(E)===c},st.isContextProvider=function(E){return _(E)===d},st.isElement=function(E){return typeof E=="object"&&E!==null&&E.$$typeof===n},st.isForwardRef=function(E){return _(E)===p},st.isFragment=function(E){return _(E)===i},st.isLazy=function(E){return _(E)===g},st.isMemo=function(E){return _(E)===m},st.isPortal=function(E){return _(E)===r},st.isProfiler=function(E){return _(E)===u},st.isStrictMode=function(E){return _(E)===l},st.isSuspense=function(E){return _(E)===h},st.isSuspenseList=function(E){return _(E)===y},st.isValidElementType=function(E){return typeof E=="string"||typeof E=="function"||E===i||E===u||E===l||E===h||E===y||typeof E=="object"&&E!==null&&(E.$$typeof===g||E.$$typeof===m||E.$$typeof===d||E.$$typeof===c||E.$$typeof===p||E.$$typeof===R||E.getModuleId!==void 0)},st.typeOf=_,st}var qb;function E3(){return qb||(qb=1,Rd.exports=x3()),Rd.exports}var zb=E3();const O3=/^\s*function(?:\s|\s*\/\*.*\*\/\s*)+([^(\s/]*)\s*/;function rO(n){const r=`${n}`.match(O3);return r&&r[1]||""}function aO(n,r=""){return n.displayName||n.name||rO(n)||r}function kb(n,r,i){const l=aO(r);return n.displayName||(l!==""?`${i}(${l})`:i)}function T3(n){if(n!=null){if(typeof n=="string")return n;if(typeof n=="function")return aO(n,"Component");if(typeof n=="object")switch(n.$$typeof){case zb.ForwardRef:return kb(n,n.render,"ForwardRef");case zb.Memo:return kb(n,n.type,"memo");default:return}}}const _3=Object.freeze(Object.defineProperty({__proto__:null,default:T3,getFunctionName:rO},Symbol.toStringTag,{value:"Module"}));function Hh(n,r){const i=ge({},r);return Object.keys(n).forEach(l=>{if(l.toString().match(/^(components|slots)$/))i[l]=ge({},n[l],i[l]);else if(l.toString().match(/^(componentsProps|slotProps)$/)){const u=n[l]||{},c=r[l];i[l]={},!c||!Object.keys(c)?i[l]=u:!u||!Object.keys(u)?i[l]=c:(i[l]=ge({},c),Object.keys(u).forEach(d=>{i[l][d]=Hh(u[d],c[d])}))}else i[l]===void 0&&(i[l]=n[l])}),i}const iO=typeof window<"u"?x.useLayoutEffect:x.useEffect;function Vi(n,r=Number.MIN_SAFE_INTEGER,i=Number.MAX_SAFE_INTEGER){return Math.max(r,Math.min(n,i))}const A3=Object.freeze(Object.defineProperty({__proto__:null,default:Vi},Symbol.toStringTag,{value:"Module"}));function ms(n){return n&&n.ownerDocument||document}function R3(n,r){typeof n=="function"?n(r):n&&(n.current=r)}function w3({controlled:n,default:r,name:i,state:l="value"}){const{current:u}=x.useRef(n!==void 0),[c,d]=x.useState(r),p=u?n:c,h=x.useCallback(y=>{u||d(y)},[]);return[p,h]}function wd(n){const r=x.useRef(n);return iO(()=>{r.current=n}),x.useRef((...i)=>(0,r.current)(...i)).current}function Gh(...n){return x.useMemo(()=>n.every(r=>r==null)?null:r=>{n.forEach(i=>{R3(i,r)})},n)}class Cy{constructor(){this.currentId=null,this.clear=()=>{this.currentId!==null&&(clearTimeout(this.currentId),this.currentId=null)},this.disposeEffect=()=>this.clear}static create(){return new Cy}start(r,i){this.clear(),this.currentId=setTimeout(()=>{this.currentId=null,i()},r)}}let Zs=!0,Yh=!1;const C3=new Cy,N3={text:!0,search:!0,url:!0,tel:!0,email:!0,password:!0,number:!0,date:!0,month:!0,week:!0,time:!0,datetime:!0,"datetime-local":!0};function M3(n){const{type:r,tagName:i}=n;return!!(i==="INPUT"&&N3[r]&&!n.readOnly||i==="TEXTAREA"&&!n.readOnly||n.isContentEditable)}function D3(n){n.metaKey||n.altKey||n.ctrlKey||(Zs=!0)}function Cd(){Zs=!1}function j3(){this.visibilityState==="hidden"&&Yh&&(Zs=!0)}function B3(n){n.addEventListener("keydown",D3,!0),n.addEventListener("mousedown",Cd,!0),n.addEventListener("pointerdown",Cd,!0),n.addEventListener("touchstart",Cd,!0),n.addEventListener("visibilitychange",j3,!0)}function $3(n){const{target:r}=n;try{return r.matches(":focus-visible")}catch{}return Zs||M3(r)}function q3(){const n=x.useCallback(u=>{u!=null&&B3(u.ownerDocument)},[]),r=x.useRef(!1);function i(){return r.current?(Yh=!0,C3.start(100,()=>{Yh=!1}),r.current=!1,!0):!1}function l(u){return $3(u)?(r.current=!0,!0):!1}return{isFocusVisibleRef:r,onFocus:l,onBlur:i,ref:n}}const z3={border:0,clip:"rect(0 0 0 0)",height:"1px",margin:"-1px",overflow:"hidden",padding:0,position:"absolute",whiteSpace:"nowrap",width:"1px"};function k3(n,r,i=void 0){const l={};return Object.keys(n).forEach(u=>{l[u]=n[u].reduce((c,d)=>{if(d){const p=r(d);p!==""&&c.push(p),i&&i[d]&&c.push(i[d])}return c},[]).join(" ")}),l}function vo(n){return typeof n=="string"}function L3(n,r,i){return n===void 0||vo(n)?r:ge({},r,{ownerState:ge({},r.ownerState,i)})}function gs(n,r=[]){if(n===void 0)return{};const i={};return Object.keys(n).filter(l=>l.match(/^on[A-Z]/)&&typeof n[l]=="function"&&!r.includes(l)).forEach(l=>{i[l]=n[l]}),i}function Lb(n){if(n===void 0)return{};const r={};return Object.keys(n).filter(i=>!(i.match(/^on[A-Z]/)&&typeof n[i]=="function")).forEach(i=>{r[i]=n[i]}),r}function U3(n){const{getSlotProps:r,additionalProps:i,externalSlotProps:l,externalForwardedProps:u,className:c}=n;if(!r){const R=Oa(i==null?void 0:i.className,c,u==null?void 0:u.className,l==null?void 0:l.className),_=ge({},i==null?void 0:i.style,u==null?void 0:u.style,l==null?void 0:l.style),E=ge({},i,u,l);return R.length>0&&(E.className=R),Object.keys(_).length>0&&(E.style=_),{props:E,internalRef:void 0}}const d=gs(ge({},u,l)),p=Lb(l),h=Lb(u),y=r(d),m=Oa(y==null?void 0:y.className,i==null?void 0:i.className,c,u==null?void 0:u.className,l==null?void 0:l.className),g=ge({},y==null?void 0:y.style,i==null?void 0:i.style,u==null?void 0:u.style,l==null?void 0:l.style),S=ge({},y,i,h,p);return m.length>0&&(S.className=m),Object.keys(g).length>0&&(S.style=g),{props:S,internalRef:y.ref}}function H3(n,r,i){return typeof n=="function"?n(r,i):n}const G3=["elementType","externalSlotProps","ownerState","skipResolvingSlotProps"];function ba(n){var r;const{elementType:i,externalSlotProps:l,ownerState:u,skipResolvingSlotProps:c=!1}=n,d=er(n,G3),p=c?{}:H3(l,u),{props:h,internalRef:y}=U3(ge({},d,{externalSlotProps:p})),m=Gh(y,p==null?void 0:p.ref,(r=n.additionalProps)==null?void 0:r.ref);return L3(i,ge({},h,{ref:m}),u)}const Y3=x.createContext(),V3=()=>{const n=x.useContext(Y3);return n??!1},P3=x.createContext(void 0);function X3(n){const{theme:r,name:i,props:l}=n;if(!r||!r.components||!r.components[i])return l;const u=r.components[i];return u.defaultProps?Hh(u.defaultProps,l):!u.styleOverrides&&!u.variants?Hh(u,l):l}function Q3({props:n,name:r}){const i=x.useContext(P3);return X3({props:n,name:r,theme:{components:i}})}function K3(n,r){return ge({toolbar:{minHeight:56,[n.up("xs")]:{"@media (orientation: landscape)":{minHeight:48}},[n.up("sm")]:{minHeight:64}}},r)}var bt={},Nd={exports:{}},Ub;function lO(){return Ub||(Ub=1,function(n){function r(i){return i&&i.__esModule?i:{default:i}}n.exports=r,n.exports.__esModule=!0,n.exports.default=n.exports}(Nd)),Nd.exports}const F3=Qr(pC),Z3=Qr(A3);var Hb;function I3(){if(Hb)return bt;Hb=1;var n=lO();Object.defineProperty(bt,"__esModule",{value:!0}),bt.alpha=_,bt.blend=$,bt.colorChannel=void 0,bt.darken=C,bt.decomposeColor=d,bt.emphasize=X,bt.getContrastRatio=R,bt.getLuminance=S,bt.hexToRgb=u,bt.hslToRgb=g,bt.lighten=M,bt.private_safeAlpha=E,bt.private_safeColorChannel=void 0,bt.private_safeDarken=j,bt.private_safeEmphasize=A,bt.private_safeLighten=B,bt.recomposeColor=y,bt.rgbToHex=m;var r=n(F3),i=n(Z3);function l(O,q=0,L=1){return(0,i.default)(O,q,L)}function u(O){O=O.slice(1);const q=new RegExp(`.{1,${O.length>=6?2:1}}`,"g");let L=O.match(q);return L&&L[0].length===1&&(L=L.map(Y=>Y+Y)),L?`rgb${L.length===4?"a":""}(${L.map((Y,W)=>W<3?parseInt(Y,16):Math.round(parseInt(Y,16)/255*1e3)/1e3).join(", ")})`:""}function c(O){const q=O.toString(16);return q.length===1?`0${q}`:q}function d(O){if(O.type)return O;if(O.charAt(0)==="#")return d(u(O));const q=O.indexOf("("),L=O.substring(0,q);if(["rgb","rgba","hsl","hsla","color"].indexOf(L)===-1)throw new Error((0,r.default)(9,O));let Y=O.substring(q+1,O.length-1),W;if(L==="color"){if(Y=Y.split(" "),W=Y.shift(),Y.length===4&&Y[3].charAt(0)==="/"&&(Y[3]=Y[3].slice(1)),["srgb","display-p3","a98-rgb","prophoto-rgb","rec-2020"].indexOf(W)===-1)throw new Error((0,r.default)(10,W))}else Y=Y.split(",");return Y=Y.map(oe=>parseFloat(oe)),{type:L,values:Y,colorSpace:W}}const p=O=>{const q=d(O);return q.values.slice(0,3).map((L,Y)=>q.type.indexOf("hsl")!==-1&&Y!==0?`${L}%`:L).join(" ")};bt.colorChannel=p;const h=(O,q)=>{try{return p(O)}catch{return O}};bt.private_safeColorChannel=h;function y(O){const{type:q,colorSpace:L}=O;let{values:Y}=O;return q.indexOf("rgb")!==-1?Y=Y.map((W,oe)=>oe<3?parseInt(W,10):W):q.indexOf("hsl")!==-1&&(Y[1]=`${Y[1]}%`,Y[2]=`${Y[2]}%`),q.indexOf("color")!==-1?Y=`${L} ${Y.join(" ")}`:Y=`${Y.join(", ")}`,`${q}(${Y})`}function m(O){if(O.indexOf("#")===0)return O;const{values:q}=d(O);return`#${q.map((L,Y)=>c(Y===3?Math.round(255*L):L)).join("")}`}function g(O){O=d(O);const{values:q}=O,L=q[0],Y=q[1]/100,W=q[2]/100,oe=Y*Math.min(W,1-W),ue=(H,I=(H+L/30)%12)=>W-oe*Math.max(Math.min(I-3,9-I,1),-1);let he="rgb";const fe=[Math.round(ue(0)*255),Math.round(ue(8)*255),Math.round(ue(4)*255)];return O.type==="hsla"&&(he+="a",fe.push(q[3])),y({type:he,values:fe})}function S(O){O=d(O);let q=O.type==="hsl"||O.type==="hsla"?d(g(O)).values:O.values;return q=q.map(L=>(O.type!=="color"&&(L/=255),L<=.03928?L/12.92:((L+.055)/1.055)**2.4)),Number((.2126*q[0]+.7152*q[1]+.0722*q[2]).toFixed(3))}function R(O,q){const L=S(O),Y=S(q);return(Math.max(L,Y)+.05)/(Math.min(L,Y)+.05)}function _(O,q){return O=d(O),q=l(q),(O.type==="rgb"||O.type==="hsl")&&(O.type+="a"),O.type==="color"?O.values[3]=`/${q}`:O.values[3]=q,y(O)}function E(O,q,L){try{return _(O,q)}catch{return O}}function C(O,q){if(O=d(O),q=l(q),O.type.indexOf("hsl")!==-1)O.values[2]*=1-q;else if(O.type.indexOf("rgb")!==-1||O.type.indexOf("color")!==-1)for(let L=0;L<3;L+=1)O.values[L]*=1-q;return y(O)}function j(O,q,L){try{return C(O,q)}catch{return O}}function M(O,q){if(O=d(O),q=l(q),O.type.indexOf("hsl")!==-1)O.values[2]+=(100-O.values[2])*q;else if(O.type.indexOf("rgb")!==-1)for(let L=0;L<3;L+=1)O.values[L]+=(255-O.values[L])*q;else if(O.type.indexOf("color")!==-1)for(let L=0;L<3;L+=1)O.values[L]+=(1-O.values[L])*q;return y(O)}function B(O,q,L){try{return M(O,q)}catch{return O}}function X(O,q=.15){return S(O)>.5?C(O,q):M(O,q)}function A(O,q,L){try{return X(O,q)}catch{return O}}function $(O,q,L,Y=1){const W=(fe,H)=>Math.round((fe**(1/Y)*(1-L)+H**(1/Y)*L)**Y),oe=d(O),ue=d(q),he=[W(oe.values[0],ue.values[0]),W(oe.values[1],ue.values[1]),W(oe.values[2],ue.values[2])];return y({type:"rgb",values:he})}return bt}var Hr=I3();const W3=["mode","contrastThreshold","tonalOffset"],Gb={text:{primary:"rgba(0, 0, 0, 0.87)",secondary:"rgba(0, 0, 0, 0.6)",disabled:"rgba(0, 0, 0, 0.38)"},divider:"rgba(0, 0, 0, 0.12)",background:{paper:xo.white,default:xo.white},action:{active:"rgba(0, 0, 0, 0.54)",hover:"rgba(0, 0, 0, 0.04)",hoverOpacity:.04,selected:"rgba(0, 0, 0, 0.08)",selectedOpacity:.08,disabled:"rgba(0, 0, 0, 0.26)",disabledBackground:"rgba(0, 0, 0, 0.12)",disabledOpacity:.38,focus:"rgba(0, 0, 0, 0.12)",focusOpacity:.12,activatedOpacity:.12}},Md={text:{primary:xo.white,secondary:"rgba(255, 255, 255, 0.7)",disabled:"rgba(255, 255, 255, 0.5)",icon:"rgba(255, 255, 255, 0.5)"},divider:"rgba(255, 255, 255, 0.12)",background:{paper:"#121212",default:"#121212"},action:{active:xo.white,hover:"rgba(255, 255, 255, 0.08)",hoverOpacity:.08,selected:"rgba(255, 255, 255, 0.16)",selectedOpacity:.16,disabled:"rgba(255, 255, 255, 0.3)",disabledBackground:"rgba(255, 255, 255, 0.12)",disabledOpacity:.38,focus:"rgba(255, 255, 255, 0.12)",focusOpacity:.12,activatedOpacity:.24}};function Yb(n,r,i,l){const u=l.light||l,c=l.dark||l*1.5;n[r]||(n.hasOwnProperty(i)?n[r]=n[i]:r==="light"?n.light=Hr.lighten(n.main,u):r==="dark"&&(n.dark=Hr.darken(n.main,c)))}function J3(n="light"){return n==="dark"?{main:Ui[200],light:Ui[50],dark:Ui[400]}:{main:Ui[700],light:Ui[400],dark:Ui[800]}}function e4(n="light"){return n==="dark"?{main:Li[200],light:Li[50],dark:Li[400]}:{main:Li[500],light:Li[300],dark:Li[700]}}function t4(n="light"){return n==="dark"?{main:ki[500],light:ki[300],dark:ki[700]}:{main:ki[700],light:ki[400],dark:ki[800]}}function n4(n="light"){return n==="dark"?{main:Hi[400],light:Hi[300],dark:Hi[700]}:{main:Hi[700],light:Hi[500],dark:Hi[900]}}function r4(n="light"){return n==="dark"?{main:Gi[400],light:Gi[300],dark:Gi[700]}:{main:Gi[800],light:Gi[500],dark:Gi[900]}}function a4(n="light"){return n==="dark"?{main:no[400],light:no[300],dark:no[700]}:{main:"#ed6c02",light:no[500],dark:no[900]}}function i4(n){const{mode:r="light",contrastThreshold:i=3,tonalOffset:l=.2}=n,u=er(n,W3),c=n.primary||J3(r),d=n.secondary||e4(r),p=n.error||t4(r),h=n.info||n4(r),y=n.success||r4(r),m=n.warning||a4(r);function g(E){return Hr.getContrastRatio(E,Md.text.primary)>=i?Md.text.primary:Gb.text.primary}const S=({color:E,name:C,mainShade:j=500,lightShade:M=300,darkShade:B=700})=>{if(E=ge({},E),!E.main&&E[j]&&(E.main=E[j]),!E.hasOwnProperty("main"))throw new Error(Eo(11,C?` (${C})`:"",j));if(typeof E.main!="string")throw new Error(Eo(12,C?` (${C})`:"",JSON.stringify(E.main)));return Yb(E,"light",M,l),Yb(E,"dark",B,l),E.contrastText||(E.contrastText=g(E.main)),E},R={dark:Md,light:Gb};return vr(ge({common:ge({},xo),mode:r,primary:S({color:c,name:"primary"}),secondary:S({color:d,name:"secondary",mainShade:"A400",lightShade:"A200",darkShade:"A700"}),error:S({color:p,name:"error"}),warning:S({color:m,name:"warning"}),info:S({color:h,name:"info"}),success:S({color:y,name:"success"}),grey:dC,contrastThreshold:i,getContrastText:g,augmentColor:S,tonalOffset:l},R[r]),u)}const l4=["fontFamily","fontSize","fontWeightLight","fontWeightRegular","fontWeightMedium","fontWeightBold","htmlFontSize","allVariants","pxToRem"];function o4(n){return Math.round(n*1e5)/1e5}const Vb={textTransform:"uppercase"},Pb='"Roboto", "Helvetica", "Arial", sans-serif';function u4(n,r){const i=typeof r=="function"?r(n):r,{fontFamily:l=Pb,fontSize:u=14,fontWeightLight:c=300,fontWeightRegular:d=400,fontWeightMedium:p=500,fontWeightBold:h=700,htmlFontSize:y=16,allVariants:m,pxToRem:g}=i,S=er(i,l4),R=u/14,_=g||(j=>`${j/y*R}rem`),E=(j,M,B,X,A)=>ge({fontFamily:l,fontWeight:j,fontSize:_(M),lineHeight:B},l===Pb?{letterSpacing:`${o4(X/M)}em`}:{},A,m),C={h1:E(c,96,1.167,-1.5),h2:E(c,60,1.2,-.5),h3:E(d,48,1.167,0),h4:E(d,34,1.235,.25),h5:E(d,24,1.334,0),h6:E(p,20,1.6,.15),subtitle1:E(d,16,1.75,.15),subtitle2:E(p,14,1.57,.1),body1:E(d,16,1.5,.15),body2:E(d,14,1.43,.15),button:E(p,14,1.75,.4,Vb),caption:E(d,12,1.66,.4),overline:E(d,12,2.66,1,Vb),inherit:{fontFamily:"inherit",fontWeight:"inherit",fontSize:"inherit",lineHeight:"inherit",letterSpacing:"inherit"}};return vr(ge({htmlFontSize:y,pxToRem:_,fontFamily:l,fontSize:u,fontWeightLight:c,fontWeightRegular:d,fontWeightMedium:p,fontWeightBold:h},C),S,{clone:!1})}const s4=.2,c4=.14,f4=.12;function vt(...n){return[`${n[0]}px ${n[1]}px ${n[2]}px ${n[3]}px rgba(0,0,0,${s4})`,`${n[4]}px ${n[5]}px ${n[6]}px ${n[7]}px rgba(0,0,0,${c4})`,`${n[8]}px ${n[9]}px ${n[10]}px ${n[11]}px rgba(0,0,0,${f4})`].join(",")}const d4=["none",vt(0,2,1,-1,0,1,1,0,0,1,3,0),vt(0,3,1,-2,0,2,2,0,0,1,5,0),vt(0,3,3,-2,0,3,4,0,0,1,8,0),vt(0,2,4,-1,0,4,5,0,0,1,10,0),vt(0,3,5,-1,0,5,8,0,0,1,14,0),vt(0,3,5,-1,0,6,10,0,0,1,18,0),vt(0,4,5,-2,0,7,10,1,0,2,16,1),vt(0,5,5,-3,0,8,10,1,0,3,14,2),vt(0,5,6,-3,0,9,12,1,0,3,16,2),vt(0,6,6,-3,0,10,14,1,0,4,18,3),vt(0,6,7,-4,0,11,15,1,0,4,20,3),vt(0,7,8,-4,0,12,17,2,0,5,22,4),vt(0,7,8,-4,0,13,19,2,0,5,24,4),vt(0,7,9,-4,0,14,21,2,0,5,26,4),vt(0,8,9,-5,0,15,22,2,0,6,28,5),vt(0,8,10,-5,0,16,24,2,0,6,30,5),vt(0,8,11,-5,0,17,26,2,0,6,32,5),vt(0,9,11,-5,0,18,28,2,0,7,34,6),vt(0,9,12,-6,0,19,29,2,0,7,36,6),vt(0,10,13,-6,0,20,31,3,0,8,38,7),vt(0,10,13,-6,0,21,33,3,0,8,40,7),vt(0,10,14,-6,0,22,35,3,0,8,42,7),vt(0,11,14,-7,0,23,36,3,0,9,44,8),vt(0,11,15,-7,0,24,38,3,0,9,46,8)],p4=["duration","easing","delay"],h4={easeInOut:"cubic-bezier(0.4, 0, 0.2, 1)",easeOut:"cubic-bezier(0.0, 0, 0.2, 1)",easeIn:"cubic-bezier(0.4, 0, 1, 1)",sharp:"cubic-bezier(0.4, 0, 0.6, 1)"},y4={shortest:150,shorter:200,short:250,standard:300,complex:375,enteringScreen:225,leavingScreen:195};function Xb(n){return`${Math.round(n)}ms`}function v4(n){if(!n)return 0;const r=n/36;return Math.round((4+15*r**.25+r/5)*10)}function m4(n){const r=ge({},h4,n.easing),i=ge({},y4,n.duration);return ge({getAutoHeightDuration:v4,create:(u=["all"],c={})=>{const{duration:d=i.standard,easing:p=r.easeInOut,delay:h=0}=c;return er(c,p4),(Array.isArray(u)?u:[u]).map(y=>`${y} ${typeof d=="string"?d:Xb(d)} ${p} ${typeof h=="string"?h:Xb(h)}`).join(",")}},n,{easing:r,duration:i})}const g4={mobileStepper:1e3,fab:1050,speedDial:1050,appBar:1100,drawer:1200,modal:1300,snackbar:1400,tooltip:1500},b4=["breakpoints","mixins","spacing","palette","transitions","typography","shape"];function S4(n={},...r){const{mixins:i={},palette:l={},transitions:u={},typography:c={}}=n,d=er(n,b4);if(n.vars&&n.generateCssVars===void 0)throw new Error(Eo(18));const p=i4(l),h=eO(n);let y=vr(h,{mixins:K3(h.breakpoints,i),palette:p,shadows:d4.slice(),typography:u4(p,c),transitions:m4(u),zIndex:ge({},g4)});return y=vr(y,d),y=r.reduce((m,g)=>vr(m,g),y),y.unstable_sxConfig=ge({},zo,d==null?void 0:d.unstable_sxConfig),y.unstable_sx=function(g){return Fs({sx:g,theme:this})},y}const x4=S4();var Xa={},Dd={exports:{}},Qb;function E4(){return Qb||(Qb=1,function(n){function r(){return n.exports=r=Object.assign?Object.assign.bind():function(i){for(var l=1;l<arguments.length;l++){var u=arguments[l];for(var c in u)({}).hasOwnProperty.call(u,c)&&(i[c]=u[c])}return i},n.exports.__esModule=!0,n.exports.default=n.exports,r.apply(null,arguments)}n.exports=r,n.exports.__esModule=!0,n.exports.default=n.exports}(Dd)),Dd.exports}var jd={exports:{}},Kb;function O4(){return Kb||(Kb=1,function(n){function r(i,l){if(i==null)return{};var u={};for(var c in i)if({}.hasOwnProperty.call(i,c)){if(l.indexOf(c)!==-1)continue;u[c]=i[c]}return u}n.exports=r,n.exports.__esModule=!0,n.exports.default=n.exports}(jd)),jd.exports}const T4=Qr(gN),_4=Qr(bN),A4=Qr(_N),R4=Qr(_3),w4=Qr(d3),C4=Qr(v3);var Fb;function N4(){if(Fb)return Xa;Fb=1;var n=lO();Object.defineProperty(Xa,"__esModule",{value:!0}),Xa.default=X,Xa.shouldForwardProp=_,Xa.systemDefaultTheme=void 0;var r=n(E4()),i=n(O4()),l=g(T4),u=_4;n(A4),n(R4);var c=n(w4),d=n(C4);const p=["ownerState"],h=["variants"],y=["name","slot","skipVariantsResolver","skipSx","overridesResolver"];function m(A){if(typeof WeakMap!="function")return null;var $=new WeakMap,O=new WeakMap;return(m=function(q){return q?O:$})(A)}function g(A,$){if(A&&A.__esModule)return A;if(A===null||typeof A!="object"&&typeof A!="function")return{default:A};var O=m($);if(O&&O.has(A))return O.get(A);var q={__proto__:null},L=Object.defineProperty&&Object.getOwnPropertyDescriptor;for(var Y in A)if(Y!=="default"&&Object.prototype.hasOwnProperty.call(A,Y)){var W=L?Object.getOwnPropertyDescriptor(A,Y):null;W&&(W.get||W.set)?Object.defineProperty(q,Y,W):q[Y]=A[Y]}return q.default=A,O&&O.set(A,q),q}function S(A){return Object.keys(A).length===0}function R(A){return typeof A=="string"&&A.charCodeAt(0)>96}function _(A){return A!=="ownerState"&&A!=="theme"&&A!=="sx"&&A!=="as"}const E=Xa.systemDefaultTheme=(0,c.default)(),C=A=>A&&A.charAt(0).toLowerCase()+A.slice(1);function j({defaultTheme:A,theme:$,themeId:O}){return S($)?A:$[O]||$}function M(A){return A?($,O)=>O[A]:null}function B(A,$){let{ownerState:O}=$,q=(0,i.default)($,p);const L=typeof A=="function"?A((0,r.default)({ownerState:O},q)):A;if(Array.isArray(L))return L.flatMap(Y=>B(Y,(0,r.default)({ownerState:O},q)));if(L&&typeof L=="object"&&Array.isArray(L.variants)){const{variants:Y=[]}=L;let oe=(0,i.default)(L,h);return Y.forEach(ue=>{let he=!0;typeof ue.props=="function"?he=ue.props((0,r.default)({ownerState:O},q,O)):Object.keys(ue.props).forEach(fe=>{(O==null?void 0:O[fe])!==ue.props[fe]&&q[fe]!==ue.props[fe]&&(he=!1)}),he&&(Array.isArray(oe)||(oe=[oe]),oe.push(typeof ue.style=="function"?ue.style((0,r.default)({ownerState:O},q,O)):ue.style))}),oe}return L}function X(A={}){const{themeId:$,defaultTheme:O=E,rootShouldForwardProp:q=_,slotShouldForwardProp:L=_}=A,Y=W=>(0,d.default)((0,r.default)({},W,{theme:j((0,r.default)({},W,{defaultTheme:O,themeId:$}))}));return Y.__mui_systemSx=!0,(W,oe={})=>{(0,l.internal_processStyles)(W,te=>te.filter(pe=>!(pe!=null&&pe.__mui_systemSx)));const{name:ue,slot:he,skipVariantsResolver:fe,skipSx:H,overridesResolver:I=M(C(he))}=oe,ae=(0,i.default)(oe,y),be=fe!==void 0?fe:he&&he!=="Root"&&he!=="root"||!1,N=H||!1;let Z,le=_;he==="Root"||he==="root"?le=q:he?le=L:R(W)&&(le=void 0);const re=(0,l.default)(W,(0,r.default)({shouldForwardProp:le,label:Z},ae)),z=te=>typeof te=="function"&&te.__emotion_real!==te||(0,u.isPlainObject)(te)?pe=>B(te,(0,r.default)({},pe,{theme:j({theme:pe.theme,defaultTheme:O,themeId:$})})):te,F=(te,...pe)=>{let ce=z(te);const xe=pe?pe.map(z):[];ue&&I&&xe.push(de=>{const ve=j((0,r.default)({},de,{defaultTheme:O,themeId:$}));if(!ve.components||!ve.components[ue]||!ve.components[ue].styleOverrides)return null;const Oe=ve.components[ue].styleOverrides,ye={};return Object.entries(Oe).forEach(([je,Me])=>{ye[je]=B(Me,(0,r.default)({},de,{theme:ve}))}),I(de,ye)}),ue&&!be&&xe.push(de=>{var ve;const Oe=j((0,r.default)({},de,{defaultTheme:O,themeId:$})),ye=Oe==null||(ve=Oe.components)==null||(ve=ve[ue])==null?void 0:ve.variants;return B({variants:ye},(0,r.default)({},de,{theme:Oe}))}),N||xe.push(Y);const me=xe.length-pe.length;if(Array.isArray(te)&&me>0){const de=new Array(me).fill("");ce=[...te,...de],ce.raw=[...te.raw,...de]}const Ee=re(ce,...xe);return W.muiName&&(Ee.muiName=W.muiName),Ee};return re.withConfig&&(F.withConfig=re.withConfig),F}}return Xa}var M4=N4();const D4=_a(M4);function Ny(n){return n!=="ownerState"&&n!=="theme"&&n!=="sx"&&n!=="as"}const j4=n=>Ny(n)&&n!=="classes",Ia=D4({themeId:hC,defaultTheme:x4,rootShouldForwardProp:j4});function B4(n){return Q3(n)}function $4(n,r,i=(l,u)=>l===u){return n.length===r.length&&n.every((l,u)=>i(l,r[u]))}const q4=2;function oO(n,r){return n-r}function Zb(n,r){var i;const{index:l}=(i=n.reduce((u,c,d)=>{const p=Math.abs(r-c);return u===null||p<u.distance||p===u.distance?{distance:p,index:d}:u},null))!=null?i:{};return l}function es(n,r){if(r.current!==void 0&&n.changedTouches){const i=n;for(let l=0;l<i.changedTouches.length;l+=1){const u=i.changedTouches[l];if(u.identifier===r.current)return{x:u.clientX,y:u.clientY}}return!1}return{x:n.clientX,y:n.clientY}}function ws(n,r,i){return(n-r)*100/(i-r)}function z4(n,r,i){return(i-r)*n+r}function k4(n){if(Math.abs(n)<1){const i=n.toExponential().split("e-"),l=i[0].split(".")[1];return(l?l.length:0)+parseInt(i[1],10)}const r=n.toString().split(".")[1];return r?r.length:0}function L4(n,r,i){const l=Math.round((n-i)/r)*r+i;return Number(l.toFixed(k4(r)))}function Ib({values:n,newValue:r,index:i}){const l=n.slice();return l[i]=r,l.sort(oO)}function ts({sliderRef:n,activeIndex:r,setActive:i}){var l,u;const c=ms(n.current);if(!((l=n.current)!=null&&l.contains(c.activeElement))||Number(c==null||(u=c.activeElement)==null?void 0:u.getAttribute("data-index"))!==r){var d;(d=n.current)==null||d.querySelector(`[type="range"][data-index="${r}"]`).focus()}i&&i(r)}function ns(n,r){return typeof n=="number"&&typeof r=="number"?n===r:typeof n=="object"&&typeof r=="object"?$4(n,r):!1}const U4={horizontal:{offset:n=>({left:`${n}%`}),leap:n=>({width:`${n}%`})},"horizontal-reverse":{offset:n=>({right:`${n}%`}),leap:n=>({width:`${n}%`})},vertical:{offset:n=>({bottom:`${n}%`}),leap:n=>({height:`${n}%`})}},H4=n=>n;let rs;function Wb(){return rs===void 0&&(typeof CSS<"u"&&typeof CSS.supports=="function"?rs=CSS.supports("touch-action","none"):rs=!0),rs}function G4(n){const{"aria-labelledby":r,defaultValue:i,disabled:l=!1,disableSwap:u=!1,isRtl:c=!1,marks:d=!1,max:p=100,min:h=0,name:y,onChange:m,onChangeCommitted:g,orientation:S="horizontal",rootRef:R,scale:_=H4,step:E=1,shiftStep:C=10,tabIndex:j,value:M}=n,B=x.useRef(void 0),[X,A]=x.useState(-1),[$,O]=x.useState(-1),[q,L]=x.useState(!1),Y=x.useRef(0),[W,oe]=w3({controlled:M,default:i??h,name:"Slider"}),ue=m&&((ie,se,Te)=>{const Ue=ie.nativeEvent||ie,Ye=new Ue.constructor(Ue.type,Ue);Object.defineProperty(Ye,"target",{writable:!0,value:{value:se,name:y}}),m(Ye,se,Te)}),he=Array.isArray(W);let fe=he?W.slice().sort(oO):[W];fe=fe.map(ie=>ie==null?h:Vi(ie,h,p));const H=d===!0&&E!==null?[...Array(Math.floor((p-h)/E)+1)].map((ie,se)=>({value:h+E*se})):d||[],I=H.map(ie=>ie.value),{isFocusVisibleRef:ae,onBlur:be,onFocus:N,ref:Z}=q3(),[le,re]=x.useState(-1),z=x.useRef(null),F=Gh(Z,z),te=Gh(R,F),pe=ie=>se=>{var Te;const Ue=Number(se.currentTarget.getAttribute("data-index"));N(se),ae.current===!0&&re(Ue),O(Ue),ie==null||(Te=ie.onFocus)==null||Te.call(ie,se)},ce=ie=>se=>{var Te;be(se),ae.current===!1&&re(-1),O(-1),ie==null||(Te=ie.onBlur)==null||Te.call(ie,se)},xe=(ie,se)=>{const Te=Number(ie.currentTarget.getAttribute("data-index")),Ue=fe[Te],Ye=I.indexOf(Ue);let Be=se;if(H&&E==null){const Nt=I[I.length-1];Be>Nt?Be=Nt:Be<I[0]?Be=I[0]:Be=Be<Ue?I[Ye-1]:I[Ye+1]}if(Be=Vi(Be,h,p),he){u&&(Be=Vi(Be,fe[Te-1]||-1/0,fe[Te+1]||1/0));const Nt=Be;Be=Ib({values:fe,newValue:Be,index:Te});let mt=Te;u||(mt=Be.indexOf(Nt)),ts({sliderRef:z,activeIndex:mt})}oe(Be),re(Te),ue&&!ns(Be,W)&&ue(ie,Be,Te),g&&g(ie,Be)},me=ie=>se=>{var Te;if(E!==null){const Ue=Number(se.currentTarget.getAttribute("data-index")),Ye=fe[Ue];let Be=null;(se.key==="ArrowLeft"||se.key==="ArrowDown")&&se.shiftKey||se.key==="PageDown"?Be=Math.max(Ye-C,h):((se.key==="ArrowRight"||se.key==="ArrowUp")&&se.shiftKey||se.key==="PageUp")&&(Be=Math.min(Ye+C,p)),Be!==null&&(xe(se,Be),se.preventDefault())}ie==null||(Te=ie.onKeyDown)==null||Te.call(ie,se)};iO(()=>{if(l&&z.current.contains(document.activeElement)){var ie;(ie=document.activeElement)==null||ie.blur()}},[l]),l&&X!==-1&&A(-1),l&&le!==-1&&re(-1);const Ee=ie=>se=>{var Te;(Te=ie.onChange)==null||Te.call(ie,se),xe(se,se.target.valueAsNumber)},de=x.useRef(void 0);let ve=S;c&&S==="horizontal"&&(ve+="-reverse");const Oe=({finger:ie,move:se=!1})=>{const{current:Te}=z,{width:Ue,height:Ye,bottom:Be,left:Nt}=Te.getBoundingClientRect();let mt;ve.indexOf("vertical")===0?mt=(Be-ie.y)/Ye:mt=(ie.x-Nt)/Ue,ve.indexOf("-reverse")!==-1&&(mt=1-mt);let k;if(k=z4(mt,h,p),E)k=L4(k,E,h);else{const qe=Zb(I,k);k=I[qe]}k=Vi(k,h,p);let V=0;if(he){se?V=de.current:V=Zb(fe,k),u&&(k=Vi(k,fe[V-1]||-1/0,fe[V+1]||1/0));const qe=k;k=Ib({values:fe,newValue:k,index:V}),u&&se||(V=k.indexOf(qe),de.current=V)}return{newValue:k,activeIndex:V}},ye=wd(ie=>{const se=es(ie,B);if(!se)return;if(Y.current+=1,ie.type==="mousemove"&&ie.buttons===0){je(ie);return}const{newValue:Te,activeIndex:Ue}=Oe({finger:se,move:!0});ts({sliderRef:z,activeIndex:Ue,setActive:A}),oe(Te),!q&&Y.current>q4&&L(!0),ue&&!ns(Te,W)&&ue(ie,Te,Ue)}),je=wd(ie=>{const se=es(ie,B);if(L(!1),!se)return;const{newValue:Te}=Oe({finger:se,move:!0});A(-1),ie.type==="touchend"&&O(-1),g&&g(ie,Te),B.current=void 0,Fe()}),Me=wd(ie=>{if(l)return;Wb()||ie.preventDefault();const se=ie.changedTouches[0];se!=null&&(B.current=se.identifier);const Te=es(ie,B);if(Te!==!1){const{newValue:Ye,activeIndex:Be}=Oe({finger:Te});ts({sliderRef:z,activeIndex:Be,setActive:A}),oe(Ye),ue&&!ns(Ye,W)&&ue(ie,Ye,Be)}Y.current=0;const Ue=ms(z.current);Ue.addEventListener("touchmove",ye,{passive:!0}),Ue.addEventListener("touchend",je,{passive:!0})}),Fe=x.useCallback(()=>{const ie=ms(z.current);ie.removeEventListener("mousemove",ye),ie.removeEventListener("mouseup",je),ie.removeEventListener("touchmove",ye),ie.removeEventListener("touchend",je)},[je,ye]);x.useEffect(()=>{const{current:ie}=z;return ie.addEventListener("touchstart",Me,{passive:Wb()}),()=>{ie.removeEventListener("touchstart",Me),Fe()}},[Fe,Me]),x.useEffect(()=>{l&&Fe()},[l,Fe]);const Ht=ie=>se=>{var Te;if((Te=ie.onMouseDown)==null||Te.call(ie,se),l||se.defaultPrevented||se.button!==0)return;se.preventDefault();const Ue=es(se,B);if(Ue!==!1){const{newValue:Be,activeIndex:Nt}=Oe({finger:Ue});ts({sliderRef:z,activeIndex:Nt,setActive:A}),oe(Be),ue&&!ns(Be,W)&&ue(se,Be,Nt)}Y.current=0;const Ye=ms(z.current);Ye.addEventListener("mousemove",ye,{passive:!0}),Ye.addEventListener("mouseup",je)},ze=ws(he?fe[0]:h,h,p),Ze=ws(fe[fe.length-1],h,p)-ze,Gt=(ie={})=>{const se=gs(ie),Te={onMouseDown:Ht(se||{})},Ue=ge({},se,Te);return ge({},ie,{ref:te},Ue)},$t=ie=>se=>{var Te;(Te=ie.onMouseOver)==null||Te.call(ie,se);const Ue=Number(se.currentTarget.getAttribute("data-index"));O(Ue)},qt=ie=>se=>{var Te;(Te=ie.onMouseLeave)==null||Te.call(ie,se),O(-1)};return{active:X,axis:ve,axisProps:U4,dragging:q,focusedThumbIndex:le,getHiddenInputProps:(ie={})=>{var se;const Te=gs(ie),Ue={onChange:Ee(Te||{}),onFocus:pe(Te||{}),onBlur:ce(Te||{}),onKeyDown:me(Te||{})},Ye=ge({},Te,Ue);return ge({tabIndex:j,"aria-labelledby":r,"aria-orientation":S,"aria-valuemax":_(p),"aria-valuemin":_(h),name:y,type:"range",min:n.min,max:n.max,step:n.step===null&&n.marks?"any":(se=n.step)!=null?se:void 0,disabled:l},ie,Ye,{style:ge({},z3,{direction:c?"rtl":"ltr",width:"100%",height:"100%"})})},getRootProps:Gt,getThumbProps:(ie={})=>{const se=gs(ie),Te={onMouseOver:$t(se||{}),onMouseLeave:qt(se||{})};return ge({},ie,se,Te)},marks:H,open:$,range:he,rootRef:te,trackLeap:Ze,trackOffset:ze,values:fe,getThumbStyle:ie=>({pointerEvents:X!==-1&&X!==ie?"none":void 0})}}const Y4=n=>!n||!vo(n);function V4(n){return nO("MuiSlider",n)}const Gn=S3("MuiSlider",["root","active","colorPrimary","colorSecondary","colorError","colorInfo","colorSuccess","colorWarning","disabled","dragging","focusVisible","mark","markActive","marked","markLabel","markLabelActive","rail","sizeSmall","thumb","thumbColorPrimary","thumbColorSecondary","thumbColorError","thumbColorSuccess","thumbColorInfo","thumbColorWarning","track","trackInverted","trackFalse","thumbSizeSmall","valueLabel","valueLabelOpen","valueLabelCircle","valueLabelLabel","vertical"]),P4=n=>{const{open:r}=n;return{offset:Oa(r&&Gn.valueLabelOpen),circle:Gn.valueLabelCircle,label:Gn.valueLabelLabel}};function X4(n){const{children:r,className:i,value:l}=n,u=P4(n);return r?x.cloneElement(r,{className:Oa(r.props.className)},T.jsxs(x.Fragment,{children:[r.props.children,T.jsx("span",{className:Oa(u.offset,i),"aria-hidden":!0,children:T.jsx("span",{className:u.circle,children:T.jsx("span",{className:u.label,children:l})})})]})):null}const Q4=["aria-label","aria-valuetext","aria-labelledby","component","components","componentsProps","color","classes","className","disableSwap","disabled","getAriaLabel","getAriaValueText","marks","max","min","name","onChange","onChangeCommitted","orientation","shiftStep","size","step","scale","slotProps","slots","tabIndex","track","value","valueLabelDisplay","valueLabelFormat"];function Jb(n){return n}const K4=Ia("span",{name:"MuiSlider",slot:"Root",overridesResolver:(n,r)=>{const{ownerState:i}=n;return[r.root,r[`color${Jn(i.color)}`],i.size!=="medium"&&r[`size${Jn(i.size)}`],i.marked&&r.marked,i.orientation==="vertical"&&r.vertical,i.track==="inverted"&&r.trackInverted,i.track===!1&&r.trackFalse]}})(({theme:n})=>{var r;return{borderRadius:12,boxSizing:"content-box",display:"inline-block",position:"relative",cursor:"pointer",touchAction:"none",WebkitTapHighlightColor:"transparent","@media print":{colorAdjust:"exact"},[`&.${Gn.disabled}`]:{pointerEvents:"none",cursor:"default",color:(n.vars||n).palette.grey[400]},[`&.${Gn.dragging}`]:{[`& .${Gn.thumb}, & .${Gn.track}`]:{transition:"none"}},variants:[...Object.keys(((r=n.vars)!=null?r:n).palette).filter(i=>{var l;return((l=n.vars)!=null?l:n).palette[i].main}).map(i=>({props:{color:i},style:{color:(n.vars||n).palette[i].main}})),{props:{orientation:"horizontal"},style:{height:4,width:"100%",padding:"13px 0","@media (pointer: coarse)":{padding:"20px 0"}}},{props:{orientation:"horizontal",size:"small"},style:{height:2}},{props:{orientation:"horizontal",marked:!0},style:{marginBottom:20}},{props:{orientation:"vertical"},style:{height:"100%",width:4,padding:"0 13px","@media (pointer: coarse)":{padding:"0 20px"}}},{props:{orientation:"vertical",size:"small"},style:{width:2}},{props:{orientation:"vertical",marked:!0},style:{marginRight:44}}]}}),F4=Ia("span",{name:"MuiSlider",slot:"Rail",overridesResolver:(n,r)=>r.rail})({display:"block",position:"absolute",borderRadius:"inherit",backgroundColor:"currentColor",opacity:.38,variants:[{props:{orientation:"horizontal"},style:{width:"100%",height:"inherit",top:"50%",transform:"translateY(-50%)"}},{props:{orientation:"vertical"},style:{height:"100%",width:"inherit",left:"50%",transform:"translateX(-50%)"}},{props:{track:"inverted"},style:{opacity:1}}]}),Z4=Ia("span",{name:"MuiSlider",slot:"Track",overridesResolver:(n,r)=>r.track})(({theme:n})=>{var r;return{display:"block",position:"absolute",borderRadius:"inherit",border:"1px solid currentColor",backgroundColor:"currentColor",transition:n.transitions.create(["left","width","bottom","height"],{duration:n.transitions.duration.shortest}),variants:[{props:{size:"small"},style:{border:"none"}},{props:{orientation:"horizontal"},style:{height:"inherit",top:"50%",transform:"translateY(-50%)"}},{props:{orientation:"vertical"},style:{width:"inherit",left:"50%",transform:"translateX(-50%)"}},{props:{track:!1},style:{display:"none"}},...Object.keys(((r=n.vars)!=null?r:n).palette).filter(i=>{var l;return((l=n.vars)!=null?l:n).palette[i].main}).map(i=>({props:{color:i,track:"inverted"},style:ge({},n.vars?{backgroundColor:n.vars.palette.Slider[`${i}Track`],borderColor:n.vars.palette.Slider[`${i}Track`]}:ge({backgroundColor:Hr.lighten(n.palette[i].main,.62),borderColor:Hr.lighten(n.palette[i].main,.62)},n.applyStyles("dark",{backgroundColor:Hr.darken(n.palette[i].main,.5)}),n.applyStyles("dark",{borderColor:Hr.darken(n.palette[i].main,.5)})))}))]}}),I4=Ia("span",{name:"MuiSlider",slot:"Thumb",overridesResolver:(n,r)=>{const{ownerState:i}=n;return[r.thumb,r[`thumbColor${Jn(i.color)}`],i.size!=="medium"&&r[`thumbSize${Jn(i.size)}`]]}})(({theme:n})=>{var r;return{position:"absolute",width:20,height:20,boxSizing:"border-box",borderRadius:"50%",outline:0,backgroundColor:"currentColor",display:"flex",alignItems:"center",justifyContent:"center",transition:n.transitions.create(["box-shadow","left","bottom"],{duration:n.transitions.duration.shortest}),"&::before":{position:"absolute",content:'""',borderRadius:"inherit",width:"100%",height:"100%",boxShadow:(n.vars||n).shadows[2]},"&::after":{position:"absolute",content:'""',borderRadius:"50%",width:42,height:42,top:"50%",left:"50%",transform:"translate(-50%, -50%)"},[`&.${Gn.disabled}`]:{"&:hover":{boxShadow:"none"}},variants:[{props:{size:"small"},style:{width:12,height:12,"&::before":{boxShadow:"none"}}},{props:{orientation:"horizontal"},style:{top:"50%",transform:"translate(-50%, -50%)"}},{props:{orientation:"vertical"},style:{left:"50%",transform:"translate(-50%, 50%)"}},...Object.keys(((r=n.vars)!=null?r:n).palette).filter(i=>{var l;return((l=n.vars)!=null?l:n).palette[i].main}).map(i=>({props:{color:i},style:{[`&:hover, &.${Gn.focusVisible}`]:ge({},n.vars?{boxShadow:`0px 0px 0px 8px rgba(${n.vars.palette[i].mainChannel} / 0.16)`}:{boxShadow:`0px 0px 0px 8px ${Hr.alpha(n.palette[i].main,.16)}`},{"@media (hover: none)":{boxShadow:"none"}}),[`&.${Gn.active}`]:ge({},n.vars?{boxShadow:`0px 0px 0px 14px rgba(${n.vars.palette[i].mainChannel} / 0.16)`}:{boxShadow:`0px 0px 0px 14px ${Hr.alpha(n.palette[i].main,.16)}`})}}))]}}),W4=Ia(X4,{name:"MuiSlider",slot:"ValueLabel",overridesResolver:(n,r)=>r.valueLabel})(({theme:n})=>ge({zIndex:1,whiteSpace:"nowrap"},n.typography.body2,{fontWeight:500,transition:n.transitions.create(["transform"],{duration:n.transitions.duration.shortest}),position:"absolute",backgroundColor:(n.vars||n).palette.grey[600],borderRadius:2,color:(n.vars||n).palette.common.white,display:"flex",alignItems:"center",justifyContent:"center",padding:"0.25rem 0.75rem",variants:[{props:{orientation:"horizontal"},style:{transform:"translateY(-100%) scale(0)",top:"-10px",transformOrigin:"bottom center","&::before":{position:"absolute",content:'""',width:8,height:8,transform:"translate(-50%, 50%) rotate(45deg)",backgroundColor:"inherit",bottom:0,left:"50%"},[`&.${Gn.valueLabelOpen}`]:{transform:"translateY(-100%) scale(1)"}}},{props:{orientation:"vertical"},style:{transform:"translateY(-50%) scale(0)",right:"30px",top:"50%",transformOrigin:"right center","&::before":{position:"absolute",content:'""',width:8,height:8,transform:"translate(-50%, -50%) rotate(45deg)",backgroundColor:"inherit",right:-8,top:"50%"},[`&.${Gn.valueLabelOpen}`]:{transform:"translateY(-50%) scale(1)"}}},{props:{size:"small"},style:{fontSize:n.typography.pxToRem(12),padding:"0.25rem 0.5rem"}},{props:{orientation:"vertical",size:"small"},style:{right:"20px"}}]})),J4=Ia("span",{name:"MuiSlider",slot:"Mark",shouldForwardProp:n=>Ny(n)&&n!=="markActive",overridesResolver:(n,r)=>{const{markActive:i}=n;return[r.mark,i&&r.markActive]}})(({theme:n})=>({position:"absolute",width:2,height:2,borderRadius:1,backgroundColor:"currentColor",variants:[{props:{orientation:"horizontal"},style:{top:"50%",transform:"translate(-1px, -50%)"}},{props:{orientation:"vertical"},style:{left:"50%",transform:"translate(-50%, 1px)"}},{props:{markActive:!0},style:{backgroundColor:(n.vars||n).palette.background.paper,opacity:.8}}]})),eM=Ia("span",{name:"MuiSlider",slot:"MarkLabel",shouldForwardProp:n=>Ny(n)&&n!=="markLabelActive",overridesResolver:(n,r)=>r.markLabel})(({theme:n})=>ge({},n.typography.body2,{color:(n.vars||n).palette.text.secondary,position:"absolute",whiteSpace:"nowrap",variants:[{props:{orientation:"horizontal"},style:{top:30,transform:"translateX(-50%)","@media (pointer: coarse)":{top:40}}},{props:{orientation:"vertical"},style:{left:36,transform:"translateY(50%)","@media (pointer: coarse)":{left:44}}},{props:{markLabelActive:!0},style:{color:(n.vars||n).palette.text.primary}}]})),tM=n=>{const{disabled:r,dragging:i,marked:l,orientation:u,track:c,classes:d,color:p,size:h}=n,y={root:["root",r&&"disabled",i&&"dragging",l&&"marked",u==="vertical"&&"vertical",c==="inverted"&&"trackInverted",c===!1&&"trackFalse",p&&`color${Jn(p)}`,h&&`size${Jn(h)}`],rail:["rail"],track:["track"],mark:["mark"],markActive:["markActive"],markLabel:["markLabel"],markLabelActive:["markLabelActive"],valueLabel:["valueLabel"],thumb:["thumb",r&&"disabled",h&&`thumbSize${Jn(h)}`,p&&`thumbColor${Jn(p)}`],active:["active"],disabled:["disabled"],focusVisible:["focusVisible"]};return k3(y,V4,d)},nM=({children:n})=>n,rM=x.forwardRef(function(r,i){var l,u,c,d,p,h,y,m,g,S,R,_,E,C,j,M,B,X,A,$,O,q,L,Y;const W=B4({props:r,name:"MuiSlider"}),oe=V3(),{"aria-label":ue,"aria-valuetext":he,"aria-labelledby":fe,component:H="span",components:I={},componentsProps:ae={},color:be="primary",classes:N,className:Z,disableSwap:le=!1,disabled:re=!1,getAriaLabel:z,getAriaValueText:F,marks:te=!1,max:pe=100,min:ce=0,orientation:xe="horizontal",shiftStep:me=10,size:Ee="medium",step:de=1,scale:ve=Jb,slotProps:Oe,slots:ye,track:je="normal",valueLabelDisplay:Me="off",valueLabelFormat:Fe=Jb}=W,Ht=er(W,Q4),ze=ge({},W,{isRtl:oe,max:pe,min:ce,classes:N,disabled:re,disableSwap:le,orientation:xe,marks:te,color:be,size:Ee,step:de,shiftStep:me,scale:ve,track:je,valueLabelDisplay:Me,valueLabelFormat:Fe}),{axisProps:Ze,getRootProps:Gt,getHiddenInputProps:$t,getThumbProps:qt,open:An,active:_t,axis:rt,focusedThumbIndex:ie,range:se,dragging:Te,marks:Ue,values:Ye,trackOffset:Be,trackLeap:Nt,getThumbStyle:mt}=G4(ge({},ze,{rootRef:i}));ze.marked=Ue.length>0&&Ue.some(We=>We.label),ze.dragging=Te,ze.focusedThumbIndex=ie;const k=tM(ze),V=(l=(u=ye==null?void 0:ye.root)!=null?u:I.Root)!=null?l:K4,qe=(c=(d=ye==null?void 0:ye.rail)!=null?d:I.Rail)!=null?c:F4,Qe=(p=(h=ye==null?void 0:ye.track)!=null?h:I.Track)!=null?p:Z4,Ie=(y=(m=ye==null?void 0:ye.thumb)!=null?m:I.Thumb)!=null?y:I4,De=(g=(S=ye==null?void 0:ye.valueLabel)!=null?S:I.ValueLabel)!=null?g:W4,Yt=(R=(_=ye==null?void 0:ye.mark)!=null?_:I.Mark)!=null?R:J4,hn=(E=(C=ye==null?void 0:ye.markLabel)!=null?C:I.MarkLabel)!=null?E:eM,zt=(j=(M=ye==null?void 0:ye.input)!=null?M:I.Input)!=null?j:"input",nn=(B=Oe==null?void 0:Oe.root)!=null?B:ae.root,br=(X=Oe==null?void 0:Oe.rail)!=null?X:ae.rail,ln=(A=Oe==null?void 0:Oe.track)!=null?A:ae.track,Vt=($=Oe==null?void 0:Oe.thumb)!=null?$:ae.thumb,Zr=(O=Oe==null?void 0:Oe.valueLabel)!=null?O:ae.valueLabel,yn=(q=Oe==null?void 0:Oe.mark)!=null?q:ae.mark,At=(L=Oe==null?void 0:Oe.markLabel)!=null?L:ae.markLabel,St=(Y=Oe==null?void 0:Oe.input)!=null?Y:ae.input,Rn=ba({elementType:V,getSlotProps:Gt,externalSlotProps:nn,externalForwardedProps:Ht,additionalProps:ge({},Y4(V)&&{as:H}),ownerState:ge({},ze,nn==null?void 0:nn.ownerState),className:[k.root,Z]}),nr=ba({elementType:qe,externalSlotProps:br,ownerState:ze,className:k.rail}),Ra=ba({elementType:Qe,externalSlotProps:ln,additionalProps:{style:ge({},Ze[rt].offset(Be),Ze[rt].leap(Nt))},ownerState:ge({},ze,ln==null?void 0:ln.ownerState),className:k.track}),Sr=ba({elementType:Ie,getSlotProps:qt,externalSlotProps:Vt,ownerState:ge({},ze,Vt==null?void 0:Vt.ownerState),className:k.thumb}),wa=ba({elementType:De,externalSlotProps:Zr,ownerState:ge({},ze,Zr==null?void 0:Zr.ownerState),className:k.valueLabel}),wn=ba({elementType:Yt,externalSlotProps:yn,ownerState:ze,className:k.mark}),Qn=ba({elementType:hn,externalSlotProps:At,ownerState:ze,className:k.markLabel}),Kn=ba({elementType:zt,getSlotProps:$t,externalSlotProps:St,ownerState:ze});return T.jsxs(V,ge({},Rn,{children:[T.jsx(qe,ge({},nr)),T.jsx(Qe,ge({},Ra)),Ue.filter(We=>We.value>=ce&&We.value<=pe).map((We,pt)=>{const Cn=ws(We.value,ce,pe),ct=Ze[rt].offset(Cn);let kt;return je===!1?kt=Ye.indexOf(We.value)!==-1:kt=je==="normal"&&(se?We.value>=Ye[0]&&We.value<=Ye[Ye.length-1]:We.value<=Ye[0])||je==="inverted"&&(se?We.value<=Ye[0]||We.value>=Ye[Ye.length-1]:We.value>=Ye[0]),T.jsxs(x.Fragment,{children:[T.jsx(Yt,ge({"data-index":pt},wn,!vo(Yt)&&{markActive:kt},{style:ge({},ct,wn.style),className:Oa(wn.className,kt&&k.markActive)})),We.label!=null?T.jsx(hn,ge({"aria-hidden":!0,"data-index":pt},Qn,!vo(hn)&&{markLabelActive:kt},{style:ge({},ct,Qn.style),className:Oa(k.markLabel,Qn.className,kt&&k.markLabelActive),children:We.label})):null]},pt)}),Ye.map((We,pt)=>{const Cn=ws(We,ce,pe),ct=Ze[rt].offset(Cn),kt=Me==="off"?nM:De;return T.jsx(kt,ge({},!vo(kt)&&{valueLabelFormat:Fe,valueLabelDisplay:Me,value:typeof Fe=="function"?Fe(ve(We),pt):Fe,index:pt,open:An===pt||_t===pt||Me==="on",disabled:re},wa,{children:T.jsx(Ie,ge({"data-index":pt},Sr,{className:Oa(k.thumb,Sr.className,_t===pt&&k.active,ie===pt&&k.focusVisible),style:ge({},ct,mt(pt),Sr.style),children:T.jsx(zt,ge({"data-index":pt,"aria-label":z?z(pt):ue,"aria-valuenow":ve(We),"aria-labelledby":fe,"aria-valuetext":F?F(ve(We),pt):he,value:Ye[pt]},Kn))}))}),pt)})]}))});var Bd,e1;function uO(){if(e1)return Bd;e1=1;var n=Object.prototype.toString;return Bd=function(i){var l=n.call(i),u=l==="[object Arguments]";return u||(u=l!=="[object Array]"&&i!==null&&typeof i=="object"&&typeof i.length=="number"&&i.length>=0&&n.call(i.callee)==="[object Function]"),u},Bd}var $d,t1;function aM(){if(t1)return $d;t1=1;var n;if(!Object.keys){var r=Object.prototype.hasOwnProperty,i=Object.prototype.toString,l=uO(),u=Object.prototype.propertyIsEnumerable,c=!u.call({toString:null},"toString"),d=u.call(function(){},"prototype"),p=["toString","toLocaleString","valueOf","hasOwnProperty","isPrototypeOf","propertyIsEnumerable","constructor"],h=function(S){var R=S.constructor;return R&&R.prototype===S},y={$applicationCache:!0,$console:!0,$external:!0,$frame:!0,$frameElement:!0,$frames:!0,$innerHeight:!0,$innerWidth:!0,$onmozfullscreenchange:!0,$onmozfullscreenerror:!0,$outerHeight:!0,$outerWidth:!0,$pageXOffset:!0,$pageYOffset:!0,$parent:!0,$scrollLeft:!0,$scrollTop:!0,$scrollX:!0,$scrollY:!0,$self:!0,$webkitIndexedDB:!0,$webkitStorageInfo:!0,$window:!0},m=function(){if(typeof window>"u")return!1;for(var S in window)try{if(!y["$"+S]&&r.call(window,S)&&window[S]!==null&&typeof window[S]=="object")try{h(window[S])}catch{return!0}}catch{return!0}return!1}(),g=function(S){if(typeof window>"u"||!m)return h(S);try{return h(S)}catch{return!1}};n=function(R){var _=R!==null&&typeof R=="object",E=i.call(R)==="[object Function]",C=l(R),j=_&&i.call(R)==="[object String]",M=[];if(!_&&!E&&!C)throw new TypeError("Object.keys called on a non-object");var B=d&&E;if(j&&R.length>0&&!r.call(R,0))for(var X=0;X<R.length;++X)M.push(String(X));if(C&&R.length>0)for(var A=0;A<R.length;++A)M.push(String(A));else for(var $ in R)!(B&&$==="prototype")&&r.call(R,$)&&M.push(String($));if(c)for(var O=g(R),q=0;q<p.length;++q)!(O&&p[q]==="constructor")&&r.call(R,p[q])&&M.push(p[q]);return M}}return $d=n,$d}var qd,n1;function My(){if(n1)return qd;n1=1;var n=Array.prototype.slice,r=uO(),i=Object.keys,l=i?function(d){return i(d)}:aM(),u=Object.keys;return l.shim=function(){if(Object.keys){var d=function(){var p=Object.keys(arguments);return p&&p.length===arguments.length}(1,2);d||(Object.keys=function(h){return r(h)?u(n.call(h)):u(h)})}else Object.keys=l;return Object.keys||l},qd=l,qd}var zd,r1;function Is(){if(r1)return zd;r1=1;var n=Object.defineProperty||!1;if(n)try{n({},"a",{value:1})}catch{n=!1}return zd=n,zd}var kd,a1;function Dy(){return a1||(a1=1,kd=SyntaxError),kd}var Ld,i1;function Xn(){return i1||(i1=1,Ld=TypeError),Ld}var Ud,l1;function iM(){return l1||(l1=1,Ud=Object.getOwnPropertyDescriptor),Ud}var Hd,o1;function Wa(){if(o1)return Hd;o1=1;var n=iM();if(n)try{n([],"length")}catch{n=null}return Hd=n,Hd}var Gd,u1;function jy(){if(u1)return Gd;u1=1;var n=Is(),r=Dy(),i=Xn(),l=Wa();return Gd=function(c,d,p){if(!c||typeof c!="object"&&typeof c!="function")throw new i("`obj` must be an object or a function`");if(typeof d!="string"&&typeof d!="symbol")throw new i("`property` must be a string or a symbol`");if(arguments.length>3&&typeof arguments[3]!="boolean"&&arguments[3]!==null)throw new i("`nonEnumerable`, if provided, must be a boolean or null");if(arguments.length>4&&typeof arguments[4]!="boolean"&&arguments[4]!==null)throw new i("`nonWritable`, if provided, must be a boolean or null");if(arguments.length>5&&typeof arguments[5]!="boolean"&&arguments[5]!==null)throw new i("`nonConfigurable`, if provided, must be a boolean or null");if(arguments.length>6&&typeof arguments[6]!="boolean")throw new i("`loose`, if provided, must be a boolean");var h=arguments.length>3?arguments[3]:null,y=arguments.length>4?arguments[4]:null,m=arguments.length>5?arguments[5]:null,g=arguments.length>6?arguments[6]:!1,S=!!l&&l(c,d);if(n)n(c,d,{configurable:m===null&&S?S.configurable:!m,enumerable:h===null&&S?S.enumerable:!h,value:p,writable:y===null&&S?S.writable:!y});else if(g||!h&&!y&&!m)c[d]=p;else throw new r("This environment does not support defining a property as non-configurable, non-writable, or non-enumerable.")},Gd}var Yd,s1;function By(){if(s1)return Yd;s1=1;var n=Is(),r=function(){return!!n};return r.hasArrayLengthDefineBug=function(){if(!n)return null;try{return n([],"length",{value:1}).length!==1}catch{return!0}},Yd=r,Yd}var Vd,c1;function Ja(){if(c1)return Vd;c1=1;var n=My(),r=typeof Symbol=="function"&&typeof Symbol("foo")=="symbol",i=Object.prototype.toString,l=Array.prototype.concat,u=jy(),c=function(y){return typeof y=="function"&&i.call(y)==="[object Function]"},d=By()(),p=function(y,m,g,S){if(m in y){if(S===!0){if(y[m]===g)return}else if(!c(S)||!S())return}d?u(y,m,g,!0):u(y,m,g)},h=function(y,m){var g=arguments.length>2?arguments[2]:{},S=n(m);r&&(S=l.call(S,Object.getOwnPropertySymbols(m)));for(var R=0;R<S.length;R+=1)p(y,S[R],m[S[R]],g[S[R]])};return h.supportsDescriptors=!!d,Vd=h,Vd}var Pd={exports:{}},Xd,f1;function $y(){return f1||(f1=1,Xd=Object),Xd}var Qd,d1;function sO(){return d1||(d1=1,Qd=Error),Qd}var Kd,p1;function lM(){return p1||(p1=1,Kd=EvalError),Kd}var Fd,h1;function oM(){return h1||(h1=1,Fd=RangeError),Fd}var Zd,y1;function uM(){return y1||(y1=1,Zd=ReferenceError),Zd}var Id,v1;function sM(){return v1||(v1=1,Id=URIError),Id}var Wd,m1;function cM(){return m1||(m1=1,Wd=Math.abs),Wd}var Jd,g1;function fM(){return g1||(g1=1,Jd=Math.floor),Jd}var ep,b1;function dM(){return b1||(b1=1,ep=Math.max),ep}var tp,S1;function pM(){return S1||(S1=1,tp=Math.min),tp}var np,x1;function hM(){return x1||(x1=1,np=Math.pow),np}var rp,E1;function yM(){return E1||(E1=1,rp=Math.round),rp}var ap,O1;function vM(){return O1||(O1=1,ap=Number.isNaN||function(r){return r!==r}),ap}var ip,T1;function mM(){if(T1)return ip;T1=1;var n=vM();return ip=function(i){return n(i)||i===0?i:i<0?-1:1},ip}var lp,_1;function Ws(){return _1||(_1=1,lp=function(){if(typeof Symbol!="function"||typeof Object.getOwnPropertySymbols!="function")return!1;if(typeof Symbol.iterator=="symbol")return!0;var r={},i=Symbol("test"),l=Object(i);if(typeof i=="string"||Object.prototype.toString.call(i)!=="[object Symbol]"||Object.prototype.toString.call(l)!=="[object Symbol]")return!1;var u=42;r[i]=u;for(var c in r)return!1;if(typeof Object.keys=="function"&&Object.keys(r).length!==0||typeof Object.getOwnPropertyNames=="function"&&Object.getOwnPropertyNames(r).length!==0)return!1;var d=Object.getOwnPropertySymbols(r);if(d.length!==1||d[0]!==i||!Object.prototype.propertyIsEnumerable.call(r,i))return!1;if(typeof Object.getOwnPropertyDescriptor=="function"){var p=Object.getOwnPropertyDescriptor(r,i);if(p.value!==u||p.enumerable!==!0)return!1}return!0}),lp}var op,A1;function qy(){if(A1)return op;A1=1;var n=typeof Symbol<"u"&&Symbol,r=Ws();return op=function(){return typeof n!="function"||typeof Symbol!="function"||typeof n("foo")!="symbol"||typeof Symbol("bar")!="symbol"?!1:r()},op}var up,R1;function cO(){return R1||(R1=1,up=typeof Reflect<"u"&&Reflect.getPrototypeOf||null),up}var sp,w1;function fO(){if(w1)return sp;w1=1;var n=$y();return sp=n.getPrototypeOf||null,sp}var cp,C1;function gM(){if(C1)return cp;C1=1;var n="Function.prototype.bind called on incompatible ",r=Object.prototype.toString,i=Math.max,l="[object Function]",u=function(h,y){for(var m=[],g=0;g<h.length;g+=1)m[g]=h[g];for(var S=0;S<y.length;S+=1)m[S+h.length]=y[S];return m},c=function(h,y){for(var m=[],g=y,S=0;g<h.length;g+=1,S+=1)m[S]=h[g];return m},d=function(p,h){for(var y="",m=0;m<p.length;m+=1)y+=p[m],m+1<p.length&&(y+=h);return y};return cp=function(h){var y=this;if(typeof y!="function"||r.apply(y)!==l)throw new TypeError(n+y);for(var m=c(arguments,1),g,S=function(){if(this instanceof g){var j=y.apply(this,u(m,arguments));return Object(j)===j?j:this}return y.apply(h,u(m,arguments))},R=i(0,y.length-m.length),_=[],E=0;E<R;E++)_[E]="$"+E;if(g=Function("binder","return function ("+d(_,",")+"){ return binder.apply(this,arguments); }")(S),y.prototype){var C=function(){};C.prototype=y.prototype,g.prototype=new C,C.prototype=null}return g},cp}var fp,N1;function ko(){if(N1)return fp;N1=1;var n=gM();return fp=Function.prototype.bind||n,fp}var dp,M1;function zy(){return M1||(M1=1,dp=Function.prototype.call),dp}var pp,D1;function ky(){return D1||(D1=1,pp=Function.prototype.apply),pp}var hp,j1;function bM(){return j1||(j1=1,hp=typeof Reflect<"u"&&Reflect&&Reflect.apply),hp}var yp,B1;function dO(){if(B1)return yp;B1=1;var n=ko(),r=ky(),i=zy(),l=bM();return yp=l||n.call(i,r),yp}var vp,$1;function Ly(){if($1)return vp;$1=1;var n=ko(),r=Xn(),i=zy(),l=dO();return vp=function(c){if(c.length<1||typeof c[0]!="function")throw new r("a function is required");return l(n,i,c)},vp}var mp,q1;function SM(){if(q1)return mp;q1=1;var n=Ly(),r=Wa(),i;try{i=[].__proto__===Array.prototype}catch(d){if(!d||typeof d!="object"||!("code"in d)||d.code!=="ERR_PROTO_ACCESS")throw d}var l=!!i&&r&&r(Object.prototype,"__proto__"),u=Object,c=u.getPrototypeOf;return mp=l&&typeof l.get=="function"?n([l.get]):typeof c=="function"?function(p){return c(p==null?p:u(p))}:!1,mp}var gp,z1;function Uy(){if(z1)return gp;z1=1;var n=cO(),r=fO(),i=SM();return gp=n?function(u){return n(u)}:r?function(u){if(!u||typeof u!="object"&&typeof u!="function")throw new TypeError("getProto: not an object");return r(u)}:i?function(u){return i(u)}:null,gp}var bp,k1;function Hy(){if(k1)return bp;k1=1;var n=Function.prototype.call,r=Object.prototype.hasOwnProperty,i=ko();return bp=i.call(n,r),bp}var Sp,L1;function Fr(){if(L1)return Sp;L1=1;var n,r=$y(),i=sO(),l=lM(),u=oM(),c=uM(),d=Dy(),p=Xn(),h=sM(),y=cM(),m=fM(),g=dM(),S=pM(),R=hM(),_=yM(),E=mM(),C=Function,j=function(xe){try{return C('"use strict"; return ('+xe+").constructor;")()}catch{}},M=Wa(),B=Is(),X=function(){throw new p},A=M?function(){try{return arguments.callee,X}catch{try{return M(arguments,"callee").get}catch{return X}}}():X,$=qy()(),O=Uy(),q=fO(),L=cO(),Y=ky(),W=zy(),oe={},ue=typeof Uint8Array>"u"||!O?n:O(Uint8Array),he={__proto__:null,"%AggregateError%":typeof AggregateError>"u"?n:AggregateError,"%Array%":Array,"%ArrayBuffer%":typeof ArrayBuffer>"u"?n:ArrayBuffer,"%ArrayIteratorPrototype%":$&&O?O([][Symbol.iterator]()):n,"%AsyncFromSyncIteratorPrototype%":n,"%AsyncFunction%":oe,"%AsyncGenerator%":oe,"%AsyncGeneratorFunction%":oe,"%AsyncIteratorPrototype%":oe,"%Atomics%":typeof Atomics>"u"?n:Atomics,"%BigInt%":typeof BigInt>"u"?n:BigInt,"%BigInt64Array%":typeof BigInt64Array>"u"?n:BigInt64Array,"%BigUint64Array%":typeof BigUint64Array>"u"?n:BigUint64Array,"%Boolean%":Boolean,"%DataView%":typeof DataView>"u"?n:DataView,"%Date%":Date,"%decodeURI%":decodeURI,"%decodeURIComponent%":decodeURIComponent,"%encodeURI%":encodeURI,"%encodeURIComponent%":encodeURIComponent,"%Error%":i,"%eval%":eval,"%EvalError%":l,"%Float16Array%":typeof Float16Array>"u"?n:Float16Array,"%Float32Array%":typeof Float32Array>"u"?n:Float32Array,"%Float64Array%":typeof Float64Array>"u"?n:Float64Array,"%FinalizationRegistry%":typeof FinalizationRegistry>"u"?n:FinalizationRegistry,"%Function%":C,"%GeneratorFunction%":oe,"%Int8Array%":typeof Int8Array>"u"?n:Int8Array,"%Int16Array%":typeof Int16Array>"u"?n:Int16Array,"%Int32Array%":typeof Int32Array>"u"?n:Int32Array,"%isFinite%":isFinite,"%isNaN%":isNaN,"%IteratorPrototype%":$&&O?O(O([][Symbol.iterator]())):n,"%JSON%":typeof JSON=="object"?JSON:n,"%Map%":typeof Map>"u"?n:Map,"%MapIteratorPrototype%":typeof Map>"u"||!$||!O?n:O(new Map()[Symbol.iterator]()),"%Math%":Math,"%Number%":Number,"%Object%":r,"%Object.getOwnPropertyDescriptor%":M,"%parseFloat%":parseFloat,"%parseInt%":parseInt,"%Promise%":typeof Promise>"u"?n:Promise,"%Proxy%":typeof Proxy>"u"?n:Proxy,"%RangeError%":u,"%ReferenceError%":c,"%Reflect%":typeof Reflect>"u"?n:Reflect,"%RegExp%":RegExp,"%Set%":typeof Set>"u"?n:Set,"%SetIteratorPrototype%":typeof Set>"u"||!$||!O?n:O(new Set()[Symbol.iterator]()),"%SharedArrayBuffer%":typeof SharedArrayBuffer>"u"?n:SharedArrayBuffer,"%String%":String,"%StringIteratorPrototype%":$&&O?O(""[Symbol.iterator]()):n,"%Symbol%":$?Symbol:n,"%SyntaxError%":d,"%ThrowTypeError%":A,"%TypedArray%":ue,"%TypeError%":p,"%Uint8Array%":typeof Uint8Array>"u"?n:Uint8Array,"%Uint8ClampedArray%":typeof Uint8ClampedArray>"u"?n:Uint8ClampedArray,"%Uint16Array%":typeof Uint16Array>"u"?n:Uint16Array,"%Uint32Array%":typeof Uint32Array>"u"?n:Uint32Array,"%URIError%":h,"%WeakMap%":typeof WeakMap>"u"?n:WeakMap,"%WeakRef%":typeof WeakRef>"u"?n:WeakRef,"%WeakSet%":typeof WeakSet>"u"?n:WeakSet,"%Function.prototype.call%":W,"%Function.prototype.apply%":Y,"%Object.defineProperty%":B,"%Object.getPrototypeOf%":q,"%Math.abs%":y,"%Math.floor%":m,"%Math.max%":g,"%Math.min%":S,"%Math.pow%":R,"%Math.round%":_,"%Math.sign%":E,"%Reflect.getPrototypeOf%":L};if(O)try{null.error}catch(xe){var fe=O(O(xe));he["%Error.prototype%"]=fe}var H=function xe(me){var Ee;if(me==="%AsyncFunction%")Ee=j("async function () {}");else if(me==="%GeneratorFunction%")Ee=j("function* () {}");else if(me==="%AsyncGeneratorFunction%")Ee=j("async function* () {}");else if(me==="%AsyncGenerator%"){var de=xe("%AsyncGeneratorFunction%");de&&(Ee=de.prototype)}else if(me==="%AsyncIteratorPrototype%"){var ve=xe("%AsyncGenerator%");ve&&O&&(Ee=O(ve.prototype))}return he[me]=Ee,Ee},I={__proto__:null,"%ArrayBufferPrototype%":["ArrayBuffer","prototype"],"%ArrayPrototype%":["Array","prototype"],"%ArrayProto_entries%":["Array","prototype","entries"],"%ArrayProto_forEach%":["Array","prototype","forEach"],"%ArrayProto_keys%":["Array","prototype","keys"],"%ArrayProto_values%":["Array","prototype","values"],"%AsyncFunctionPrototype%":["AsyncFunction","prototype"],"%AsyncGenerator%":["AsyncGeneratorFunction","prototype"],"%AsyncGeneratorPrototype%":["AsyncGeneratorFunction","prototype","prototype"],"%BooleanPrototype%":["Boolean","prototype"],"%DataViewPrototype%":["DataView","prototype"],"%DatePrototype%":["Date","prototype"],"%ErrorPrototype%":["Error","prototype"],"%EvalErrorPrototype%":["EvalError","prototype"],"%Float32ArrayPrototype%":["Float32Array","prototype"],"%Float64ArrayPrototype%":["Float64Array","prototype"],"%FunctionPrototype%":["Function","prototype"],"%Generator%":["GeneratorFunction","prototype"],"%GeneratorPrototype%":["GeneratorFunction","prototype","prototype"],"%Int8ArrayPrototype%":["Int8Array","prototype"],"%Int16ArrayPrototype%":["Int16Array","prototype"],"%Int32ArrayPrototype%":["Int32Array","prototype"],"%JSONParse%":["JSON","parse"],"%JSONStringify%":["JSON","stringify"],"%MapPrototype%":["Map","prototype"],"%NumberPrototype%":["Number","prototype"],"%ObjectPrototype%":["Object","prototype"],"%ObjProto_toString%":["Object","prototype","toString"],"%ObjProto_valueOf%":["Object","prototype","valueOf"],"%PromisePrototype%":["Promise","prototype"],"%PromiseProto_then%":["Promise","prototype","then"],"%Promise_all%":["Promise","all"],"%Promise_reject%":["Promise","reject"],"%Promise_resolve%":["Promise","resolve"],"%RangeErrorPrototype%":["RangeError","prototype"],"%ReferenceErrorPrototype%":["ReferenceError","prototype"],"%RegExpPrototype%":["RegExp","prototype"],"%SetPrototype%":["Set","prototype"],"%SharedArrayBufferPrototype%":["SharedArrayBuffer","prototype"],"%StringPrototype%":["String","prototype"],"%SymbolPrototype%":["Symbol","prototype"],"%SyntaxErrorPrototype%":["SyntaxError","prototype"],"%TypedArrayPrototype%":["TypedArray","prototype"],"%TypeErrorPrototype%":["TypeError","prototype"],"%Uint8ArrayPrototype%":["Uint8Array","prototype"],"%Uint8ClampedArrayPrototype%":["Uint8ClampedArray","prototype"],"%Uint16ArrayPrototype%":["Uint16Array","prototype"],"%Uint32ArrayPrototype%":["Uint32Array","prototype"],"%URIErrorPrototype%":["URIError","prototype"],"%WeakMapPrototype%":["WeakMap","prototype"],"%WeakSetPrototype%":["WeakSet","prototype"]},ae=ko(),be=Hy(),N=ae.call(W,Array.prototype.concat),Z=ae.call(Y,Array.prototype.splice),le=ae.call(W,String.prototype.replace),re=ae.call(W,String.prototype.slice),z=ae.call(W,RegExp.prototype.exec),F=/[^%.[\]]+|\[(?:(-?\d+(?:\.\d+)?)|(["'])((?:(?!\2)[^\\]|\\.)*?)\2)\]|(?=(?:\.|\[\])(?:\.|\[\]|%$))/g,te=/\\(\\)?/g,pe=function(me){var Ee=re(me,0,1),de=re(me,-1);if(Ee==="%"&&de!=="%")throw new d("invalid intrinsic syntax, expected closing `%`");if(de==="%"&&Ee!=="%")throw new d("invalid intrinsic syntax, expected opening `%`");var ve=[];return le(me,F,function(Oe,ye,je,Me){ve[ve.length]=je?le(Me,te,"$1"):ye||Oe}),ve},ce=function(me,Ee){var de=me,ve;if(be(I,de)&&(ve=I[de],de="%"+ve[0]+"%"),be(he,de)){var Oe=he[de];if(Oe===oe&&(Oe=H(de)),typeof Oe>"u"&&!Ee)throw new p("intrinsic "+me+" exists, but is not available. Please file an issue!");return{alias:ve,name:de,value:Oe}}throw new d("intrinsic "+me+" does not exist!")};return Sp=function(me,Ee){if(typeof me!="string"||me.length===0)throw new p("intrinsic name must be a non-empty string");if(arguments.length>1&&typeof Ee!="boolean")throw new p('"allowMissing" argument must be a boolean');if(z(/^%?[^%]*%?$/,me)===null)throw new d("`%` may not be present anywhere but at the beginning and end of the intrinsic name");var de=pe(me),ve=de.length>0?de[0]:"",Oe=ce("%"+ve+"%",Ee),ye=Oe.name,je=Oe.value,Me=!1,Fe=Oe.alias;Fe&&(ve=Fe[0],Z(de,N([0,1],Fe)));for(var Ht=1,ze=!0;Ht<de.length;Ht+=1){var Ze=de[Ht],Gt=re(Ze,0,1),$t=re(Ze,-1);if((Gt==='"'||Gt==="'"||Gt==="`"||$t==='"'||$t==="'"||$t==="`")&&Gt!==$t)throw new d("property names with quotes must have matching quotes");if((Ze==="constructor"||!ze)&&(Me=!0),ve+="."+Ze,ye="%"+ve+"%",be(he,ye))je=he[ye];else if(je!=null){if(!(Ze in je)){if(!Ee)throw new p("base intrinsic for "+me+" exists, but the property is not available.");return}if(M&&Ht+1>=de.length){var qt=M(je,Ze);ze=!!qt,ze&&"get"in qt&&!("originalValue"in qt.get)?je=qt.get:je=je[Ze]}else ze=be(je,Ze),je=je[Ze];ze&&!Me&&(he[ye]=je)}}return je},Sp}var xp,U1;function xM(){if(U1)return xp;U1=1;var n=Fr(),r=jy(),i=By()(),l=Wa(),u=Xn(),c=n("%Math.floor%");return xp=function(p,h){if(typeof p!="function")throw new u("`fn` is not a function");if(typeof h!="number"||h<0||h>4294967295||c(h)!==h)throw new u("`length` must be a positive 32-bit integer");var y=arguments.length>2&&!!arguments[2],m=!0,g=!0;if("length"in p&&l){var S=l(p,"length");S&&!S.configurable&&(m=!1),S&&!S.writable&&(g=!1)}return(m||g||!y)&&(i?r(p,"length",h,!0,!0):r(p,"length",h)),p},xp}var Ep,H1;function EM(){if(H1)return Ep;H1=1;var n=ko(),r=ky(),i=dO();return Ep=function(){return i(n,r,arguments)},Ep}var G1;function il(){return G1||(G1=1,function(n){var r=xM(),i=Is(),l=Ly(),u=EM();n.exports=function(d){var p=l(arguments),h=d.length-(arguments.length-1);return r(p,1+(h>0?h:0),!0)},i?i(n.exports,"apply",{value:u}):n.exports.apply=u}(Pd)),Pd.exports}var Op,Y1;function tn(){if(Y1)return Op;Y1=1;var n=Fr(),r=Ly(),i=r([n("%String.prototype.indexOf%")]);return Op=function(u,c){var d=n(u,!!c);return typeof d=="function"&&i(u,".prototype.")>-1?r([d]):d},Op}var Tp,V1;function pO(){if(V1)return Tp;V1=1;var n=My(),r=Ws()(),i=tn(),l=$y(),u=i("Array.prototype.push"),c=i("Object.prototype.propertyIsEnumerable"),d=r?l.getOwnPropertySymbols:null;return Tp=function(h,y){if(h==null)throw new TypeError("target must be an object");var m=l(h);if(arguments.length===1)return m;for(var g=1;g<arguments.length;++g){var S=l(arguments[g]),R=n(S),_=r&&(l.getOwnPropertySymbols||d);if(_)for(var E=_(S),C=0;C<E.length;++C){var j=E[C];c(S,j)&&u(R,j)}for(var M=0;M<R.length;++M){var B=R[M];if(c(S,B)){var X=S[B];m[B]=X}}}return m},Tp}var _p,P1;function hO(){if(P1)return _p;P1=1;var n=pO(),r=function(){if(!Object.assign)return!1;for(var l="abcdefghijklmnopqrst",u=l.split(""),c={},d=0;d<u.length;++d)c[u[d]]=u[d];var p=Object.assign({},c),h="";for(var y in p)h+=y;return l!==h},i=function(){if(!Object.assign||!Object.preventExtensions)return!1;var l=Object.preventExtensions({1:2});try{Object.assign(l,"xy")}catch{return l[1]==="y"}return!1};return _p=function(){return!Object.assign||r()||i()?n:Object.assign},_p}var Ap,X1;function OM(){if(X1)return Ap;X1=1;var n=Ja(),r=hO();return Ap=function(){var l=r();return n(Object,{assign:l},{assign:function(){return Object.assign!==l}}),l},Ap}var Rp,Q1;function TM(){if(Q1)return Rp;Q1=1;var n=Ja(),r=il(),i=pO(),l=hO(),u=OM(),c=r.apply(l()),d=function(h,y){return c(Object,arguments)};return n(d,{getPolyfill:l,implementation:i,shim:u}),Rp=d,Rp}var wp,K1;function yO(){if(K1)return wp;K1=1;var n=Fr(),r=il(),i=r(n("String.prototype.indexOf"));return wp=function(u,c){var d=n(u,!!c);return typeof d=="function"&&i(u,".prototype.")>-1?r(d):d},wp}var Cp,F1;function _M(){if(F1)return Cp;F1=1;var n=function(){return typeof(function(){}).name=="string"},r=Object.getOwnPropertyDescriptor;if(r)try{r([],"length")}catch{r=null}n.functionsHaveConfigurableNames=function(){if(!n()||!r)return!1;var u=r(function(){},"name");return!!u&&!!u.configurable};var i=Function.prototype.bind;return n.boundFunctionsHaveNames=function(){return n()&&typeof i=="function"&&(function(){}).bind().name!==""},Cp=n,Cp}var Np,Z1;function AM(){if(Z1)return Np;Z1=1;var n=jy(),r=By()(),i=_M().functionsHaveConfigurableNames(),l=Xn();return Np=function(c,d){if(typeof c!="function")throw new l("`fn` is not a function");var p=arguments.length>2&&!!arguments[2];return(!p||i)&&(r?n(c,"name",d,!0,!0):n(c,"name",d)),c},Np}var Mp,I1;function vO(){if(I1)return Mp;I1=1;var n=AM(),r=Xn(),i=Object;return Mp=n(function(){if(this==null||this!==i(this))throw new r("RegExp.prototype.flags getter called on non-object");var u="";return this.hasIndices&&(u+="d"),this.global&&(u+="g"),this.ignoreCase&&(u+="i"),this.multiline&&(u+="m"),this.dotAll&&(u+="s"),this.unicode&&(u+="u"),this.unicodeSets&&(u+="v"),this.sticky&&(u+="y"),u},"get flags",!0),Mp}var Dp,W1;function mO(){if(W1)return Dp;W1=1;var n=vO(),r=Ja().supportsDescriptors,i=Object.getOwnPropertyDescriptor;return Dp=function(){if(r&&/a/mig.flags==="gim"){var u=i(RegExp.prototype,"flags");if(u&&typeof u.get=="function"&&"dotAll"in RegExp.prototype&&"hasIndices"in RegExp.prototype){var c="",d={};if(Object.defineProperty(d,"hasIndices",{get:function(){c+="d"}}),Object.defineProperty(d,"sticky",{get:function(){c+="y"}}),u.get.call(d),c==="dy")return u.get}}return n},Dp}var jp,J1;function RM(){if(J1)return jp;J1=1;var n=Ja().supportsDescriptors,r=mO(),i=Wa(),l=Object.defineProperty,u=sO(),c=Uy(),d=/a/;return jp=function(){if(!n||!c)throw new u("RegExp.prototype.flags requires a true ES5 environment that supports property descriptors");var h=r(),y=c(d),m=i(y,"flags");return(!m||m.get!==h)&&l(y,"flags",{configurable:!0,enumerable:!1,get:h}),h},jp}var Bp,eS;function wM(){if(eS)return Bp;eS=1;var n=Ja(),r=il(),i=vO(),l=mO(),u=RM(),c=r(l());return n(c,{getPolyfill:l,implementation:i,shim:u}),Bp=c,Bp}var ao={exports:{}},$p,tS;function ei(){if(tS)return $p;tS=1;var n=Ws();return $p=function(){return n()&&!!Symbol.toStringTag},$p}var qp,nS;function gO(){if(nS)return qp;nS=1;var n=ei()(),r=tn(),i=r("Object.prototype.toString"),l=function(p){return n&&p&&typeof p=="object"&&Symbol.toStringTag in p?!1:i(p)==="[object Arguments]"},u=function(p){return l(p)?!0:p!==null&&typeof p=="object"&&"length"in p&&typeof p.length=="number"&&p.length>=0&&i(p)!=="[object Array]"&&"callee"in p&&i(p.callee)==="[object Function]"},c=function(){return l(arguments)}();return l.isLegacyArguments=u,qp=c?l:u,qp}const CM={},NM=Object.freeze(Object.defineProperty({__proto__:null,default:CM},Symbol.toStringTag,{value:"Module"})),MM=Qr(NM);var zp,rS;function Js(){if(rS)return zp;rS=1;var n=typeof Map=="function"&&Map.prototype,r=Object.getOwnPropertyDescriptor&&n?Object.getOwnPropertyDescriptor(Map.prototype,"size"):null,i=n&&r&&typeof r.get=="function"?r.get:null,l=n&&Map.prototype.forEach,u=typeof Set=="function"&&Set.prototype,c=Object.getOwnPropertyDescriptor&&u?Object.getOwnPropertyDescriptor(Set.prototype,"size"):null,d=u&&c&&typeof c.get=="function"?c.get:null,p=u&&Set.prototype.forEach,h=typeof WeakMap=="function"&&WeakMap.prototype,y=h?WeakMap.prototype.has:null,m=typeof WeakSet=="function"&&WeakSet.prototype,g=m?WeakSet.prototype.has:null,S=typeof WeakRef=="function"&&WeakRef.prototype,R=S?WeakRef.prototype.deref:null,_=Boolean.prototype.valueOf,E=Object.prototype.toString,C=Function.prototype.toString,j=String.prototype.match,M=String.prototype.slice,B=String.prototype.replace,X=String.prototype.toUpperCase,A=String.prototype.toLowerCase,$=RegExp.prototype.test,O=Array.prototype.concat,q=Array.prototype.join,L=Array.prototype.slice,Y=Math.floor,W=typeof BigInt=="function"?BigInt.prototype.valueOf:null,oe=Object.getOwnPropertySymbols,ue=typeof Symbol=="function"&&typeof Symbol.iterator=="symbol"?Symbol.prototype.toString:null,he=typeof Symbol=="function"&&typeof Symbol.iterator=="object",fe=typeof Symbol=="function"&&Symbol.toStringTag&&(typeof Symbol.toStringTag===he||!0)?Symbol.toStringTag:null,H=Object.prototype.propertyIsEnumerable,I=(typeof Reflect=="function"?Reflect.getPrototypeOf:Object.getPrototypeOf)||([].__proto__===Array.prototype?function(k){return k.__proto__}:null);function ae(k,V){if(k===1/0||k===-1/0||k!==k||k&&k>-1e3&&k<1e3||$.call(/e/,V))return V;var qe=/[0-9](?=(?:[0-9]{3})+(?![0-9]))/g;if(typeof k=="number"){var Qe=k<0?-Y(-k):Y(k);if(Qe!==k){var Ie=String(Qe),De=M.call(V,Ie.length+1);return B.call(Ie,qe,"$&_")+"."+B.call(B.call(De,/([0-9]{3})/g,"$&_"),/_$/,"")}}return B.call(V,qe,"$&_")}var be=MM,N=be.custom,Z=Oe(N)?N:null,le={__proto__:null,double:'"',single:"'"},re={__proto__:null,double:/(["\\])/g,single:/(['\\])/g};zp=function k(V,qe,Qe,Ie){var De=qe||{};if(Me(De,"quoteStyle")&&!Me(le,De.quoteStyle))throw new TypeError('option "quoteStyle" must be "single" or "double"');if(Me(De,"maxStringLength")&&(typeof De.maxStringLength=="number"?De.maxStringLength<0&&De.maxStringLength!==1/0:De.maxStringLength!==null))throw new TypeError('option "maxStringLength", if provided, must be a positive integer, Infinity, or `null`');var Yt=Me(De,"customInspect")?De.customInspect:!0;if(typeof Yt!="boolean"&&Yt!=="symbol")throw new TypeError("option \"customInspect\", if provided, must be `true`, `false`, or `'symbol'`");if(Me(De,"indent")&&De.indent!==null&&De.indent!=="	"&&!(parseInt(De.indent,10)===De.indent&&De.indent>0))throw new TypeError('option "indent" must be "\\t", an integer > 0, or `null`');if(Me(De,"numericSeparator")&&typeof De.numericSeparator!="boolean")throw new TypeError('option "numericSeparator", if provided, must be `true` or `false`');var hn=De.numericSeparator;if(typeof V>"u")return"undefined";if(V===null)return"null";if(typeof V=="boolean")return V?"true":"false";if(typeof V=="string")return rt(V,De);if(typeof V=="number"){if(V===0)return 1/0/V>0?"0":"-0";var zt=String(V);return hn?ae(V,zt):zt}if(typeof V=="bigint"){var nn=String(V)+"n";return hn?ae(V,nn):nn}var br=typeof De.depth>"u"?5:De.depth;if(typeof Qe>"u"&&(Qe=0),Qe>=br&&br>0&&typeof V=="object")return pe(V)?"[Array]":"[Object]";var ln=Be(De,Qe);if(typeof Ie>"u")Ie=[];else if(ze(Ie,V)>=0)return"[Circular]";function Vt(kt,Ca,xr){if(Ca&&(Ie=L.call(Ie),Ie.push(Ca)),xr){var Er={depth:De.depth};return Me(De,"quoteStyle")&&(Er.quoteStyle=De.quoteStyle),k(kt,Er,Qe+1,Ie)}return k(kt,De,Qe+1,Ie)}if(typeof V=="function"&&!xe(V)){var Zr=Ht(V),yn=mt(V,Vt);return"[Function"+(Zr?": "+Zr:" (anonymous)")+"]"+(yn.length>0?" { "+q.call(yn,", ")+" }":"")}if(Oe(V)){var At=he?B.call(String(V),/^(Symbol\(.*\))_[^)]*$/,"$1"):ue.call(V);return typeof V=="object"&&!he?se(At):At}if(_t(V)){for(var St="<"+A.call(String(V.nodeName)),Rn=V.attributes||[],nr=0;nr<Rn.length;nr++)St+=" "+Rn[nr].name+"="+z(F(Rn[nr].value),"double",De);return St+=">",V.childNodes&&V.childNodes.length&&(St+="..."),St+="</"+A.call(String(V.nodeName))+">",St}if(pe(V)){if(V.length===0)return"[]";var Ra=mt(V,Vt);return ln&&!Ye(Ra)?"["+Nt(Ra,ln)+"]":"[ "+q.call(Ra,", ")+" ]"}if(me(V)){var Sr=mt(V,Vt);return!("cause"in Error.prototype)&&"cause"in V&&!H.call(V,"cause")?"{ ["+String(V)+"] "+q.call(O.call("[cause]: "+Vt(V.cause),Sr),", ")+" }":Sr.length===0?"["+String(V)+"]":"{ ["+String(V)+"] "+q.call(Sr,", ")+" }"}if(typeof V=="object"&&Yt){if(Z&&typeof V[Z]=="function"&&be)return be(V,{depth:br-Qe});if(Yt!=="symbol"&&typeof V.inspect=="function")return V.inspect()}if(Ze(V)){var wa=[];return l&&l.call(V,function(kt,Ca){wa.push(Vt(Ca,V,!0)+" => "+Vt(kt,V))}),Ue("Map",i.call(V),wa,ln)}if(qt(V)){var wn=[];return p&&p.call(V,function(kt){wn.push(Vt(kt,V))}),Ue("Set",d.call(V),wn,ln)}if(Gt(V))return Te("WeakMap");if(An(V))return Te("WeakSet");if($t(V))return Te("WeakRef");if(de(V))return se(Vt(Number(V)));if(ye(V))return se(Vt(W.call(V)));if(ve(V))return se(_.call(V));if(Ee(V))return se(Vt(String(V)));if(typeof window<"u"&&V===window)return"{ [object Window] }";if(typeof globalThis<"u"&&V===globalThis||typeof bs<"u"&&V===bs)return"{ [object globalThis] }";if(!ce(V)&&!xe(V)){var Qn=mt(V,Vt),Kn=I?I(V)===Object.prototype:V instanceof Object||V.constructor===Object,We=V instanceof Object?"":"null prototype",pt=!Kn&&fe&&Object(V)===V&&fe in V?M.call(Fe(V),8,-1):We?"Object":"",Cn=Kn||typeof V.constructor!="function"?"":V.constructor.name?V.constructor.name+" ":"",ct=Cn+(pt||We?"["+q.call(O.call([],pt||[],We||[]),": ")+"] ":"");return Qn.length===0?ct+"{}":ln?ct+"{"+Nt(Qn,ln)+"}":ct+"{ "+q.call(Qn,", ")+" }"}return String(V)};function z(k,V,qe){var Qe=qe.quoteStyle||V,Ie=le[Qe];return Ie+k+Ie}function F(k){return B.call(String(k),/"/g,"&quot;")}function te(k){return!fe||!(typeof k=="object"&&(fe in k||typeof k[fe]<"u"))}function pe(k){return Fe(k)==="[object Array]"&&te(k)}function ce(k){return Fe(k)==="[object Date]"&&te(k)}function xe(k){return Fe(k)==="[object RegExp]"&&te(k)}function me(k){return Fe(k)==="[object Error]"&&te(k)}function Ee(k){return Fe(k)==="[object String]"&&te(k)}function de(k){return Fe(k)==="[object Number]"&&te(k)}function ve(k){return Fe(k)==="[object Boolean]"&&te(k)}function Oe(k){if(he)return k&&typeof k=="object"&&k instanceof Symbol;if(typeof k=="symbol")return!0;if(!k||typeof k!="object"||!ue)return!1;try{return ue.call(k),!0}catch{}return!1}function ye(k){if(!k||typeof k!="object"||!W)return!1;try{return W.call(k),!0}catch{}return!1}var je=Object.prototype.hasOwnProperty||function(k){return k in this};function Me(k,V){return je.call(k,V)}function Fe(k){return E.call(k)}function Ht(k){if(k.name)return k.name;var V=j.call(C.call(k),/^function\s*([\w$]+)/);return V?V[1]:null}function ze(k,V){if(k.indexOf)return k.indexOf(V);for(var qe=0,Qe=k.length;qe<Qe;qe++)if(k[qe]===V)return qe;return-1}function Ze(k){if(!i||!k||typeof k!="object")return!1;try{i.call(k);try{d.call(k)}catch{return!0}return k instanceof Map}catch{}return!1}function Gt(k){if(!y||!k||typeof k!="object")return!1;try{y.call(k,y);try{g.call(k,g)}catch{return!0}return k instanceof WeakMap}catch{}return!1}function $t(k){if(!R||!k||typeof k!="object")return!1;try{return R.call(k),!0}catch{}return!1}function qt(k){if(!d||!k||typeof k!="object")return!1;try{d.call(k);try{i.call(k)}catch{return!0}return k instanceof Set}catch{}return!1}function An(k){if(!g||!k||typeof k!="object")return!1;try{g.call(k,g);try{y.call(k,y)}catch{return!0}return k instanceof WeakSet}catch{}return!1}function _t(k){return!k||typeof k!="object"?!1:typeof HTMLElement<"u"&&k instanceof HTMLElement?!0:typeof k.nodeName=="string"&&typeof k.getAttribute=="function"}function rt(k,V){if(k.length>V.maxStringLength){var qe=k.length-V.maxStringLength,Qe="... "+qe+" more character"+(qe>1?"s":"");return rt(M.call(k,0,V.maxStringLength),V)+Qe}var Ie=re[V.quoteStyle||"single"];Ie.lastIndex=0;var De=B.call(B.call(k,Ie,"\\$1"),/[\x00-\x1f]/g,ie);return z(De,"single",V)}function ie(k){var V=k.charCodeAt(0),qe={8:"b",9:"t",10:"n",12:"f",13:"r"}[V];return qe?"\\"+qe:"\\x"+(V<16?"0":"")+X.call(V.toString(16))}function se(k){return"Object("+k+")"}function Te(k){return k+" { ? }"}function Ue(k,V,qe,Qe){var Ie=Qe?Nt(qe,Qe):q.call(qe,", ");return k+" ("+V+") {"+Ie+"}"}function Ye(k){for(var V=0;V<k.length;V++)if(ze(k[V],`
`)>=0)return!1;return!0}function Be(k,V){var qe;if(k.indent==="	")qe="	";else if(typeof k.indent=="number"&&k.indent>0)qe=q.call(Array(k.indent+1)," ");else return null;return{base:qe,prev:q.call(Array(V+1),qe)}}function Nt(k,V){if(k.length===0)return"";var qe=`
`+V.prev+V.base;return qe+q.call(k,","+qe)+`
`+V.prev}function mt(k,V){var qe=pe(k),Qe=[];if(qe){Qe.length=k.length;for(var Ie=0;Ie<k.length;Ie++)Qe[Ie]=Me(k,Ie)?V(k[Ie],k):""}var De=typeof oe=="function"?oe(k):[],Yt;if(he){Yt={};for(var hn=0;hn<De.length;hn++)Yt["$"+De[hn]]=De[hn]}for(var zt in k)Me(k,zt)&&(qe&&String(Number(zt))===zt&&zt<k.length||he&&Yt["$"+zt]instanceof Symbol||($.call(/[^\w$]/,zt)?Qe.push(V(zt,k)+": "+V(k[zt],k)):Qe.push(zt+": "+V(k[zt],k))));if(typeof oe=="function")for(var nn=0;nn<De.length;nn++)H.call(k,De[nn])&&Qe.push("["+V(De[nn])+"]: "+V(k[De[nn]],k));return Qe}return zp}var kp,aS;function DM(){if(aS)return kp;aS=1;var n=Js(),r=Xn(),i=function(p,h,y){for(var m=p,g;(g=m.next)!=null;m=g)if(g.key===h)return m.next=g.next,y||(g.next=p.next,p.next=g),g},l=function(p,h){if(p){var y=i(p,h);return y&&y.value}},u=function(p,h,y){var m=i(p,h);m?m.value=y:p.next={key:h,next:p.next,value:y}},c=function(p,h){return p?!!i(p,h):!1},d=function(p,h){if(p)return i(p,h,!0)};return kp=function(){var h,y={assert:function(m){if(!y.has(m))throw new r("Side channel does not contain "+n(m))},delete:function(m){var g=h&&h.next,S=d(h,m);return S&&g&&g===S&&(h=void 0),!!S},get:function(m){return l(h,m)},has:function(m){return c(h,m)},set:function(m,g){h||(h={next:void 0}),u(h,m,g)}};return y},kp}var Lp,iS;function bO(){if(iS)return Lp;iS=1;var n=Fr(),r=tn(),i=Js(),l=Xn(),u=n("%Map%",!0),c=r("Map.prototype.get",!0),d=r("Map.prototype.set",!0),p=r("Map.prototype.has",!0),h=r("Map.prototype.delete",!0),y=r("Map.prototype.size",!0);return Lp=!!u&&function(){var g,S={assert:function(R){if(!S.has(R))throw new l("Side channel does not contain "+i(R))},delete:function(R){if(g){var _=h(g,R);return y(g)===0&&(g=void 0),_}return!1},get:function(R){if(g)return c(g,R)},has:function(R){return g?p(g,R):!1},set:function(R,_){g||(g=new u),d(g,R,_)}};return S},Lp}var Up,lS;function jM(){if(lS)return Up;lS=1;var n=Fr(),r=tn(),i=Js(),l=bO(),u=Xn(),c=n("%WeakMap%",!0),d=r("WeakMap.prototype.get",!0),p=r("WeakMap.prototype.set",!0),h=r("WeakMap.prototype.has",!0),y=r("WeakMap.prototype.delete",!0);return Up=c?function(){var g,S,R={assert:function(_){if(!R.has(_))throw new u("Side channel does not contain "+i(_))},delete:function(_){if(c&&_&&(typeof _=="object"||typeof _=="function")){if(g)return y(g,_)}else if(l&&S)return S.delete(_);return!1},get:function(_){return c&&_&&(typeof _=="object"||typeof _=="function")&&g?d(g,_):S&&S.get(_)},has:function(_){return c&&_&&(typeof _=="object"||typeof _=="function")&&g?h(g,_):!!S&&S.has(_)},set:function(_,E){c&&_&&(typeof _=="object"||typeof _=="function")?(g||(g=new c),p(g,_,E)):l&&(S||(S=l()),S.set(_,E))}};return R}:l,Up}var Hp,oS;function SO(){if(oS)return Hp;oS=1;var n=Xn(),r=Js(),i=DM(),l=bO(),u=jM(),c=u||l||i;return Hp=function(){var p,h={assert:function(y){if(!h.has(y))throw new n("Side channel does not contain "+r(y))},delete:function(y){return!!p&&p.delete(y)},get:function(y){return p&&p.get(y)},has:function(y){return!!p&&p.has(y)},set:function(y,m){p||(p=c()),p.set(y,m)}};return h},Hp}var Gp,uS;function BM(){if(uS)return Gp;uS=1;var n=Hy(),r=SO()(),i=Xn(),l={assert:function(u,c){if(!u||typeof u!="object"&&typeof u!="function")throw new i("`O` is not an object");if(typeof c!="string")throw new i("`slot` must be a string");if(r.assert(u),!l.has(u,c))throw new i("`"+c+"` is not present on `O`")},get:function(u,c){if(!u||typeof u!="object"&&typeof u!="function")throw new i("`O` is not an object");if(typeof c!="string")throw new i("`slot` must be a string");var d=r.get(u);return d&&d["$"+c]},has:function(u,c){if(!u||typeof u!="object"&&typeof u!="function")throw new i("`O` is not an object");if(typeof c!="string")throw new i("`slot` must be a string");var d=r.get(u);return!!d&&n(d,"$"+c)},set:function(u,c,d){if(!u||typeof u!="object"&&typeof u!="function")throw new i("`O` is not an object");if(typeof c!="string")throw new i("`slot` must be a string");var p=r.get(u);p||(p={},r.set(u,p)),p["$"+c]=d}};return Object.freeze&&Object.freeze(l),Gp=l,Gp}var Yp,sS;function $M(){if(sS)return Yp;sS=1;var n=BM(),r=Dy(),i=typeof StopIteration=="object"?StopIteration:null;return Yp=function(u){if(!i)throw new r("this environment lacks StopIteration");n.set(u,"[[Done]]",!1);var c={next:function(){var p=n.get(this,"[[Iterator]]"),h=!!n.get(p,"[[Done]]");try{return{done:h,value:h?void 0:p.next()}}catch(y){if(n.set(p,"[[Done]]",!0),y!==i)throw y;return{done:!0,value:void 0}}}};return n.set(c,"[[Iterator]]",u),c},Yp}var Vp,cS;function xO(){if(cS)return Vp;cS=1;var n={}.toString;return Vp=Array.isArray||function(r){return n.call(r)=="[object Array]"},Vp}var Pp,fS;function EO(){if(fS)return Pp;fS=1;var n=tn(),r=n("String.prototype.valueOf"),i=function(p){try{return r(p),!0}catch{return!1}},l=n("Object.prototype.toString"),u="[object String]",c=ei()();return Pp=function(p){return typeof p=="string"?!0:!p||typeof p!="object"?!1:c?i(p):l(p)===u},Pp}var Xp,dS;function OO(){if(dS)return Xp;dS=1;var n=typeof Map=="function"&&Map.prototype?Map:null,r=typeof Set=="function"&&Set.prototype?Set:null,i;n||(i=function(d){return!1});var l=n?Map.prototype.has:null,u=r?Set.prototype.has:null;return!i&&!l&&(i=function(d){return!1}),Xp=i||function(d){if(!d||typeof d!="object")return!1;try{if(l.call(d),u)try{u.call(d)}catch{return!0}return d instanceof n}catch{}return!1},Xp}var Qp,pS;function TO(){if(pS)return Qp;pS=1;var n=typeof Map=="function"&&Map.prototype?Map:null,r=typeof Set=="function"&&Set.prototype?Set:null,i;r||(i=function(d){return!1});var l=n?Map.prototype.has:null,u=r?Set.prototype.has:null;return!i&&!u&&(i=function(d){return!1}),Qp=i||function(d){if(!d||typeof d!="object")return!1;try{if(u.call(d),l)try{l.call(d)}catch{return!0}return d instanceof r}catch{}return!1},Qp}var hS;function qM(){if(hS)return ao.exports;hS=1;var n=gO(),r=$M();if(qy()()||Ws()()){var i=Symbol.iterator;ao.exports=function(L){if(L!=null&&typeof L[i]<"u")return L[i]();if(n(L))return Array.prototype[i].call(L)}}else{var l=xO(),u=EO(),c=Fr(),d=c("%Map%",!0),p=c("%Set%",!0),h=yO(),y=h("Array.prototype.push"),m=h("String.prototype.charCodeAt"),g=h("String.prototype.slice"),S=function(L,Y){var W=L.length;if(Y+1>=W)return Y+1;var oe=m(L,Y);if(oe<55296||oe>56319)return Y+1;var ue=m(L,Y+1);return ue<56320||ue>57343?Y+1:Y+2},R=function(L){var Y=0;return{next:function(){var oe=Y>=L.length,ue;return oe||(ue=L[Y],Y+=1),{done:oe,value:ue}}}},_=function(L,Y){if(l(L)||n(L))return R(L);if(u(L)){var W=0;return{next:function(){var ue=S(L,W),he=g(L,W,ue);return W=ue,{done:ue>L.length,value:he}}}}if(Y&&typeof L["_es6-shim iterator_"]<"u")return L["_es6-shim iterator_"]()};if(!d&&!p)ao.exports=function(L){if(L!=null)return _(L,!0)};else{var E=OO(),C=TO(),j=h("Map.prototype.forEach",!0),M=h("Set.prototype.forEach",!0);if(typeof process>"u"||!process.versions||!process.versions.node)var B=h("Map.prototype.iterator",!0),X=h("Set.prototype.iterator",!0);var A=h("Map.prototype.@@iterator",!0)||h("Map.prototype._es6-shim iterator_",!0),$=h("Set.prototype.@@iterator",!0)||h("Set.prototype._es6-shim iterator_",!0),O=function(L){if(E(L)){if(B)return r(B(L));if(A)return A(L);if(j){var Y=[];return j(L,function(oe,ue){y(Y,[ue,oe])}),R(Y)}}if(C(L)){if(X)return r(X(L));if($)return $(L);if(M){var W=[];return M(L,function(oe){y(W,oe)}),R(W)}}};ao.exports=function(L){return O(L)||_(L)}}}return ao.exports}var Kp,yS;function _O(){if(yS)return Kp;yS=1;var n=function(r){return r!==r};return Kp=function(i,l){return i===0&&l===0?1/i===1/l:!!(i===l||n(i)&&n(l))},Kp}var Fp,vS;function AO(){if(vS)return Fp;vS=1;var n=_O();return Fp=function(){return typeof Object.is=="function"?Object.is:n},Fp}var Zp,mS;function zM(){if(mS)return Zp;mS=1;var n=AO(),r=Ja();return Zp=function(){var l=n();return r(Object,{is:l},{is:function(){return Object.is!==l}}),l},Zp}var Ip,gS;function kM(){if(gS)return Ip;gS=1;var n=Ja(),r=il(),i=_O(),l=AO(),u=zM(),c=r(l(),Object);return n(c,{getPolyfill:l,implementation:i,shim:u}),Ip=c,Ip}var Wp,bS;function RO(){if(bS)return Wp;bS=1;var n=il(),r=tn(),i=Fr(),l=i("%ArrayBuffer%",!0),u=r("ArrayBuffer.prototype.byteLength",!0),c=r("Object.prototype.toString"),d=!!l&&!u&&new l(0).slice,p=!!d&&n(d);return Wp=u||p?function(y){if(!y||typeof y!="object")return!1;try{return u?u(y):p(y,0),!0}catch{return!1}}:l?function(y){return c(y)==="[object ArrayBuffer]"}:function(y){return!1},Wp}var Jp,SS;function LM(){if(SS)return Jp;SS=1;var n=tn(),r=n("Date.prototype.getDay"),i=function(p){try{return r(p),!0}catch{return!1}},l=n("Object.prototype.toString"),u="[object Date]",c=ei()();return Jp=function(p){return typeof p!="object"||p===null?!1:c?i(p):l(p)===u},Jp}var eh,xS;function wO(){if(xS)return eh;xS=1;var n=tn(),r=ei()(),i=Hy(),l=Wa(),u;if(r){var c=n("RegExp.prototype.exec"),d={},p=function(){throw d},h={toString:p,valueOf:p};typeof Symbol.toPrimitive=="symbol"&&(h[Symbol.toPrimitive]=p),u=function(S){if(!S||typeof S!="object")return!1;var R=l(S,"lastIndex"),_=R&&i(R,"value");if(!_)return!1;try{c(S,h)}catch(E){return E===d}}}else{var y=n("Object.prototype.toString"),m="[object RegExp]";u=function(S){return!S||typeof S!="object"&&typeof S!="function"?!1:y(S)===m}}return eh=u,eh}var th,ES;function UM(){if(ES)return th;ES=1;var n=tn(),r=n("SharedArrayBuffer.prototype.byteLength",!0);return th=r?function(l){if(!l||typeof l!="object")return!1;try{return r(l),!0}catch{return!1}}:function(l){return!1},th}var nh,OS;function HM(){if(OS)return nh;OS=1;var n=tn(),r=n("Number.prototype.toString"),i=function(p){try{return r(p),!0}catch{return!1}},l=n("Object.prototype.toString"),u="[object Number]",c=ei()();return nh=function(p){return typeof p=="number"?!0:!p||typeof p!="object"?!1:c?i(p):l(p)===u},nh}var rh,TS;function GM(){if(TS)return rh;TS=1;var n=tn(),r=n("Boolean.prototype.toString"),i=n("Object.prototype.toString"),l=function(p){try{return r(p),!0}catch{return!1}},u="[object Boolean]",c=ei()();return rh=function(p){return typeof p=="boolean"?!0:p===null||typeof p!="object"?!1:c?l(p):i(p)===u},rh}var as={exports:{}},ah,_S;function YM(){if(_S)return ah;_S=1;var n=tn(),r=wO(),i=n("RegExp.prototype.exec"),l=Xn();return ah=function(c){if(!r(c))throw new l("`regex` must be a RegExp");return function(p){return i(c,p)!==null}},ah}var AS;function VM(){if(AS)return as.exports;AS=1;var n=tn(),r=n("Object.prototype.toString"),i=qy()(),l=YM();if(i){var u=n("Symbol.prototype.toString"),c=l(/^Symbol\(.*\)$/),d=function(h){return typeof h.valueOf()!="symbol"?!1:c(u(h))};as.exports=function(h){if(typeof h=="symbol")return!0;if(!h||typeof h!="object"||r(h)!=="[object Symbol]")return!1;try{return d(h)}catch{return!1}}}else as.exports=function(h){return!1};return as.exports}var is={exports:{}},ih,RS;function PM(){if(RS)return ih;RS=1;var n=typeof BigInt<"u"&&BigInt;return ih=function(){return typeof n=="function"&&typeof BigInt=="function"&&typeof n(42)=="bigint"&&typeof BigInt(42)=="bigint"},ih}var wS;function XM(){if(wS)return is.exports;wS=1;var n=PM()();if(n){var r=BigInt.prototype.valueOf,i=function(u){try{return r.call(u),!0}catch{}return!1};is.exports=function(u){return u===null||typeof u>"u"||typeof u=="boolean"||typeof u=="string"||typeof u=="number"||typeof u=="symbol"||typeof u=="function"?!1:typeof u=="bigint"?!0:i(u)}}else is.exports=function(u){return!1};return is.exports}var lh,CS;function QM(){if(CS)return lh;CS=1;var n=EO(),r=HM(),i=GM(),l=VM(),u=XM();return lh=function(d){if(d==null||typeof d!="object"&&typeof d!="function")return null;if(n(d))return"String";if(r(d))return"Number";if(i(d))return"Boolean";if(l(d))return"Symbol";if(u(d))return"BigInt"},lh}var oh,NS;function KM(){if(NS)return oh;NS=1;var n=typeof WeakMap=="function"&&WeakMap.prototype?WeakMap:null,r=typeof WeakSet=="function"&&WeakSet.prototype?WeakSet:null,i;n||(i=function(d){return!1});var l=n?n.prototype.has:null,u=r?r.prototype.has:null;return!i&&!l&&(i=function(d){return!1}),oh=i||function(d){if(!d||typeof d!="object")return!1;try{if(l.call(d,l),u)try{u.call(d,u)}catch{return!0}return d instanceof n}catch{}return!1},oh}var ls={exports:{}},MS;function FM(){if(MS)return ls.exports;MS=1;var n=Fr(),r=tn(),i=n("%WeakSet%",!0),l=r("WeakSet.prototype.has",!0);if(l){var u=r("WeakMap.prototype.has",!0);ls.exports=function(d){if(!d||typeof d!="object")return!1;try{if(l(d,l),u)try{u(d,u)}catch{return!0}return d instanceof i}catch{}return!1}}else ls.exports=function(d){return!1};return ls.exports}var uh,DS;function ZM(){if(DS)return uh;DS=1;var n=OO(),r=TO(),i=KM(),l=FM();return uh=function(c){if(c&&typeof c=="object"){if(n(c))return"Map";if(r(c))return"Set";if(i(c))return"WeakMap";if(l(c))return"WeakSet"}return!1},uh}var sh,jS;function IM(){if(jS)return sh;jS=1;var n=Function.prototype.toString,r=typeof Reflect=="object"&&Reflect!==null&&Reflect.apply,i,l;if(typeof r=="function"&&typeof Object.defineProperty=="function")try{i=Object.defineProperty({},"length",{get:function(){throw l}}),l={},r(function(){throw 42},null,i)}catch(M){M!==l&&(r=null)}else r=null;var u=/^\s*class\b/,c=function(B){try{var X=n.call(B);return u.test(X)}catch{return!1}},d=function(B){try{return c(B)?!1:(n.call(B),!0)}catch{return!1}},p=Object.prototype.toString,h="[object Object]",y="[object Function]",m="[object GeneratorFunction]",g="[object HTMLAllCollection]",S="[object HTML document.all class]",R="[object HTMLCollection]",_=typeof Symbol=="function"&&!!Symbol.toStringTag,E=!(0 in[,]),C=function(){return!1};if(typeof document=="object"){var j=document.all;p.call(j)===p.call(document.all)&&(C=function(B){if((E||!B)&&(typeof B>"u"||typeof B=="object"))try{var X=p.call(B);return(X===g||X===S||X===R||X===h)&&B("")==null}catch{}return!1})}return sh=r?function(B){if(C(B))return!0;if(!B||typeof B!="function"&&typeof B!="object")return!1;try{r(B,null,i)}catch(X){if(X!==l)return!1}return!c(B)&&d(B)}:function(B){if(C(B))return!0;if(!B||typeof B!="function"&&typeof B!="object")return!1;if(_)return d(B);if(c(B))return!1;var X=p.call(B);return X!==y&&X!==m&&!/^\[object HTML/.test(X)?!1:d(B)},sh}var ch,BS;function WM(){if(BS)return ch;BS=1;var n=IM(),r=Object.prototype.toString,i=Object.prototype.hasOwnProperty,l=function(h,y,m){for(var g=0,S=h.length;g<S;g++)i.call(h,g)&&(m==null?y(h[g],g,h):y.call(m,h[g],g,h))},u=function(h,y,m){for(var g=0,S=h.length;g<S;g++)m==null?y(h.charAt(g),g,h):y.call(m,h.charAt(g),g,h)},c=function(h,y,m){for(var g in h)i.call(h,g)&&(m==null?y(h[g],g,h):y.call(m,h[g],g,h))};function d(p){return r.call(p)==="[object Array]"}return ch=function(h,y,m){if(!n(y))throw new TypeError("iterator must be a function");var g;arguments.length>=3&&(g=m),d(h)?l(h,y,g):typeof h=="string"?u(h,y,g):c(h,y,g)},ch}var fh,$S;function JM(){return $S||($S=1,fh=["Float16Array","Float32Array","Float64Array","Int8Array","Int16Array","Int32Array","Uint8Array","Uint8ClampedArray","Uint16Array","Uint32Array","BigInt64Array","BigUint64Array"]),fh}var dh,qS;function e5(){if(qS)return dh;qS=1;var n=JM(),r=typeof globalThis>"u"?bs:globalThis;return dh=function(){for(var l=[],u=0;u<n.length;u++)typeof r[n[u]]=="function"&&(l[l.length]=n[u]);return l},dh}var ph,zS;function t5(){if(zS)return ph;zS=1;var n=WM(),r=e5(),i=il(),l=tn(),u=Wa(),c=Uy(),d=l("Object.prototype.toString"),p=ei()(),h=typeof globalThis>"u"?bs:globalThis,y=r(),m=l("String.prototype.slice"),g=l("Array.prototype.indexOf",!0)||function(C,j){for(var M=0;M<C.length;M+=1)if(C[M]===j)return M;return-1},S={__proto__:null};p&&u&&c?n(y,function(E){var C=new h[E];if(Symbol.toStringTag in C&&c){var j=c(C),M=u(j,Symbol.toStringTag);if(!M&&j){var B=c(j);M=u(B,Symbol.toStringTag)}S["$"+E]=i(M.get)}}):n(y,function(E){var C=new h[E],j=C.slice||C.set;j&&(S["$"+E]=i(j))});var R=function(C){var j=!1;return n(S,function(M,B){if(!j)try{"$"+M(C)===B&&(j=m(B,1))}catch{}}),j},_=function(C){var j=!1;return n(S,function(M,B){if(!j)try{M(C),j=m(B,1)}catch{}}),j};return ph=function(C){if(!C||typeof C!="object")return!1;if(!p){var j=m(d(C),8,-1);return g(y,j)>-1?j:j!=="Object"?!1:_(C)}return u?R(C):null},ph}var hh,kS;function n5(){if(kS)return hh;kS=1;var n=tn(),r=n("ArrayBuffer.prototype.byteLength",!0),i=RO();return hh=function(u){return i(u)?r?r(u):u.byteLength:NaN},hh}var yh,LS;function r5(){if(LS)return yh;LS=1;var n=TM(),r=yO(),i=wM(),l=Fr(),u=qM(),c=SO(),d=kM(),p=gO(),h=xO(),y=RO(),m=LM(),g=wO(),S=UM(),R=My(),_=QM(),E=ZM(),C=t5(),j=n5(),M=r("SharedArrayBuffer.prototype.byteLength",!0),B=r("Date.prototype.getTime"),X=Object.getPrototypeOf,A=r("Object.prototype.toString"),$=l("%Set%",!0),O=r("Map.prototype.has",!0),q=r("Map.prototype.get",!0),L=r("Map.prototype.size",!0),Y=r("Set.prototype.add",!0),W=r("Set.prototype.delete",!0),oe=r("Set.prototype.has",!0),ue=r("Set.prototype.size",!0);function he(z,F,te,pe){for(var ce=u(z),xe;(xe=ce.next())&&!xe.done;)if(be(F,xe.value,te,pe))return W(z,xe.value),!0;return!1}function fe(z){if(typeof z>"u")return null;if(typeof z!="object")return typeof z=="symbol"?!1:typeof z=="string"||typeof z=="number"?+z==+z:!0}function H(z,F,te,pe,ce,xe){var me=fe(te);if(me!=null)return me;var Ee=q(F,me),de=n({},ce,{strict:!1});return typeof Ee>"u"&&!O(F,me)||!be(pe,Ee,de,xe)?!1:!O(z,me)&&be(pe,Ee,de,xe)}function I(z,F,te){var pe=fe(te);return pe??(oe(F,pe)&&!oe(z,pe))}function ae(z,F,te,pe,ce,xe){for(var me=u(z),Ee,de;(Ee=me.next())&&!Ee.done;)if(de=Ee.value,be(te,de,ce,xe)&&be(pe,q(F,de),ce,xe))return W(z,de),!0;return!1}function be(z,F,te,pe){var ce=te||{};if(ce.strict?d(z,F):z===F)return!0;var xe=_(z),me=_(F);if(xe!==me)return!1;if(!z||!F||typeof z!="object"&&typeof F!="object")return ce.strict?d(z,F):z==F;var Ee=pe.has(z),de=pe.has(F),ve;if(Ee&&de){if(pe.get(z)===pe.get(F))return!0}else ve={};return Ee||pe.set(z,ve),de||pe.set(F,ve),re(z,F,ce,pe)}function N(z){return!z||typeof z!="object"||typeof z.length!="number"||typeof z.copy!="function"||typeof z.slice!="function"||z.length>0&&typeof z[0]!="number"?!1:!!(z.constructor&&z.constructor.isBuffer&&z.constructor.isBuffer(z))}function Z(z,F,te,pe){if(ue(z)!==ue(F))return!1;for(var ce=u(z),xe=u(F),me,Ee,de;(me=ce.next())&&!me.done;)if(me.value&&typeof me.value=="object")de||(de=new $),Y(de,me.value);else if(!oe(F,me.value)){if(te.strict||!I(z,F,me.value))return!1;de||(de=new $),Y(de,me.value)}if(de){for(;(Ee=xe.next())&&!Ee.done;)if(Ee.value&&typeof Ee.value=="object"){if(!he(de,Ee.value,te.strict,pe))return!1}else if(!te.strict&&!oe(z,Ee.value)&&!he(de,Ee.value,te.strict,pe))return!1;return ue(de)===0}return!0}function le(z,F,te,pe){if(L(z)!==L(F))return!1;for(var ce=u(z),xe=u(F),me,Ee,de,ve,Oe,ye;(me=ce.next())&&!me.done;)if(ve=me.value[0],Oe=me.value[1],ve&&typeof ve=="object")de||(de=new $),Y(de,ve);else if(ye=q(F,ve),typeof ye>"u"&&!O(F,ve)||!be(Oe,ye,te,pe)){if(te.strict||!H(z,F,ve,Oe,te,pe))return!1;de||(de=new $),Y(de,ve)}if(de){for(;(Ee=xe.next())&&!Ee.done;)if(ve=Ee.value[0],ye=Ee.value[1],ve&&typeof ve=="object"){if(!ae(de,z,ve,ye,te,pe))return!1}else if(!te.strict&&(!z.has(ve)||!be(q(z,ve),ye,te,pe))&&!ae(de,z,ve,ye,n({},te,{strict:!1}),pe))return!1;return ue(de)===0}return!0}function re(z,F,te,pe){var ce,xe;if(typeof z!=typeof F||z==null||F==null||A(z)!==A(F)||p(z)!==p(F))return!1;var me=h(z),Ee=h(F);if(me!==Ee)return!1;var de=z instanceof Error,ve=F instanceof Error;if(de!==ve||(de||ve)&&(z.name!==F.name||z.message!==F.message))return!1;var Oe=g(z),ye=g(F);if(Oe!==ye||(Oe||ye)&&(z.source!==F.source||i(z)!==i(F)))return!1;var je=m(z),Me=m(F);if(je!==Me||(je||Me)&&B(z)!==B(F)||te.strict&&X&&X(z)!==X(F))return!1;var Fe=C(z),Ht=C(F);if(Fe!==Ht)return!1;if(Fe||Ht){if(z.length!==F.length)return!1;for(ce=0;ce<z.length;ce++)if(z[ce]!==F[ce])return!1;return!0}var ze=N(z),Ze=N(F);if(ze!==Ze)return!1;if(ze||Ze){if(z.length!==F.length)return!1;for(ce=0;ce<z.length;ce++)if(z[ce]!==F[ce])return!1;return!0}var Gt=y(z),$t=y(F);if(Gt!==$t)return!1;if(Gt||$t)return j(z)!==j(F)?!1:typeof Uint8Array=="function"&&be(new Uint8Array(z),new Uint8Array(F),te,pe);var qt=S(z),An=S(F);if(qt!==An)return!1;if(qt||An)return M(z)!==M(F)?!1:typeof Uint8Array=="function"&&be(new Uint8Array(z),new Uint8Array(F),te,pe);if(typeof z!=typeof F)return!1;var _t=R(z),rt=R(F);if(_t.length!==rt.length)return!1;for(_t.sort(),rt.sort(),ce=_t.length-1;ce>=0;ce--)if(_t[ce]!=rt[ce])return!1;for(ce=_t.length-1;ce>=0;ce--)if(xe=_t[ce],!be(z[xe],F[xe],te,pe))return!1;var ie=E(z),se=E(F);return ie!==se?!1:ie==="Set"||se==="Set"?Z(z,F,te,pe):ie==="Map"?le(z,F,te,pe):!0}return yh=function(F,te,pe){return be(F,te,pe,c())},yh}var a5=r5();const i5=_a(a5),Gy=(n,r)=>{for(const i in r)if(typeof r[i]=="object"){if(!i5(n[i],r[i]))return!1}else if(!Object.is(n[i],r[i]))return!1;return!0},os=n=>{let r=0,i;const l=n.readonly;return n.type==="int"||n.type==="float"?r=n.value:n.type==="Quantity"&&(r=n.value.magnitude,i=n.value.unit),[r,l,i]},CO=Xe.memo(n=>{gr();const[r,i]=x.useState(!1),{fullAccessPath:l,value:u,min:c,max:d,stepSize:p,docString:h,isInstantUpdate:y,addNotification:m,changeCallback:g=()=>{},displayName:S,id:R}=n;x.useEffect(()=>{m(`${l} changed to ${u.value}.`)},[n.value.value]),x.useEffect(()=>{m(`${l}.min changed to ${c.value}.`)},[n.min.value,n.min.type]),x.useEffect(()=>{m(`${l}.max changed to ${d.value}.`)},[n.max.value,n.max.type]),x.useEffect(()=>{m(`${l}.stepSize changed to ${p.value}.`)},[n.stepSize.value,n.stepSize.type]);const _=(L,Y)=>{Array.isArray(Y)&&(Y=Y[0]);let W;u.type==="Quantity"?W={type:"Quantity",value:{magnitude:Y,unit:u.value.unit},full_access_path:`${l}.value`,readonly:u.readonly,doc:h}:W={type:u.type,value:Y,full_access_path:`${l}.value`,readonly:u.readonly,doc:h},g(W)},E=(L,Y,W)=>{let oe;W.type==="Quantity"?oe={type:W.type,value:{magnitude:L,unit:W.value.unit},full_access_path:`${l}.${Y}`,readonly:W.readonly,doc:null}:oe={type:W.type,value:L,full_access_path:`${l}.${Y}`,readonly:W.readonly,doc:null},g(oe)},[C,j,M]=os(u),[B,X]=os(c),[A,$]=os(d),[O,q]=os(p);return T.jsxs("div",{className:"component sliderComponent",id:R,children:[!1,T.jsxs(Ts,{children:[T.jsx(ur,{xs:"auto",xl:"auto",children:T.jsxs(Yr.Text,{children:[S,T.jsx(tr,{docString:h})]})}),T.jsx(ur,{xs:"5",xl:!0,children:T.jsx(rM,{style:{margin:"0px 0px 10px 0px"},"aria-label":"Always visible",disabled:j,value:C,onChange:(L,Y)=>_(L,Y),min:B,max:A,step:O,marks:[{value:B,label:`${B}`},{value:A,label:`${A}`}]})}),T.jsx(ur,{xs:"3",xl:!0,children:T.jsx(_s,{isInstantUpdate:y,fullAccessPath:`${l}.value`,docString:h,readOnly:j,type:u.type,value:C,unit:M,addNotification:()=>{},changeCallback:g,id:R+"-value"})}),T.jsx(ur,{xs:"auto",children:T.jsx(fy,{id:`button-${R}`,onClick:()=>i(!r),type:"checkbox",checked:r,value:"",className:"btn",variant:"light","aria-controls":"slider-settings","aria-expanded":r,children:T.jsxs("svg",{xmlns:"http://www.w3.org/2000/svg",width:"16",height:"16",className:"bi bi-gear",viewBox:"0 0 16 16",children:[T.jsx("path",{d:"M8 4.754a3.246 3.246 0 1 0 0 6.492 3.246 3.246 0 0 0 0-6.492zM5.754 8a2.246 2.246 0 1 1 4.492 0 2.246 2.246 0 0 1-4.492 0z"}),T.jsx("path",{d:"M9.796 1.343c-.527-1.79-3.065-1.79-3.592 0l-.094.319a.873.873 0 0 1-1.255.52l-.292-.16c-1.64-.892-3.433.902-2.54 2.541l.159.292a.873.873 0 0 1-.52 1.255l-.319.094c-1.79.527-1.79 3.065 0 3.592l.319.094a.873.873 0 0 1 .52 1.255l-.16.292c-.892 1.64.901 3.434 2.541 2.54l.292-.159a.873.873 0 0 1 1.255.52l.094.319c.527 1.79 3.065 1.79 3.592 0l.094-.319a.873.873 0 0 1 1.255-.52l.292.16c1.64.893 3.434-.902 2.54-2.541l-.159-.292a.873.873 0 0 1 .52-1.255l.319-.094c1.79-.527 1.79-3.065 0-3.592l-.319-.094a.873.873 0 0 1-.52-1.255l.16-.292c.893-1.64-.902-3.433-2.541-2.54l-.292.159a.873.873 0 0 1-1.255-.52l-.094-.319zm-2.633.283c.246-.835 1.428-.835 1.674 0l.094.319a1.873 1.873 0 0 0 2.693 1.115l.291-.16c.764-.415 1.6.42 1.184 1.185l-.159.292a1.873 1.873 0 0 0 1.116 2.692l.318.094c.835.246.835 1.428 0 1.674l-.319.094a1.873 1.873 0 0 0-1.115 2.693l.16.291c.415.764-.42 1.6-1.185 1.184l-.291-.159a1.873 1.873 0 0 0-2.693 1.116l-.094.318c-.246.835-1.428.835-1.674 0l-.094-.319a1.873 1.873 0 0 0-2.692-1.115l-.292.16c-.764.415-1.6-.42-1.184-1.185l.159-.291A1.873 1.873 0 0 0 1.945 8.93l-.319-.094c-.835-.246-.835-1.428 0-1.674l.319-.094A1.873 1.873 0 0 0 3.06 4.377l-.16-.292c-.415-.764.42-1.6 1.185-1.184l.292.159a1.873 1.873 0 0 0 2.692-1.115l.094-.319z"})]})})})]}),T.jsx(wo,{in:r,children:T.jsx(an.Group,{children:T.jsxs(Ts,{className:"justify-content-center",style:{paddingTop:"20px",margin:"10px"},children:[T.jsxs(ur,{xs:"auto",children:[T.jsx(an.Label,{children:"Min Value"}),T.jsx(an.Control,{type:"number",value:B,disabled:X,onChange:L=>E(Number(L.target.value),"min",c)})]}),T.jsxs(ur,{xs:"auto",children:[T.jsx(an.Label,{children:"Max Value"}),T.jsx(an.Control,{type:"number",value:A,disabled:$,onChange:L=>E(Number(L.target.value),"max",d)})]}),T.jsxs(ur,{xs:"auto",children:[T.jsx(an.Label,{children:"Step Size"}),T.jsx(an.Control,{type:"number",value:O,disabled:q,onChange:L=>E(Number(L.target.value),"step_size",p)})]})]})})})]})},Gy);CO.displayName="SliderComponent";const NO=Xe.memo(n=>{const{addNotification:r,displayName:i,id:l,value:u,full_access_path:c,enum:d,doc:p,readonly:h,changeCallback:y}=n;return gr(),x.useEffect(()=>{r(`${c} changed to ${u}.`)},[u]),T.jsxs("div",{className:"component enumComponent",id:l,children:[!1,T.jsx(Ts,{children:T.jsxs(ur,{className:"d-flex align-items-center",children:[T.jsxs(Yr.Text,{children:[i,T.jsx(tr,{docString:p})]}),h?T.jsx(an.Control,{style:n.type=="ColouredEnum"?{backgroundColor:d[u]}:{},value:n.type=="ColouredEnum"?u:d[u],name:c,disabled:!0}):T.jsx(an.Select,{"aria-label":"example-select",value:u,name:c,style:n.type=="ColouredEnum"?{backgroundColor:d[u]}:{},onChange:m=>y({type:n.type,name:n.name,enum:d,value:m.target.value,full_access_path:c,readonly:n.readonly,doc:n.doc}),children:Object.entries(d).map(([m,g])=>T.jsx("option",{value:m,children:n.type=="ColouredEnum"?m:g},m))})]})})]})},Gy);NO.displayName="EnumComponent";const Yy=Xe.memo(n=>{const{fullAccessPath:r,docString:i,addNotification:l,displayName:u,id:c}=n;if(!n.render)return null;gr();const d=x.useRef(null),p=()=>{const y=`Method ${r} was triggered.`;l(y)},h=async y=>{y.preventDefault(),CE(r),p()};return T.jsxs("div",{className:"component methodComponent",id:c,children:[!1,T.jsx(an,{onSubmit:h,ref:d,children:T.jsxs(Co,{className:"component",variant:"primary",type:"submit",children:[`${u} `,T.jsx(tr,{docString:i})]})})]})},Gy);Yy.displayName="MethodComponent";const MO=Xe.memo(n=>{const{fullAccessPath:r,readOnly:i,docString:l,isInstantUpdate:u,addNotification:c,changeCallback:d=()=>{},displayName:p,id:h}=n;gr();const[y,m]=x.useState(n.value);x.useEffect(()=>{n.value!==y&&m(n.value),c(`${r} changed to ${n.value}.`)},[n.value]);const g=_=>{m(_.target.value),u&&d({type:"str",value:_.target.value,full_access_path:r,readonly:i,doc:l})},S=_=>{_.key==="Enter"&&!u&&(d({type:"str",value:y,full_access_path:r,readonly:i,doc:l}),_.preventDefault())},R=()=>{u||d({type:"str",value:y,full_access_path:r,readonly:i,doc:l})};return T.jsxs("div",{className:"component stringComponent",id:h,children:[!1,T.jsxs(Yr,{children:[T.jsxs(Yr.Text,{children:[p,T.jsx(tr,{docString:l})]}),T.jsx(an.Control,{type:"text",name:h,value:y,disabled:i,onChange:g,onKeyDown:S,onBlur:R,className:u&&!i?"instantUpdate":""})]})]})});MO.displayName="StringComponent";function Vy(n){const r=x.useContext(my),i=u=>{var c;return((c=r[u])==null?void 0:c.displayOrder)??Number.MAX_SAFE_INTEGER};let l;return Array.isArray(n)?l=[...n].sort((u,c)=>i(u.full_access_path)-i(c.full_access_path)):l=Object.values(n).sort((u,c)=>i(u.full_access_path)-i(c.full_access_path)),l}const DO=Xe.memo(n=>{const{docString:r,isInstantUpdate:i,addNotification:l,id:u}=n,c=Vy(n.value);return gr(),T.jsxs("div",{className:"listComponent",id:u,children:[!1,T.jsx(tr,{docString:r}),c.map(d=>T.jsx(tl,{attribute:d,isInstantUpdate:i,addNotification:l},d.full_access_path))]})});DO.displayName="ListComponent";var l5=["color","size","title","className"];function Vh(){return Vh=Object.assign?Object.assign.bind():function(n){for(var r=1;r<arguments.length;r++){var i=arguments[r];for(var l in i)({}).hasOwnProperty.call(i,l)&&(n[l]=i[l])}return n},Vh.apply(null,arguments)}function o5(n,r){if(n==null)return{};var i,l,u=u5(n,r);if(Object.getOwnPropertySymbols){var c=Object.getOwnPropertySymbols(n);for(l=0;l<c.length;l++)i=c[l],r.indexOf(i)===-1&&{}.propertyIsEnumerable.call(n,i)&&(u[i]=n[i])}return u}function u5(n,r){if(n==null)return{};var i={};for(var l in n)if({}.hasOwnProperty.call(n,l)){if(r.indexOf(l)!==-1)continue;i[l]=n[l]}return i}var Py=x.forwardRef(function(n,r){var i=n.color,l=i===void 0?"currentColor":i,u=n.size,c=u===void 0?"1em":u,d=n.title,p=d===void 0?null:d,h=n.className,y=h===void 0?"":h,m=o5(n,l5);return Xe.createElement("svg",Vh({ref:r,xmlns:"http://www.w3.org/2000/svg",viewBox:"0 0 16 16",width:c,height:c,fill:l,className:["bi","bi-chevron-down",y].filter(Boolean).join(" ")},m),p?Xe.createElement("title",null,p):null,Xe.createElement("path",{fillRule:"evenodd",d:"M1.646 4.646a.5.5 0 0 1 .708 0L8 10.293l5.646-5.647a.5.5 0 0 1 .708.708l-6 6a.5.5 0 0 1-.708 0l-6-6a.5.5 0 0 1 0-.708"}))});Py.propTypes={color:dt.string,size:dt.oneOfType([dt.string,dt.number]),title:dt.string,className:dt.string};var s5=["color","size","title","className"];function Ph(){return Ph=Object.assign?Object.assign.bind():function(n){for(var r=1;r<arguments.length;r++){var i=arguments[r];for(var l in i)({}).hasOwnProperty.call(i,l)&&(n[l]=i[l])}return n},Ph.apply(null,arguments)}function c5(n,r){if(n==null)return{};var i,l,u=f5(n,r);if(Object.getOwnPropertySymbols){var c=Object.getOwnPropertySymbols(n);for(l=0;l<c.length;l++)i=c[l],r.indexOf(i)===-1&&{}.propertyIsEnumerable.call(n,i)&&(u[i]=n[i])}return u}function f5(n,r){if(n==null)return{};var i={};for(var l in n)if({}.hasOwnProperty.call(n,l)){if(r.indexOf(l)!==-1)continue;i[l]=n[l]}return i}var Xy=x.forwardRef(function(n,r){var i=n.color,l=i===void 0?"currentColor":i,u=n.size,c=u===void 0?"1em":u,d=n.title,p=d===void 0?null:d,h=n.className,y=h===void 0?"":h,m=c5(n,s5);return Xe.createElement("svg",Ph({ref:r,xmlns:"http://www.w3.org/2000/svg",viewBox:"0 0 16 16",width:c,height:c,fill:l,className:["bi","bi-chevron-right",y].filter(Boolean).join(" ")},m),p?Xe.createElement("title",null,p):null,Xe.createElement("path",{fillRule:"evenodd",d:"M4.646 1.646a.5.5 0 0 1 .708 0l6 6a.5.5 0 0 1 0 .708l-6 6a.5.5 0 0 1-.708-.708L10.293 8 4.646 2.354a.5.5 0 0 1 0-.708"}))});Xy.propTypes={color:dt.string,size:dt.oneOfType([dt.string,dt.number]),title:dt.string,className:dt.string};function Xh(n,r){const[i,l]=x.useState(()=>{const u=localStorage.getItem(`${Pi}:${n}`);return u?JSON.parse(u):r});return x.useEffect(()=>{i!==void 0&&localStorage.setItem(`${Pi}:${n}`,JSON.stringify(i))},[i,n]),[i,l]}const Qy=Xe.memo(({props:n,isInstantUpdate:r,addNotification:i,displayName:l,id:u})=>{const[c,d]=Xh(`dataServiceComponent-${u}-open`,!0),p=Vy(n);return l!==""?T.jsx("div",{className:"component dataServiceComponent",id:u,children:T.jsxs(Xi,{children:[T.jsxs(Xi.Header,{onClick:()=>d(!c),style:{cursor:"pointer"},children:[l," ",c?T.jsx(Py,{}):T.jsx(Xy,{})]}),T.jsx(wo,{in:c,children:T.jsx(Xi.Body,{children:p.map(h=>T.jsx(tl,{attribute:h,isInstantUpdate:r,addNotification:i},h.full_access_path))})})]})}):T.jsx("div",{className:"component dataServiceComponent",id:u,children:p.map(h=>T.jsx(tl,{attribute:h,isInstantUpdate:r,addNotification:i},h.full_access_path))})});Qy.displayName="DataServiceComponent";const jO=Xe.memo(({fullAccessPath:n,props:r,isInstantUpdate:i,addNotification:l,displayName:u,id:c})=>{const{connected:d,connect:p,...h}=r,y=d.value;return T.jsxs("div",{className:"deviceConnectionComponent",id:c,children:[!y&&T.jsxs("div",{className:"overlayContent",children:[T.jsxs("div",{children:[u!=""?u:"Device"," is currently not available!"]}),T.jsx(Yy,{fullAccessPath:`${n}.connect`,docString:p.doc,addNotification:l,displayName:"reconnect",id:c+"-connect",render:!0})]}),T.jsx(Qy,{props:h,isInstantUpdate:i,addNotification:l,displayName:u,id:c})]})});jO.displayName="DeviceConnectionComponent";const BO=Xe.memo(n=>{const{fullAccessPath:r,value:i,docString:l,format:u,addNotification:c,displayName:d,id:p}=n;gr();const[h,y]=x.useState(!0);return x.useEffect(()=>{c(`${r} changed.`)},[n.value]),T.jsx("div",{className:"component imageComponent",id:p,children:T.jsxs(Xi,{children:[T.jsxs(Xi.Header,{onClick:()=>y(!h),style:{cursor:"pointer"},children:[d,T.jsx(tr,{docString:l}),h?T.jsx(Py,{}):T.jsx(Xy,{})]}),T.jsx(wo,{in:h,children:T.jsxs(Xi.Body,{children:[!1,u===""&&i===""?T.jsx("p",{children:"No image set in the backend."}):T.jsx(Ax,{src:`data:image/${u.toLowerCase()};base64,${i}`})]})})]})})});BO.displayName="ImageComponent";function d5(n){if(n){let r=n.replace(/\]\./g,"-");return r=r.replace(/[^\w_]+/g,"-"),r=r.replace(/-+$/,""),r}else return"main"}const $O=Xe.memo(n=>{const{docString:r,isInstantUpdate:i,addNotification:l,id:u}=n,c=Vy(n.value);return gr(),T.jsxs("div",{className:"listComponent",id:u,children:[!1,T.jsx(tr,{docString:r}),c.map(d=>T.jsx(tl,{attribute:d,isInstantUpdate:i,addNotification:l},d.full_access_path))]})});$O.displayName="DictComponent";const qO=Xe.memo(n=>{const{fullAccessPath:r,docString:i,status:l,addNotification:u,displayName:c,id:d}=n;gr();const p=x.useRef(null),[h,y]=x.useState(!1);x.useEffect(()=>{let g;l==="RUNNING"?g=`${r} was started.`:g=`${r} was stopped.`,u(g),y(!1)},[l]);const m=async g=>{g.preventDefault();const S=l=="RUNNING"?"stop":"start",R=[r,S].filter(_=>_).join(".");y(!0),CE(R)};return T.jsxs("div",{className:"component taskComponent",id:d,children:[!1,T.jsx(an,{onSubmit:m,ref:p,children:T.jsxs(Yr,{children:[T.jsxs(Yr.Text,{children:[c,T.jsx(tr,{docString:i})]}),T.jsx(Co,{id:`button-${d}`,type:"submit",children:h?T.jsx(lE,{size:"sm",role:"status","aria-hidden":"true"}):l==="RUNNING"?"Stop ":"Start "})]})})]})});qO.displayName="TaskComponent";const p5=n=>{let r="";for(const i of n)!i.startsWith("[")&&r!==""&&(r+="."),r+=i;return r},h5=n=>{const r=[],i=ME(n);for(let l=i.length-1;l>=0;l--){const u=i[l];if(r.unshift(u),!u.startsWith("["))break}return p5(r)};function Yi(n,r=()=>{}){rC(n,r)}const tl=Xe.memo(({attribute:n,isInstantUpdate:r,addNotification:i})=>{const{full_access_path:l}=n,u=d5(l),c=x.useContext(my);let d=h5(l);if(c[l]){if(c[l].display===!1)return null;c[l].displayName&&(d=c[l].displayName)}return n.type==="bool"?T.jsx(DE,{fullAccessPath:l,docString:n.doc,readOnly:n.readonly,value:!!n.value,addNotification:i,changeCallback:Yi,displayName:d,id:u}):n.type==="float"||n.type==="int"?T.jsx(_s,{type:n.type,fullAccessPath:l,docString:n.doc,readOnly:n.readonly,value:Number(n.value),isInstantUpdate:r,addNotification:i,changeCallback:Yi,displayName:d,id:u}):n.type==="Quantity"?T.jsx(_s,{type:"Quantity",fullAccessPath:l,docString:n.doc,readOnly:n.readonly,value:Number(n.value.magnitude),unit:n.value.unit,isInstantUpdate:r,addNotification:i,changeCallback:Yi,displayName:d,id:u}):n.type==="NumberSlider"?T.jsx(CO,{fullAccessPath:l,docString:n.value.value.doc,readOnly:n.readonly,value:n.value.value,min:n.value.min,max:n.value.max,stepSize:n.value.step_size,isInstantUpdate:r,addNotification:i,changeCallback:Yi,displayName:d,id:u}):n.type==="Enum"||n.type==="ColouredEnum"?T.jsx(NO,{...n,addNotification:i,changeCallback:Yi,displayName:d,id:u}):n.type==="method"?T.jsx(Yy,{fullAccessPath:l,docString:n.doc,addNotification:i,displayName:d,id:u,render:n.frontend_render}):n.type==="str"?T.jsx(MO,{fullAccessPath:l,value:n.value,readOnly:n.readonly,docString:n.doc,isInstantUpdate:r,addNotification:i,changeCallback:Yi,displayName:d,id:u}):n.type=="Task"?T.jsx(qO,{fullAccessPath:l,docString:n.doc,status:n.value.status.value,addNotification:i,displayName:d,id:u}):n.type==="DataService"?T.jsx(Qy,{props:n.value,isInstantUpdate:r,addNotification:i,displayName:d,id:u}):n.type==="DeviceConnection"?T.jsx(jO,{fullAccessPath:l,props:n.value,isInstantUpdate:r,addNotification:i,displayName:d,id:u}):n.type==="list"?T.jsx(DO,{value:n.value,docString:n.doc,isInstantUpdate:r,addNotification:i,id:u}):n.type==="dict"?T.jsx($O,{value:n.value,docString:n.doc,isInstantUpdate:r,addNotification:i,id:u}):n.type==="Image"?T.jsx(BO,{fullAccessPath:l,docString:n.value.value.doc,displayName:d,id:u,addNotification:i,value:n.value.value.value,format:n.value.format.value}):T.jsx("div",{children:l},l)});tl.displayName="GenericComponent";const y5=(n,r)=>{switch(r.type){case"SET_DATA":return r.data;case"UPDATE_ATTRIBUTE":return n===null?null:{...n,value:lC(n.value,r.fullAccessPath,r.newValue)};default:throw new Error}},v5=()=>{const[n,r]=x.useReducer(y5,null),[i,l]=x.useState(null),[u,c]=x.useState({}),[d,p]=Xh("isInstantUpdate",!1),[h,y]=x.useState(!1),[m,g]=Xh("showNotification",!1),[S,R]=x.useState([]),[_,E]=x.useState("connecting");x.useEffect(()=>(fetch(`${so}://${Pi}/custom.css`,{credentials:"include"}).then($=>{if($.ok){const O=document.createElement("link");O.href=`${so}://${Pi}/custom.css`,O.type="text/css",O.rel="stylesheet",document.head.appendChild(O)}}).catch(console.error),kr.on("connect",()=>{fetch(`${so}://${Pi}/service-properties`,{credentials:"include"}).then($=>$.json()).then($=>{r({type:"SET_DATA",data:$}),l($.name),document.title=$.name}),fetch(`${so}://${Pi}/web-settings`,{credentials:"include"}).then($=>$.json()).then($=>c($)),E("connected")}),kr.on("disconnect",()=>{E("disconnected"),setTimeout(()=>{E($=>$==="disconnected"?"reconnecting":$)},2e3)}),kr.on("notify",X),kr.on("log",A),()=>{kr.off("notify",X),kr.off("log",A)}),[]);const C=x.useCallback(($,O="DEBUG")=>{const q=new Date().toISOString().substring(11,19),L=Math.random();R(Y=>[{levelname:O,id:L,message:$,timeStamp:q},...Y])},[]),j=$=>{R(O=>O.filter(q=>q.id!==$))},M=()=>y(!1),B=()=>y(!0);function X($){const{full_access_path:O,value:q}=$.data;r({type:"UPDATE_ATTRIBUTE",fullAccessPath:O,newValue:q})}function A($){C($.message,$.levelname)}return n?T.jsxs(T.Fragment,{children:[T.jsx(Sd,{expand:!1,bg:"primary",variant:"dark",fixed:"top",children:T.jsxs(px,{fluid:!0,children:[T.jsx(Sd.Brand,{children:i}),T.jsx(Sd.Toggle,{"aria-controls":"offcanvasNavbar",onClick:B})]})}),T.jsx(NE,{showNotification:m,notifications:S,removeNotificationById:j}),T.jsxs(oo,{show:h,onHide:M,placement:"end",style:{zIndex:9999},children:[T.jsx(oo.Header,{closeButton:!0,children:T.jsx(oo.Title,{children:"Settings"})}),T.jsxs(oo.Body,{children:[T.jsx(an.Check,{checked:d,onChange:$=>p($.target.checked),type:"switch",label:"Enable Instant Update"}),T.jsx(an.Check,{checked:m,onChange:$=>g($.target.checked),type:"switch",label:"Show Notifications"})]})]}),T.jsx("div",{className:"App navbarOffset",children:T.jsx(my.Provider,{value:u,children:T.jsx(tl,{attribute:n,isInstantUpdate:d,addNotification:C})})}),T.jsx($h,{connectionStatus:_})]}):T.jsx($h,{connectionStatus:_})};var vh={exports:{}},io={},mh={exports:{}},gh={};/**
 * @license React
 * scheduler.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var US;function m5(){return US||(US=1,function(n){function r(H,I){var ae=H.length;H.push(I);e:for(;0<ae;){var be=ae-1>>>1,N=H[be];if(0<u(N,I))H[be]=I,H[ae]=N,ae=be;else break e}}function i(H){return H.length===0?null:H[0]}function l(H){if(H.length===0)return null;var I=H[0],ae=H.pop();if(ae!==I){H[0]=ae;e:for(var be=0,N=H.length,Z=N>>>1;be<Z;){var le=2*(be+1)-1,re=H[le],z=le+1,F=H[z];if(0>u(re,ae))z<N&&0>u(F,re)?(H[be]=F,H[z]=ae,be=z):(H[be]=re,H[le]=ae,be=le);else if(z<N&&0>u(F,ae))H[be]=F,H[z]=ae,be=z;else break e}}return I}function u(H,I){var ae=H.sortIndex-I.sortIndex;return ae!==0?ae:H.id-I.id}if(n.unstable_now=void 0,typeof performance=="object"&&typeof performance.now=="function"){var c=performance;n.unstable_now=function(){return c.now()}}else{var d=Date,p=d.now();n.unstable_now=function(){return d.now()-p}}var h=[],y=[],m=1,g=null,S=3,R=!1,_=!1,E=!1,C=!1,j=typeof setTimeout=="function"?setTimeout:null,M=typeof clearTimeout=="function"?clearTimeout:null,B=typeof setImmediate<"u"?setImmediate:null;function X(H){for(var I=i(y);I!==null;){if(I.callback===null)l(y);else if(I.startTime<=H)l(y),I.sortIndex=I.expirationTime,r(h,I);else break;I=i(y)}}function A(H){if(E=!1,X(H),!_)if(i(h)!==null)_=!0,$||($=!0,oe());else{var I=i(y);I!==null&&fe(A,I.startTime-H)}}var $=!1,O=-1,q=5,L=-1;function Y(){return C?!0:!(n.unstable_now()-L<q)}function W(){if(C=!1,$){var H=n.unstable_now();L=H;var I=!0;try{e:{_=!1,E&&(E=!1,M(O),O=-1),R=!0;var ae=S;try{t:{for(X(H),g=i(h);g!==null&&!(g.expirationTime>H&&Y());){var be=g.callback;if(typeof be=="function"){g.callback=null,S=g.priorityLevel;var N=be(g.expirationTime<=H);if(H=n.unstable_now(),typeof N=="function"){g.callback=N,X(H),I=!0;break t}g===i(h)&&l(h),X(H)}else l(h);g=i(h)}if(g!==null)I=!0;else{var Z=i(y);Z!==null&&fe(A,Z.startTime-H),I=!1}}break e}finally{g=null,S=ae,R=!1}I=void 0}}finally{I?oe():$=!1}}}var oe;if(typeof B=="function")oe=function(){B(W)};else if(typeof MessageChannel<"u"){var ue=new MessageChannel,he=ue.port2;ue.port1.onmessage=W,oe=function(){he.postMessage(null)}}else oe=function(){j(W,0)};function fe(H,I){O=j(function(){H(n.unstable_now())},I)}n.unstable_IdlePriority=5,n.unstable_ImmediatePriority=1,n.unstable_LowPriority=4,n.unstable_NormalPriority=3,n.unstable_Profiling=null,n.unstable_UserBlockingPriority=2,n.unstable_cancelCallback=function(H){H.callback=null},n.unstable_forceFrameRate=function(H){0>H||125<H||(q=0<H?Math.floor(1e3/H):5)},n.unstable_getCurrentPriorityLevel=function(){return S},n.unstable_next=function(H){switch(S){case 1:case 2:case 3:var I=3;break;default:I=S}var ae=S;S=I;try{return H()}finally{S=ae}},n.unstable_requestPaint=function(){C=!0},n.unstable_runWithPriority=function(H,I){switch(H){case 1:case 2:case 3:case 4:case 5:break;default:H=3}var ae=S;S=H;try{return I()}finally{S=ae}},n.unstable_scheduleCallback=function(H,I,ae){var be=n.unstable_now();switch(typeof ae=="object"&&ae!==null?(ae=ae.delay,ae=typeof ae=="number"&&0<ae?be+ae:be):ae=be,H){case 1:var N=-1;break;case 2:N=250;break;case 5:N=1073741823;break;case 4:N=1e4;break;default:N=5e3}return N=ae+N,H={id:m++,callback:I,priorityLevel:H,startTime:ae,expirationTime:N,sortIndex:-1},ae>be?(H.sortIndex=ae,r(y,H),i(h)===null&&H===i(y)&&(E?(M(O),O=-1):E=!0,fe(A,ae-be))):(H.sortIndex=N,r(h,H),_||R||(_=!0,$||($=!0,oe()))),H},n.unstable_shouldYield=Y,n.unstable_wrapCallback=function(H){var I=S;return function(){var ae=S;S=I;try{return H.apply(this,arguments)}finally{S=ae}}}}(gh)),gh}var HS;function g5(){return HS||(HS=1,mh.exports=m5()),mh.exports}/**
 * @license React
 * react-dom-client.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var GS;function b5(){if(GS)return io;GS=1;var n=g5(),r=Qh(),i=KS();function l(e){var t="https://react.dev/errors/"+e;if(1<arguments.length){t+="?args[]="+encodeURIComponent(arguments[1]);for(var a=2;a<arguments.length;a++)t+="&args[]="+encodeURIComponent(arguments[a])}return"Minified React error #"+e+"; visit "+t+" for the full message or use the non-minified dev environment for full errors and additional helpful warnings."}function u(e){return!(!e||e.nodeType!==1&&e.nodeType!==9&&e.nodeType!==11)}function c(e){var t=e,a=e;if(e.alternate)for(;t.return;)t=t.return;else{e=t;do t=e,(t.flags&4098)!==0&&(a=t.return),e=t.return;while(e)}return t.tag===3?a:null}function d(e){if(e.tag===13){var t=e.memoizedState;if(t===null&&(e=e.alternate,e!==null&&(t=e.memoizedState)),t!==null)return t.dehydrated}return null}function p(e){if(c(e)!==e)throw Error(l(188))}function h(e){var t=e.alternate;if(!t){if(t=c(e),t===null)throw Error(l(188));return t!==e?null:e}for(var a=e,o=t;;){var s=a.return;if(s===null)break;var f=s.alternate;if(f===null){if(o=s.return,o!==null){a=o;continue}break}if(s.child===f.child){for(f=s.child;f;){if(f===a)return p(s),e;if(f===o)return p(s),t;f=f.sibling}throw Error(l(188))}if(a.return!==o.return)a=s,o=f;else{for(var v=!1,b=s.child;b;){if(b===a){v=!0,a=s,o=f;break}if(b===o){v=!0,o=s,a=f;break}b=b.sibling}if(!v){for(b=f.child;b;){if(b===a){v=!0,a=f,o=s;break}if(b===o){v=!0,o=f,a=s;break}b=b.sibling}if(!v)throw Error(l(189))}}if(a.alternate!==o)throw Error(l(190))}if(a.tag!==3)throw Error(l(188));return a.stateNode.current===a?e:t}function y(e){var t=e.tag;if(t===5||t===26||t===27||t===6)return e;for(e=e.child;e!==null;){if(t=y(e),t!==null)return t;e=e.sibling}return null}var m=Object.assign,g=Symbol.for("react.element"),S=Symbol.for("react.transitional.element"),R=Symbol.for("react.portal"),_=Symbol.for("react.fragment"),E=Symbol.for("react.strict_mode"),C=Symbol.for("react.profiler"),j=Symbol.for("react.provider"),M=Symbol.for("react.consumer"),B=Symbol.for("react.context"),X=Symbol.for("react.forward_ref"),A=Symbol.for("react.suspense"),$=Symbol.for("react.suspense_list"),O=Symbol.for("react.memo"),q=Symbol.for("react.lazy"),L=Symbol.for("react.activity"),Y=Symbol.for("react.memo_cache_sentinel"),W=Symbol.iterator;function oe(e){return e===null||typeof e!="object"?null:(e=W&&e[W]||e["@@iterator"],typeof e=="function"?e:null)}var ue=Symbol.for("react.client.reference");function he(e){if(e==null)return null;if(typeof e=="function")return e.$$typeof===ue?null:e.displayName||e.name||null;if(typeof e=="string")return e;switch(e){case _:return"Fragment";case C:return"Profiler";case E:return"StrictMode";case A:return"Suspense";case $:return"SuspenseList";case L:return"Activity"}if(typeof e=="object")switch(e.$$typeof){case R:return"Portal";case B:return(e.displayName||"Context")+".Provider";case M:return(e._context.displayName||"Context")+".Consumer";case X:var t=e.render;return e=e.displayName,e||(e=t.displayName||t.name||"",e=e!==""?"ForwardRef("+e+")":"ForwardRef"),e;case O:return t=e.displayName||null,t!==null?t:he(e.type)||"Memo";case q:t=e._payload,e=e._init;try{return he(e(t))}catch{}}return null}var fe=Array.isArray,H=r.__CLIENT_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE,I=i.__DOM_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE,ae={pending:!1,data:null,method:null,action:null},be=[],N=-1;function Z(e){return{current:e}}function le(e){0>N||(e.current=be[N],be[N]=null,N--)}function re(e,t){N++,be[N]=e.current,e.current=t}var z=Z(null),F=Z(null),te=Z(null),pe=Z(null);function ce(e,t){switch(re(te,t),re(F,e),re(z,null),t.nodeType){case 9:case 11:e=(e=t.documentElement)&&(e=e.namespaceURI)?r0(e):0;break;default:if(e=t.tagName,t=t.namespaceURI)t=r0(t),e=a0(t,e);else switch(e){case"svg":e=1;break;case"math":e=2;break;default:e=0}}le(z),re(z,e)}function xe(){le(z),le(F),le(te)}function me(e){e.memoizedState!==null&&re(pe,e);var t=z.current,a=a0(t,e.type);t!==a&&(re(F,e),re(z,a))}function Ee(e){F.current===e&&(le(z),le(F)),pe.current===e&&(le(pe),Ql._currentValue=ae)}var de=Object.prototype.hasOwnProperty,ve=n.unstable_scheduleCallback,Oe=n.unstable_cancelCallback,ye=n.unstable_shouldYield,je=n.unstable_requestPaint,Me=n.unstable_now,Fe=n.unstable_getCurrentPriorityLevel,Ht=n.unstable_ImmediatePriority,ze=n.unstable_UserBlockingPriority,Ze=n.unstable_NormalPriority,Gt=n.unstable_LowPriority,$t=n.unstable_IdlePriority,qt=n.log,An=n.unstable_setDisableYieldValue,_t=null,rt=null;function ie(e){if(typeof qt=="function"&&An(e),rt&&typeof rt.setStrictMode=="function")try{rt.setStrictMode(_t,e)}catch{}}var se=Math.clz32?Math.clz32:Ye,Te=Math.log,Ue=Math.LN2;function Ye(e){return e>>>=0,e===0?32:31-(Te(e)/Ue|0)|0}var Be=256,Nt=4194304;function mt(e){var t=e&42;if(t!==0)return t;switch(e&-e){case 1:return 1;case 2:return 2;case 4:return 4;case 8:return 8;case 16:return 16;case 32:return 32;case 64:return 64;case 128:return 128;case 256:case 512:case 1024:case 2048:case 4096:case 8192:case 16384:case 32768:case 65536:case 131072:case 262144:case 524288:case 1048576:case 2097152:return e&4194048;case 4194304:case 8388608:case 16777216:case 33554432:return e&62914560;case 67108864:return 67108864;case 134217728:return 134217728;case 268435456:return 268435456;case 536870912:return 536870912;case 1073741824:return 0;default:return e}}function k(e,t,a){var o=e.pendingLanes;if(o===0)return 0;var s=0,f=e.suspendedLanes,v=e.pingedLanes;e=e.warmLanes;var b=o&134217727;return b!==0?(o=b&~f,o!==0?s=mt(o):(v&=b,v!==0?s=mt(v):a||(a=b&~e,a!==0&&(s=mt(a))))):(b=o&~f,b!==0?s=mt(b):v!==0?s=mt(v):a||(a=o&~e,a!==0&&(s=mt(a)))),s===0?0:t!==0&&t!==s&&(t&f)===0&&(f=s&-s,a=t&-t,f>=a||f===32&&(a&4194048)!==0)?t:s}function V(e,t){return(e.pendingLanes&~(e.suspendedLanes&~e.pingedLanes)&t)===0}function qe(e,t){switch(e){case 1:case 2:case 4:case 8:case 64:return t+250;case 16:case 32:case 128:case 256:case 512:case 1024:case 2048:case 4096:case 8192:case 16384:case 32768:case 65536:case 131072:case 262144:case 524288:case 1048576:case 2097152:return t+5e3;case 4194304:case 8388608:case 16777216:case 33554432:return-1;case 67108864:case 134217728:case 268435456:case 536870912:case 1073741824:return-1;default:return-1}}function Qe(){var e=Be;return Be<<=1,(Be&4194048)===0&&(Be=256),e}function Ie(){var e=Nt;return Nt<<=1,(Nt&62914560)===0&&(Nt=4194304),e}function De(e){for(var t=[],a=0;31>a;a++)t.push(e);return t}function Yt(e,t){e.pendingLanes|=t,t!==268435456&&(e.suspendedLanes=0,e.pingedLanes=0,e.warmLanes=0)}function hn(e,t,a,o,s,f){var v=e.pendingLanes;e.pendingLanes=a,e.suspendedLanes=0,e.pingedLanes=0,e.warmLanes=0,e.expiredLanes&=a,e.entangledLanes&=a,e.errorRecoveryDisabledLanes&=a,e.shellSuspendCounter=0;var b=e.entanglements,w=e.expirationTimes,P=e.hiddenUpdates;for(a=v&~a;0<a;){var J=31-se(a),ne=1<<J;b[J]=0,w[J]=-1;var Q=P[J];if(Q!==null)for(P[J]=null,J=0;J<Q.length;J++){var K=Q[J];K!==null&&(K.lane&=-536870913)}a&=~ne}o!==0&&zt(e,o,0),f!==0&&s===0&&e.tag!==0&&(e.suspendedLanes|=f&~(v&~t))}function zt(e,t,a){e.pendingLanes|=t,e.suspendedLanes&=~t;var o=31-se(t);e.entangledLanes|=t,e.entanglements[o]=e.entanglements[o]|1073741824|a&4194090}function nn(e,t){var a=e.entangledLanes|=t;for(e=e.entanglements;a;){var o=31-se(a),s=1<<o;s&t|e[o]&t&&(e[o]|=t),a&=~s}}function br(e){switch(e){case 2:e=1;break;case 8:e=4;break;case 32:e=16;break;case 256:case 512:case 1024:case 2048:case 4096:case 8192:case 16384:case 32768:case 65536:case 131072:case 262144:case 524288:case 1048576:case 2097152:case 4194304:case 8388608:case 16777216:case 33554432:e=128;break;case 268435456:e=134217728;break;default:e=0}return e}function ln(e){return e&=-e,2<e?8<e?(e&134217727)!==0?32:268435456:8:2}function Vt(){var e=I.p;return e!==0?e:(e=window.event,e===void 0?32:O0(e.type))}function Zr(e,t){var a=I.p;try{return I.p=e,t()}finally{I.p=a}}var yn=Math.random().toString(36).slice(2),At="__reactFiber$"+yn,St="__reactProps$"+yn,Rn="__reactContainer$"+yn,nr="__reactEvents$"+yn,Ra="__reactListeners$"+yn,Sr="__reactHandles$"+yn,wa="__reactResources$"+yn,wn="__reactMarker$"+yn;function Qn(e){delete e[At],delete e[St],delete e[nr],delete e[Ra],delete e[Sr]}function Kn(e){var t=e[At];if(t)return t;for(var a=e.parentNode;a;){if(t=a[Rn]||a[At]){if(a=t.alternate,t.child!==null||a!==null&&a.child!==null)for(e=u0(e);e!==null;){if(a=e[At])return a;e=u0(e)}return t}e=a,a=e.parentNode}return null}function We(e){if(e=e[At]||e[Rn]){var t=e.tag;if(t===5||t===6||t===13||t===26||t===27||t===3)return e}return null}function pt(e){var t=e.tag;if(t===5||t===26||t===27||t===6)return e.stateNode;throw Error(l(33))}function Cn(e){var t=e[wa];return t||(t=e[wa]={hoistableStyles:new Map,hoistableScripts:new Map}),t}function ct(e){e[wn]=!0}var kt=new Set,Ca={};function xr(e,t){Er(e,t),Er(e+"Capture",t)}function Er(e,t){for(Ca[e]=t,e=0;e<t.length;e++)kt.add(t[e])}var zO=RegExp("^[:A-Z_a-z\\u00C0-\\u00D6\\u00D8-\\u00F6\\u00F8-\\u02FF\\u0370-\\u037D\\u037F-\\u1FFF\\u200C-\\u200D\\u2070-\\u218F\\u2C00-\\u2FEF\\u3001-\\uD7FF\\uF900-\\uFDCF\\uFDF0-\\uFFFD][:A-Z_a-z\\u00C0-\\u00D6\\u00D8-\\u00F6\\u00F8-\\u02FF\\u0370-\\u037D\\u037F-\\u1FFF\\u200C-\\u200D\\u2070-\\u218F\\u2C00-\\u2FEF\\u3001-\\uD7FF\\uF900-\\uFDCF\\uFDF0-\\uFFFD\\-.0-9\\u00B7\\u0300-\\u036F\\u203F-\\u2040]*$"),Ky={},Fy={};function kO(e){return de.call(Fy,e)?!0:de.call(Ky,e)?!1:zO.test(e)?Fy[e]=!0:(Ky[e]=!0,!1)}function Lo(e,t,a){if(kO(t))if(a===null)e.removeAttribute(t);else{switch(typeof a){case"undefined":case"function":case"symbol":e.removeAttribute(t);return;case"boolean":var o=t.toLowerCase().slice(0,5);if(o!=="data-"&&o!=="aria-"){e.removeAttribute(t);return}}e.setAttribute(t,""+a)}}function Uo(e,t,a){if(a===null)e.removeAttribute(t);else{switch(typeof a){case"undefined":case"function":case"symbol":case"boolean":e.removeAttribute(t);return}e.setAttribute(t,""+a)}}function Or(e,t,a,o){if(o===null)e.removeAttribute(a);else{switch(typeof o){case"undefined":case"function":case"symbol":case"boolean":e.removeAttribute(a);return}e.setAttributeNS(t,a,""+o)}}var ec,Zy;function ti(e){if(ec===void 0)try{throw Error()}catch(a){var t=a.stack.trim().match(/\n( *(at )?)/);ec=t&&t[1]||"",Zy=-1<a.stack.indexOf(`
    at`)?" (<anonymous>)":-1<a.stack.indexOf("@")?"@unknown:0:0":""}return`
`+ec+e+Zy}var tc=!1;function nc(e,t){if(!e||tc)return"";tc=!0;var a=Error.prepareStackTrace;Error.prepareStackTrace=void 0;try{var o={DetermineComponentFrameRoot:function(){try{if(t){var ne=function(){throw Error()};if(Object.defineProperty(ne.prototype,"props",{set:function(){throw Error()}}),typeof Reflect=="object"&&Reflect.construct){try{Reflect.construct(ne,[])}catch(K){var Q=K}Reflect.construct(e,[],ne)}else{try{ne.call()}catch(K){Q=K}e.call(ne.prototype)}}else{try{throw Error()}catch(K){Q=K}(ne=e())&&typeof ne.catch=="function"&&ne.catch(function(){})}}catch(K){if(K&&Q&&typeof K.stack=="string")return[K.stack,Q.stack]}return[null,null]}};o.DetermineComponentFrameRoot.displayName="DetermineComponentFrameRoot";var s=Object.getOwnPropertyDescriptor(o.DetermineComponentFrameRoot,"name");s&&s.configurable&&Object.defineProperty(o.DetermineComponentFrameRoot,"name",{value:"DetermineComponentFrameRoot"});var f=o.DetermineComponentFrameRoot(),v=f[0],b=f[1];if(v&&b){var w=v.split(`
`),P=b.split(`
`);for(s=o=0;o<w.length&&!w[o].includes("DetermineComponentFrameRoot");)o++;for(;s<P.length&&!P[s].includes("DetermineComponentFrameRoot");)s++;if(o===w.length||s===P.length)for(o=w.length-1,s=P.length-1;1<=o&&0<=s&&w[o]!==P[s];)s--;for(;1<=o&&0<=s;o--,s--)if(w[o]!==P[s]){if(o!==1||s!==1)do if(o--,s--,0>s||w[o]!==P[s]){var J=`
`+w[o].replace(" at new "," at ");return e.displayName&&J.includes("<anonymous>")&&(J=J.replace("<anonymous>",e.displayName)),J}while(1<=o&&0<=s);break}}}finally{tc=!1,Error.prepareStackTrace=a}return(a=e?e.displayName||e.name:"")?ti(a):""}function LO(e){switch(e.tag){case 26:case 27:case 5:return ti(e.type);case 16:return ti("Lazy");case 13:return ti("Suspense");case 19:return ti("SuspenseList");case 0:case 15:return nc(e.type,!1);case 11:return nc(e.type.render,!1);case 1:return nc(e.type,!0);case 31:return ti("Activity");default:return""}}function Iy(e){try{var t="";do t+=LO(e),e=e.return;while(e);return t}catch(a){return`
Error generating stack: `+a.message+`
`+a.stack}}function Nn(e){switch(typeof e){case"bigint":case"boolean":case"number":case"string":case"undefined":return e;case"object":return e;default:return""}}function Wy(e){var t=e.type;return(e=e.nodeName)&&e.toLowerCase()==="input"&&(t==="checkbox"||t==="radio")}function UO(e){var t=Wy(e)?"checked":"value",a=Object.getOwnPropertyDescriptor(e.constructor.prototype,t),o=""+e[t];if(!e.hasOwnProperty(t)&&typeof a<"u"&&typeof a.get=="function"&&typeof a.set=="function"){var s=a.get,f=a.set;return Object.defineProperty(e,t,{configurable:!0,get:function(){return s.call(this)},set:function(v){o=""+v,f.call(this,v)}}),Object.defineProperty(e,t,{enumerable:a.enumerable}),{getValue:function(){return o},setValue:function(v){o=""+v},stopTracking:function(){e._valueTracker=null,delete e[t]}}}}function Ho(e){e._valueTracker||(e._valueTracker=UO(e))}function Jy(e){if(!e)return!1;var t=e._valueTracker;if(!t)return!0;var a=t.getValue(),o="";return e&&(o=Wy(e)?e.checked?"true":"false":e.value),e=o,e!==a?(t.setValue(e),!0):!1}function Go(e){if(e=e||(typeof document<"u"?document:void 0),typeof e>"u")return null;try{return e.activeElement||e.body}catch{return e.body}}var HO=/[\n"\\]/g;function Mn(e){return e.replace(HO,function(t){return"\\"+t.charCodeAt(0).toString(16)+" "})}function rc(e,t,a,o,s,f,v,b){e.name="",v!=null&&typeof v!="function"&&typeof v!="symbol"&&typeof v!="boolean"?e.type=v:e.removeAttribute("type"),t!=null?v==="number"?(t===0&&e.value===""||e.value!=t)&&(e.value=""+Nn(t)):e.value!==""+Nn(t)&&(e.value=""+Nn(t)):v!=="submit"&&v!=="reset"||e.removeAttribute("value"),t!=null?ac(e,v,Nn(t)):a!=null?ac(e,v,Nn(a)):o!=null&&e.removeAttribute("value"),s==null&&f!=null&&(e.defaultChecked=!!f),s!=null&&(e.checked=s&&typeof s!="function"&&typeof s!="symbol"),b!=null&&typeof b!="function"&&typeof b!="symbol"&&typeof b!="boolean"?e.name=""+Nn(b):e.removeAttribute("name")}function ev(e,t,a,o,s,f,v,b){if(f!=null&&typeof f!="function"&&typeof f!="symbol"&&typeof f!="boolean"&&(e.type=f),t!=null||a!=null){if(!(f!=="submit"&&f!=="reset"||t!=null))return;a=a!=null?""+Nn(a):"",t=t!=null?""+Nn(t):a,b||t===e.value||(e.value=t),e.defaultValue=t}o=o??s,o=typeof o!="function"&&typeof o!="symbol"&&!!o,e.checked=b?e.checked:!!o,e.defaultChecked=!!o,v!=null&&typeof v!="function"&&typeof v!="symbol"&&typeof v!="boolean"&&(e.name=v)}function ac(e,t,a){t==="number"&&Go(e.ownerDocument)===e||e.defaultValue===""+a||(e.defaultValue=""+a)}function ni(e,t,a,o){if(e=e.options,t){t={};for(var s=0;s<a.length;s++)t["$"+a[s]]=!0;for(a=0;a<e.length;a++)s=t.hasOwnProperty("$"+e[a].value),e[a].selected!==s&&(e[a].selected=s),s&&o&&(e[a].defaultSelected=!0)}else{for(a=""+Nn(a),t=null,s=0;s<e.length;s++){if(e[s].value===a){e[s].selected=!0,o&&(e[s].defaultSelected=!0);return}t!==null||e[s].disabled||(t=e[s])}t!==null&&(t.selected=!0)}}function tv(e,t,a){if(t!=null&&(t=""+Nn(t),t!==e.value&&(e.value=t),a==null)){e.defaultValue!==t&&(e.defaultValue=t);return}e.defaultValue=a!=null?""+Nn(a):""}function nv(e,t,a,o){if(t==null){if(o!=null){if(a!=null)throw Error(l(92));if(fe(o)){if(1<o.length)throw Error(l(93));o=o[0]}a=o}a==null&&(a=""),t=a}a=Nn(t),e.defaultValue=a,o=e.textContent,o===a&&o!==""&&o!==null&&(e.value=o)}function ri(e,t){if(t){var a=e.firstChild;if(a&&a===e.lastChild&&a.nodeType===3){a.nodeValue=t;return}}e.textContent=t}var GO=new Set("animationIterationCount aspectRatio borderImageOutset borderImageSlice borderImageWidth boxFlex boxFlexGroup boxOrdinalGroup columnCount columns flex flexGrow flexPositive flexShrink flexNegative flexOrder gridArea gridRow gridRowEnd gridRowSpan gridRowStart gridColumn gridColumnEnd gridColumnSpan gridColumnStart fontWeight lineClamp lineHeight opacity order orphans scale tabSize widows zIndex zoom fillOpacity floodOpacity stopOpacity strokeDasharray strokeDashoffset strokeMiterlimit strokeOpacity strokeWidth MozAnimationIterationCount MozBoxFlex MozBoxFlexGroup MozLineClamp msAnimationIterationCount msFlex msZoom msFlexGrow msFlexNegative msFlexOrder msFlexPositive msFlexShrink msGridColumn msGridColumnSpan msGridRow msGridRowSpan WebkitAnimationIterationCount WebkitBoxFlex WebKitBoxFlexGroup WebkitBoxOrdinalGroup WebkitColumnCount WebkitColumns WebkitFlex WebkitFlexGrow WebkitFlexPositive WebkitFlexShrink WebkitLineClamp".split(" "));function rv(e,t,a){var o=t.indexOf("--")===0;a==null||typeof a=="boolean"||a===""?o?e.setProperty(t,""):t==="float"?e.cssFloat="":e[t]="":o?e.setProperty(t,a):typeof a!="number"||a===0||GO.has(t)?t==="float"?e.cssFloat=a:e[t]=(""+a).trim():e[t]=a+"px"}function av(e,t,a){if(t!=null&&typeof t!="object")throw Error(l(62));if(e=e.style,a!=null){for(var o in a)!a.hasOwnProperty(o)||t!=null&&t.hasOwnProperty(o)||(o.indexOf("--")===0?e.setProperty(o,""):o==="float"?e.cssFloat="":e[o]="");for(var s in t)o=t[s],t.hasOwnProperty(s)&&a[s]!==o&&rv(e,s,o)}else for(var f in t)t.hasOwnProperty(f)&&rv(e,f,t[f])}function ic(e){if(e.indexOf("-")===-1)return!1;switch(e){case"annotation-xml":case"color-profile":case"font-face":case"font-face-src":case"font-face-uri":case"font-face-format":case"font-face-name":case"missing-glyph":return!1;default:return!0}}var YO=new Map([["acceptCharset","accept-charset"],["htmlFor","for"],["httpEquiv","http-equiv"],["crossOrigin","crossorigin"],["accentHeight","accent-height"],["alignmentBaseline","alignment-baseline"],["arabicForm","arabic-form"],["baselineShift","baseline-shift"],["capHeight","cap-height"],["clipPath","clip-path"],["clipRule","clip-rule"],["colorInterpolation","color-interpolation"],["colorInterpolationFilters","color-interpolation-filters"],["colorProfile","color-profile"],["colorRendering","color-rendering"],["dominantBaseline","dominant-baseline"],["enableBackground","enable-background"],["fillOpacity","fill-opacity"],["fillRule","fill-rule"],["floodColor","flood-color"],["floodOpacity","flood-opacity"],["fontFamily","font-family"],["fontSize","font-size"],["fontSizeAdjust","font-size-adjust"],["fontStretch","font-stretch"],["fontStyle","font-style"],["fontVariant","font-variant"],["fontWeight","font-weight"],["glyphName","glyph-name"],["glyphOrientationHorizontal","glyph-orientation-horizontal"],["glyphOrientationVertical","glyph-orientation-vertical"],["horizAdvX","horiz-adv-x"],["horizOriginX","horiz-origin-x"],["imageRendering","image-rendering"],["letterSpacing","letter-spacing"],["lightingColor","lighting-color"],["markerEnd","marker-end"],["markerMid","marker-mid"],["markerStart","marker-start"],["overlinePosition","overline-position"],["overlineThickness","overline-thickness"],["paintOrder","paint-order"],["panose-1","panose-1"],["pointerEvents","pointer-events"],["renderingIntent","rendering-intent"],["shapeRendering","shape-rendering"],["stopColor","stop-color"],["stopOpacity","stop-opacity"],["strikethroughPosition","strikethrough-position"],["strikethroughThickness","strikethrough-thickness"],["strokeDasharray","stroke-dasharray"],["strokeDashoffset","stroke-dashoffset"],["strokeLinecap","stroke-linecap"],["strokeLinejoin","stroke-linejoin"],["strokeMiterlimit","stroke-miterlimit"],["strokeOpacity","stroke-opacity"],["strokeWidth","stroke-width"],["textAnchor","text-anchor"],["textDecoration","text-decoration"],["textRendering","text-rendering"],["transformOrigin","transform-origin"],["underlinePosition","underline-position"],["underlineThickness","underline-thickness"],["unicodeBidi","unicode-bidi"],["unicodeRange","unicode-range"],["unitsPerEm","units-per-em"],["vAlphabetic","v-alphabetic"],["vHanging","v-hanging"],["vIdeographic","v-ideographic"],["vMathematical","v-mathematical"],["vectorEffect","vector-effect"],["vertAdvY","vert-adv-y"],["vertOriginX","vert-origin-x"],["vertOriginY","vert-origin-y"],["wordSpacing","word-spacing"],["writingMode","writing-mode"],["xmlnsXlink","xmlns:xlink"],["xHeight","x-height"]]),VO=/^[\u0000-\u001F ]*j[\r\n\t]*a[\r\n\t]*v[\r\n\t]*a[\r\n\t]*s[\r\n\t]*c[\r\n\t]*r[\r\n\t]*i[\r\n\t]*p[\r\n\t]*t[\r\n\t]*:/i;function Yo(e){return VO.test(""+e)?"javascript:throw new Error('React has blocked a javascript: URL as a security precaution.')":e}var lc=null;function oc(e){return e=e.target||e.srcElement||window,e.correspondingUseElement&&(e=e.correspondingUseElement),e.nodeType===3?e.parentNode:e}var ai=null,ii=null;function iv(e){var t=We(e);if(t&&(e=t.stateNode)){var a=e[St]||null;e:switch(e=t.stateNode,t.type){case"input":if(rc(e,a.value,a.defaultValue,a.defaultValue,a.checked,a.defaultChecked,a.type,a.name),t=a.name,a.type==="radio"&&t!=null){for(a=e;a.parentNode;)a=a.parentNode;for(a=a.querySelectorAll('input[name="'+Mn(""+t)+'"][type="radio"]'),t=0;t<a.length;t++){var o=a[t];if(o!==e&&o.form===e.form){var s=o[St]||null;if(!s)throw Error(l(90));rc(o,s.value,s.defaultValue,s.defaultValue,s.checked,s.defaultChecked,s.type,s.name)}}for(t=0;t<a.length;t++)o=a[t],o.form===e.form&&Jy(o)}break e;case"textarea":tv(e,a.value,a.defaultValue);break e;case"select":t=a.value,t!=null&&ni(e,!!a.multiple,t,!1)}}}var uc=!1;function lv(e,t,a){if(uc)return e(t,a);uc=!0;try{var o=e(t);return o}finally{if(uc=!1,(ai!==null||ii!==null)&&(wu(),ai&&(t=ai,e=ii,ii=ai=null,iv(t),e)))for(t=0;t<e.length;t++)iv(e[t])}}function ll(e,t){var a=e.stateNode;if(a===null)return null;var o=a[St]||null;if(o===null)return null;a=o[t];e:switch(t){case"onClick":case"onClickCapture":case"onDoubleClick":case"onDoubleClickCapture":case"onMouseDown":case"onMouseDownCapture":case"onMouseMove":case"onMouseMoveCapture":case"onMouseUp":case"onMouseUpCapture":case"onMouseEnter":(o=!o.disabled)||(e=e.type,o=!(e==="button"||e==="input"||e==="select"||e==="textarea")),e=!o;break e;default:e=!1}if(e)return null;if(a&&typeof a!="function")throw Error(l(231,t,typeof a));return a}var Tr=!(typeof window>"u"||typeof window.document>"u"||typeof window.document.createElement>"u"),sc=!1;if(Tr)try{var ol={};Object.defineProperty(ol,"passive",{get:function(){sc=!0}}),window.addEventListener("test",ol,ol),window.removeEventListener("test",ol,ol)}catch{sc=!1}var Ir=null,cc=null,Vo=null;function ov(){if(Vo)return Vo;var e,t=cc,a=t.length,o,s="value"in Ir?Ir.value:Ir.textContent,f=s.length;for(e=0;e<a&&t[e]===s[e];e++);var v=a-e;for(o=1;o<=v&&t[a-o]===s[f-o];o++);return Vo=s.slice(e,1<o?1-o:void 0)}function Po(e){var t=e.keyCode;return"charCode"in e?(e=e.charCode,e===0&&t===13&&(e=13)):e=t,e===10&&(e=13),32<=e||e===13?e:0}function Xo(){return!0}function uv(){return!1}function on(e){function t(a,o,s,f,v){this._reactName=a,this._targetInst=s,this.type=o,this.nativeEvent=f,this.target=v,this.currentTarget=null;for(var b in e)e.hasOwnProperty(b)&&(a=e[b],this[b]=a?a(f):f[b]);return this.isDefaultPrevented=(f.defaultPrevented!=null?f.defaultPrevented:f.returnValue===!1)?Xo:uv,this.isPropagationStopped=uv,this}return m(t.prototype,{preventDefault:function(){this.defaultPrevented=!0;var a=this.nativeEvent;a&&(a.preventDefault?a.preventDefault():typeof a.returnValue!="unknown"&&(a.returnValue=!1),this.isDefaultPrevented=Xo)},stopPropagation:function(){var a=this.nativeEvent;a&&(a.stopPropagation?a.stopPropagation():typeof a.cancelBubble!="unknown"&&(a.cancelBubble=!0),this.isPropagationStopped=Xo)},persist:function(){},isPersistent:Xo}),t}var Na={eventPhase:0,bubbles:0,cancelable:0,timeStamp:function(e){return e.timeStamp||Date.now()},defaultPrevented:0,isTrusted:0},Qo=on(Na),ul=m({},Na,{view:0,detail:0}),PO=on(ul),fc,dc,sl,Ko=m({},ul,{screenX:0,screenY:0,clientX:0,clientY:0,pageX:0,pageY:0,ctrlKey:0,shiftKey:0,altKey:0,metaKey:0,getModifierState:hc,button:0,buttons:0,relatedTarget:function(e){return e.relatedTarget===void 0?e.fromElement===e.srcElement?e.toElement:e.fromElement:e.relatedTarget},movementX:function(e){return"movementX"in e?e.movementX:(e!==sl&&(sl&&e.type==="mousemove"?(fc=e.screenX-sl.screenX,dc=e.screenY-sl.screenY):dc=fc=0,sl=e),fc)},movementY:function(e){return"movementY"in e?e.movementY:dc}}),sv=on(Ko),XO=m({},Ko,{dataTransfer:0}),QO=on(XO),KO=m({},ul,{relatedTarget:0}),pc=on(KO),FO=m({},Na,{animationName:0,elapsedTime:0,pseudoElement:0}),ZO=on(FO),IO=m({},Na,{clipboardData:function(e){return"clipboardData"in e?e.clipboardData:window.clipboardData}}),WO=on(IO),JO=m({},Na,{data:0}),cv=on(JO),eT={Esc:"Escape",Spacebar:" ",Left:"ArrowLeft",Up:"ArrowUp",Right:"ArrowRight",Down:"ArrowDown",Del:"Delete",Win:"OS",Menu:"ContextMenu",Apps:"ContextMenu",Scroll:"ScrollLock",MozPrintableKey:"Unidentified"},tT={8:"Backspace",9:"Tab",12:"Clear",13:"Enter",16:"Shift",17:"Control",18:"Alt",19:"Pause",20:"CapsLock",27:"Escape",32:" ",33:"PageUp",34:"PageDown",35:"End",36:"Home",37:"ArrowLeft",38:"ArrowUp",39:"ArrowRight",40:"ArrowDown",45:"Insert",46:"Delete",112:"F1",113:"F2",114:"F3",115:"F4",116:"F5",117:"F6",118:"F7",119:"F8",120:"F9",121:"F10",122:"F11",123:"F12",144:"NumLock",145:"ScrollLock",224:"Meta"},nT={Alt:"altKey",Control:"ctrlKey",Meta:"metaKey",Shift:"shiftKey"};function rT(e){var t=this.nativeEvent;return t.getModifierState?t.getModifierState(e):(e=nT[e])?!!t[e]:!1}function hc(){return rT}var aT=m({},ul,{key:function(e){if(e.key){var t=eT[e.key]||e.key;if(t!=="Unidentified")return t}return e.type==="keypress"?(e=Po(e),e===13?"Enter":String.fromCharCode(e)):e.type==="keydown"||e.type==="keyup"?tT[e.keyCode]||"Unidentified":""},code:0,location:0,ctrlKey:0,shiftKey:0,altKey:0,metaKey:0,repeat:0,locale:0,getModifierState:hc,charCode:function(e){return e.type==="keypress"?Po(e):0},keyCode:function(e){return e.type==="keydown"||e.type==="keyup"?e.keyCode:0},which:function(e){return e.type==="keypress"?Po(e):e.type==="keydown"||e.type==="keyup"?e.keyCode:0}}),iT=on(aT),lT=m({},Ko,{pointerId:0,width:0,height:0,pressure:0,tangentialPressure:0,tiltX:0,tiltY:0,twist:0,pointerType:0,isPrimary:0}),fv=on(lT),oT=m({},ul,{touches:0,targetTouches:0,changedTouches:0,altKey:0,metaKey:0,ctrlKey:0,shiftKey:0,getModifierState:hc}),uT=on(oT),sT=m({},Na,{propertyName:0,elapsedTime:0,pseudoElement:0}),cT=on(sT),fT=m({},Ko,{deltaX:function(e){return"deltaX"in e?e.deltaX:"wheelDeltaX"in e?-e.wheelDeltaX:0},deltaY:function(e){return"deltaY"in e?e.deltaY:"wheelDeltaY"in e?-e.wheelDeltaY:"wheelDelta"in e?-e.wheelDelta:0},deltaZ:0,deltaMode:0}),dT=on(fT),pT=m({},Na,{newState:0,oldState:0}),hT=on(pT),yT=[9,13,27,32],yc=Tr&&"CompositionEvent"in window,cl=null;Tr&&"documentMode"in document&&(cl=document.documentMode);var vT=Tr&&"TextEvent"in window&&!cl,dv=Tr&&(!yc||cl&&8<cl&&11>=cl),pv=" ",hv=!1;function yv(e,t){switch(e){case"keyup":return yT.indexOf(t.keyCode)!==-1;case"keydown":return t.keyCode!==229;case"keypress":case"mousedown":case"focusout":return!0;default:return!1}}function vv(e){return e=e.detail,typeof e=="object"&&"data"in e?e.data:null}var li=!1;function mT(e,t){switch(e){case"compositionend":return vv(t);case"keypress":return t.which!==32?null:(hv=!0,pv);case"textInput":return e=t.data,e===pv&&hv?null:e;default:return null}}function gT(e,t){if(li)return e==="compositionend"||!yc&&yv(e,t)?(e=ov(),Vo=cc=Ir=null,li=!1,e):null;switch(e){case"paste":return null;case"keypress":if(!(t.ctrlKey||t.altKey||t.metaKey)||t.ctrlKey&&t.altKey){if(t.char&&1<t.char.length)return t.char;if(t.which)return String.fromCharCode(t.which)}return null;case"compositionend":return dv&&t.locale!=="ko"?null:t.data;default:return null}}var bT={color:!0,date:!0,datetime:!0,"datetime-local":!0,email:!0,month:!0,number:!0,password:!0,range:!0,search:!0,tel:!0,text:!0,time:!0,url:!0,week:!0};function mv(e){var t=e&&e.nodeName&&e.nodeName.toLowerCase();return t==="input"?!!bT[e.type]:t==="textarea"}function gv(e,t,a,o){ai?ii?ii.push(o):ii=[o]:ai=o,t=Bu(t,"onChange"),0<t.length&&(a=new Qo("onChange","change",null,a,o),e.push({event:a,listeners:t}))}var fl=null,dl=null;function ST(e){Wg(e,0)}function Fo(e){var t=pt(e);if(Jy(t))return e}function bv(e,t){if(e==="change")return t}var Sv=!1;if(Tr){var vc;if(Tr){var mc="oninput"in document;if(!mc){var xv=document.createElement("div");xv.setAttribute("oninput","return;"),mc=typeof xv.oninput=="function"}vc=mc}else vc=!1;Sv=vc&&(!document.documentMode||9<document.documentMode)}function Ev(){fl&&(fl.detachEvent("onpropertychange",Ov),dl=fl=null)}function Ov(e){if(e.propertyName==="value"&&Fo(dl)){var t=[];gv(t,dl,e,oc(e)),lv(ST,t)}}function xT(e,t,a){e==="focusin"?(Ev(),fl=t,dl=a,fl.attachEvent("onpropertychange",Ov)):e==="focusout"&&Ev()}function ET(e){if(e==="selectionchange"||e==="keyup"||e==="keydown")return Fo(dl)}function OT(e,t){if(e==="click")return Fo(t)}function TT(e,t){if(e==="input"||e==="change")return Fo(t)}function _T(e,t){return e===t&&(e!==0||1/e===1/t)||e!==e&&t!==t}var vn=typeof Object.is=="function"?Object.is:_T;function pl(e,t){if(vn(e,t))return!0;if(typeof e!="object"||e===null||typeof t!="object"||t===null)return!1;var a=Object.keys(e),o=Object.keys(t);if(a.length!==o.length)return!1;for(o=0;o<a.length;o++){var s=a[o];if(!de.call(t,s)||!vn(e[s],t[s]))return!1}return!0}function Tv(e){for(;e&&e.firstChild;)e=e.firstChild;return e}function _v(e,t){var a=Tv(e);e=0;for(var o;a;){if(a.nodeType===3){if(o=e+a.textContent.length,e<=t&&o>=t)return{node:a,offset:t-e};e=o}e:{for(;a;){if(a.nextSibling){a=a.nextSibling;break e}a=a.parentNode}a=void 0}a=Tv(a)}}function Av(e,t){return e&&t?e===t?!0:e&&e.nodeType===3?!1:t&&t.nodeType===3?Av(e,t.parentNode):"contains"in e?e.contains(t):e.compareDocumentPosition?!!(e.compareDocumentPosition(t)&16):!1:!1}function Rv(e){e=e!=null&&e.ownerDocument!=null&&e.ownerDocument.defaultView!=null?e.ownerDocument.defaultView:window;for(var t=Go(e.document);t instanceof e.HTMLIFrameElement;){try{var a=typeof t.contentWindow.location.href=="string"}catch{a=!1}if(a)e=t.contentWindow;else break;t=Go(e.document)}return t}function gc(e){var t=e&&e.nodeName&&e.nodeName.toLowerCase();return t&&(t==="input"&&(e.type==="text"||e.type==="search"||e.type==="tel"||e.type==="url"||e.type==="password")||t==="textarea"||e.contentEditable==="true")}var AT=Tr&&"documentMode"in document&&11>=document.documentMode,oi=null,bc=null,hl=null,Sc=!1;function wv(e,t,a){var o=a.window===a?a.document:a.nodeType===9?a:a.ownerDocument;Sc||oi==null||oi!==Go(o)||(o=oi,"selectionStart"in o&&gc(o)?o={start:o.selectionStart,end:o.selectionEnd}:(o=(o.ownerDocument&&o.ownerDocument.defaultView||window).getSelection(),o={anchorNode:o.anchorNode,anchorOffset:o.anchorOffset,focusNode:o.focusNode,focusOffset:o.focusOffset}),hl&&pl(hl,o)||(hl=o,o=Bu(bc,"onSelect"),0<o.length&&(t=new Qo("onSelect","select",null,t,a),e.push({event:t,listeners:o}),t.target=oi)))}function Ma(e,t){var a={};return a[e.toLowerCase()]=t.toLowerCase(),a["Webkit"+e]="webkit"+t,a["Moz"+e]="moz"+t,a}var ui={animationend:Ma("Animation","AnimationEnd"),animationiteration:Ma("Animation","AnimationIteration"),animationstart:Ma("Animation","AnimationStart"),transitionrun:Ma("Transition","TransitionRun"),transitionstart:Ma("Transition","TransitionStart"),transitioncancel:Ma("Transition","TransitionCancel"),transitionend:Ma("Transition","TransitionEnd")},xc={},Cv={};Tr&&(Cv=document.createElement("div").style,"AnimationEvent"in window||(delete ui.animationend.animation,delete ui.animationiteration.animation,delete ui.animationstart.animation),"TransitionEvent"in window||delete ui.transitionend.transition);function Da(e){if(xc[e])return xc[e];if(!ui[e])return e;var t=ui[e],a;for(a in t)if(t.hasOwnProperty(a)&&a in Cv)return xc[e]=t[a];return e}var Nv=Da("animationend"),Mv=Da("animationiteration"),Dv=Da("animationstart"),RT=Da("transitionrun"),wT=Da("transitionstart"),CT=Da("transitioncancel"),jv=Da("transitionend"),Bv=new Map,Ec="abort auxClick beforeToggle cancel canPlay canPlayThrough click close contextMenu copy cut drag dragEnd dragEnter dragExit dragLeave dragOver dragStart drop durationChange emptied encrypted ended error gotPointerCapture input invalid keyDown keyPress keyUp load loadedData loadedMetadata loadStart lostPointerCapture mouseDown mouseMove mouseOut mouseOver mouseUp paste pause play playing pointerCancel pointerDown pointerMove pointerOut pointerOver pointerUp progress rateChange reset resize seeked seeking stalled submit suspend timeUpdate touchCancel touchEnd touchStart volumeChange scroll toggle touchMove waiting wheel".split(" ");Ec.push("scrollEnd");function Fn(e,t){Bv.set(e,t),xr(t,[e])}var $v=new WeakMap;function Dn(e,t){if(typeof e=="object"&&e!==null){var a=$v.get(e);return a!==void 0?a:(t={value:e,source:t,stack:Iy(t)},$v.set(e,t),t)}return{value:e,source:t,stack:Iy(t)}}var jn=[],si=0,Oc=0;function Zo(){for(var e=si,t=Oc=si=0;t<e;){var a=jn[t];jn[t++]=null;var o=jn[t];jn[t++]=null;var s=jn[t];jn[t++]=null;var f=jn[t];if(jn[t++]=null,o!==null&&s!==null){var v=o.pending;v===null?s.next=s:(s.next=v.next,v.next=s),o.pending=s}f!==0&&qv(a,s,f)}}function Io(e,t,a,o){jn[si++]=e,jn[si++]=t,jn[si++]=a,jn[si++]=o,Oc|=o,e.lanes|=o,e=e.alternate,e!==null&&(e.lanes|=o)}function Tc(e,t,a,o){return Io(e,t,a,o),Wo(e)}function ci(e,t){return Io(e,null,null,t),Wo(e)}function qv(e,t,a){e.lanes|=a;var o=e.alternate;o!==null&&(o.lanes|=a);for(var s=!1,f=e.return;f!==null;)f.childLanes|=a,o=f.alternate,o!==null&&(o.childLanes|=a),f.tag===22&&(e=f.stateNode,e===null||e._visibility&1||(s=!0)),e=f,f=f.return;return e.tag===3?(f=e.stateNode,s&&t!==null&&(s=31-se(a),e=f.hiddenUpdates,o=e[s],o===null?e[s]=[t]:o.push(t),t.lane=a|536870912),f):null}function Wo(e){if(50<Ll)throw Ll=0,Mf=null,Error(l(185));for(var t=e.return;t!==null;)e=t,t=e.return;return e.tag===3?e.stateNode:null}var fi={};function NT(e,t,a,o){this.tag=e,this.key=a,this.sibling=this.child=this.return=this.stateNode=this.type=this.elementType=null,this.index=0,this.refCleanup=this.ref=null,this.pendingProps=t,this.dependencies=this.memoizedState=this.updateQueue=this.memoizedProps=null,this.mode=o,this.subtreeFlags=this.flags=0,this.deletions=null,this.childLanes=this.lanes=0,this.alternate=null}function mn(e,t,a,o){return new NT(e,t,a,o)}function _c(e){return e=e.prototype,!(!e||!e.isReactComponent)}function _r(e,t){var a=e.alternate;return a===null?(a=mn(e.tag,t,e.key,e.mode),a.elementType=e.elementType,a.type=e.type,a.stateNode=e.stateNode,a.alternate=e,e.alternate=a):(a.pendingProps=t,a.type=e.type,a.flags=0,a.subtreeFlags=0,a.deletions=null),a.flags=e.flags&65011712,a.childLanes=e.childLanes,a.lanes=e.lanes,a.child=e.child,a.memoizedProps=e.memoizedProps,a.memoizedState=e.memoizedState,a.updateQueue=e.updateQueue,t=e.dependencies,a.dependencies=t===null?null:{lanes:t.lanes,firstContext:t.firstContext},a.sibling=e.sibling,a.index=e.index,a.ref=e.ref,a.refCleanup=e.refCleanup,a}function zv(e,t){e.flags&=65011714;var a=e.alternate;return a===null?(e.childLanes=0,e.lanes=t,e.child=null,e.subtreeFlags=0,e.memoizedProps=null,e.memoizedState=null,e.updateQueue=null,e.dependencies=null,e.stateNode=null):(e.childLanes=a.childLanes,e.lanes=a.lanes,e.child=a.child,e.subtreeFlags=0,e.deletions=null,e.memoizedProps=a.memoizedProps,e.memoizedState=a.memoizedState,e.updateQueue=a.updateQueue,e.type=a.type,t=a.dependencies,e.dependencies=t===null?null:{lanes:t.lanes,firstContext:t.firstContext}),e}function Jo(e,t,a,o,s,f){var v=0;if(o=e,typeof e=="function")_c(e)&&(v=1);else if(typeof e=="string")v=D_(e,a,z.current)?26:e==="html"||e==="head"||e==="body"?27:5;else e:switch(e){case L:return e=mn(31,a,t,s),e.elementType=L,e.lanes=f,e;case _:return ja(a.children,s,f,t);case E:v=8,s|=24;break;case C:return e=mn(12,a,t,s|2),e.elementType=C,e.lanes=f,e;case A:return e=mn(13,a,t,s),e.elementType=A,e.lanes=f,e;case $:return e=mn(19,a,t,s),e.elementType=$,e.lanes=f,e;default:if(typeof e=="object"&&e!==null)switch(e.$$typeof){case j:case B:v=10;break e;case M:v=9;break e;case X:v=11;break e;case O:v=14;break e;case q:v=16,o=null;break e}v=29,a=Error(l(130,e===null?"null":typeof e,"")),o=null}return t=mn(v,a,t,s),t.elementType=e,t.type=o,t.lanes=f,t}function ja(e,t,a,o){return e=mn(7,e,o,t),e.lanes=a,e}function Ac(e,t,a){return e=mn(6,e,null,t),e.lanes=a,e}function Rc(e,t,a){return t=mn(4,e.children!==null?e.children:[],e.key,t),t.lanes=a,t.stateNode={containerInfo:e.containerInfo,pendingChildren:null,implementation:e.implementation},t}var di=[],pi=0,eu=null,tu=0,Bn=[],$n=0,Ba=null,Ar=1,Rr="";function $a(e,t){di[pi++]=tu,di[pi++]=eu,eu=e,tu=t}function kv(e,t,a){Bn[$n++]=Ar,Bn[$n++]=Rr,Bn[$n++]=Ba,Ba=e;var o=Ar;e=Rr;var s=32-se(o)-1;o&=~(1<<s),a+=1;var f=32-se(t)+s;if(30<f){var v=s-s%5;f=(o&(1<<v)-1).toString(32),o>>=v,s-=v,Ar=1<<32-se(t)+s|a<<s|o,Rr=f+e}else Ar=1<<f|a<<s|o,Rr=e}function wc(e){e.return!==null&&($a(e,1),kv(e,1,0))}function Cc(e){for(;e===eu;)eu=di[--pi],di[pi]=null,tu=di[--pi],di[pi]=null;for(;e===Ba;)Ba=Bn[--$n],Bn[$n]=null,Rr=Bn[--$n],Bn[$n]=null,Ar=Bn[--$n],Bn[$n]=null}var rn=null,xt=null,Je=!1,qa=null,rr=!1,Nc=Error(l(519));function za(e){var t=Error(l(418,""));throw ml(Dn(t,e)),Nc}function Lv(e){var t=e.stateNode,a=e.type,o=e.memoizedProps;switch(t[At]=e,t[St]=o,a){case"dialog":Ge("cancel",t),Ge("close",t);break;case"iframe":case"object":case"embed":Ge("load",t);break;case"video":case"audio":for(a=0;a<Hl.length;a++)Ge(Hl[a],t);break;case"source":Ge("error",t);break;case"img":case"image":case"link":Ge("error",t),Ge("load",t);break;case"details":Ge("toggle",t);break;case"input":Ge("invalid",t),ev(t,o.value,o.defaultValue,o.checked,o.defaultChecked,o.type,o.name,!0),Ho(t);break;case"select":Ge("invalid",t);break;case"textarea":Ge("invalid",t),nv(t,o.value,o.defaultValue,o.children),Ho(t)}a=o.children,typeof a!="string"&&typeof a!="number"&&typeof a!="bigint"||t.textContent===""+a||o.suppressHydrationWarning===!0||n0(t.textContent,a)?(o.popover!=null&&(Ge("beforetoggle",t),Ge("toggle",t)),o.onScroll!=null&&Ge("scroll",t),o.onScrollEnd!=null&&Ge("scrollend",t),o.onClick!=null&&(t.onclick=$u),t=!0):t=!1,t||za(e)}function Uv(e){for(rn=e.return;rn;)switch(rn.tag){case 5:case 13:rr=!1;return;case 27:case 3:rr=!0;return;default:rn=rn.return}}function yl(e){if(e!==rn)return!1;if(!Je)return Uv(e),Je=!0,!1;var t=e.tag,a;if((a=t!==3&&t!==27)&&((a=t===5)&&(a=e.type,a=!(a!=="form"&&a!=="button")||Qf(e.type,e.memoizedProps)),a=!a),a&&xt&&za(e),Uv(e),t===13){if(e=e.memoizedState,e=e!==null?e.dehydrated:null,!e)throw Error(l(317));e:{for(e=e.nextSibling,t=0;e;){if(e.nodeType===8)if(a=e.data,a==="/$"){if(t===0){xt=In(e.nextSibling);break e}t--}else a!=="$"&&a!=="$!"&&a!=="$?"||t++;e=e.nextSibling}xt=null}}else t===27?(t=xt,pa(e.type)?(e=If,If=null,xt=e):xt=t):xt=rn?In(e.stateNode.nextSibling):null;return!0}function vl(){xt=rn=null,Je=!1}function Hv(){var e=qa;return e!==null&&(cn===null?cn=e:cn.push.apply(cn,e),qa=null),e}function ml(e){qa===null?qa=[e]:qa.push(e)}var Mc=Z(null),ka=null,wr=null;function Wr(e,t,a){re(Mc,t._currentValue),t._currentValue=a}function Cr(e){e._currentValue=Mc.current,le(Mc)}function Dc(e,t,a){for(;e!==null;){var o=e.alternate;if((e.childLanes&t)!==t?(e.childLanes|=t,o!==null&&(o.childLanes|=t)):o!==null&&(o.childLanes&t)!==t&&(o.childLanes|=t),e===a)break;e=e.return}}function jc(e,t,a,o){var s=e.child;for(s!==null&&(s.return=e);s!==null;){var f=s.dependencies;if(f!==null){var v=s.child;f=f.firstContext;e:for(;f!==null;){var b=f;f=s;for(var w=0;w<t.length;w++)if(b.context===t[w]){f.lanes|=a,b=f.alternate,b!==null&&(b.lanes|=a),Dc(f.return,a,e),o||(v=null);break e}f=b.next}}else if(s.tag===18){if(v=s.return,v===null)throw Error(l(341));v.lanes|=a,f=v.alternate,f!==null&&(f.lanes|=a),Dc(v,a,e),v=null}else v=s.child;if(v!==null)v.return=s;else for(v=s;v!==null;){if(v===e){v=null;break}if(s=v.sibling,s!==null){s.return=v.return,v=s;break}v=v.return}s=v}}function gl(e,t,a,o){e=null;for(var s=t,f=!1;s!==null;){if(!f){if((s.flags&524288)!==0)f=!0;else if((s.flags&262144)!==0)break}if(s.tag===10){var v=s.alternate;if(v===null)throw Error(l(387));if(v=v.memoizedProps,v!==null){var b=s.type;vn(s.pendingProps.value,v.value)||(e!==null?e.push(b):e=[b])}}else if(s===pe.current){if(v=s.alternate,v===null)throw Error(l(387));v.memoizedState.memoizedState!==s.memoizedState.memoizedState&&(e!==null?e.push(Ql):e=[Ql])}s=s.return}e!==null&&jc(t,e,a,o),t.flags|=262144}function nu(e){for(e=e.firstContext;e!==null;){if(!vn(e.context._currentValue,e.memoizedValue))return!0;e=e.next}return!1}function La(e){ka=e,wr=null,e=e.dependencies,e!==null&&(e.firstContext=null)}function Wt(e){return Gv(ka,e)}function ru(e,t){return ka===null&&La(e),Gv(e,t)}function Gv(e,t){var a=t._currentValue;if(t={context:t,memoizedValue:a,next:null},wr===null){if(e===null)throw Error(l(308));wr=t,e.dependencies={lanes:0,firstContext:t},e.flags|=524288}else wr=wr.next=t;return a}var MT=typeof AbortController<"u"?AbortController:function(){var e=[],t=this.signal={aborted:!1,addEventListener:function(a,o){e.push(o)}};this.abort=function(){t.aborted=!0,e.forEach(function(a){return a()})}},DT=n.unstable_scheduleCallback,jT=n.unstable_NormalPriority,Lt={$$typeof:B,Consumer:null,Provider:null,_currentValue:null,_currentValue2:null,_threadCount:0};function Bc(){return{controller:new MT,data:new Map,refCount:0}}function bl(e){e.refCount--,e.refCount===0&&DT(jT,function(){e.controller.abort()})}var Sl=null,$c=0,hi=0,yi=null;function BT(e,t){if(Sl===null){var a=Sl=[];$c=0,hi=kf(),yi={status:"pending",value:void 0,then:function(o){a.push(o)}}}return $c++,t.then(Yv,Yv),t}function Yv(){if(--$c===0&&Sl!==null){yi!==null&&(yi.status="fulfilled");var e=Sl;Sl=null,hi=0,yi=null;for(var t=0;t<e.length;t++)(0,e[t])()}}function $T(e,t){var a=[],o={status:"pending",value:null,reason:null,then:function(s){a.push(s)}};return e.then(function(){o.status="fulfilled",o.value=t;for(var s=0;s<a.length;s++)(0,a[s])(t)},function(s){for(o.status="rejected",o.reason=s,s=0;s<a.length;s++)(0,a[s])(void 0)}),o}var Vv=H.S;H.S=function(e,t){typeof t=="object"&&t!==null&&typeof t.then=="function"&&BT(e,t),Vv!==null&&Vv(e,t)};var Ua=Z(null);function qc(){var e=Ua.current;return e!==null?e:ht.pooledCache}function au(e,t){t===null?re(Ua,Ua.current):re(Ua,t.pool)}function Pv(){var e=qc();return e===null?null:{parent:Lt._currentValue,pool:e}}var xl=Error(l(460)),Xv=Error(l(474)),iu=Error(l(542)),zc={then:function(){}};function Qv(e){return e=e.status,e==="fulfilled"||e==="rejected"}function lu(){}function Kv(e,t,a){switch(a=e[a],a===void 0?e.push(t):a!==t&&(t.then(lu,lu),t=a),t.status){case"fulfilled":return t.value;case"rejected":throw e=t.reason,Zv(e),e;default:if(typeof t.status=="string")t.then(lu,lu);else{if(e=ht,e!==null&&100<e.shellSuspendCounter)throw Error(l(482));e=t,e.status="pending",e.then(function(o){if(t.status==="pending"){var s=t;s.status="fulfilled",s.value=o}},function(o){if(t.status==="pending"){var s=t;s.status="rejected",s.reason=o}})}switch(t.status){case"fulfilled":return t.value;case"rejected":throw e=t.reason,Zv(e),e}throw El=t,xl}}var El=null;function Fv(){if(El===null)throw Error(l(459));var e=El;return El=null,e}function Zv(e){if(e===xl||e===iu)throw Error(l(483))}var Jr=!1;function kc(e){e.updateQueue={baseState:e.memoizedState,firstBaseUpdate:null,lastBaseUpdate:null,shared:{pending:null,lanes:0,hiddenCallbacks:null},callbacks:null}}function Lc(e,t){e=e.updateQueue,t.updateQueue===e&&(t.updateQueue={baseState:e.baseState,firstBaseUpdate:e.firstBaseUpdate,lastBaseUpdate:e.lastBaseUpdate,shared:e.shared,callbacks:null})}function ea(e){return{lane:e,tag:0,payload:null,callback:null,next:null}}function ta(e,t,a){var o=e.updateQueue;if(o===null)return null;if(o=o.shared,(at&2)!==0){var s=o.pending;return s===null?t.next=t:(t.next=s.next,s.next=t),o.pending=t,t=Wo(e),qv(e,null,a),t}return Io(e,o,t,a),Wo(e)}function Ol(e,t,a){if(t=t.updateQueue,t!==null&&(t=t.shared,(a&4194048)!==0)){var o=t.lanes;o&=e.pendingLanes,a|=o,t.lanes=a,nn(e,a)}}function Uc(e,t){var a=e.updateQueue,o=e.alternate;if(o!==null&&(o=o.updateQueue,a===o)){var s=null,f=null;if(a=a.firstBaseUpdate,a!==null){do{var v={lane:a.lane,tag:a.tag,payload:a.payload,callback:null,next:null};f===null?s=f=v:f=f.next=v,a=a.next}while(a!==null);f===null?s=f=t:f=f.next=t}else s=f=t;a={baseState:o.baseState,firstBaseUpdate:s,lastBaseUpdate:f,shared:o.shared,callbacks:o.callbacks},e.updateQueue=a;return}e=a.lastBaseUpdate,e===null?a.firstBaseUpdate=t:e.next=t,a.lastBaseUpdate=t}var Hc=!1;function Tl(){if(Hc){var e=yi;if(e!==null)throw e}}function _l(e,t,a,o){Hc=!1;var s=e.updateQueue;Jr=!1;var f=s.firstBaseUpdate,v=s.lastBaseUpdate,b=s.shared.pending;if(b!==null){s.shared.pending=null;var w=b,P=w.next;w.next=null,v===null?f=P:v.next=P,v=w;var J=e.alternate;J!==null&&(J=J.updateQueue,b=J.lastBaseUpdate,b!==v&&(b===null?J.firstBaseUpdate=P:b.next=P,J.lastBaseUpdate=w))}if(f!==null){var ne=s.baseState;v=0,J=P=w=null,b=f;do{var Q=b.lane&-536870913,K=Q!==b.lane;if(K?(Pe&Q)===Q:(o&Q)===Q){Q!==0&&Q===hi&&(Hc=!0),J!==null&&(J=J.next={lane:0,tag:b.tag,payload:b.payload,callback:null,next:null});e:{var Ne=e,Re=b;Q=t;var ut=a;switch(Re.tag){case 1:if(Ne=Re.payload,typeof Ne=="function"){ne=Ne.call(ut,ne,Q);break e}ne=Ne;break e;case 3:Ne.flags=Ne.flags&-65537|128;case 0:if(Ne=Re.payload,Q=typeof Ne=="function"?Ne.call(ut,ne,Q):Ne,Q==null)break e;ne=m({},ne,Q);break e;case 2:Jr=!0}}Q=b.callback,Q!==null&&(e.flags|=64,K&&(e.flags|=8192),K=s.callbacks,K===null?s.callbacks=[Q]:K.push(Q))}else K={lane:Q,tag:b.tag,payload:b.payload,callback:b.callback,next:null},J===null?(P=J=K,w=ne):J=J.next=K,v|=Q;if(b=b.next,b===null){if(b=s.shared.pending,b===null)break;K=b,b=K.next,K.next=null,s.lastBaseUpdate=K,s.shared.pending=null}}while(!0);J===null&&(w=ne),s.baseState=w,s.firstBaseUpdate=P,s.lastBaseUpdate=J,f===null&&(s.shared.lanes=0),sa|=v,e.lanes=v,e.memoizedState=ne}}function Iv(e,t){if(typeof e!="function")throw Error(l(191,e));e.call(t)}function Wv(e,t){var a=e.callbacks;if(a!==null)for(e.callbacks=null,e=0;e<a.length;e++)Iv(a[e],t)}var vi=Z(null),ou=Z(0);function Jv(e,t){e=qr,re(ou,e),re(vi,t),qr=e|t.baseLanes}function Gc(){re(ou,qr),re(vi,vi.current)}function Yc(){qr=ou.current,le(vi),le(ou)}var na=0,ke=null,lt=null,Mt=null,uu=!1,mi=!1,Ha=!1,su=0,Al=0,gi=null,qT=0;function Rt(){throw Error(l(321))}function Vc(e,t){if(t===null)return!1;for(var a=0;a<t.length&&a<e.length;a++)if(!vn(e[a],t[a]))return!1;return!0}function Pc(e,t,a,o,s,f){return na=f,ke=t,t.memoizedState=null,t.updateQueue=null,t.lanes=0,H.H=e===null||e.memoizedState===null?qm:zm,Ha=!1,f=a(o,s),Ha=!1,mi&&(f=tm(t,a,o,s)),em(e),f}function em(e){H.H=yu;var t=lt!==null&&lt.next!==null;if(na=0,Mt=lt=ke=null,uu=!1,Al=0,gi=null,t)throw Error(l(300));e===null||Pt||(e=e.dependencies,e!==null&&nu(e)&&(Pt=!0))}function tm(e,t,a,o){ke=e;var s=0;do{if(mi&&(gi=null),Al=0,mi=!1,25<=s)throw Error(l(301));if(s+=1,Mt=lt=null,e.updateQueue!=null){var f=e.updateQueue;f.lastEffect=null,f.events=null,f.stores=null,f.memoCache!=null&&(f.memoCache.index=0)}H.H=YT,f=t(a,o)}while(mi);return f}function zT(){var e=H.H,t=e.useState()[0];return t=typeof t.then=="function"?Rl(t):t,e=e.useState()[0],(lt!==null?lt.memoizedState:null)!==e&&(ke.flags|=1024),t}function Xc(){var e=su!==0;return su=0,e}function Qc(e,t,a){t.updateQueue=e.updateQueue,t.flags&=-2053,e.lanes&=~a}function Kc(e){if(uu){for(e=e.memoizedState;e!==null;){var t=e.queue;t!==null&&(t.pending=null),e=e.next}uu=!1}na=0,Mt=lt=ke=null,mi=!1,Al=su=0,gi=null}function un(){var e={memoizedState:null,baseState:null,baseQueue:null,queue:null,next:null};return Mt===null?ke.memoizedState=Mt=e:Mt=Mt.next=e,Mt}function Dt(){if(lt===null){var e=ke.alternate;e=e!==null?e.memoizedState:null}else e=lt.next;var t=Mt===null?ke.memoizedState:Mt.next;if(t!==null)Mt=t,lt=e;else{if(e===null)throw ke.alternate===null?Error(l(467)):Error(l(310));lt=e,e={memoizedState:lt.memoizedState,baseState:lt.baseState,baseQueue:lt.baseQueue,queue:lt.queue,next:null},Mt===null?ke.memoizedState=Mt=e:Mt=Mt.next=e}return Mt}function Fc(){return{lastEffect:null,events:null,stores:null,memoCache:null}}function Rl(e){var t=Al;return Al+=1,gi===null&&(gi=[]),e=Kv(gi,e,t),t=ke,(Mt===null?t.memoizedState:Mt.next)===null&&(t=t.alternate,H.H=t===null||t.memoizedState===null?qm:zm),e}function cu(e){if(e!==null&&typeof e=="object"){if(typeof e.then=="function")return Rl(e);if(e.$$typeof===B)return Wt(e)}throw Error(l(438,String(e)))}function Zc(e){var t=null,a=ke.updateQueue;if(a!==null&&(t=a.memoCache),t==null){var o=ke.alternate;o!==null&&(o=o.updateQueue,o!==null&&(o=o.memoCache,o!=null&&(t={data:o.data.map(function(s){return s.slice()}),index:0})))}if(t==null&&(t={data:[],index:0}),a===null&&(a=Fc(),ke.updateQueue=a),a.memoCache=t,a=t.data[t.index],a===void 0)for(a=t.data[t.index]=Array(e),o=0;o<e;o++)a[o]=Y;return t.index++,a}function Nr(e,t){return typeof t=="function"?t(e):t}function fu(e){var t=Dt();return Ic(t,lt,e)}function Ic(e,t,a){var o=e.queue;if(o===null)throw Error(l(311));o.lastRenderedReducer=a;var s=e.baseQueue,f=o.pending;if(f!==null){if(s!==null){var v=s.next;s.next=f.next,f.next=v}t.baseQueue=s=f,o.pending=null}if(f=e.baseState,s===null)e.memoizedState=f;else{t=s.next;var b=v=null,w=null,P=t,J=!1;do{var ne=P.lane&-536870913;if(ne!==P.lane?(Pe&ne)===ne:(na&ne)===ne){var Q=P.revertLane;if(Q===0)w!==null&&(w=w.next={lane:0,revertLane:0,action:P.action,hasEagerState:P.hasEagerState,eagerState:P.eagerState,next:null}),ne===hi&&(J=!0);else if((na&Q)===Q){P=P.next,Q===hi&&(J=!0);continue}else ne={lane:0,revertLane:P.revertLane,action:P.action,hasEagerState:P.hasEagerState,eagerState:P.eagerState,next:null},w===null?(b=w=ne,v=f):w=w.next=ne,ke.lanes|=Q,sa|=Q;ne=P.action,Ha&&a(f,ne),f=P.hasEagerState?P.eagerState:a(f,ne)}else Q={lane:ne,revertLane:P.revertLane,action:P.action,hasEagerState:P.hasEagerState,eagerState:P.eagerState,next:null},w===null?(b=w=Q,v=f):w=w.next=Q,ke.lanes|=ne,sa|=ne;P=P.next}while(P!==null&&P!==t);if(w===null?v=f:w.next=b,!vn(f,e.memoizedState)&&(Pt=!0,J&&(a=yi,a!==null)))throw a;e.memoizedState=f,e.baseState=v,e.baseQueue=w,o.lastRenderedState=f}return s===null&&(o.lanes=0),[e.memoizedState,o.dispatch]}function Wc(e){var t=Dt(),a=t.queue;if(a===null)throw Error(l(311));a.lastRenderedReducer=e;var o=a.dispatch,s=a.pending,f=t.memoizedState;if(s!==null){a.pending=null;var v=s=s.next;do f=e(f,v.action),v=v.next;while(v!==s);vn(f,t.memoizedState)||(Pt=!0),t.memoizedState=f,t.baseQueue===null&&(t.baseState=f),a.lastRenderedState=f}return[f,o]}function nm(e,t,a){var o=ke,s=Dt(),f=Je;if(f){if(a===void 0)throw Error(l(407));a=a()}else a=t();var v=!vn((lt||s).memoizedState,a);v&&(s.memoizedState=a,Pt=!0),s=s.queue;var b=im.bind(null,o,s,e);if(wl(2048,8,b,[e]),s.getSnapshot!==t||v||Mt!==null&&Mt.memoizedState.tag&1){if(o.flags|=2048,bi(9,du(),am.bind(null,o,s,a,t),null),ht===null)throw Error(l(349));f||(na&124)!==0||rm(o,t,a)}return a}function rm(e,t,a){e.flags|=16384,e={getSnapshot:t,value:a},t=ke.updateQueue,t===null?(t=Fc(),ke.updateQueue=t,t.stores=[e]):(a=t.stores,a===null?t.stores=[e]:a.push(e))}function am(e,t,a,o){t.value=a,t.getSnapshot=o,lm(t)&&om(e)}function im(e,t,a){return a(function(){lm(t)&&om(e)})}function lm(e){var t=e.getSnapshot;e=e.value;try{var a=t();return!vn(e,a)}catch{return!0}}function om(e){var t=ci(e,2);t!==null&&En(t,e,2)}function Jc(e){var t=un();if(typeof e=="function"){var a=e;if(e=a(),Ha){ie(!0);try{a()}finally{ie(!1)}}}return t.memoizedState=t.baseState=e,t.queue={pending:null,lanes:0,dispatch:null,lastRenderedReducer:Nr,lastRenderedState:e},t}function um(e,t,a,o){return e.baseState=a,Ic(e,lt,typeof o=="function"?o:Nr)}function kT(e,t,a,o,s){if(hu(e))throw Error(l(485));if(e=t.action,e!==null){var f={payload:s,action:e,next:null,isTransition:!0,status:"pending",value:null,reason:null,listeners:[],then:function(v){f.listeners.push(v)}};H.T!==null?a(!0):f.isTransition=!1,o(f),a=t.pending,a===null?(f.next=t.pending=f,sm(t,f)):(f.next=a.next,t.pending=a.next=f)}}function sm(e,t){var a=t.action,o=t.payload,s=e.state;if(t.isTransition){var f=H.T,v={};H.T=v;try{var b=a(s,o),w=H.S;w!==null&&w(v,b),cm(e,t,b)}catch(P){ef(e,t,P)}finally{H.T=f}}else try{f=a(s,o),cm(e,t,f)}catch(P){ef(e,t,P)}}function cm(e,t,a){a!==null&&typeof a=="object"&&typeof a.then=="function"?a.then(function(o){fm(e,t,o)},function(o){return ef(e,t,o)}):fm(e,t,a)}function fm(e,t,a){t.status="fulfilled",t.value=a,dm(t),e.state=a,t=e.pending,t!==null&&(a=t.next,a===t?e.pending=null:(a=a.next,t.next=a,sm(e,a)))}function ef(e,t,a){var o=e.pending;if(e.pending=null,o!==null){o=o.next;do t.status="rejected",t.reason=a,dm(t),t=t.next;while(t!==o)}e.action=null}function dm(e){e=e.listeners;for(var t=0;t<e.length;t++)(0,e[t])()}function pm(e,t){return t}function hm(e,t){if(Je){var a=ht.formState;if(a!==null){e:{var o=ke;if(Je){if(xt){t:{for(var s=xt,f=rr;s.nodeType!==8;){if(!f){s=null;break t}if(s=In(s.nextSibling),s===null){s=null;break t}}f=s.data,s=f==="F!"||f==="F"?s:null}if(s){xt=In(s.nextSibling),o=s.data==="F!";break e}}za(o)}o=!1}o&&(t=a[0])}}return a=un(),a.memoizedState=a.baseState=t,o={pending:null,lanes:0,dispatch:null,lastRenderedReducer:pm,lastRenderedState:t},a.queue=o,a=jm.bind(null,ke,o),o.dispatch=a,o=Jc(!1),f=lf.bind(null,ke,!1,o.queue),o=un(),s={state:t,dispatch:null,action:e,pending:null},o.queue=s,a=kT.bind(null,ke,s,f,a),s.dispatch=a,o.memoizedState=e,[t,a,!1]}function ym(e){var t=Dt();return vm(t,lt,e)}function vm(e,t,a){if(t=Ic(e,t,pm)[0],e=fu(Nr)[0],typeof t=="object"&&t!==null&&typeof t.then=="function")try{var o=Rl(t)}catch(v){throw v===xl?iu:v}else o=t;t=Dt();var s=t.queue,f=s.dispatch;return a!==t.memoizedState&&(ke.flags|=2048,bi(9,du(),LT.bind(null,s,a),null)),[o,f,e]}function LT(e,t){e.action=t}function mm(e){var t=Dt(),a=lt;if(a!==null)return vm(t,a,e);Dt(),t=t.memoizedState,a=Dt();var o=a.queue.dispatch;return a.memoizedState=e,[t,o,!1]}function bi(e,t,a,o){return e={tag:e,create:a,deps:o,inst:t,next:null},t=ke.updateQueue,t===null&&(t=Fc(),ke.updateQueue=t),a=t.lastEffect,a===null?t.lastEffect=e.next=e:(o=a.next,a.next=e,e.next=o,t.lastEffect=e),e}function du(){return{destroy:void 0,resource:void 0}}function gm(){return Dt().memoizedState}function pu(e,t,a,o){var s=un();o=o===void 0?null:o,ke.flags|=e,s.memoizedState=bi(1|t,du(),a,o)}function wl(e,t,a,o){var s=Dt();o=o===void 0?null:o;var f=s.memoizedState.inst;lt!==null&&o!==null&&Vc(o,lt.memoizedState.deps)?s.memoizedState=bi(t,f,a,o):(ke.flags|=e,s.memoizedState=bi(1|t,f,a,o))}function bm(e,t){pu(8390656,8,e,t)}function Sm(e,t){wl(2048,8,e,t)}function xm(e,t){return wl(4,2,e,t)}function Em(e,t){return wl(4,4,e,t)}function Om(e,t){if(typeof t=="function"){e=e();var a=t(e);return function(){typeof a=="function"?a():t(null)}}if(t!=null)return e=e(),t.current=e,function(){t.current=null}}function Tm(e,t,a){a=a!=null?a.concat([e]):null,wl(4,4,Om.bind(null,t,e),a)}function tf(){}function _m(e,t){var a=Dt();t=t===void 0?null:t;var o=a.memoizedState;return t!==null&&Vc(t,o[1])?o[0]:(a.memoizedState=[e,t],e)}function Am(e,t){var a=Dt();t=t===void 0?null:t;var o=a.memoizedState;if(t!==null&&Vc(t,o[1]))return o[0];if(o=e(),Ha){ie(!0);try{e()}finally{ie(!1)}}return a.memoizedState=[o,t],o}function nf(e,t,a){return a===void 0||(na&1073741824)!==0?e.memoizedState=t:(e.memoizedState=a,e=Cg(),ke.lanes|=e,sa|=e,a)}function Rm(e,t,a,o){return vn(a,t)?a:vi.current!==null?(e=nf(e,a,o),vn(e,t)||(Pt=!0),e):(na&42)===0?(Pt=!0,e.memoizedState=a):(e=Cg(),ke.lanes|=e,sa|=e,t)}function wm(e,t,a,o,s){var f=I.p;I.p=f!==0&&8>f?f:8;var v=H.T,b={};H.T=b,lf(e,!1,t,a);try{var w=s(),P=H.S;if(P!==null&&P(b,w),w!==null&&typeof w=="object"&&typeof w.then=="function"){var J=$T(w,o);Cl(e,t,J,xn(e))}else Cl(e,t,o,xn(e))}catch(ne){Cl(e,t,{then:function(){},status:"rejected",reason:ne},xn())}finally{I.p=f,H.T=v}}function UT(){}function rf(e,t,a,o){if(e.tag!==5)throw Error(l(476));var s=Cm(e).queue;wm(e,s,t,ae,a===null?UT:function(){return Nm(e),a(o)})}function Cm(e){var t=e.memoizedState;if(t!==null)return t;t={memoizedState:ae,baseState:ae,baseQueue:null,queue:{pending:null,lanes:0,dispatch:null,lastRenderedReducer:Nr,lastRenderedState:ae},next:null};var a={};return t.next={memoizedState:a,baseState:a,baseQueue:null,queue:{pending:null,lanes:0,dispatch:null,lastRenderedReducer:Nr,lastRenderedState:a},next:null},e.memoizedState=t,e=e.alternate,e!==null&&(e.memoizedState=t),t}function Nm(e){var t=Cm(e).next.queue;Cl(e,t,{},xn())}function af(){return Wt(Ql)}function Mm(){return Dt().memoizedState}function Dm(){return Dt().memoizedState}function HT(e){for(var t=e.return;t!==null;){switch(t.tag){case 24:case 3:var a=xn();e=ea(a);var o=ta(t,e,a);o!==null&&(En(o,t,a),Ol(o,t,a)),t={cache:Bc()},e.payload=t;return}t=t.return}}function GT(e,t,a){var o=xn();a={lane:o,revertLane:0,action:a,hasEagerState:!1,eagerState:null,next:null},hu(e)?Bm(t,a):(a=Tc(e,t,a,o),a!==null&&(En(a,e,o),$m(a,t,o)))}function jm(e,t,a){var o=xn();Cl(e,t,a,o)}function Cl(e,t,a,o){var s={lane:o,revertLane:0,action:a,hasEagerState:!1,eagerState:null,next:null};if(hu(e))Bm(t,s);else{var f=e.alternate;if(e.lanes===0&&(f===null||f.lanes===0)&&(f=t.lastRenderedReducer,f!==null))try{var v=t.lastRenderedState,b=f(v,a);if(s.hasEagerState=!0,s.eagerState=b,vn(b,v))return Io(e,t,s,0),ht===null&&Zo(),!1}catch{}finally{}if(a=Tc(e,t,s,o),a!==null)return En(a,e,o),$m(a,t,o),!0}return!1}function lf(e,t,a,o){if(o={lane:2,revertLane:kf(),action:o,hasEagerState:!1,eagerState:null,next:null},hu(e)){if(t)throw Error(l(479))}else t=Tc(e,a,o,2),t!==null&&En(t,e,2)}function hu(e){var t=e.alternate;return e===ke||t!==null&&t===ke}function Bm(e,t){mi=uu=!0;var a=e.pending;a===null?t.next=t:(t.next=a.next,a.next=t),e.pending=t}function $m(e,t,a){if((a&4194048)!==0){var o=t.lanes;o&=e.pendingLanes,a|=o,t.lanes=a,nn(e,a)}}var yu={readContext:Wt,use:cu,useCallback:Rt,useContext:Rt,useEffect:Rt,useImperativeHandle:Rt,useLayoutEffect:Rt,useInsertionEffect:Rt,useMemo:Rt,useReducer:Rt,useRef:Rt,useState:Rt,useDebugValue:Rt,useDeferredValue:Rt,useTransition:Rt,useSyncExternalStore:Rt,useId:Rt,useHostTransitionStatus:Rt,useFormState:Rt,useActionState:Rt,useOptimistic:Rt,useMemoCache:Rt,useCacheRefresh:Rt},qm={readContext:Wt,use:cu,useCallback:function(e,t){return un().memoizedState=[e,t===void 0?null:t],e},useContext:Wt,useEffect:bm,useImperativeHandle:function(e,t,a){a=a!=null?a.concat([e]):null,pu(4194308,4,Om.bind(null,t,e),a)},useLayoutEffect:function(e,t){return pu(4194308,4,e,t)},useInsertionEffect:function(e,t){pu(4,2,e,t)},useMemo:function(e,t){var a=un();t=t===void 0?null:t;var o=e();if(Ha){ie(!0);try{e()}finally{ie(!1)}}return a.memoizedState=[o,t],o},useReducer:function(e,t,a){var o=un();if(a!==void 0){var s=a(t);if(Ha){ie(!0);try{a(t)}finally{ie(!1)}}}else s=t;return o.memoizedState=o.baseState=s,e={pending:null,lanes:0,dispatch:null,lastRenderedReducer:e,lastRenderedState:s},o.queue=e,e=e.dispatch=GT.bind(null,ke,e),[o.memoizedState,e]},useRef:function(e){var t=un();return e={current:e},t.memoizedState=e},useState:function(e){e=Jc(e);var t=e.queue,a=jm.bind(null,ke,t);return t.dispatch=a,[e.memoizedState,a]},useDebugValue:tf,useDeferredValue:function(e,t){var a=un();return nf(a,e,t)},useTransition:function(){var e=Jc(!1);return e=wm.bind(null,ke,e.queue,!0,!1),un().memoizedState=e,[!1,e]},useSyncExternalStore:function(e,t,a){var o=ke,s=un();if(Je){if(a===void 0)throw Error(l(407));a=a()}else{if(a=t(),ht===null)throw Error(l(349));(Pe&124)!==0||rm(o,t,a)}s.memoizedState=a;var f={value:a,getSnapshot:t};return s.queue=f,bm(im.bind(null,o,f,e),[e]),o.flags|=2048,bi(9,du(),am.bind(null,o,f,a,t),null),a},useId:function(){var e=un(),t=ht.identifierPrefix;if(Je){var a=Rr,o=Ar;a=(o&~(1<<32-se(o)-1)).toString(32)+a,t="«"+t+"R"+a,a=su++,0<a&&(t+="H"+a.toString(32)),t+="»"}else a=qT++,t="«"+t+"r"+a.toString(32)+"»";return e.memoizedState=t},useHostTransitionStatus:af,useFormState:hm,useActionState:hm,useOptimistic:function(e){var t=un();t.memoizedState=t.baseState=e;var a={pending:null,lanes:0,dispatch:null,lastRenderedReducer:null,lastRenderedState:null};return t.queue=a,t=lf.bind(null,ke,!0,a),a.dispatch=t,[e,t]},useMemoCache:Zc,useCacheRefresh:function(){return un().memoizedState=HT.bind(null,ke)}},zm={readContext:Wt,use:cu,useCallback:_m,useContext:Wt,useEffect:Sm,useImperativeHandle:Tm,useInsertionEffect:xm,useLayoutEffect:Em,useMemo:Am,useReducer:fu,useRef:gm,useState:function(){return fu(Nr)},useDebugValue:tf,useDeferredValue:function(e,t){var a=Dt();return Rm(a,lt.memoizedState,e,t)},useTransition:function(){var e=fu(Nr)[0],t=Dt().memoizedState;return[typeof e=="boolean"?e:Rl(e),t]},useSyncExternalStore:nm,useId:Mm,useHostTransitionStatus:af,useFormState:ym,useActionState:ym,useOptimistic:function(e,t){var a=Dt();return um(a,lt,e,t)},useMemoCache:Zc,useCacheRefresh:Dm},YT={readContext:Wt,use:cu,useCallback:_m,useContext:Wt,useEffect:Sm,useImperativeHandle:Tm,useInsertionEffect:xm,useLayoutEffect:Em,useMemo:Am,useReducer:Wc,useRef:gm,useState:function(){return Wc(Nr)},useDebugValue:tf,useDeferredValue:function(e,t){var a=Dt();return lt===null?nf(a,e,t):Rm(a,lt.memoizedState,e,t)},useTransition:function(){var e=Wc(Nr)[0],t=Dt().memoizedState;return[typeof e=="boolean"?e:Rl(e),t]},useSyncExternalStore:nm,useId:Mm,useHostTransitionStatus:af,useFormState:mm,useActionState:mm,useOptimistic:function(e,t){var a=Dt();return lt!==null?um(a,lt,e,t):(a.baseState=e,[e,a.queue.dispatch])},useMemoCache:Zc,useCacheRefresh:Dm},Si=null,Nl=0;function vu(e){var t=Nl;return Nl+=1,Si===null&&(Si=[]),Kv(Si,e,t)}function Ml(e,t){t=t.props.ref,e.ref=t!==void 0?t:null}function mu(e,t){throw t.$$typeof===g?Error(l(525)):(e=Object.prototype.toString.call(t),Error(l(31,e==="[object Object]"?"object with keys {"+Object.keys(t).join(", ")+"}":e)))}function km(e){var t=e._init;return t(e._payload)}function Lm(e){function t(U,D){if(e){var G=U.deletions;G===null?(U.deletions=[D],U.flags|=16):G.push(D)}}function a(U,D){if(!e)return null;for(;D!==null;)t(U,D),D=D.sibling;return null}function o(U){for(var D=new Map;U!==null;)U.key!==null?D.set(U.key,U):D.set(U.index,U),U=U.sibling;return D}function s(U,D){return U=_r(U,D),U.index=0,U.sibling=null,U}function f(U,D,G){return U.index=G,e?(G=U.alternate,G!==null?(G=G.index,G<D?(U.flags|=67108866,D):G):(U.flags|=67108866,D)):(U.flags|=1048576,D)}function v(U){return e&&U.alternate===null&&(U.flags|=67108866),U}function b(U,D,G,ee){return D===null||D.tag!==6?(D=Ac(G,U.mode,ee),D.return=U,D):(D=s(D,G),D.return=U,D)}function w(U,D,G,ee){var Se=G.type;return Se===_?J(U,D,G.props.children,ee,G.key):D!==null&&(D.elementType===Se||typeof Se=="object"&&Se!==null&&Se.$$typeof===q&&km(Se)===D.type)?(D=s(D,G.props),Ml(D,G),D.return=U,D):(D=Jo(G.type,G.key,G.props,null,U.mode,ee),Ml(D,G),D.return=U,D)}function P(U,D,G,ee){return D===null||D.tag!==4||D.stateNode.containerInfo!==G.containerInfo||D.stateNode.implementation!==G.implementation?(D=Rc(G,U.mode,ee),D.return=U,D):(D=s(D,G.children||[]),D.return=U,D)}function J(U,D,G,ee,Se){return D===null||D.tag!==7?(D=ja(G,U.mode,ee,Se),D.return=U,D):(D=s(D,G),D.return=U,D)}function ne(U,D,G){if(typeof D=="string"&&D!==""||typeof D=="number"||typeof D=="bigint")return D=Ac(""+D,U.mode,G),D.return=U,D;if(typeof D=="object"&&D!==null){switch(D.$$typeof){case S:return G=Jo(D.type,D.key,D.props,null,U.mode,G),Ml(G,D),G.return=U,G;case R:return D=Rc(D,U.mode,G),D.return=U,D;case q:var ee=D._init;return D=ee(D._payload),ne(U,D,G)}if(fe(D)||oe(D))return D=ja(D,U.mode,G,null),D.return=U,D;if(typeof D.then=="function")return ne(U,vu(D),G);if(D.$$typeof===B)return ne(U,ru(U,D),G);mu(U,D)}return null}function Q(U,D,G,ee){var Se=D!==null?D.key:null;if(typeof G=="string"&&G!==""||typeof G=="number"||typeof G=="bigint")return Se!==null?null:b(U,D,""+G,ee);if(typeof G=="object"&&G!==null){switch(G.$$typeof){case S:return G.key===Se?w(U,D,G,ee):null;case R:return G.key===Se?P(U,D,G,ee):null;case q:return Se=G._init,G=Se(G._payload),Q(U,D,G,ee)}if(fe(G)||oe(G))return Se!==null?null:J(U,D,G,ee,null);if(typeof G.then=="function")return Q(U,D,vu(G),ee);if(G.$$typeof===B)return Q(U,D,ru(U,G),ee);mu(U,G)}return null}function K(U,D,G,ee,Se){if(typeof ee=="string"&&ee!==""||typeof ee=="number"||typeof ee=="bigint")return U=U.get(G)||null,b(D,U,""+ee,Se);if(typeof ee=="object"&&ee!==null){switch(ee.$$typeof){case S:return U=U.get(ee.key===null?G:ee.key)||null,w(D,U,ee,Se);case R:return U=U.get(ee.key===null?G:ee.key)||null,P(D,U,ee,Se);case q:var Le=ee._init;return ee=Le(ee._payload),K(U,D,G,ee,Se)}if(fe(ee)||oe(ee))return U=U.get(G)||null,J(D,U,ee,Se,null);if(typeof ee.then=="function")return K(U,D,G,vu(ee),Se);if(ee.$$typeof===B)return K(U,D,G,ru(D,ee),Se);mu(D,ee)}return null}function Ne(U,D,G,ee){for(var Se=null,Le=null,_e=D,Ce=D=0,Qt=null;_e!==null&&Ce<G.length;Ce++){_e.index>Ce?(Qt=_e,_e=null):Qt=_e.sibling;var Ke=Q(U,_e,G[Ce],ee);if(Ke===null){_e===null&&(_e=Qt);break}e&&_e&&Ke.alternate===null&&t(U,_e),D=f(Ke,D,Ce),Le===null?Se=Ke:Le.sibling=Ke,Le=Ke,_e=Qt}if(Ce===G.length)return a(U,_e),Je&&$a(U,Ce),Se;if(_e===null){for(;Ce<G.length;Ce++)_e=ne(U,G[Ce],ee),_e!==null&&(D=f(_e,D,Ce),Le===null?Se=_e:Le.sibling=_e,Le=_e);return Je&&$a(U,Ce),Se}for(_e=o(_e);Ce<G.length;Ce++)Qt=K(_e,U,Ce,G[Ce],ee),Qt!==null&&(e&&Qt.alternate!==null&&_e.delete(Qt.key===null?Ce:Qt.key),D=f(Qt,D,Ce),Le===null?Se=Qt:Le.sibling=Qt,Le=Qt);return e&&_e.forEach(function(ga){return t(U,ga)}),Je&&$a(U,Ce),Se}function Re(U,D,G,ee){if(G==null)throw Error(l(151));for(var Se=null,Le=null,_e=D,Ce=D=0,Qt=null,Ke=G.next();_e!==null&&!Ke.done;Ce++,Ke=G.next()){_e.index>Ce?(Qt=_e,_e=null):Qt=_e.sibling;var ga=Q(U,_e,Ke.value,ee);if(ga===null){_e===null&&(_e=Qt);break}e&&_e&&ga.alternate===null&&t(U,_e),D=f(ga,D,Ce),Le===null?Se=ga:Le.sibling=ga,Le=ga,_e=Qt}if(Ke.done)return a(U,_e),Je&&$a(U,Ce),Se;if(_e===null){for(;!Ke.done;Ce++,Ke=G.next())Ke=ne(U,Ke.value,ee),Ke!==null&&(D=f(Ke,D,Ce),Le===null?Se=Ke:Le.sibling=Ke,Le=Ke);return Je&&$a(U,Ce),Se}for(_e=o(_e);!Ke.done;Ce++,Ke=G.next())Ke=K(_e,U,Ce,Ke.value,ee),Ke!==null&&(e&&Ke.alternate!==null&&_e.delete(Ke.key===null?Ce:Ke.key),D=f(Ke,D,Ce),Le===null?Se=Ke:Le.sibling=Ke,Le=Ke);return e&&_e.forEach(function(V_){return t(U,V_)}),Je&&$a(U,Ce),Se}function ut(U,D,G,ee){if(typeof G=="object"&&G!==null&&G.type===_&&G.key===null&&(G=G.props.children),typeof G=="object"&&G!==null){switch(G.$$typeof){case S:e:{for(var Se=G.key;D!==null;){if(D.key===Se){if(Se=G.type,Se===_){if(D.tag===7){a(U,D.sibling),ee=s(D,G.props.children),ee.return=U,U=ee;break e}}else if(D.elementType===Se||typeof Se=="object"&&Se!==null&&Se.$$typeof===q&&km(Se)===D.type){a(U,D.sibling),ee=s(D,G.props),Ml(ee,G),ee.return=U,U=ee;break e}a(U,D);break}else t(U,D);D=D.sibling}G.type===_?(ee=ja(G.props.children,U.mode,ee,G.key),ee.return=U,U=ee):(ee=Jo(G.type,G.key,G.props,null,U.mode,ee),Ml(ee,G),ee.return=U,U=ee)}return v(U);case R:e:{for(Se=G.key;D!==null;){if(D.key===Se)if(D.tag===4&&D.stateNode.containerInfo===G.containerInfo&&D.stateNode.implementation===G.implementation){a(U,D.sibling),ee=s(D,G.children||[]),ee.return=U,U=ee;break e}else{a(U,D);break}else t(U,D);D=D.sibling}ee=Rc(G,U.mode,ee),ee.return=U,U=ee}return v(U);case q:return Se=G._init,G=Se(G._payload),ut(U,D,G,ee)}if(fe(G))return Ne(U,D,G,ee);if(oe(G)){if(Se=oe(G),typeof Se!="function")throw Error(l(150));return G=Se.call(G),Re(U,D,G,ee)}if(typeof G.then=="function")return ut(U,D,vu(G),ee);if(G.$$typeof===B)return ut(U,D,ru(U,G),ee);mu(U,G)}return typeof G=="string"&&G!==""||typeof G=="number"||typeof G=="bigint"?(G=""+G,D!==null&&D.tag===6?(a(U,D.sibling),ee=s(D,G),ee.return=U,U=ee):(a(U,D),ee=Ac(G,U.mode,ee),ee.return=U,U=ee),v(U)):a(U,D)}return function(U,D,G,ee){try{Nl=0;var Se=ut(U,D,G,ee);return Si=null,Se}catch(_e){if(_e===xl||_e===iu)throw _e;var Le=mn(29,_e,null,U.mode);return Le.lanes=ee,Le.return=U,Le}finally{}}}var xi=Lm(!0),Um=Lm(!1),qn=Z(null),ar=null;function ra(e){var t=e.alternate;re(Ut,Ut.current&1),re(qn,e),ar===null&&(t===null||vi.current!==null||t.memoizedState!==null)&&(ar=e)}function Hm(e){if(e.tag===22){if(re(Ut,Ut.current),re(qn,e),ar===null){var t=e.alternate;t!==null&&t.memoizedState!==null&&(ar=e)}}else aa()}function aa(){re(Ut,Ut.current),re(qn,qn.current)}function Mr(e){le(qn),ar===e&&(ar=null),le(Ut)}var Ut=Z(0);function gu(e){for(var t=e;t!==null;){if(t.tag===13){var a=t.memoizedState;if(a!==null&&(a=a.dehydrated,a===null||a.data==="$?"||Zf(a)))return t}else if(t.tag===19&&t.memoizedProps.revealOrder!==void 0){if((t.flags&128)!==0)return t}else if(t.child!==null){t.child.return=t,t=t.child;continue}if(t===e)break;for(;t.sibling===null;){if(t.return===null||t.return===e)return null;t=t.return}t.sibling.return=t.return,t=t.sibling}return null}function of(e,t,a,o){t=e.memoizedState,a=a(o,t),a=a==null?t:m({},t,a),e.memoizedState=a,e.lanes===0&&(e.updateQueue.baseState=a)}var uf={enqueueSetState:function(e,t,a){e=e._reactInternals;var o=xn(),s=ea(o);s.payload=t,a!=null&&(s.callback=a),t=ta(e,s,o),t!==null&&(En(t,e,o),Ol(t,e,o))},enqueueReplaceState:function(e,t,a){e=e._reactInternals;var o=xn(),s=ea(o);s.tag=1,s.payload=t,a!=null&&(s.callback=a),t=ta(e,s,o),t!==null&&(En(t,e,o),Ol(t,e,o))},enqueueForceUpdate:function(e,t){e=e._reactInternals;var a=xn(),o=ea(a);o.tag=2,t!=null&&(o.callback=t),t=ta(e,o,a),t!==null&&(En(t,e,a),Ol(t,e,a))}};function Gm(e,t,a,o,s,f,v){return e=e.stateNode,typeof e.shouldComponentUpdate=="function"?e.shouldComponentUpdate(o,f,v):t.prototype&&t.prototype.isPureReactComponent?!pl(a,o)||!pl(s,f):!0}function Ym(e,t,a,o){e=t.state,typeof t.componentWillReceiveProps=="function"&&t.componentWillReceiveProps(a,o),typeof t.UNSAFE_componentWillReceiveProps=="function"&&t.UNSAFE_componentWillReceiveProps(a,o),t.state!==e&&uf.enqueueReplaceState(t,t.state,null)}function Ga(e,t){var a=t;if("ref"in t){a={};for(var o in t)o!=="ref"&&(a[o]=t[o])}if(e=e.defaultProps){a===t&&(a=m({},a));for(var s in e)a[s]===void 0&&(a[s]=e[s])}return a}var bu=typeof reportError=="function"?reportError:function(e){if(typeof window=="object"&&typeof window.ErrorEvent=="function"){var t=new window.ErrorEvent("error",{bubbles:!0,cancelable:!0,message:typeof e=="object"&&e!==null&&typeof e.message=="string"?String(e.message):String(e),error:e});if(!window.dispatchEvent(t))return}else if(typeof process=="object"&&typeof process.emit=="function"){process.emit("uncaughtException",e);return}};function Vm(e){bu(e)}function Pm(e){}function Xm(e){bu(e)}function Su(e,t){try{var a=e.onUncaughtError;a(t.value,{componentStack:t.stack})}catch(o){setTimeout(function(){throw o})}}function Qm(e,t,a){try{var o=e.onCaughtError;o(a.value,{componentStack:a.stack,errorBoundary:t.tag===1?t.stateNode:null})}catch(s){setTimeout(function(){throw s})}}function sf(e,t,a){return a=ea(a),a.tag=3,a.payload={element:null},a.callback=function(){Su(e,t)},a}function Km(e){return e=ea(e),e.tag=3,e}function Fm(e,t,a,o){var s=a.type.getDerivedStateFromError;if(typeof s=="function"){var f=o.value;e.payload=function(){return s(f)},e.callback=function(){Qm(t,a,o)}}var v=a.stateNode;v!==null&&typeof v.componentDidCatch=="function"&&(e.callback=function(){Qm(t,a,o),typeof s!="function"&&(ca===null?ca=new Set([this]):ca.add(this));var b=o.stack;this.componentDidCatch(o.value,{componentStack:b!==null?b:""})})}function VT(e,t,a,o,s){if(a.flags|=32768,o!==null&&typeof o=="object"&&typeof o.then=="function"){if(t=a.alternate,t!==null&&gl(t,a,s,!0),a=qn.current,a!==null){switch(a.tag){case 13:return ar===null?jf():a.alternate===null&&Et===0&&(Et=3),a.flags&=-257,a.flags|=65536,a.lanes=s,o===zc?a.flags|=16384:(t=a.updateQueue,t===null?a.updateQueue=new Set([o]):t.add(o),$f(e,o,s)),!1;case 22:return a.flags|=65536,o===zc?a.flags|=16384:(t=a.updateQueue,t===null?(t={transitions:null,markerInstances:null,retryQueue:new Set([o])},a.updateQueue=t):(a=t.retryQueue,a===null?t.retryQueue=new Set([o]):a.add(o)),$f(e,o,s)),!1}throw Error(l(435,a.tag))}return $f(e,o,s),jf(),!1}if(Je)return t=qn.current,t!==null?((t.flags&65536)===0&&(t.flags|=256),t.flags|=65536,t.lanes=s,o!==Nc&&(e=Error(l(422),{cause:o}),ml(Dn(e,a)))):(o!==Nc&&(t=Error(l(423),{cause:o}),ml(Dn(t,a))),e=e.current.alternate,e.flags|=65536,s&=-s,e.lanes|=s,o=Dn(o,a),s=sf(e.stateNode,o,s),Uc(e,s),Et!==4&&(Et=2)),!1;var f=Error(l(520),{cause:o});if(f=Dn(f,a),kl===null?kl=[f]:kl.push(f),Et!==4&&(Et=2),t===null)return!0;o=Dn(o,a),a=t;do{switch(a.tag){case 3:return a.flags|=65536,e=s&-s,a.lanes|=e,e=sf(a.stateNode,o,e),Uc(a,e),!1;case 1:if(t=a.type,f=a.stateNode,(a.flags&128)===0&&(typeof t.getDerivedStateFromError=="function"||f!==null&&typeof f.componentDidCatch=="function"&&(ca===null||!ca.has(f))))return a.flags|=65536,s&=-s,a.lanes|=s,s=Km(s),Fm(s,e,a,o),Uc(a,s),!1}a=a.return}while(a!==null);return!1}var Zm=Error(l(461)),Pt=!1;function Kt(e,t,a,o){t.child=e===null?Um(t,null,a,o):xi(t,e.child,a,o)}function Im(e,t,a,o,s){a=a.render;var f=t.ref;if("ref"in o){var v={};for(var b in o)b!=="ref"&&(v[b]=o[b])}else v=o;return La(t),o=Pc(e,t,a,v,f,s),b=Xc(),e!==null&&!Pt?(Qc(e,t,s),Dr(e,t,s)):(Je&&b&&wc(t),t.flags|=1,Kt(e,t,o,s),t.child)}function Wm(e,t,a,o,s){if(e===null){var f=a.type;return typeof f=="function"&&!_c(f)&&f.defaultProps===void 0&&a.compare===null?(t.tag=15,t.type=f,Jm(e,t,f,o,s)):(e=Jo(a.type,null,o,t,t.mode,s),e.ref=t.ref,e.return=t,t.child=e)}if(f=e.child,!mf(e,s)){var v=f.memoizedProps;if(a=a.compare,a=a!==null?a:pl,a(v,o)&&e.ref===t.ref)return Dr(e,t,s)}return t.flags|=1,e=_r(f,o),e.ref=t.ref,e.return=t,t.child=e}function Jm(e,t,a,o,s){if(e!==null){var f=e.memoizedProps;if(pl(f,o)&&e.ref===t.ref)if(Pt=!1,t.pendingProps=o=f,mf(e,s))(e.flags&131072)!==0&&(Pt=!0);else return t.lanes=e.lanes,Dr(e,t,s)}return cf(e,t,a,o,s)}function eg(e,t,a){var o=t.pendingProps,s=o.children,f=e!==null?e.memoizedState:null;if(o.mode==="hidden"){if((t.flags&128)!==0){if(o=f!==null?f.baseLanes|a:a,e!==null){for(s=t.child=e.child,f=0;s!==null;)f=f|s.lanes|s.childLanes,s=s.sibling;t.childLanes=f&~o}else t.childLanes=0,t.child=null;return tg(e,t,o,a)}if((a&536870912)!==0)t.memoizedState={baseLanes:0,cachePool:null},e!==null&&au(t,f!==null?f.cachePool:null),f!==null?Jv(t,f):Gc(),Hm(t);else return t.lanes=t.childLanes=536870912,tg(e,t,f!==null?f.baseLanes|a:a,a)}else f!==null?(au(t,f.cachePool),Jv(t,f),aa(),t.memoizedState=null):(e!==null&&au(t,null),Gc(),aa());return Kt(e,t,s,a),t.child}function tg(e,t,a,o){var s=qc();return s=s===null?null:{parent:Lt._currentValue,pool:s},t.memoizedState={baseLanes:a,cachePool:s},e!==null&&au(t,null),Gc(),Hm(t),e!==null&&gl(e,t,o,!0),null}function xu(e,t){var a=t.ref;if(a===null)e!==null&&e.ref!==null&&(t.flags|=4194816);else{if(typeof a!="function"&&typeof a!="object")throw Error(l(284));(e===null||e.ref!==a)&&(t.flags|=4194816)}}function cf(e,t,a,o,s){return La(t),a=Pc(e,t,a,o,void 0,s),o=Xc(),e!==null&&!Pt?(Qc(e,t,s),Dr(e,t,s)):(Je&&o&&wc(t),t.flags|=1,Kt(e,t,a,s),t.child)}function ng(e,t,a,o,s,f){return La(t),t.updateQueue=null,a=tm(t,o,a,s),em(e),o=Xc(),e!==null&&!Pt?(Qc(e,t,f),Dr(e,t,f)):(Je&&o&&wc(t),t.flags|=1,Kt(e,t,a,f),t.child)}function rg(e,t,a,o,s){if(La(t),t.stateNode===null){var f=fi,v=a.contextType;typeof v=="object"&&v!==null&&(f=Wt(v)),f=new a(o,f),t.memoizedState=f.state!==null&&f.state!==void 0?f.state:null,f.updater=uf,t.stateNode=f,f._reactInternals=t,f=t.stateNode,f.props=o,f.state=t.memoizedState,f.refs={},kc(t),v=a.contextType,f.context=typeof v=="object"&&v!==null?Wt(v):fi,f.state=t.memoizedState,v=a.getDerivedStateFromProps,typeof v=="function"&&(of(t,a,v,o),f.state=t.memoizedState),typeof a.getDerivedStateFromProps=="function"||typeof f.getSnapshotBeforeUpdate=="function"||typeof f.UNSAFE_componentWillMount!="function"&&typeof f.componentWillMount!="function"||(v=f.state,typeof f.componentWillMount=="function"&&f.componentWillMount(),typeof f.UNSAFE_componentWillMount=="function"&&f.UNSAFE_componentWillMount(),v!==f.state&&uf.enqueueReplaceState(f,f.state,null),_l(t,o,f,s),Tl(),f.state=t.memoizedState),typeof f.componentDidMount=="function"&&(t.flags|=4194308),o=!0}else if(e===null){f=t.stateNode;var b=t.memoizedProps,w=Ga(a,b);f.props=w;var P=f.context,J=a.contextType;v=fi,typeof J=="object"&&J!==null&&(v=Wt(J));var ne=a.getDerivedStateFromProps;J=typeof ne=="function"||typeof f.getSnapshotBeforeUpdate=="function",b=t.pendingProps!==b,J||typeof f.UNSAFE_componentWillReceiveProps!="function"&&typeof f.componentWillReceiveProps!="function"||(b||P!==v)&&Ym(t,f,o,v),Jr=!1;var Q=t.memoizedState;f.state=Q,_l(t,o,f,s),Tl(),P=t.memoizedState,b||Q!==P||Jr?(typeof ne=="function"&&(of(t,a,ne,o),P=t.memoizedState),(w=Jr||Gm(t,a,w,o,Q,P,v))?(J||typeof f.UNSAFE_componentWillMount!="function"&&typeof f.componentWillMount!="function"||(typeof f.componentWillMount=="function"&&f.componentWillMount(),typeof f.UNSAFE_componentWillMount=="function"&&f.UNSAFE_componentWillMount()),typeof f.componentDidMount=="function"&&(t.flags|=4194308)):(typeof f.componentDidMount=="function"&&(t.flags|=4194308),t.memoizedProps=o,t.memoizedState=P),f.props=o,f.state=P,f.context=v,o=w):(typeof f.componentDidMount=="function"&&(t.flags|=4194308),o=!1)}else{f=t.stateNode,Lc(e,t),v=t.memoizedProps,J=Ga(a,v),f.props=J,ne=t.pendingProps,Q=f.context,P=a.contextType,w=fi,typeof P=="object"&&P!==null&&(w=Wt(P)),b=a.getDerivedStateFromProps,(P=typeof b=="function"||typeof f.getSnapshotBeforeUpdate=="function")||typeof f.UNSAFE_componentWillReceiveProps!="function"&&typeof f.componentWillReceiveProps!="function"||(v!==ne||Q!==w)&&Ym(t,f,o,w),Jr=!1,Q=t.memoizedState,f.state=Q,_l(t,o,f,s),Tl();var K=t.memoizedState;v!==ne||Q!==K||Jr||e!==null&&e.dependencies!==null&&nu(e.dependencies)?(typeof b=="function"&&(of(t,a,b,o),K=t.memoizedState),(J=Jr||Gm(t,a,J,o,Q,K,w)||e!==null&&e.dependencies!==null&&nu(e.dependencies))?(P||typeof f.UNSAFE_componentWillUpdate!="function"&&typeof f.componentWillUpdate!="function"||(typeof f.componentWillUpdate=="function"&&f.componentWillUpdate(o,K,w),typeof f.UNSAFE_componentWillUpdate=="function"&&f.UNSAFE_componentWillUpdate(o,K,w)),typeof f.componentDidUpdate=="function"&&(t.flags|=4),typeof f.getSnapshotBeforeUpdate=="function"&&(t.flags|=1024)):(typeof f.componentDidUpdate!="function"||v===e.memoizedProps&&Q===e.memoizedState||(t.flags|=4),typeof f.getSnapshotBeforeUpdate!="function"||v===e.memoizedProps&&Q===e.memoizedState||(t.flags|=1024),t.memoizedProps=o,t.memoizedState=K),f.props=o,f.state=K,f.context=w,o=J):(typeof f.componentDidUpdate!="function"||v===e.memoizedProps&&Q===e.memoizedState||(t.flags|=4),typeof f.getSnapshotBeforeUpdate!="function"||v===e.memoizedProps&&Q===e.memoizedState||(t.flags|=1024),o=!1)}return f=o,xu(e,t),o=(t.flags&128)!==0,f||o?(f=t.stateNode,a=o&&typeof a.getDerivedStateFromError!="function"?null:f.render(),t.flags|=1,e!==null&&o?(t.child=xi(t,e.child,null,s),t.child=xi(t,null,a,s)):Kt(e,t,a,s),t.memoizedState=f.state,e=t.child):e=Dr(e,t,s),e}function ag(e,t,a,o){return vl(),t.flags|=256,Kt(e,t,a,o),t.child}var ff={dehydrated:null,treeContext:null,retryLane:0,hydrationErrors:null};function df(e){return{baseLanes:e,cachePool:Pv()}}function pf(e,t,a){return e=e!==null?e.childLanes&~a:0,t&&(e|=zn),e}function ig(e,t,a){var o=t.pendingProps,s=!1,f=(t.flags&128)!==0,v;if((v=f)||(v=e!==null&&e.memoizedState===null?!1:(Ut.current&2)!==0),v&&(s=!0,t.flags&=-129),v=(t.flags&32)!==0,t.flags&=-33,e===null){if(Je){if(s?ra(t):aa(),Je){var b=xt,w;if(w=b){e:{for(w=b,b=rr;w.nodeType!==8;){if(!b){b=null;break e}if(w=In(w.nextSibling),w===null){b=null;break e}}b=w}b!==null?(t.memoizedState={dehydrated:b,treeContext:Ba!==null?{id:Ar,overflow:Rr}:null,retryLane:536870912,hydrationErrors:null},w=mn(18,null,null,0),w.stateNode=b,w.return=t,t.child=w,rn=t,xt=null,w=!0):w=!1}w||za(t)}if(b=t.memoizedState,b!==null&&(b=b.dehydrated,b!==null))return Zf(b)?t.lanes=32:t.lanes=536870912,null;Mr(t)}return b=o.children,o=o.fallback,s?(aa(),s=t.mode,b=Eu({mode:"hidden",children:b},s),o=ja(o,s,a,null),b.return=t,o.return=t,b.sibling=o,t.child=b,s=t.child,s.memoizedState=df(a),s.childLanes=pf(e,v,a),t.memoizedState=ff,o):(ra(t),hf(t,b))}if(w=e.memoizedState,w!==null&&(b=w.dehydrated,b!==null)){if(f)t.flags&256?(ra(t),t.flags&=-257,t=yf(e,t,a)):t.memoizedState!==null?(aa(),t.child=e.child,t.flags|=128,t=null):(aa(),s=o.fallback,b=t.mode,o=Eu({mode:"visible",children:o.children},b),s=ja(s,b,a,null),s.flags|=2,o.return=t,s.return=t,o.sibling=s,t.child=o,xi(t,e.child,null,a),o=t.child,o.memoizedState=df(a),o.childLanes=pf(e,v,a),t.memoizedState=ff,t=s);else if(ra(t),Zf(b)){if(v=b.nextSibling&&b.nextSibling.dataset,v)var P=v.dgst;v=P,o=Error(l(419)),o.stack="",o.digest=v,ml({value:o,source:null,stack:null}),t=yf(e,t,a)}else if(Pt||gl(e,t,a,!1),v=(a&e.childLanes)!==0,Pt||v){if(v=ht,v!==null&&(o=a&-a,o=(o&42)!==0?1:br(o),o=(o&(v.suspendedLanes|a))!==0?0:o,o!==0&&o!==w.retryLane))throw w.retryLane=o,ci(e,o),En(v,e,o),Zm;b.data==="$?"||jf(),t=yf(e,t,a)}else b.data==="$?"?(t.flags|=192,t.child=e.child,t=null):(e=w.treeContext,xt=In(b.nextSibling),rn=t,Je=!0,qa=null,rr=!1,e!==null&&(Bn[$n++]=Ar,Bn[$n++]=Rr,Bn[$n++]=Ba,Ar=e.id,Rr=e.overflow,Ba=t),t=hf(t,o.children),t.flags|=4096);return t}return s?(aa(),s=o.fallback,b=t.mode,w=e.child,P=w.sibling,o=_r(w,{mode:"hidden",children:o.children}),o.subtreeFlags=w.subtreeFlags&65011712,P!==null?s=_r(P,s):(s=ja(s,b,a,null),s.flags|=2),s.return=t,o.return=t,o.sibling=s,t.child=o,o=s,s=t.child,b=e.child.memoizedState,b===null?b=df(a):(w=b.cachePool,w!==null?(P=Lt._currentValue,w=w.parent!==P?{parent:P,pool:P}:w):w=Pv(),b={baseLanes:b.baseLanes|a,cachePool:w}),s.memoizedState=b,s.childLanes=pf(e,v,a),t.memoizedState=ff,o):(ra(t),a=e.child,e=a.sibling,a=_r(a,{mode:"visible",children:o.children}),a.return=t,a.sibling=null,e!==null&&(v=t.deletions,v===null?(t.deletions=[e],t.flags|=16):v.push(e)),t.child=a,t.memoizedState=null,a)}function hf(e,t){return t=Eu({mode:"visible",children:t},e.mode),t.return=e,e.child=t}function Eu(e,t){return e=mn(22,e,null,t),e.lanes=0,e.stateNode={_visibility:1,_pendingMarkers:null,_retryCache:null,_transitions:null},e}function yf(e,t,a){return xi(t,e.child,null,a),e=hf(t,t.pendingProps.children),e.flags|=2,t.memoizedState=null,e}function lg(e,t,a){e.lanes|=t;var o=e.alternate;o!==null&&(o.lanes|=t),Dc(e.return,t,a)}function vf(e,t,a,o,s){var f=e.memoizedState;f===null?e.memoizedState={isBackwards:t,rendering:null,renderingStartTime:0,last:o,tail:a,tailMode:s}:(f.isBackwards=t,f.rendering=null,f.renderingStartTime=0,f.last=o,f.tail=a,f.tailMode=s)}function og(e,t,a){var o=t.pendingProps,s=o.revealOrder,f=o.tail;if(Kt(e,t,o.children,a),o=Ut.current,(o&2)!==0)o=o&1|2,t.flags|=128;else{if(e!==null&&(e.flags&128)!==0)e:for(e=t.child;e!==null;){if(e.tag===13)e.memoizedState!==null&&lg(e,a,t);else if(e.tag===19)lg(e,a,t);else if(e.child!==null){e.child.return=e,e=e.child;continue}if(e===t)break e;for(;e.sibling===null;){if(e.return===null||e.return===t)break e;e=e.return}e.sibling.return=e.return,e=e.sibling}o&=1}switch(re(Ut,o),s){case"forwards":for(a=t.child,s=null;a!==null;)e=a.alternate,e!==null&&gu(e)===null&&(s=a),a=a.sibling;a=s,a===null?(s=t.child,t.child=null):(s=a.sibling,a.sibling=null),vf(t,!1,s,a,f);break;case"backwards":for(a=null,s=t.child,t.child=null;s!==null;){if(e=s.alternate,e!==null&&gu(e)===null){t.child=s;break}e=s.sibling,s.sibling=a,a=s,s=e}vf(t,!0,a,null,f);break;case"together":vf(t,!1,null,null,void 0);break;default:t.memoizedState=null}return t.child}function Dr(e,t,a){if(e!==null&&(t.dependencies=e.dependencies),sa|=t.lanes,(a&t.childLanes)===0)if(e!==null){if(gl(e,t,a,!1),(a&t.childLanes)===0)return null}else return null;if(e!==null&&t.child!==e.child)throw Error(l(153));if(t.child!==null){for(e=t.child,a=_r(e,e.pendingProps),t.child=a,a.return=t;e.sibling!==null;)e=e.sibling,a=a.sibling=_r(e,e.pendingProps),a.return=t;a.sibling=null}return t.child}function mf(e,t){return(e.lanes&t)!==0?!0:(e=e.dependencies,!!(e!==null&&nu(e)))}function PT(e,t,a){switch(t.tag){case 3:ce(t,t.stateNode.containerInfo),Wr(t,Lt,e.memoizedState.cache),vl();break;case 27:case 5:me(t);break;case 4:ce(t,t.stateNode.containerInfo);break;case 10:Wr(t,t.type,t.memoizedProps.value);break;case 13:var o=t.memoizedState;if(o!==null)return o.dehydrated!==null?(ra(t),t.flags|=128,null):(a&t.child.childLanes)!==0?ig(e,t,a):(ra(t),e=Dr(e,t,a),e!==null?e.sibling:null);ra(t);break;case 19:var s=(e.flags&128)!==0;if(o=(a&t.childLanes)!==0,o||(gl(e,t,a,!1),o=(a&t.childLanes)!==0),s){if(o)return og(e,t,a);t.flags|=128}if(s=t.memoizedState,s!==null&&(s.rendering=null,s.tail=null,s.lastEffect=null),re(Ut,Ut.current),o)break;return null;case 22:case 23:return t.lanes=0,eg(e,t,a);case 24:Wr(t,Lt,e.memoizedState.cache)}return Dr(e,t,a)}function ug(e,t,a){if(e!==null)if(e.memoizedProps!==t.pendingProps)Pt=!0;else{if(!mf(e,a)&&(t.flags&128)===0)return Pt=!1,PT(e,t,a);Pt=(e.flags&131072)!==0}else Pt=!1,Je&&(t.flags&1048576)!==0&&kv(t,tu,t.index);switch(t.lanes=0,t.tag){case 16:e:{e=t.pendingProps;var o=t.elementType,s=o._init;if(o=s(o._payload),t.type=o,typeof o=="function")_c(o)?(e=Ga(o,e),t.tag=1,t=rg(null,t,o,e,a)):(t.tag=0,t=cf(null,t,o,e,a));else{if(o!=null){if(s=o.$$typeof,s===X){t.tag=11,t=Im(null,t,o,e,a);break e}else if(s===O){t.tag=14,t=Wm(null,t,o,e,a);break e}}throw t=he(o)||o,Error(l(306,t,""))}}return t;case 0:return cf(e,t,t.type,t.pendingProps,a);case 1:return o=t.type,s=Ga(o,t.pendingProps),rg(e,t,o,s,a);case 3:e:{if(ce(t,t.stateNode.containerInfo),e===null)throw Error(l(387));o=t.pendingProps;var f=t.memoizedState;s=f.element,Lc(e,t),_l(t,o,null,a);var v=t.memoizedState;if(o=v.cache,Wr(t,Lt,o),o!==f.cache&&jc(t,[Lt],a,!0),Tl(),o=v.element,f.isDehydrated)if(f={element:o,isDehydrated:!1,cache:v.cache},t.updateQueue.baseState=f,t.memoizedState=f,t.flags&256){t=ag(e,t,o,a);break e}else if(o!==s){s=Dn(Error(l(424)),t),ml(s),t=ag(e,t,o,a);break e}else{switch(e=t.stateNode.containerInfo,e.nodeType){case 9:e=e.body;break;default:e=e.nodeName==="HTML"?e.ownerDocument.body:e}for(xt=In(e.firstChild),rn=t,Je=!0,qa=null,rr=!0,a=Um(t,null,o,a),t.child=a;a;)a.flags=a.flags&-3|4096,a=a.sibling}else{if(vl(),o===s){t=Dr(e,t,a);break e}Kt(e,t,o,a)}t=t.child}return t;case 26:return xu(e,t),e===null?(a=d0(t.type,null,t.pendingProps,null))?t.memoizedState=a:Je||(a=t.type,e=t.pendingProps,o=qu(te.current).createElement(a),o[At]=t,o[St]=e,Zt(o,a,e),ct(o),t.stateNode=o):t.memoizedState=d0(t.type,e.memoizedProps,t.pendingProps,e.memoizedState),null;case 27:return me(t),e===null&&Je&&(o=t.stateNode=s0(t.type,t.pendingProps,te.current),rn=t,rr=!0,s=xt,pa(t.type)?(If=s,xt=In(o.firstChild)):xt=s),Kt(e,t,t.pendingProps.children,a),xu(e,t),e===null&&(t.flags|=4194304),t.child;case 5:return e===null&&Je&&((s=o=xt)&&(o=b_(o,t.type,t.pendingProps,rr),o!==null?(t.stateNode=o,rn=t,xt=In(o.firstChild),rr=!1,s=!0):s=!1),s||za(t)),me(t),s=t.type,f=t.pendingProps,v=e!==null?e.memoizedProps:null,o=f.children,Qf(s,f)?o=null:v!==null&&Qf(s,v)&&(t.flags|=32),t.memoizedState!==null&&(s=Pc(e,t,zT,null,null,a),Ql._currentValue=s),xu(e,t),Kt(e,t,o,a),t.child;case 6:return e===null&&Je&&((e=a=xt)&&(a=S_(a,t.pendingProps,rr),a!==null?(t.stateNode=a,rn=t,xt=null,e=!0):e=!1),e||za(t)),null;case 13:return ig(e,t,a);case 4:return ce(t,t.stateNode.containerInfo),o=t.pendingProps,e===null?t.child=xi(t,null,o,a):Kt(e,t,o,a),t.child;case 11:return Im(e,t,t.type,t.pendingProps,a);case 7:return Kt(e,t,t.pendingProps,a),t.child;case 8:return Kt(e,t,t.pendingProps.children,a),t.child;case 12:return Kt(e,t,t.pendingProps.children,a),t.child;case 10:return o=t.pendingProps,Wr(t,t.type,o.value),Kt(e,t,o.children,a),t.child;case 9:return s=t.type._context,o=t.pendingProps.children,La(t),s=Wt(s),o=o(s),t.flags|=1,Kt(e,t,o,a),t.child;case 14:return Wm(e,t,t.type,t.pendingProps,a);case 15:return Jm(e,t,t.type,t.pendingProps,a);case 19:return og(e,t,a);case 31:return o=t.pendingProps,a=t.mode,o={mode:o.mode,children:o.children},e===null?(a=Eu(o,a),a.ref=t.ref,t.child=a,a.return=t,t=a):(a=_r(e.child,o),a.ref=t.ref,t.child=a,a.return=t,t=a),t;case 22:return eg(e,t,a);case 24:return La(t),o=Wt(Lt),e===null?(s=qc(),s===null&&(s=ht,f=Bc(),s.pooledCache=f,f.refCount++,f!==null&&(s.pooledCacheLanes|=a),s=f),t.memoizedState={parent:o,cache:s},kc(t),Wr(t,Lt,s)):((e.lanes&a)!==0&&(Lc(e,t),_l(t,null,null,a),Tl()),s=e.memoizedState,f=t.memoizedState,s.parent!==o?(s={parent:o,cache:o},t.memoizedState=s,t.lanes===0&&(t.memoizedState=t.updateQueue.baseState=s),Wr(t,Lt,o)):(o=f.cache,Wr(t,Lt,o),o!==s.cache&&jc(t,[Lt],a,!0))),Kt(e,t,t.pendingProps.children,a),t.child;case 29:throw t.pendingProps}throw Error(l(156,t.tag))}function jr(e){e.flags|=4}function sg(e,t){if(t.type!=="stylesheet"||(t.state.loading&4)!==0)e.flags&=-16777217;else if(e.flags|=16777216,!m0(t)){if(t=qn.current,t!==null&&((Pe&4194048)===Pe?ar!==null:(Pe&62914560)!==Pe&&(Pe&536870912)===0||t!==ar))throw El=zc,Xv;e.flags|=8192}}function Ou(e,t){t!==null&&(e.flags|=4),e.flags&16384&&(t=e.tag!==22?Ie():536870912,e.lanes|=t,_i|=t)}function Dl(e,t){if(!Je)switch(e.tailMode){case"hidden":t=e.tail;for(var a=null;t!==null;)t.alternate!==null&&(a=t),t=t.sibling;a===null?e.tail=null:a.sibling=null;break;case"collapsed":a=e.tail;for(var o=null;a!==null;)a.alternate!==null&&(o=a),a=a.sibling;o===null?t||e.tail===null?e.tail=null:e.tail.sibling=null:o.sibling=null}}function gt(e){var t=e.alternate!==null&&e.alternate.child===e.child,a=0,o=0;if(t)for(var s=e.child;s!==null;)a|=s.lanes|s.childLanes,o|=s.subtreeFlags&65011712,o|=s.flags&65011712,s.return=e,s=s.sibling;else for(s=e.child;s!==null;)a|=s.lanes|s.childLanes,o|=s.subtreeFlags,o|=s.flags,s.return=e,s=s.sibling;return e.subtreeFlags|=o,e.childLanes=a,t}function XT(e,t,a){var o=t.pendingProps;switch(Cc(t),t.tag){case 31:case 16:case 15:case 0:case 11:case 7:case 8:case 12:case 9:case 14:return gt(t),null;case 1:return gt(t),null;case 3:return a=t.stateNode,o=null,e!==null&&(o=e.memoizedState.cache),t.memoizedState.cache!==o&&(t.flags|=2048),Cr(Lt),xe(),a.pendingContext&&(a.context=a.pendingContext,a.pendingContext=null),(e===null||e.child===null)&&(yl(t)?jr(t):e===null||e.memoizedState.isDehydrated&&(t.flags&256)===0||(t.flags|=1024,Hv())),gt(t),null;case 26:return a=t.memoizedState,e===null?(jr(t),a!==null?(gt(t),sg(t,a)):(gt(t),t.flags&=-16777217)):a?a!==e.memoizedState?(jr(t),gt(t),sg(t,a)):(gt(t),t.flags&=-16777217):(e.memoizedProps!==o&&jr(t),gt(t),t.flags&=-16777217),null;case 27:Ee(t),a=te.current;var s=t.type;if(e!==null&&t.stateNode!=null)e.memoizedProps!==o&&jr(t);else{if(!o){if(t.stateNode===null)throw Error(l(166));return gt(t),null}e=z.current,yl(t)?Lv(t):(e=s0(s,o,a),t.stateNode=e,jr(t))}return gt(t),null;case 5:if(Ee(t),a=t.type,e!==null&&t.stateNode!=null)e.memoizedProps!==o&&jr(t);else{if(!o){if(t.stateNode===null)throw Error(l(166));return gt(t),null}if(e=z.current,yl(t))Lv(t);else{switch(s=qu(te.current),e){case 1:e=s.createElementNS("http://www.w3.org/2000/svg",a);break;case 2:e=s.createElementNS("http://www.w3.org/1998/Math/MathML",a);break;default:switch(a){case"svg":e=s.createElementNS("http://www.w3.org/2000/svg",a);break;case"math":e=s.createElementNS("http://www.w3.org/1998/Math/MathML",a);break;case"script":e=s.createElement("div"),e.innerHTML="<script><\/script>",e=e.removeChild(e.firstChild);break;case"select":e=typeof o.is=="string"?s.createElement("select",{is:o.is}):s.createElement("select"),o.multiple?e.multiple=!0:o.size&&(e.size=o.size);break;default:e=typeof o.is=="string"?s.createElement(a,{is:o.is}):s.createElement(a)}}e[At]=t,e[St]=o;e:for(s=t.child;s!==null;){if(s.tag===5||s.tag===6)e.appendChild(s.stateNode);else if(s.tag!==4&&s.tag!==27&&s.child!==null){s.child.return=s,s=s.child;continue}if(s===t)break e;for(;s.sibling===null;){if(s.return===null||s.return===t)break e;s=s.return}s.sibling.return=s.return,s=s.sibling}t.stateNode=e;e:switch(Zt(e,a,o),a){case"button":case"input":case"select":case"textarea":e=!!o.autoFocus;break e;case"img":e=!0;break e;default:e=!1}e&&jr(t)}}return gt(t),t.flags&=-16777217,null;case 6:if(e&&t.stateNode!=null)e.memoizedProps!==o&&jr(t);else{if(typeof o!="string"&&t.stateNode===null)throw Error(l(166));if(e=te.current,yl(t)){if(e=t.stateNode,a=t.memoizedProps,o=null,s=rn,s!==null)switch(s.tag){case 27:case 5:o=s.memoizedProps}e[At]=t,e=!!(e.nodeValue===a||o!==null&&o.suppressHydrationWarning===!0||n0(e.nodeValue,a)),e||za(t)}else e=qu(e).createTextNode(o),e[At]=t,t.stateNode=e}return gt(t),null;case 13:if(o=t.memoizedState,e===null||e.memoizedState!==null&&e.memoizedState.dehydrated!==null){if(s=yl(t),o!==null&&o.dehydrated!==null){if(e===null){if(!s)throw Error(l(318));if(s=t.memoizedState,s=s!==null?s.dehydrated:null,!s)throw Error(l(317));s[At]=t}else vl(),(t.flags&128)===0&&(t.memoizedState=null),t.flags|=4;gt(t),s=!1}else s=Hv(),e!==null&&e.memoizedState!==null&&(e.memoizedState.hydrationErrors=s),s=!0;if(!s)return t.flags&256?(Mr(t),t):(Mr(t),null)}if(Mr(t),(t.flags&128)!==0)return t.lanes=a,t;if(a=o!==null,e=e!==null&&e.memoizedState!==null,a){o=t.child,s=null,o.alternate!==null&&o.alternate.memoizedState!==null&&o.alternate.memoizedState.cachePool!==null&&(s=o.alternate.memoizedState.cachePool.pool);var f=null;o.memoizedState!==null&&o.memoizedState.cachePool!==null&&(f=o.memoizedState.cachePool.pool),f!==s&&(o.flags|=2048)}return a!==e&&a&&(t.child.flags|=8192),Ou(t,t.updateQueue),gt(t),null;case 4:return xe(),e===null&&Gf(t.stateNode.containerInfo),gt(t),null;case 10:return Cr(t.type),gt(t),null;case 19:if(le(Ut),s=t.memoizedState,s===null)return gt(t),null;if(o=(t.flags&128)!==0,f=s.rendering,f===null)if(o)Dl(s,!1);else{if(Et!==0||e!==null&&(e.flags&128)!==0)for(e=t.child;e!==null;){if(f=gu(e),f!==null){for(t.flags|=128,Dl(s,!1),e=f.updateQueue,t.updateQueue=e,Ou(t,e),t.subtreeFlags=0,e=a,a=t.child;a!==null;)zv(a,e),a=a.sibling;return re(Ut,Ut.current&1|2),t.child}e=e.sibling}s.tail!==null&&Me()>Au&&(t.flags|=128,o=!0,Dl(s,!1),t.lanes=4194304)}else{if(!o)if(e=gu(f),e!==null){if(t.flags|=128,o=!0,e=e.updateQueue,t.updateQueue=e,Ou(t,e),Dl(s,!0),s.tail===null&&s.tailMode==="hidden"&&!f.alternate&&!Je)return gt(t),null}else 2*Me()-s.renderingStartTime>Au&&a!==536870912&&(t.flags|=128,o=!0,Dl(s,!1),t.lanes=4194304);s.isBackwards?(f.sibling=t.child,t.child=f):(e=s.last,e!==null?e.sibling=f:t.child=f,s.last=f)}return s.tail!==null?(t=s.tail,s.rendering=t,s.tail=t.sibling,s.renderingStartTime=Me(),t.sibling=null,e=Ut.current,re(Ut,o?e&1|2:e&1),t):(gt(t),null);case 22:case 23:return Mr(t),Yc(),o=t.memoizedState!==null,e!==null?e.memoizedState!==null!==o&&(t.flags|=8192):o&&(t.flags|=8192),o?(a&536870912)!==0&&(t.flags&128)===0&&(gt(t),t.subtreeFlags&6&&(t.flags|=8192)):gt(t),a=t.updateQueue,a!==null&&Ou(t,a.retryQueue),a=null,e!==null&&e.memoizedState!==null&&e.memoizedState.cachePool!==null&&(a=e.memoizedState.cachePool.pool),o=null,t.memoizedState!==null&&t.memoizedState.cachePool!==null&&(o=t.memoizedState.cachePool.pool),o!==a&&(t.flags|=2048),e!==null&&le(Ua),null;case 24:return a=null,e!==null&&(a=e.memoizedState.cache),t.memoizedState.cache!==a&&(t.flags|=2048),Cr(Lt),gt(t),null;case 25:return null;case 30:return null}throw Error(l(156,t.tag))}function QT(e,t){switch(Cc(t),t.tag){case 1:return e=t.flags,e&65536?(t.flags=e&-65537|128,t):null;case 3:return Cr(Lt),xe(),e=t.flags,(e&65536)!==0&&(e&128)===0?(t.flags=e&-65537|128,t):null;case 26:case 27:case 5:return Ee(t),null;case 13:if(Mr(t),e=t.memoizedState,e!==null&&e.dehydrated!==null){if(t.alternate===null)throw Error(l(340));vl()}return e=t.flags,e&65536?(t.flags=e&-65537|128,t):null;case 19:return le(Ut),null;case 4:return xe(),null;case 10:return Cr(t.type),null;case 22:case 23:return Mr(t),Yc(),e!==null&&le(Ua),e=t.flags,e&65536?(t.flags=e&-65537|128,t):null;case 24:return Cr(Lt),null;case 25:return null;default:return null}}function cg(e,t){switch(Cc(t),t.tag){case 3:Cr(Lt),xe();break;case 26:case 27:case 5:Ee(t);break;case 4:xe();break;case 13:Mr(t);break;case 19:le(Ut);break;case 10:Cr(t.type);break;case 22:case 23:Mr(t),Yc(),e!==null&&le(Ua);break;case 24:Cr(Lt)}}function jl(e,t){try{var a=t.updateQueue,o=a!==null?a.lastEffect:null;if(o!==null){var s=o.next;a=s;do{if((a.tag&e)===e){o=void 0;var f=a.create,v=a.inst;o=f(),v.destroy=o}a=a.next}while(a!==s)}}catch(b){ft(t,t.return,b)}}function ia(e,t,a){try{var o=t.updateQueue,s=o!==null?o.lastEffect:null;if(s!==null){var f=s.next;o=f;do{if((o.tag&e)===e){var v=o.inst,b=v.destroy;if(b!==void 0){v.destroy=void 0,s=t;var w=a,P=b;try{P()}catch(J){ft(s,w,J)}}}o=o.next}while(o!==f)}}catch(J){ft(t,t.return,J)}}function fg(e){var t=e.updateQueue;if(t!==null){var a=e.stateNode;try{Wv(t,a)}catch(o){ft(e,e.return,o)}}}function dg(e,t,a){a.props=Ga(e.type,e.memoizedProps),a.state=e.memoizedState;try{a.componentWillUnmount()}catch(o){ft(e,t,o)}}function Bl(e,t){try{var a=e.ref;if(a!==null){switch(e.tag){case 26:case 27:case 5:var o=e.stateNode;break;case 30:o=e.stateNode;break;default:o=e.stateNode}typeof a=="function"?e.refCleanup=a(o):a.current=o}}catch(s){ft(e,t,s)}}function ir(e,t){var a=e.ref,o=e.refCleanup;if(a!==null)if(typeof o=="function")try{o()}catch(s){ft(e,t,s)}finally{e.refCleanup=null,e=e.alternate,e!=null&&(e.refCleanup=null)}else if(typeof a=="function")try{a(null)}catch(s){ft(e,t,s)}else a.current=null}function pg(e){var t=e.type,a=e.memoizedProps,o=e.stateNode;try{e:switch(t){case"button":case"input":case"select":case"textarea":a.autoFocus&&o.focus();break e;case"img":a.src?o.src=a.src:a.srcSet&&(o.srcset=a.srcSet)}}catch(s){ft(e,e.return,s)}}function gf(e,t,a){try{var o=e.stateNode;h_(o,e.type,a,t),o[St]=t}catch(s){ft(e,e.return,s)}}function hg(e){return e.tag===5||e.tag===3||e.tag===26||e.tag===27&&pa(e.type)||e.tag===4}function bf(e){e:for(;;){for(;e.sibling===null;){if(e.return===null||hg(e.return))return null;e=e.return}for(e.sibling.return=e.return,e=e.sibling;e.tag!==5&&e.tag!==6&&e.tag!==18;){if(e.tag===27&&pa(e.type)||e.flags&2||e.child===null||e.tag===4)continue e;e.child.return=e,e=e.child}if(!(e.flags&2))return e.stateNode}}function Sf(e,t,a){var o=e.tag;if(o===5||o===6)e=e.stateNode,t?(a.nodeType===9?a.body:a.nodeName==="HTML"?a.ownerDocument.body:a).insertBefore(e,t):(t=a.nodeType===9?a.body:a.nodeName==="HTML"?a.ownerDocument.body:a,t.appendChild(e),a=a._reactRootContainer,a!=null||t.onclick!==null||(t.onclick=$u));else if(o!==4&&(o===27&&pa(e.type)&&(a=e.stateNode,t=null),e=e.child,e!==null))for(Sf(e,t,a),e=e.sibling;e!==null;)Sf(e,t,a),e=e.sibling}function Tu(e,t,a){var o=e.tag;if(o===5||o===6)e=e.stateNode,t?a.insertBefore(e,t):a.appendChild(e);else if(o!==4&&(o===27&&pa(e.type)&&(a=e.stateNode),e=e.child,e!==null))for(Tu(e,t,a),e=e.sibling;e!==null;)Tu(e,t,a),e=e.sibling}function yg(e){var t=e.stateNode,a=e.memoizedProps;try{for(var o=e.type,s=t.attributes;s.length;)t.removeAttributeNode(s[0]);Zt(t,o,a),t[At]=e,t[St]=a}catch(f){ft(e,e.return,f)}}var Br=!1,wt=!1,xf=!1,vg=typeof WeakSet=="function"?WeakSet:Set,Xt=null;function KT(e,t){if(e=e.containerInfo,Pf=Gu,e=Rv(e),gc(e)){if("selectionStart"in e)var a={start:e.selectionStart,end:e.selectionEnd};else e:{a=(a=e.ownerDocument)&&a.defaultView||window;var o=a.getSelection&&a.getSelection();if(o&&o.rangeCount!==0){a=o.anchorNode;var s=o.anchorOffset,f=o.focusNode;o=o.focusOffset;try{a.nodeType,f.nodeType}catch{a=null;break e}var v=0,b=-1,w=-1,P=0,J=0,ne=e,Q=null;t:for(;;){for(var K;ne!==a||s!==0&&ne.nodeType!==3||(b=v+s),ne!==f||o!==0&&ne.nodeType!==3||(w=v+o),ne.nodeType===3&&(v+=ne.nodeValue.length),(K=ne.firstChild)!==null;)Q=ne,ne=K;for(;;){if(ne===e)break t;if(Q===a&&++P===s&&(b=v),Q===f&&++J===o&&(w=v),(K=ne.nextSibling)!==null)break;ne=Q,Q=ne.parentNode}ne=K}a=b===-1||w===-1?null:{start:b,end:w}}else a=null}a=a||{start:0,end:0}}else a=null;for(Xf={focusedElem:e,selectionRange:a},Gu=!1,Xt=t;Xt!==null;)if(t=Xt,e=t.child,(t.subtreeFlags&1024)!==0&&e!==null)e.return=t,Xt=e;else for(;Xt!==null;){switch(t=Xt,f=t.alternate,e=t.flags,t.tag){case 0:break;case 11:case 15:break;case 1:if((e&1024)!==0&&f!==null){e=void 0,a=t,s=f.memoizedProps,f=f.memoizedState,o=a.stateNode;try{var Ne=Ga(a.type,s,a.elementType===a.type);e=o.getSnapshotBeforeUpdate(Ne,f),o.__reactInternalSnapshotBeforeUpdate=e}catch(Re){ft(a,a.return,Re)}}break;case 3:if((e&1024)!==0){if(e=t.stateNode.containerInfo,a=e.nodeType,a===9)Ff(e);else if(a===1)switch(e.nodeName){case"HEAD":case"HTML":case"BODY":Ff(e);break;default:e.textContent=""}}break;case 5:case 26:case 27:case 6:case 4:case 17:break;default:if((e&1024)!==0)throw Error(l(163))}if(e=t.sibling,e!==null){e.return=t.return,Xt=e;break}Xt=t.return}}function mg(e,t,a){var o=a.flags;switch(a.tag){case 0:case 11:case 15:la(e,a),o&4&&jl(5,a);break;case 1:if(la(e,a),o&4)if(e=a.stateNode,t===null)try{e.componentDidMount()}catch(v){ft(a,a.return,v)}else{var s=Ga(a.type,t.memoizedProps);t=t.memoizedState;try{e.componentDidUpdate(s,t,e.__reactInternalSnapshotBeforeUpdate)}catch(v){ft(a,a.return,v)}}o&64&&fg(a),o&512&&Bl(a,a.return);break;case 3:if(la(e,a),o&64&&(e=a.updateQueue,e!==null)){if(t=null,a.child!==null)switch(a.child.tag){case 27:case 5:t=a.child.stateNode;break;case 1:t=a.child.stateNode}try{Wv(e,t)}catch(v){ft(a,a.return,v)}}break;case 27:t===null&&o&4&&yg(a);case 26:case 5:la(e,a),t===null&&o&4&&pg(a),o&512&&Bl(a,a.return);break;case 12:la(e,a);break;case 13:la(e,a),o&4&&Sg(e,a),o&64&&(e=a.memoizedState,e!==null&&(e=e.dehydrated,e!==null&&(a=r_.bind(null,a),x_(e,a))));break;case 22:if(o=a.memoizedState!==null||Br,!o){t=t!==null&&t.memoizedState!==null||wt,s=Br;var f=wt;Br=o,(wt=t)&&!f?oa(e,a,(a.subtreeFlags&8772)!==0):la(e,a),Br=s,wt=f}break;case 30:break;default:la(e,a)}}function gg(e){var t=e.alternate;t!==null&&(e.alternate=null,gg(t)),e.child=null,e.deletions=null,e.sibling=null,e.tag===5&&(t=e.stateNode,t!==null&&Qn(t)),e.stateNode=null,e.return=null,e.dependencies=null,e.memoizedProps=null,e.memoizedState=null,e.pendingProps=null,e.stateNode=null,e.updateQueue=null}var yt=null,sn=!1;function $r(e,t,a){for(a=a.child;a!==null;)bg(e,t,a),a=a.sibling}function bg(e,t,a){if(rt&&typeof rt.onCommitFiberUnmount=="function")try{rt.onCommitFiberUnmount(_t,a)}catch{}switch(a.tag){case 26:wt||ir(a,t),$r(e,t,a),a.memoizedState?a.memoizedState.count--:a.stateNode&&(a=a.stateNode,a.parentNode.removeChild(a));break;case 27:wt||ir(a,t);var o=yt,s=sn;pa(a.type)&&(yt=a.stateNode,sn=!1),$r(e,t,a),Yl(a.stateNode),yt=o,sn=s;break;case 5:wt||ir(a,t);case 6:if(o=yt,s=sn,yt=null,$r(e,t,a),yt=o,sn=s,yt!==null)if(sn)try{(yt.nodeType===9?yt.body:yt.nodeName==="HTML"?yt.ownerDocument.body:yt).removeChild(a.stateNode)}catch(f){ft(a,t,f)}else try{yt.removeChild(a.stateNode)}catch(f){ft(a,t,f)}break;case 18:yt!==null&&(sn?(e=yt,o0(e.nodeType===9?e.body:e.nodeName==="HTML"?e.ownerDocument.body:e,a.stateNode),Il(e)):o0(yt,a.stateNode));break;case 4:o=yt,s=sn,yt=a.stateNode.containerInfo,sn=!0,$r(e,t,a),yt=o,sn=s;break;case 0:case 11:case 14:case 15:wt||ia(2,a,t),wt||ia(4,a,t),$r(e,t,a);break;case 1:wt||(ir(a,t),o=a.stateNode,typeof o.componentWillUnmount=="function"&&dg(a,t,o)),$r(e,t,a);break;case 21:$r(e,t,a);break;case 22:wt=(o=wt)||a.memoizedState!==null,$r(e,t,a),wt=o;break;default:$r(e,t,a)}}function Sg(e,t){if(t.memoizedState===null&&(e=t.alternate,e!==null&&(e=e.memoizedState,e!==null&&(e=e.dehydrated,e!==null))))try{Il(e)}catch(a){ft(t,t.return,a)}}function FT(e){switch(e.tag){case 13:case 19:var t=e.stateNode;return t===null&&(t=e.stateNode=new vg),t;case 22:return e=e.stateNode,t=e._retryCache,t===null&&(t=e._retryCache=new vg),t;default:throw Error(l(435,e.tag))}}function Ef(e,t){var a=FT(e);t.forEach(function(o){var s=a_.bind(null,e,o);a.has(o)||(a.add(o),o.then(s,s))})}function gn(e,t){var a=t.deletions;if(a!==null)for(var o=0;o<a.length;o++){var s=a[o],f=e,v=t,b=v;e:for(;b!==null;){switch(b.tag){case 27:if(pa(b.type)){yt=b.stateNode,sn=!1;break e}break;case 5:yt=b.stateNode,sn=!1;break e;case 3:case 4:yt=b.stateNode.containerInfo,sn=!0;break e}b=b.return}if(yt===null)throw Error(l(160));bg(f,v,s),yt=null,sn=!1,f=s.alternate,f!==null&&(f.return=null),s.return=null}if(t.subtreeFlags&13878)for(t=t.child;t!==null;)xg(t,e),t=t.sibling}var Zn=null;function xg(e,t){var a=e.alternate,o=e.flags;switch(e.tag){case 0:case 11:case 14:case 15:gn(t,e),bn(e),o&4&&(ia(3,e,e.return),jl(3,e),ia(5,e,e.return));break;case 1:gn(t,e),bn(e),o&512&&(wt||a===null||ir(a,a.return)),o&64&&Br&&(e=e.updateQueue,e!==null&&(o=e.callbacks,o!==null&&(a=e.shared.hiddenCallbacks,e.shared.hiddenCallbacks=a===null?o:a.concat(o))));break;case 26:var s=Zn;if(gn(t,e),bn(e),o&512&&(wt||a===null||ir(a,a.return)),o&4){var f=a!==null?a.memoizedState:null;if(o=e.memoizedState,a===null)if(o===null)if(e.stateNode===null){e:{o=e.type,a=e.memoizedProps,s=s.ownerDocument||s;t:switch(o){case"title":f=s.getElementsByTagName("title")[0],(!f||f[wn]||f[At]||f.namespaceURI==="http://www.w3.org/2000/svg"||f.hasAttribute("itemprop"))&&(f=s.createElement(o),s.head.insertBefore(f,s.querySelector("head > title"))),Zt(f,o,a),f[At]=e,ct(f),o=f;break e;case"link":var v=y0("link","href",s).get(o+(a.href||""));if(v){for(var b=0;b<v.length;b++)if(f=v[b],f.getAttribute("href")===(a.href==null||a.href===""?null:a.href)&&f.getAttribute("rel")===(a.rel==null?null:a.rel)&&f.getAttribute("title")===(a.title==null?null:a.title)&&f.getAttribute("crossorigin")===(a.crossOrigin==null?null:a.crossOrigin)){v.splice(b,1);break t}}f=s.createElement(o),Zt(f,o,a),s.head.appendChild(f);break;case"meta":if(v=y0("meta","content",s).get(o+(a.content||""))){for(b=0;b<v.length;b++)if(f=v[b],f.getAttribute("content")===(a.content==null?null:""+a.content)&&f.getAttribute("name")===(a.name==null?null:a.name)&&f.getAttribute("property")===(a.property==null?null:a.property)&&f.getAttribute("http-equiv")===(a.httpEquiv==null?null:a.httpEquiv)&&f.getAttribute("charset")===(a.charSet==null?null:a.charSet)){v.splice(b,1);break t}}f=s.createElement(o),Zt(f,o,a),s.head.appendChild(f);break;default:throw Error(l(468,o))}f[At]=e,ct(f),o=f}e.stateNode=o}else v0(s,e.type,e.stateNode);else e.stateNode=h0(s,o,e.memoizedProps);else f!==o?(f===null?a.stateNode!==null&&(a=a.stateNode,a.parentNode.removeChild(a)):f.count--,o===null?v0(s,e.type,e.stateNode):h0(s,o,e.memoizedProps)):o===null&&e.stateNode!==null&&gf(e,e.memoizedProps,a.memoizedProps)}break;case 27:gn(t,e),bn(e),o&512&&(wt||a===null||ir(a,a.return)),a!==null&&o&4&&gf(e,e.memoizedProps,a.memoizedProps);break;case 5:if(gn(t,e),bn(e),o&512&&(wt||a===null||ir(a,a.return)),e.flags&32){s=e.stateNode;try{ri(s,"")}catch(K){ft(e,e.return,K)}}o&4&&e.stateNode!=null&&(s=e.memoizedProps,gf(e,s,a!==null?a.memoizedProps:s)),o&1024&&(xf=!0);break;case 6:if(gn(t,e),bn(e),o&4){if(e.stateNode===null)throw Error(l(162));o=e.memoizedProps,a=e.stateNode;try{a.nodeValue=o}catch(K){ft(e,e.return,K)}}break;case 3:if(Lu=null,s=Zn,Zn=zu(t.containerInfo),gn(t,e),Zn=s,bn(e),o&4&&a!==null&&a.memoizedState.isDehydrated)try{Il(t.containerInfo)}catch(K){ft(e,e.return,K)}xf&&(xf=!1,Eg(e));break;case 4:o=Zn,Zn=zu(e.stateNode.containerInfo),gn(t,e),bn(e),Zn=o;break;case 12:gn(t,e),bn(e);break;case 13:gn(t,e),bn(e),e.child.flags&8192&&e.memoizedState!==null!=(a!==null&&a.memoizedState!==null)&&(wf=Me()),o&4&&(o=e.updateQueue,o!==null&&(e.updateQueue=null,Ef(e,o)));break;case 22:s=e.memoizedState!==null;var w=a!==null&&a.memoizedState!==null,P=Br,J=wt;if(Br=P||s,wt=J||w,gn(t,e),wt=J,Br=P,bn(e),o&8192)e:for(t=e.stateNode,t._visibility=s?t._visibility&-2:t._visibility|1,s&&(a===null||w||Br||wt||Ya(e)),a=null,t=e;;){if(t.tag===5||t.tag===26){if(a===null){w=a=t;try{if(f=w.stateNode,s)v=f.style,typeof v.setProperty=="function"?v.setProperty("display","none","important"):v.display="none";else{b=w.stateNode;var ne=w.memoizedProps.style,Q=ne!=null&&ne.hasOwnProperty("display")?ne.display:null;b.style.display=Q==null||typeof Q=="boolean"?"":(""+Q).trim()}}catch(K){ft(w,w.return,K)}}}else if(t.tag===6){if(a===null){w=t;try{w.stateNode.nodeValue=s?"":w.memoizedProps}catch(K){ft(w,w.return,K)}}}else if((t.tag!==22&&t.tag!==23||t.memoizedState===null||t===e)&&t.child!==null){t.child.return=t,t=t.child;continue}if(t===e)break e;for(;t.sibling===null;){if(t.return===null||t.return===e)break e;a===t&&(a=null),t=t.return}a===t&&(a=null),t.sibling.return=t.return,t=t.sibling}o&4&&(o=e.updateQueue,o!==null&&(a=o.retryQueue,a!==null&&(o.retryQueue=null,Ef(e,a))));break;case 19:gn(t,e),bn(e),o&4&&(o=e.updateQueue,o!==null&&(e.updateQueue=null,Ef(e,o)));break;case 30:break;case 21:break;default:gn(t,e),bn(e)}}function bn(e){var t=e.flags;if(t&2){try{for(var a,o=e.return;o!==null;){if(hg(o)){a=o;break}o=o.return}if(a==null)throw Error(l(160));switch(a.tag){case 27:var s=a.stateNode,f=bf(e);Tu(e,f,s);break;case 5:var v=a.stateNode;a.flags&32&&(ri(v,""),a.flags&=-33);var b=bf(e);Tu(e,b,v);break;case 3:case 4:var w=a.stateNode.containerInfo,P=bf(e);Sf(e,P,w);break;default:throw Error(l(161))}}catch(J){ft(e,e.return,J)}e.flags&=-3}t&4096&&(e.flags&=-4097)}function Eg(e){if(e.subtreeFlags&1024)for(e=e.child;e!==null;){var t=e;Eg(t),t.tag===5&&t.flags&1024&&t.stateNode.reset(),e=e.sibling}}function la(e,t){if(t.subtreeFlags&8772)for(t=t.child;t!==null;)mg(e,t.alternate,t),t=t.sibling}function Ya(e){for(e=e.child;e!==null;){var t=e;switch(t.tag){case 0:case 11:case 14:case 15:ia(4,t,t.return),Ya(t);break;case 1:ir(t,t.return);var a=t.stateNode;typeof a.componentWillUnmount=="function"&&dg(t,t.return,a),Ya(t);break;case 27:Yl(t.stateNode);case 26:case 5:ir(t,t.return),Ya(t);break;case 22:t.memoizedState===null&&Ya(t);break;case 30:Ya(t);break;default:Ya(t)}e=e.sibling}}function oa(e,t,a){for(a=a&&(t.subtreeFlags&8772)!==0,t=t.child;t!==null;){var o=t.alternate,s=e,f=t,v=f.flags;switch(f.tag){case 0:case 11:case 15:oa(s,f,a),jl(4,f);break;case 1:if(oa(s,f,a),o=f,s=o.stateNode,typeof s.componentDidMount=="function")try{s.componentDidMount()}catch(P){ft(o,o.return,P)}if(o=f,s=o.updateQueue,s!==null){var b=o.stateNode;try{var w=s.shared.hiddenCallbacks;if(w!==null)for(s.shared.hiddenCallbacks=null,s=0;s<w.length;s++)Iv(w[s],b)}catch(P){ft(o,o.return,P)}}a&&v&64&&fg(f),Bl(f,f.return);break;case 27:yg(f);case 26:case 5:oa(s,f,a),a&&o===null&&v&4&&pg(f),Bl(f,f.return);break;case 12:oa(s,f,a);break;case 13:oa(s,f,a),a&&v&4&&Sg(s,f);break;case 22:f.memoizedState===null&&oa(s,f,a),Bl(f,f.return);break;case 30:break;default:oa(s,f,a)}t=t.sibling}}function Of(e,t){var a=null;e!==null&&e.memoizedState!==null&&e.memoizedState.cachePool!==null&&(a=e.memoizedState.cachePool.pool),e=null,t.memoizedState!==null&&t.memoizedState.cachePool!==null&&(e=t.memoizedState.cachePool.pool),e!==a&&(e!=null&&e.refCount++,a!=null&&bl(a))}function Tf(e,t){e=null,t.alternate!==null&&(e=t.alternate.memoizedState.cache),t=t.memoizedState.cache,t!==e&&(t.refCount++,e!=null&&bl(e))}function lr(e,t,a,o){if(t.subtreeFlags&10256)for(t=t.child;t!==null;)Og(e,t,a,o),t=t.sibling}function Og(e,t,a,o){var s=t.flags;switch(t.tag){case 0:case 11:case 15:lr(e,t,a,o),s&2048&&jl(9,t);break;case 1:lr(e,t,a,o);break;case 3:lr(e,t,a,o),s&2048&&(e=null,t.alternate!==null&&(e=t.alternate.memoizedState.cache),t=t.memoizedState.cache,t!==e&&(t.refCount++,e!=null&&bl(e)));break;case 12:if(s&2048){lr(e,t,a,o),e=t.stateNode;try{var f=t.memoizedProps,v=f.id,b=f.onPostCommit;typeof b=="function"&&b(v,t.alternate===null?"mount":"update",e.passiveEffectDuration,-0)}catch(w){ft(t,t.return,w)}}else lr(e,t,a,o);break;case 13:lr(e,t,a,o);break;case 23:break;case 22:f=t.stateNode,v=t.alternate,t.memoizedState!==null?f._visibility&2?lr(e,t,a,o):$l(e,t):f._visibility&2?lr(e,t,a,o):(f._visibility|=2,Ei(e,t,a,o,(t.subtreeFlags&10256)!==0)),s&2048&&Of(v,t);break;case 24:lr(e,t,a,o),s&2048&&Tf(t.alternate,t);break;default:lr(e,t,a,o)}}function Ei(e,t,a,o,s){for(s=s&&(t.subtreeFlags&10256)!==0,t=t.child;t!==null;){var f=e,v=t,b=a,w=o,P=v.flags;switch(v.tag){case 0:case 11:case 15:Ei(f,v,b,w,s),jl(8,v);break;case 23:break;case 22:var J=v.stateNode;v.memoizedState!==null?J._visibility&2?Ei(f,v,b,w,s):$l(f,v):(J._visibility|=2,Ei(f,v,b,w,s)),s&&P&2048&&Of(v.alternate,v);break;case 24:Ei(f,v,b,w,s),s&&P&2048&&Tf(v.alternate,v);break;default:Ei(f,v,b,w,s)}t=t.sibling}}function $l(e,t){if(t.subtreeFlags&10256)for(t=t.child;t!==null;){var a=e,o=t,s=o.flags;switch(o.tag){case 22:$l(a,o),s&2048&&Of(o.alternate,o);break;case 24:$l(a,o),s&2048&&Tf(o.alternate,o);break;default:$l(a,o)}t=t.sibling}}var ql=8192;function Oi(e){if(e.subtreeFlags&ql)for(e=e.child;e!==null;)Tg(e),e=e.sibling}function Tg(e){switch(e.tag){case 26:Oi(e),e.flags&ql&&e.memoizedState!==null&&B_(Zn,e.memoizedState,e.memoizedProps);break;case 5:Oi(e);break;case 3:case 4:var t=Zn;Zn=zu(e.stateNode.containerInfo),Oi(e),Zn=t;break;case 22:e.memoizedState===null&&(t=e.alternate,t!==null&&t.memoizedState!==null?(t=ql,ql=16777216,Oi(e),ql=t):Oi(e));break;default:Oi(e)}}function _g(e){var t=e.alternate;if(t!==null&&(e=t.child,e!==null)){t.child=null;do t=e.sibling,e.sibling=null,e=t;while(e!==null)}}function zl(e){var t=e.deletions;if((e.flags&16)!==0){if(t!==null)for(var a=0;a<t.length;a++){var o=t[a];Xt=o,Rg(o,e)}_g(e)}if(e.subtreeFlags&10256)for(e=e.child;e!==null;)Ag(e),e=e.sibling}function Ag(e){switch(e.tag){case 0:case 11:case 15:zl(e),e.flags&2048&&ia(9,e,e.return);break;case 3:zl(e);break;case 12:zl(e);break;case 22:var t=e.stateNode;e.memoizedState!==null&&t._visibility&2&&(e.return===null||e.return.tag!==13)?(t._visibility&=-3,_u(e)):zl(e);break;default:zl(e)}}function _u(e){var t=e.deletions;if((e.flags&16)!==0){if(t!==null)for(var a=0;a<t.length;a++){var o=t[a];Xt=o,Rg(o,e)}_g(e)}for(e=e.child;e!==null;){switch(t=e,t.tag){case 0:case 11:case 15:ia(8,t,t.return),_u(t);break;case 22:a=t.stateNode,a._visibility&2&&(a._visibility&=-3,_u(t));break;default:_u(t)}e=e.sibling}}function Rg(e,t){for(;Xt!==null;){var a=Xt;switch(a.tag){case 0:case 11:case 15:ia(8,a,t);break;case 23:case 22:if(a.memoizedState!==null&&a.memoizedState.cachePool!==null){var o=a.memoizedState.cachePool.pool;o!=null&&o.refCount++}break;case 24:bl(a.memoizedState.cache)}if(o=a.child,o!==null)o.return=a,Xt=o;else e:for(a=e;Xt!==null;){o=Xt;var s=o.sibling,f=o.return;if(gg(o),o===a){Xt=null;break e}if(s!==null){s.return=f,Xt=s;break e}Xt=f}}}var ZT={getCacheForType:function(e){var t=Wt(Lt),a=t.data.get(e);return a===void 0&&(a=e(),t.data.set(e,a)),a}},IT=typeof WeakMap=="function"?WeakMap:Map,at=0,ht=null,He=null,Pe=0,it=0,Sn=null,ua=!1,Ti=!1,_f=!1,qr=0,Et=0,sa=0,Va=0,Af=0,zn=0,_i=0,kl=null,cn=null,Rf=!1,wf=0,Au=1/0,Ru=null,ca=null,Ft=0,fa=null,Ai=null,Ri=0,Cf=0,Nf=null,wg=null,Ll=0,Mf=null;function xn(){if((at&2)!==0&&Pe!==0)return Pe&-Pe;if(H.T!==null){var e=hi;return e!==0?e:kf()}return Vt()}function Cg(){zn===0&&(zn=(Pe&536870912)===0||Je?Qe():536870912);var e=qn.current;return e!==null&&(e.flags|=32),zn}function En(e,t,a){(e===ht&&(it===2||it===9)||e.cancelPendingCommit!==null)&&(wi(e,0),da(e,Pe,zn,!1)),Yt(e,a),((at&2)===0||e!==ht)&&(e===ht&&((at&2)===0&&(Va|=a),Et===4&&da(e,Pe,zn,!1)),or(e))}function Ng(e,t,a){if((at&6)!==0)throw Error(l(327));var o=!a&&(t&124)===0&&(t&e.expiredLanes)===0||V(e,t),s=o?e_(e,t):Bf(e,t,!0),f=o;do{if(s===0){Ti&&!o&&da(e,t,0,!1);break}else{if(a=e.current.alternate,f&&!WT(a)){s=Bf(e,t,!1),f=!1;continue}if(s===2){if(f=t,e.errorRecoveryDisabledLanes&f)var v=0;else v=e.pendingLanes&-536870913,v=v!==0?v:v&536870912?536870912:0;if(v!==0){t=v;e:{var b=e;s=kl;var w=b.current.memoizedState.isDehydrated;if(w&&(wi(b,v).flags|=256),v=Bf(b,v,!1),v!==2){if(_f&&!w){b.errorRecoveryDisabledLanes|=f,Va|=f,s=4;break e}f=cn,cn=s,f!==null&&(cn===null?cn=f:cn.push.apply(cn,f))}s=v}if(f=!1,s!==2)continue}}if(s===1){wi(e,0),da(e,t,0,!0);break}e:{switch(o=e,f=s,f){case 0:case 1:throw Error(l(345));case 4:if((t&4194048)!==t)break;case 6:da(o,t,zn,!ua);break e;case 2:cn=null;break;case 3:case 5:break;default:throw Error(l(329))}if((t&62914560)===t&&(s=wf+300-Me(),10<s)){if(da(o,t,zn,!ua),k(o,0,!0)!==0)break e;o.timeoutHandle=i0(Mg.bind(null,o,a,cn,Ru,Rf,t,zn,Va,_i,ua,f,2,-0,0),s);break e}Mg(o,a,cn,Ru,Rf,t,zn,Va,_i,ua,f,0,-0,0)}}break}while(!0);or(e)}function Mg(e,t,a,o,s,f,v,b,w,P,J,ne,Q,K){if(e.timeoutHandle=-1,ne=t.subtreeFlags,(ne&8192||(ne&16785408)===16785408)&&(Xl={stylesheets:null,count:0,unsuspend:j_},Tg(t),ne=$_(),ne!==null)){e.cancelPendingCommit=ne(kg.bind(null,e,t,f,a,o,s,v,b,w,J,1,Q,K)),da(e,f,v,!P);return}kg(e,t,f,a,o,s,v,b,w)}function WT(e){for(var t=e;;){var a=t.tag;if((a===0||a===11||a===15)&&t.flags&16384&&(a=t.updateQueue,a!==null&&(a=a.stores,a!==null)))for(var o=0;o<a.length;o++){var s=a[o],f=s.getSnapshot;s=s.value;try{if(!vn(f(),s))return!1}catch{return!1}}if(a=t.child,t.subtreeFlags&16384&&a!==null)a.return=t,t=a;else{if(t===e)break;for(;t.sibling===null;){if(t.return===null||t.return===e)return!0;t=t.return}t.sibling.return=t.return,t=t.sibling}}return!0}function da(e,t,a,o){t&=~Af,t&=~Va,e.suspendedLanes|=t,e.pingedLanes&=~t,o&&(e.warmLanes|=t),o=e.expirationTimes;for(var s=t;0<s;){var f=31-se(s),v=1<<f;o[f]=-1,s&=~v}a!==0&&zt(e,a,t)}function wu(){return(at&6)===0?(Ul(0),!1):!0}function Df(){if(He!==null){if(it===0)var e=He.return;else e=He,wr=ka=null,Kc(e),Si=null,Nl=0,e=He;for(;e!==null;)cg(e.alternate,e),e=e.return;He=null}}function wi(e,t){var a=e.timeoutHandle;a!==-1&&(e.timeoutHandle=-1,v_(a)),a=e.cancelPendingCommit,a!==null&&(e.cancelPendingCommit=null,a()),Df(),ht=e,He=a=_r(e.current,null),Pe=t,it=0,Sn=null,ua=!1,Ti=V(e,t),_f=!1,_i=zn=Af=Va=sa=Et=0,cn=kl=null,Rf=!1,(t&8)!==0&&(t|=t&32);var o=e.entangledLanes;if(o!==0)for(e=e.entanglements,o&=t;0<o;){var s=31-se(o),f=1<<s;t|=e[s],o&=~f}return qr=t,Zo(),a}function Dg(e,t){ke=null,H.H=yu,t===xl||t===iu?(t=Fv(),it=3):t===Xv?(t=Fv(),it=4):it=t===Zm?8:t!==null&&typeof t=="object"&&typeof t.then=="function"?6:1,Sn=t,He===null&&(Et=1,Su(e,Dn(t,e.current)))}function jg(){var e=H.H;return H.H=yu,e===null?yu:e}function Bg(){var e=H.A;return H.A=ZT,e}function jf(){Et=4,ua||(Pe&4194048)!==Pe&&qn.current!==null||(Ti=!0),(sa&134217727)===0&&(Va&134217727)===0||ht===null||da(ht,Pe,zn,!1)}function Bf(e,t,a){var o=at;at|=2;var s=jg(),f=Bg();(ht!==e||Pe!==t)&&(Ru=null,wi(e,t)),t=!1;var v=Et;e:do try{if(it!==0&&He!==null){var b=He,w=Sn;switch(it){case 8:Df(),v=6;break e;case 3:case 2:case 9:case 6:qn.current===null&&(t=!0);var P=it;if(it=0,Sn=null,Ci(e,b,w,P),a&&Ti){v=0;break e}break;default:P=it,it=0,Sn=null,Ci(e,b,w,P)}}JT(),v=Et;break}catch(J){Dg(e,J)}while(!0);return t&&e.shellSuspendCounter++,wr=ka=null,at=o,H.H=s,H.A=f,He===null&&(ht=null,Pe=0,Zo()),v}function JT(){for(;He!==null;)$g(He)}function e_(e,t){var a=at;at|=2;var o=jg(),s=Bg();ht!==e||Pe!==t?(Ru=null,Au=Me()+500,wi(e,t)):Ti=V(e,t);e:do try{if(it!==0&&He!==null){t=He;var f=Sn;t:switch(it){case 1:it=0,Sn=null,Ci(e,t,f,1);break;case 2:case 9:if(Qv(f)){it=0,Sn=null,qg(t);break}t=function(){it!==2&&it!==9||ht!==e||(it=7),or(e)},f.then(t,t);break e;case 3:it=7;break e;case 4:it=5;break e;case 7:Qv(f)?(it=0,Sn=null,qg(t)):(it=0,Sn=null,Ci(e,t,f,7));break;case 5:var v=null;switch(He.tag){case 26:v=He.memoizedState;case 5:case 27:var b=He;if(!v||m0(v)){it=0,Sn=null;var w=b.sibling;if(w!==null)He=w;else{var P=b.return;P!==null?(He=P,Cu(P)):He=null}break t}}it=0,Sn=null,Ci(e,t,f,5);break;case 6:it=0,Sn=null,Ci(e,t,f,6);break;case 8:Df(),Et=6;break e;default:throw Error(l(462))}}t_();break}catch(J){Dg(e,J)}while(!0);return wr=ka=null,H.H=o,H.A=s,at=a,He!==null?0:(ht=null,Pe=0,Zo(),Et)}function t_(){for(;He!==null&&!ye();)$g(He)}function $g(e){var t=ug(e.alternate,e,qr);e.memoizedProps=e.pendingProps,t===null?Cu(e):He=t}function qg(e){var t=e,a=t.alternate;switch(t.tag){case 15:case 0:t=ng(a,t,t.pendingProps,t.type,void 0,Pe);break;case 11:t=ng(a,t,t.pendingProps,t.type.render,t.ref,Pe);break;case 5:Kc(t);default:cg(a,t),t=He=zv(t,qr),t=ug(a,t,qr)}e.memoizedProps=e.pendingProps,t===null?Cu(e):He=t}function Ci(e,t,a,o){wr=ka=null,Kc(t),Si=null,Nl=0;var s=t.return;try{if(VT(e,s,t,a,Pe)){Et=1,Su(e,Dn(a,e.current)),He=null;return}}catch(f){if(s!==null)throw He=s,f;Et=1,Su(e,Dn(a,e.current)),He=null;return}t.flags&32768?(Je||o===1?e=!0:Ti||(Pe&536870912)!==0?e=!1:(ua=e=!0,(o===2||o===9||o===3||o===6)&&(o=qn.current,o!==null&&o.tag===13&&(o.flags|=16384))),zg(t,e)):Cu(t)}function Cu(e){var t=e;do{if((t.flags&32768)!==0){zg(t,ua);return}e=t.return;var a=XT(t.alternate,t,qr);if(a!==null){He=a;return}if(t=t.sibling,t!==null){He=t;return}He=t=e}while(t!==null);Et===0&&(Et=5)}function zg(e,t){do{var a=QT(e.alternate,e);if(a!==null){a.flags&=32767,He=a;return}if(a=e.return,a!==null&&(a.flags|=32768,a.subtreeFlags=0,a.deletions=null),!t&&(e=e.sibling,e!==null)){He=e;return}He=e=a}while(e!==null);Et=6,He=null}function kg(e,t,a,o,s,f,v,b,w){e.cancelPendingCommit=null;do Nu();while(Ft!==0);if((at&6)!==0)throw Error(l(327));if(t!==null){if(t===e.current)throw Error(l(177));if(f=t.lanes|t.childLanes,f|=Oc,hn(e,a,f,v,b,w),e===ht&&(He=ht=null,Pe=0),Ai=t,fa=e,Ri=a,Cf=f,Nf=s,wg=o,(t.subtreeFlags&10256)!==0||(t.flags&10256)!==0?(e.callbackNode=null,e.callbackPriority=0,i_(Ze,function(){return Yg(),null})):(e.callbackNode=null,e.callbackPriority=0),o=(t.flags&13878)!==0,(t.subtreeFlags&13878)!==0||o){o=H.T,H.T=null,s=I.p,I.p=2,v=at,at|=4;try{KT(e,t,a)}finally{at=v,I.p=s,H.T=o}}Ft=1,Lg(),Ug(),Hg()}}function Lg(){if(Ft===1){Ft=0;var e=fa,t=Ai,a=(t.flags&13878)!==0;if((t.subtreeFlags&13878)!==0||a){a=H.T,H.T=null;var o=I.p;I.p=2;var s=at;at|=4;try{xg(t,e);var f=Xf,v=Rv(e.containerInfo),b=f.focusedElem,w=f.selectionRange;if(v!==b&&b&&b.ownerDocument&&Av(b.ownerDocument.documentElement,b)){if(w!==null&&gc(b)){var P=w.start,J=w.end;if(J===void 0&&(J=P),"selectionStart"in b)b.selectionStart=P,b.selectionEnd=Math.min(J,b.value.length);else{var ne=b.ownerDocument||document,Q=ne&&ne.defaultView||window;if(Q.getSelection){var K=Q.getSelection(),Ne=b.textContent.length,Re=Math.min(w.start,Ne),ut=w.end===void 0?Re:Math.min(w.end,Ne);!K.extend&&Re>ut&&(v=ut,ut=Re,Re=v);var U=_v(b,Re),D=_v(b,ut);if(U&&D&&(K.rangeCount!==1||K.anchorNode!==U.node||K.anchorOffset!==U.offset||K.focusNode!==D.node||K.focusOffset!==D.offset)){var G=ne.createRange();G.setStart(U.node,U.offset),K.removeAllRanges(),Re>ut?(K.addRange(G),K.extend(D.node,D.offset)):(G.setEnd(D.node,D.offset),K.addRange(G))}}}}for(ne=[],K=b;K=K.parentNode;)K.nodeType===1&&ne.push({element:K,left:K.scrollLeft,top:K.scrollTop});for(typeof b.focus=="function"&&b.focus(),b=0;b<ne.length;b++){var ee=ne[b];ee.element.scrollLeft=ee.left,ee.element.scrollTop=ee.top}}Gu=!!Pf,Xf=Pf=null}finally{at=s,I.p=o,H.T=a}}e.current=t,Ft=2}}function Ug(){if(Ft===2){Ft=0;var e=fa,t=Ai,a=(t.flags&8772)!==0;if((t.subtreeFlags&8772)!==0||a){a=H.T,H.T=null;var o=I.p;I.p=2;var s=at;at|=4;try{mg(e,t.alternate,t)}finally{at=s,I.p=o,H.T=a}}Ft=3}}function Hg(){if(Ft===4||Ft===3){Ft=0,je();var e=fa,t=Ai,a=Ri,o=wg;(t.subtreeFlags&10256)!==0||(t.flags&10256)!==0?Ft=5:(Ft=0,Ai=fa=null,Gg(e,e.pendingLanes));var s=e.pendingLanes;if(s===0&&(ca=null),ln(a),t=t.stateNode,rt&&typeof rt.onCommitFiberRoot=="function")try{rt.onCommitFiberRoot(_t,t,void 0,(t.current.flags&128)===128)}catch{}if(o!==null){t=H.T,s=I.p,I.p=2,H.T=null;try{for(var f=e.onRecoverableError,v=0;v<o.length;v++){var b=o[v];f(b.value,{componentStack:b.stack})}}finally{H.T=t,I.p=s}}(Ri&3)!==0&&Nu(),or(e),s=e.pendingLanes,(a&4194090)!==0&&(s&42)!==0?e===Mf?Ll++:(Ll=0,Mf=e):Ll=0,Ul(0)}}function Gg(e,t){(e.pooledCacheLanes&=t)===0&&(t=e.pooledCache,t!=null&&(e.pooledCache=null,bl(t)))}function Nu(e){return Lg(),Ug(),Hg(),Yg()}function Yg(){if(Ft!==5)return!1;var e=fa,t=Cf;Cf=0;var a=ln(Ri),o=H.T,s=I.p;try{I.p=32>a?32:a,H.T=null,a=Nf,Nf=null;var f=fa,v=Ri;if(Ft=0,Ai=fa=null,Ri=0,(at&6)!==0)throw Error(l(331));var b=at;if(at|=4,Ag(f.current),Og(f,f.current,v,a),at=b,Ul(0,!1),rt&&typeof rt.onPostCommitFiberRoot=="function")try{rt.onPostCommitFiberRoot(_t,f)}catch{}return!0}finally{I.p=s,H.T=o,Gg(e,t)}}function Vg(e,t,a){t=Dn(a,t),t=sf(e.stateNode,t,2),e=ta(e,t,2),e!==null&&(Yt(e,2),or(e))}function ft(e,t,a){if(e.tag===3)Vg(e,e,a);else for(;t!==null;){if(t.tag===3){Vg(t,e,a);break}else if(t.tag===1){var o=t.stateNode;if(typeof t.type.getDerivedStateFromError=="function"||typeof o.componentDidCatch=="function"&&(ca===null||!ca.has(o))){e=Dn(a,e),a=Km(2),o=ta(t,a,2),o!==null&&(Fm(a,o,t,e),Yt(o,2),or(o));break}}t=t.return}}function $f(e,t,a){var o=e.pingCache;if(o===null){o=e.pingCache=new IT;var s=new Set;o.set(t,s)}else s=o.get(t),s===void 0&&(s=new Set,o.set(t,s));s.has(a)||(_f=!0,s.add(a),e=n_.bind(null,e,t,a),t.then(e,e))}function n_(e,t,a){var o=e.pingCache;o!==null&&o.delete(t),e.pingedLanes|=e.suspendedLanes&a,e.warmLanes&=~a,ht===e&&(Pe&a)===a&&(Et===4||Et===3&&(Pe&62914560)===Pe&&300>Me()-wf?(at&2)===0&&wi(e,0):Af|=a,_i===Pe&&(_i=0)),or(e)}function Pg(e,t){t===0&&(t=Ie()),e=ci(e,t),e!==null&&(Yt(e,t),or(e))}function r_(e){var t=e.memoizedState,a=0;t!==null&&(a=t.retryLane),Pg(e,a)}function a_(e,t){var a=0;switch(e.tag){case 13:var o=e.stateNode,s=e.memoizedState;s!==null&&(a=s.retryLane);break;case 19:o=e.stateNode;break;case 22:o=e.stateNode._retryCache;break;default:throw Error(l(314))}o!==null&&o.delete(t),Pg(e,a)}function i_(e,t){return ve(e,t)}var Mu=null,Ni=null,qf=!1,Du=!1,zf=!1,Pa=0;function or(e){e!==Ni&&e.next===null&&(Ni===null?Mu=Ni=e:Ni=Ni.next=e),Du=!0,qf||(qf=!0,o_())}function Ul(e,t){if(!zf&&Du){zf=!0;do for(var a=!1,o=Mu;o!==null;){if(e!==0){var s=o.pendingLanes;if(s===0)var f=0;else{var v=o.suspendedLanes,b=o.pingedLanes;f=(1<<31-se(42|e)+1)-1,f&=s&~(v&~b),f=f&201326741?f&201326741|1:f?f|2:0}f!==0&&(a=!0,Fg(o,f))}else f=Pe,f=k(o,o===ht?f:0,o.cancelPendingCommit!==null||o.timeoutHandle!==-1),(f&3)===0||V(o,f)||(a=!0,Fg(o,f));o=o.next}while(a);zf=!1}}function l_(){Xg()}function Xg(){Du=qf=!1;var e=0;Pa!==0&&(y_()&&(e=Pa),Pa=0);for(var t=Me(),a=null,o=Mu;o!==null;){var s=o.next,f=Qg(o,t);f===0?(o.next=null,a===null?Mu=s:a.next=s,s===null&&(Ni=a)):(a=o,(e!==0||(f&3)!==0)&&(Du=!0)),o=s}Ul(e)}function Qg(e,t){for(var a=e.suspendedLanes,o=e.pingedLanes,s=e.expirationTimes,f=e.pendingLanes&-62914561;0<f;){var v=31-se(f),b=1<<v,w=s[v];w===-1?((b&a)===0||(b&o)!==0)&&(s[v]=qe(b,t)):w<=t&&(e.expiredLanes|=b),f&=~b}if(t=ht,a=Pe,a=k(e,e===t?a:0,e.cancelPendingCommit!==null||e.timeoutHandle!==-1),o=e.callbackNode,a===0||e===t&&(it===2||it===9)||e.cancelPendingCommit!==null)return o!==null&&o!==null&&Oe(o),e.callbackNode=null,e.callbackPriority=0;if((a&3)===0||V(e,a)){if(t=a&-a,t===e.callbackPriority)return t;switch(o!==null&&Oe(o),ln(a)){case 2:case 8:a=ze;break;case 32:a=Ze;break;case 268435456:a=$t;break;default:a=Ze}return o=Kg.bind(null,e),a=ve(a,o),e.callbackPriority=t,e.callbackNode=a,t}return o!==null&&o!==null&&Oe(o),e.callbackPriority=2,e.callbackNode=null,2}function Kg(e,t){if(Ft!==0&&Ft!==5)return e.callbackNode=null,e.callbackPriority=0,null;var a=e.callbackNode;if(Nu()&&e.callbackNode!==a)return null;var o=Pe;return o=k(e,e===ht?o:0,e.cancelPendingCommit!==null||e.timeoutHandle!==-1),o===0?null:(Ng(e,o,t),Qg(e,Me()),e.callbackNode!=null&&e.callbackNode===a?Kg.bind(null,e):null)}function Fg(e,t){if(Nu())return null;Ng(e,t,!0)}function o_(){m_(function(){(at&6)!==0?ve(Ht,l_):Xg()})}function kf(){return Pa===0&&(Pa=Qe()),Pa}function Zg(e){return e==null||typeof e=="symbol"||typeof e=="boolean"?null:typeof e=="function"?e:Yo(""+e)}function Ig(e,t){var a=t.ownerDocument.createElement("input");return a.name=t.name,a.value=t.value,e.id&&a.setAttribute("form",e.id),t.parentNode.insertBefore(a,t),e=new FormData(e),a.parentNode.removeChild(a),e}function u_(e,t,a,o,s){if(t==="submit"&&a&&a.stateNode===s){var f=Zg((s[St]||null).action),v=o.submitter;v&&(t=(t=v[St]||null)?Zg(t.formAction):v.getAttribute("formAction"),t!==null&&(f=t,v=null));var b=new Qo("action","action",null,o,s);e.push({event:b,listeners:[{instance:null,listener:function(){if(o.defaultPrevented){if(Pa!==0){var w=v?Ig(s,v):new FormData(s);rf(a,{pending:!0,data:w,method:s.method,action:f},null,w)}}else typeof f=="function"&&(b.preventDefault(),w=v?Ig(s,v):new FormData(s),rf(a,{pending:!0,data:w,method:s.method,action:f},f,w))},currentTarget:s}]})}}for(var Lf=0;Lf<Ec.length;Lf++){var Uf=Ec[Lf],s_=Uf.toLowerCase(),c_=Uf[0].toUpperCase()+Uf.slice(1);Fn(s_,"on"+c_)}Fn(Nv,"onAnimationEnd"),Fn(Mv,"onAnimationIteration"),Fn(Dv,"onAnimationStart"),Fn("dblclick","onDoubleClick"),Fn("focusin","onFocus"),Fn("focusout","onBlur"),Fn(RT,"onTransitionRun"),Fn(wT,"onTransitionStart"),Fn(CT,"onTransitionCancel"),Fn(jv,"onTransitionEnd"),Er("onMouseEnter",["mouseout","mouseover"]),Er("onMouseLeave",["mouseout","mouseover"]),Er("onPointerEnter",["pointerout","pointerover"]),Er("onPointerLeave",["pointerout","pointerover"]),xr("onChange","change click focusin focusout input keydown keyup selectionchange".split(" ")),xr("onSelect","focusout contextmenu dragend focusin keydown keyup mousedown mouseup selectionchange".split(" ")),xr("onBeforeInput",["compositionend","keypress","textInput","paste"]),xr("onCompositionEnd","compositionend focusout keydown keypress keyup mousedown".split(" ")),xr("onCompositionStart","compositionstart focusout keydown keypress keyup mousedown".split(" ")),xr("onCompositionUpdate","compositionupdate focusout keydown keypress keyup mousedown".split(" "));var Hl="abort canplay canplaythrough durationchange emptied encrypted ended error loadeddata loadedmetadata loadstart pause play playing progress ratechange resize seeked seeking stalled suspend timeupdate volumechange waiting".split(" "),f_=new Set("beforetoggle cancel close invalid load scroll scrollend toggle".split(" ").concat(Hl));function Wg(e,t){t=(t&4)!==0;for(var a=0;a<e.length;a++){var o=e[a],s=o.event;o=o.listeners;e:{var f=void 0;if(t)for(var v=o.length-1;0<=v;v--){var b=o[v],w=b.instance,P=b.currentTarget;if(b=b.listener,w!==f&&s.isPropagationStopped())break e;f=b,s.currentTarget=P;try{f(s)}catch(J){bu(J)}s.currentTarget=null,f=w}else for(v=0;v<o.length;v++){if(b=o[v],w=b.instance,P=b.currentTarget,b=b.listener,w!==f&&s.isPropagationStopped())break e;f=b,s.currentTarget=P;try{f(s)}catch(J){bu(J)}s.currentTarget=null,f=w}}}}function Ge(e,t){var a=t[nr];a===void 0&&(a=t[nr]=new Set);var o=e+"__bubble";a.has(o)||(Jg(t,e,2,!1),a.add(o))}function Hf(e,t,a){var o=0;t&&(o|=4),Jg(a,e,o,t)}var ju="_reactListening"+Math.random().toString(36).slice(2);function Gf(e){if(!e[ju]){e[ju]=!0,kt.forEach(function(a){a!=="selectionchange"&&(f_.has(a)||Hf(a,!1,e),Hf(a,!0,e))});var t=e.nodeType===9?e:e.ownerDocument;t===null||t[ju]||(t[ju]=!0,Hf("selectionchange",!1,t))}}function Jg(e,t,a,o){switch(O0(t)){case 2:var s=k_;break;case 8:s=L_;break;default:s=nd}a=s.bind(null,t,a,e),s=void 0,!sc||t!=="touchstart"&&t!=="touchmove"&&t!=="wheel"||(s=!0),o?s!==void 0?e.addEventListener(t,a,{capture:!0,passive:s}):e.addEventListener(t,a,!0):s!==void 0?e.addEventListener(t,a,{passive:s}):e.addEventListener(t,a,!1)}function Yf(e,t,a,o,s){var f=o;if((t&1)===0&&(t&2)===0&&o!==null)e:for(;;){if(o===null)return;var v=o.tag;if(v===3||v===4){var b=o.stateNode.containerInfo;if(b===s)break;if(v===4)for(v=o.return;v!==null;){var w=v.tag;if((w===3||w===4)&&v.stateNode.containerInfo===s)return;v=v.return}for(;b!==null;){if(v=Kn(b),v===null)return;if(w=v.tag,w===5||w===6||w===26||w===27){o=f=v;continue e}b=b.parentNode}}o=o.return}lv(function(){var P=f,J=oc(a),ne=[];e:{var Q=Bv.get(e);if(Q!==void 0){var K=Qo,Ne=e;switch(e){case"keypress":if(Po(a)===0)break e;case"keydown":case"keyup":K=iT;break;case"focusin":Ne="focus",K=pc;break;case"focusout":Ne="blur",K=pc;break;case"beforeblur":case"afterblur":K=pc;break;case"click":if(a.button===2)break e;case"auxclick":case"dblclick":case"mousedown":case"mousemove":case"mouseup":case"mouseout":case"mouseover":case"contextmenu":K=sv;break;case"drag":case"dragend":case"dragenter":case"dragexit":case"dragleave":case"dragover":case"dragstart":case"drop":K=QO;break;case"touchcancel":case"touchend":case"touchmove":case"touchstart":K=uT;break;case Nv:case Mv:case Dv:K=ZO;break;case jv:K=cT;break;case"scroll":case"scrollend":K=PO;break;case"wheel":K=dT;break;case"copy":case"cut":case"paste":K=WO;break;case"gotpointercapture":case"lostpointercapture":case"pointercancel":case"pointerdown":case"pointermove":case"pointerout":case"pointerover":case"pointerup":K=fv;break;case"toggle":case"beforetoggle":K=hT}var Re=(t&4)!==0,ut=!Re&&(e==="scroll"||e==="scrollend"),U=Re?Q!==null?Q+"Capture":null:Q;Re=[];for(var D=P,G;D!==null;){var ee=D;if(G=ee.stateNode,ee=ee.tag,ee!==5&&ee!==26&&ee!==27||G===null||U===null||(ee=ll(D,U),ee!=null&&Re.push(Gl(D,ee,G))),ut)break;D=D.return}0<Re.length&&(Q=new K(Q,Ne,null,a,J),ne.push({event:Q,listeners:Re}))}}if((t&7)===0){e:{if(Q=e==="mouseover"||e==="pointerover",K=e==="mouseout"||e==="pointerout",Q&&a!==lc&&(Ne=a.relatedTarget||a.fromElement)&&(Kn(Ne)||Ne[Rn]))break e;if((K||Q)&&(Q=J.window===J?J:(Q=J.ownerDocument)?Q.defaultView||Q.parentWindow:window,K?(Ne=a.relatedTarget||a.toElement,K=P,Ne=Ne?Kn(Ne):null,Ne!==null&&(ut=c(Ne),Re=Ne.tag,Ne!==ut||Re!==5&&Re!==27&&Re!==6)&&(Ne=null)):(K=null,Ne=P),K!==Ne)){if(Re=sv,ee="onMouseLeave",U="onMouseEnter",D="mouse",(e==="pointerout"||e==="pointerover")&&(Re=fv,ee="onPointerLeave",U="onPointerEnter",D="pointer"),ut=K==null?Q:pt(K),G=Ne==null?Q:pt(Ne),Q=new Re(ee,D+"leave",K,a,J),Q.target=ut,Q.relatedTarget=G,ee=null,Kn(J)===P&&(Re=new Re(U,D+"enter",Ne,a,J),Re.target=G,Re.relatedTarget=ut,ee=Re),ut=ee,K&&Ne)t:{for(Re=K,U=Ne,D=0,G=Re;G;G=Mi(G))D++;for(G=0,ee=U;ee;ee=Mi(ee))G++;for(;0<D-G;)Re=Mi(Re),D--;for(;0<G-D;)U=Mi(U),G--;for(;D--;){if(Re===U||U!==null&&Re===U.alternate)break t;Re=Mi(Re),U=Mi(U)}Re=null}else Re=null;K!==null&&e0(ne,Q,K,Re,!1),Ne!==null&&ut!==null&&e0(ne,ut,Ne,Re,!0)}}e:{if(Q=P?pt(P):window,K=Q.nodeName&&Q.nodeName.toLowerCase(),K==="select"||K==="input"&&Q.type==="file")var Se=bv;else if(mv(Q))if(Sv)Se=TT;else{Se=ET;var Le=xT}else K=Q.nodeName,!K||K.toLowerCase()!=="input"||Q.type!=="checkbox"&&Q.type!=="radio"?P&&ic(P.elementType)&&(Se=bv):Se=OT;if(Se&&(Se=Se(e,P))){gv(ne,Se,a,J);break e}Le&&Le(e,Q,P),e==="focusout"&&P&&Q.type==="number"&&P.memoizedProps.value!=null&&ac(Q,"number",Q.value)}switch(Le=P?pt(P):window,e){case"focusin":(mv(Le)||Le.contentEditable==="true")&&(oi=Le,bc=P,hl=null);break;case"focusout":hl=bc=oi=null;break;case"mousedown":Sc=!0;break;case"contextmenu":case"mouseup":case"dragend":Sc=!1,wv(ne,a,J);break;case"selectionchange":if(AT)break;case"keydown":case"keyup":wv(ne,a,J)}var _e;if(yc)e:{switch(e){case"compositionstart":var Ce="onCompositionStart";break e;case"compositionend":Ce="onCompositionEnd";break e;case"compositionupdate":Ce="onCompositionUpdate";break e}Ce=void 0}else li?yv(e,a)&&(Ce="onCompositionEnd"):e==="keydown"&&a.keyCode===229&&(Ce="onCompositionStart");Ce&&(dv&&a.locale!=="ko"&&(li||Ce!=="onCompositionStart"?Ce==="onCompositionEnd"&&li&&(_e=ov()):(Ir=J,cc="value"in Ir?Ir.value:Ir.textContent,li=!0)),Le=Bu(P,Ce),0<Le.length&&(Ce=new cv(Ce,e,null,a,J),ne.push({event:Ce,listeners:Le}),_e?Ce.data=_e:(_e=vv(a),_e!==null&&(Ce.data=_e)))),(_e=vT?mT(e,a):gT(e,a))&&(Ce=Bu(P,"onBeforeInput"),0<Ce.length&&(Le=new cv("onBeforeInput","beforeinput",null,a,J),ne.push({event:Le,listeners:Ce}),Le.data=_e)),u_(ne,e,P,a,J)}Wg(ne,t)})}function Gl(e,t,a){return{instance:e,listener:t,currentTarget:a}}function Bu(e,t){for(var a=t+"Capture",o=[];e!==null;){var s=e,f=s.stateNode;if(s=s.tag,s!==5&&s!==26&&s!==27||f===null||(s=ll(e,a),s!=null&&o.unshift(Gl(e,s,f)),s=ll(e,t),s!=null&&o.push(Gl(e,s,f))),e.tag===3)return o;e=e.return}return[]}function Mi(e){if(e===null)return null;do e=e.return;while(e&&e.tag!==5&&e.tag!==27);return e||null}function e0(e,t,a,o,s){for(var f=t._reactName,v=[];a!==null&&a!==o;){var b=a,w=b.alternate,P=b.stateNode;if(b=b.tag,w!==null&&w===o)break;b!==5&&b!==26&&b!==27||P===null||(w=P,s?(P=ll(a,f),P!=null&&v.unshift(Gl(a,P,w))):s||(P=ll(a,f),P!=null&&v.push(Gl(a,P,w)))),a=a.return}v.length!==0&&e.push({event:t,listeners:v})}var d_=/\r\n?/g,p_=/\u0000|\uFFFD/g;function t0(e){return(typeof e=="string"?e:""+e).replace(d_,`
`).replace(p_,"")}function n0(e,t){return t=t0(t),t0(e)===t}function $u(){}function ot(e,t,a,o,s,f){switch(a){case"children":typeof o=="string"?t==="body"||t==="textarea"&&o===""||ri(e,o):(typeof o=="number"||typeof o=="bigint")&&t!=="body"&&ri(e,""+o);break;case"className":Uo(e,"class",o);break;case"tabIndex":Uo(e,"tabindex",o);break;case"dir":case"role":case"viewBox":case"width":case"height":Uo(e,a,o);break;case"style":av(e,o,f);break;case"data":if(t!=="object"){Uo(e,"data",o);break}case"src":case"href":if(o===""&&(t!=="a"||a!=="href")){e.removeAttribute(a);break}if(o==null||typeof o=="function"||typeof o=="symbol"||typeof o=="boolean"){e.removeAttribute(a);break}o=Yo(""+o),e.setAttribute(a,o);break;case"action":case"formAction":if(typeof o=="function"){e.setAttribute(a,"javascript:throw new Error('A React form was unexpectedly submitted. If you called form.submit() manually, consider using form.requestSubmit() instead. If you\\'re trying to use event.stopPropagation() in a submit event handler, consider also calling event.preventDefault().')");break}else typeof f=="function"&&(a==="formAction"?(t!=="input"&&ot(e,t,"name",s.name,s,null),ot(e,t,"formEncType",s.formEncType,s,null),ot(e,t,"formMethod",s.formMethod,s,null),ot(e,t,"formTarget",s.formTarget,s,null)):(ot(e,t,"encType",s.encType,s,null),ot(e,t,"method",s.method,s,null),ot(e,t,"target",s.target,s,null)));if(o==null||typeof o=="symbol"||typeof o=="boolean"){e.removeAttribute(a);break}o=Yo(""+o),e.setAttribute(a,o);break;case"onClick":o!=null&&(e.onclick=$u);break;case"onScroll":o!=null&&Ge("scroll",e);break;case"onScrollEnd":o!=null&&Ge("scrollend",e);break;case"dangerouslySetInnerHTML":if(o!=null){if(typeof o!="object"||!("__html"in o))throw Error(l(61));if(a=o.__html,a!=null){if(s.children!=null)throw Error(l(60));e.innerHTML=a}}break;case"multiple":e.multiple=o&&typeof o!="function"&&typeof o!="symbol";break;case"muted":e.muted=o&&typeof o!="function"&&typeof o!="symbol";break;case"suppressContentEditableWarning":case"suppressHydrationWarning":case"defaultValue":case"defaultChecked":case"innerHTML":case"ref":break;case"autoFocus":break;case"xlinkHref":if(o==null||typeof o=="function"||typeof o=="boolean"||typeof o=="symbol"){e.removeAttribute("xlink:href");break}a=Yo(""+o),e.setAttributeNS("http://www.w3.org/1999/xlink","xlink:href",a);break;case"contentEditable":case"spellCheck":case"draggable":case"value":case"autoReverse":case"externalResourcesRequired":case"focusable":case"preserveAlpha":o!=null&&typeof o!="function"&&typeof o!="symbol"?e.setAttribute(a,""+o):e.removeAttribute(a);break;case"inert":case"allowFullScreen":case"async":case"autoPlay":case"controls":case"default":case"defer":case"disabled":case"disablePictureInPicture":case"disableRemotePlayback":case"formNoValidate":case"hidden":case"loop":case"noModule":case"noValidate":case"open":case"playsInline":case"readOnly":case"required":case"reversed":case"scoped":case"seamless":case"itemScope":o&&typeof o!="function"&&typeof o!="symbol"?e.setAttribute(a,""):e.removeAttribute(a);break;case"capture":case"download":o===!0?e.setAttribute(a,""):o!==!1&&o!=null&&typeof o!="function"&&typeof o!="symbol"?e.setAttribute(a,o):e.removeAttribute(a);break;case"cols":case"rows":case"size":case"span":o!=null&&typeof o!="function"&&typeof o!="symbol"&&!isNaN(o)&&1<=o?e.setAttribute(a,o):e.removeAttribute(a);break;case"rowSpan":case"start":o==null||typeof o=="function"||typeof o=="symbol"||isNaN(o)?e.removeAttribute(a):e.setAttribute(a,o);break;case"popover":Ge("beforetoggle",e),Ge("toggle",e),Lo(e,"popover",o);break;case"xlinkActuate":Or(e,"http://www.w3.org/1999/xlink","xlink:actuate",o);break;case"xlinkArcrole":Or(e,"http://www.w3.org/1999/xlink","xlink:arcrole",o);break;case"xlinkRole":Or(e,"http://www.w3.org/1999/xlink","xlink:role",o);break;case"xlinkShow":Or(e,"http://www.w3.org/1999/xlink","xlink:show",o);break;case"xlinkTitle":Or(e,"http://www.w3.org/1999/xlink","xlink:title",o);break;case"xlinkType":Or(e,"http://www.w3.org/1999/xlink","xlink:type",o);break;case"xmlBase":Or(e,"http://www.w3.org/XML/1998/namespace","xml:base",o);break;case"xmlLang":Or(e,"http://www.w3.org/XML/1998/namespace","xml:lang",o);break;case"xmlSpace":Or(e,"http://www.w3.org/XML/1998/namespace","xml:space",o);break;case"is":Lo(e,"is",o);break;case"innerText":case"textContent":break;default:(!(2<a.length)||a[0]!=="o"&&a[0]!=="O"||a[1]!=="n"&&a[1]!=="N")&&(a=YO.get(a)||a,Lo(e,a,o))}}function Vf(e,t,a,o,s,f){switch(a){case"style":av(e,o,f);break;case"dangerouslySetInnerHTML":if(o!=null){if(typeof o!="object"||!("__html"in o))throw Error(l(61));if(a=o.__html,a!=null){if(s.children!=null)throw Error(l(60));e.innerHTML=a}}break;case"children":typeof o=="string"?ri(e,o):(typeof o=="number"||typeof o=="bigint")&&ri(e,""+o);break;case"onScroll":o!=null&&Ge("scroll",e);break;case"onScrollEnd":o!=null&&Ge("scrollend",e);break;case"onClick":o!=null&&(e.onclick=$u);break;case"suppressContentEditableWarning":case"suppressHydrationWarning":case"innerHTML":case"ref":break;case"innerText":case"textContent":break;default:if(!Ca.hasOwnProperty(a))e:{if(a[0]==="o"&&a[1]==="n"&&(s=a.endsWith("Capture"),t=a.slice(2,s?a.length-7:void 0),f=e[St]||null,f=f!=null?f[a]:null,typeof f=="function"&&e.removeEventListener(t,f,s),typeof o=="function")){typeof f!="function"&&f!==null&&(a in e?e[a]=null:e.hasAttribute(a)&&e.removeAttribute(a)),e.addEventListener(t,o,s);break e}a in e?e[a]=o:o===!0?e.setAttribute(a,""):Lo(e,a,o)}}}function Zt(e,t,a){switch(t){case"div":case"span":case"svg":case"path":case"a":case"g":case"p":case"li":break;case"img":Ge("error",e),Ge("load",e);var o=!1,s=!1,f;for(f in a)if(a.hasOwnProperty(f)){var v=a[f];if(v!=null)switch(f){case"src":o=!0;break;case"srcSet":s=!0;break;case"children":case"dangerouslySetInnerHTML":throw Error(l(137,t));default:ot(e,t,f,v,a,null)}}s&&ot(e,t,"srcSet",a.srcSet,a,null),o&&ot(e,t,"src",a.src,a,null);return;case"input":Ge("invalid",e);var b=f=v=s=null,w=null,P=null;for(o in a)if(a.hasOwnProperty(o)){var J=a[o];if(J!=null)switch(o){case"name":s=J;break;case"type":v=J;break;case"checked":w=J;break;case"defaultChecked":P=J;break;case"value":f=J;break;case"defaultValue":b=J;break;case"children":case"dangerouslySetInnerHTML":if(J!=null)throw Error(l(137,t));break;default:ot(e,t,o,J,a,null)}}ev(e,f,b,w,P,v,s,!1),Ho(e);return;case"select":Ge("invalid",e),o=v=f=null;for(s in a)if(a.hasOwnProperty(s)&&(b=a[s],b!=null))switch(s){case"value":f=b;break;case"defaultValue":v=b;break;case"multiple":o=b;default:ot(e,t,s,b,a,null)}t=f,a=v,e.multiple=!!o,t!=null?ni(e,!!o,t,!1):a!=null&&ni(e,!!o,a,!0);return;case"textarea":Ge("invalid",e),f=s=o=null;for(v in a)if(a.hasOwnProperty(v)&&(b=a[v],b!=null))switch(v){case"value":o=b;break;case"defaultValue":s=b;break;case"children":f=b;break;case"dangerouslySetInnerHTML":if(b!=null)throw Error(l(91));break;default:ot(e,t,v,b,a,null)}nv(e,o,s,f),Ho(e);return;case"option":for(w in a)if(a.hasOwnProperty(w)&&(o=a[w],o!=null))switch(w){case"selected":e.selected=o&&typeof o!="function"&&typeof o!="symbol";break;default:ot(e,t,w,o,a,null)}return;case"dialog":Ge("beforetoggle",e),Ge("toggle",e),Ge("cancel",e),Ge("close",e);break;case"iframe":case"object":Ge("load",e);break;case"video":case"audio":for(o=0;o<Hl.length;o++)Ge(Hl[o],e);break;case"image":Ge("error",e),Ge("load",e);break;case"details":Ge("toggle",e);break;case"embed":case"source":case"link":Ge("error",e),Ge("load",e);case"area":case"base":case"br":case"col":case"hr":case"keygen":case"meta":case"param":case"track":case"wbr":case"menuitem":for(P in a)if(a.hasOwnProperty(P)&&(o=a[P],o!=null))switch(P){case"children":case"dangerouslySetInnerHTML":throw Error(l(137,t));default:ot(e,t,P,o,a,null)}return;default:if(ic(t)){for(J in a)a.hasOwnProperty(J)&&(o=a[J],o!==void 0&&Vf(e,t,J,o,a,void 0));return}}for(b in a)a.hasOwnProperty(b)&&(o=a[b],o!=null&&ot(e,t,b,o,a,null))}function h_(e,t,a,o){switch(t){case"div":case"span":case"svg":case"path":case"a":case"g":case"p":case"li":break;case"input":var s=null,f=null,v=null,b=null,w=null,P=null,J=null;for(K in a){var ne=a[K];if(a.hasOwnProperty(K)&&ne!=null)switch(K){case"checked":break;case"value":break;case"defaultValue":w=ne;default:o.hasOwnProperty(K)||ot(e,t,K,null,o,ne)}}for(var Q in o){var K=o[Q];if(ne=a[Q],o.hasOwnProperty(Q)&&(K!=null||ne!=null))switch(Q){case"type":f=K;break;case"name":s=K;break;case"checked":P=K;break;case"defaultChecked":J=K;break;case"value":v=K;break;case"defaultValue":b=K;break;case"children":case"dangerouslySetInnerHTML":if(K!=null)throw Error(l(137,t));break;default:K!==ne&&ot(e,t,Q,K,o,ne)}}rc(e,v,b,w,P,J,f,s);return;case"select":K=v=b=Q=null;for(f in a)if(w=a[f],a.hasOwnProperty(f)&&w!=null)switch(f){case"value":break;case"multiple":K=w;default:o.hasOwnProperty(f)||ot(e,t,f,null,o,w)}for(s in o)if(f=o[s],w=a[s],o.hasOwnProperty(s)&&(f!=null||w!=null))switch(s){case"value":Q=f;break;case"defaultValue":b=f;break;case"multiple":v=f;default:f!==w&&ot(e,t,s,f,o,w)}t=b,a=v,o=K,Q!=null?ni(e,!!a,Q,!1):!!o!=!!a&&(t!=null?ni(e,!!a,t,!0):ni(e,!!a,a?[]:"",!1));return;case"textarea":K=Q=null;for(b in a)if(s=a[b],a.hasOwnProperty(b)&&s!=null&&!o.hasOwnProperty(b))switch(b){case"value":break;case"children":break;default:ot(e,t,b,null,o,s)}for(v in o)if(s=o[v],f=a[v],o.hasOwnProperty(v)&&(s!=null||f!=null))switch(v){case"value":Q=s;break;case"defaultValue":K=s;break;case"children":break;case"dangerouslySetInnerHTML":if(s!=null)throw Error(l(91));break;default:s!==f&&ot(e,t,v,s,o,f)}tv(e,Q,K);return;case"option":for(var Ne in a)if(Q=a[Ne],a.hasOwnProperty(Ne)&&Q!=null&&!o.hasOwnProperty(Ne))switch(Ne){case"selected":e.selected=!1;break;default:ot(e,t,Ne,null,o,Q)}for(w in o)if(Q=o[w],K=a[w],o.hasOwnProperty(w)&&Q!==K&&(Q!=null||K!=null))switch(w){case"selected":e.selected=Q&&typeof Q!="function"&&typeof Q!="symbol";break;default:ot(e,t,w,Q,o,K)}return;case"img":case"link":case"area":case"base":case"br":case"col":case"embed":case"hr":case"keygen":case"meta":case"param":case"source":case"track":case"wbr":case"menuitem":for(var Re in a)Q=a[Re],a.hasOwnProperty(Re)&&Q!=null&&!o.hasOwnProperty(Re)&&ot(e,t,Re,null,o,Q);for(P in o)if(Q=o[P],K=a[P],o.hasOwnProperty(P)&&Q!==K&&(Q!=null||K!=null))switch(P){case"children":case"dangerouslySetInnerHTML":if(Q!=null)throw Error(l(137,t));break;default:ot(e,t,P,Q,o,K)}return;default:if(ic(t)){for(var ut in a)Q=a[ut],a.hasOwnProperty(ut)&&Q!==void 0&&!o.hasOwnProperty(ut)&&Vf(e,t,ut,void 0,o,Q);for(J in o)Q=o[J],K=a[J],!o.hasOwnProperty(J)||Q===K||Q===void 0&&K===void 0||Vf(e,t,J,Q,o,K);return}}for(var U in a)Q=a[U],a.hasOwnProperty(U)&&Q!=null&&!o.hasOwnProperty(U)&&ot(e,t,U,null,o,Q);for(ne in o)Q=o[ne],K=a[ne],!o.hasOwnProperty(ne)||Q===K||Q==null&&K==null||ot(e,t,ne,Q,o,K)}var Pf=null,Xf=null;function qu(e){return e.nodeType===9?e:e.ownerDocument}function r0(e){switch(e){case"http://www.w3.org/2000/svg":return 1;case"http://www.w3.org/1998/Math/MathML":return 2;default:return 0}}function a0(e,t){if(e===0)switch(t){case"svg":return 1;case"math":return 2;default:return 0}return e===1&&t==="foreignObject"?0:e}function Qf(e,t){return e==="textarea"||e==="noscript"||typeof t.children=="string"||typeof t.children=="number"||typeof t.children=="bigint"||typeof t.dangerouslySetInnerHTML=="object"&&t.dangerouslySetInnerHTML!==null&&t.dangerouslySetInnerHTML.__html!=null}var Kf=null;function y_(){var e=window.event;return e&&e.type==="popstate"?e===Kf?!1:(Kf=e,!0):(Kf=null,!1)}var i0=typeof setTimeout=="function"?setTimeout:void 0,v_=typeof clearTimeout=="function"?clearTimeout:void 0,l0=typeof Promise=="function"?Promise:void 0,m_=typeof queueMicrotask=="function"?queueMicrotask:typeof l0<"u"?function(e){return l0.resolve(null).then(e).catch(g_)}:i0;function g_(e){setTimeout(function(){throw e})}function pa(e){return e==="head"}function o0(e,t){var a=t,o=0,s=0;do{var f=a.nextSibling;if(e.removeChild(a),f&&f.nodeType===8)if(a=f.data,a==="/$"){if(0<o&&8>o){a=o;var v=e.ownerDocument;if(a&1&&Yl(v.documentElement),a&2&&Yl(v.body),a&4)for(a=v.head,Yl(a),v=a.firstChild;v;){var b=v.nextSibling,w=v.nodeName;v[wn]||w==="SCRIPT"||w==="STYLE"||w==="LINK"&&v.rel.toLowerCase()==="stylesheet"||a.removeChild(v),v=b}}if(s===0){e.removeChild(f),Il(t);return}s--}else a==="$"||a==="$?"||a==="$!"?s++:o=a.charCodeAt(0)-48;else o=0;a=f}while(a);Il(t)}function Ff(e){var t=e.firstChild;for(t&&t.nodeType===10&&(t=t.nextSibling);t;){var a=t;switch(t=t.nextSibling,a.nodeName){case"HTML":case"HEAD":case"BODY":Ff(a),Qn(a);continue;case"SCRIPT":case"STYLE":continue;case"LINK":if(a.rel.toLowerCase()==="stylesheet")continue}e.removeChild(a)}}function b_(e,t,a,o){for(;e.nodeType===1;){var s=a;if(e.nodeName.toLowerCase()!==t.toLowerCase()){if(!o&&(e.nodeName!=="INPUT"||e.type!=="hidden"))break}else if(o){if(!e[wn])switch(t){case"meta":if(!e.hasAttribute("itemprop"))break;return e;case"link":if(f=e.getAttribute("rel"),f==="stylesheet"&&e.hasAttribute("data-precedence"))break;if(f!==s.rel||e.getAttribute("href")!==(s.href==null||s.href===""?null:s.href)||e.getAttribute("crossorigin")!==(s.crossOrigin==null?null:s.crossOrigin)||e.getAttribute("title")!==(s.title==null?null:s.title))break;return e;case"style":if(e.hasAttribute("data-precedence"))break;return e;case"script":if(f=e.getAttribute("src"),(f!==(s.src==null?null:s.src)||e.getAttribute("type")!==(s.type==null?null:s.type)||e.getAttribute("crossorigin")!==(s.crossOrigin==null?null:s.crossOrigin))&&f&&e.hasAttribute("async")&&!e.hasAttribute("itemprop"))break;return e;default:return e}}else if(t==="input"&&e.type==="hidden"){var f=s.name==null?null:""+s.name;if(s.type==="hidden"&&e.getAttribute("name")===f)return e}else return e;if(e=In(e.nextSibling),e===null)break}return null}function S_(e,t,a){if(t==="")return null;for(;e.nodeType!==3;)if((e.nodeType!==1||e.nodeName!=="INPUT"||e.type!=="hidden")&&!a||(e=In(e.nextSibling),e===null))return null;return e}function Zf(e){return e.data==="$!"||e.data==="$?"&&e.ownerDocument.readyState==="complete"}function x_(e,t){var a=e.ownerDocument;if(e.data!=="$?"||a.readyState==="complete")t();else{var o=function(){t(),a.removeEventListener("DOMContentLoaded",o)};a.addEventListener("DOMContentLoaded",o),e._reactRetry=o}}function In(e){for(;e!=null;e=e.nextSibling){var t=e.nodeType;if(t===1||t===3)break;if(t===8){if(t=e.data,t==="$"||t==="$!"||t==="$?"||t==="F!"||t==="F")break;if(t==="/$")return null}}return e}var If=null;function u0(e){e=e.previousSibling;for(var t=0;e;){if(e.nodeType===8){var a=e.data;if(a==="$"||a==="$!"||a==="$?"){if(t===0)return e;t--}else a==="/$"&&t++}e=e.previousSibling}return null}function s0(e,t,a){switch(t=qu(a),e){case"html":if(e=t.documentElement,!e)throw Error(l(452));return e;case"head":if(e=t.head,!e)throw Error(l(453));return e;case"body":if(e=t.body,!e)throw Error(l(454));return e;default:throw Error(l(451))}}function Yl(e){for(var t=e.attributes;t.length;)e.removeAttributeNode(t[0]);Qn(e)}var kn=new Map,c0=new Set;function zu(e){return typeof e.getRootNode=="function"?e.getRootNode():e.nodeType===9?e:e.ownerDocument}var zr=I.d;I.d={f:E_,r:O_,D:T_,C:__,L:A_,m:R_,X:C_,S:w_,M:N_};function E_(){var e=zr.f(),t=wu();return e||t}function O_(e){var t=We(e);t!==null&&t.tag===5&&t.type==="form"?Nm(t):zr.r(e)}var Di=typeof document>"u"?null:document;function f0(e,t,a){var o=Di;if(o&&typeof t=="string"&&t){var s=Mn(t);s='link[rel="'+e+'"][href="'+s+'"]',typeof a=="string"&&(s+='[crossorigin="'+a+'"]'),c0.has(s)||(c0.add(s),e={rel:e,crossOrigin:a,href:t},o.querySelector(s)===null&&(t=o.createElement("link"),Zt(t,"link",e),ct(t),o.head.appendChild(t)))}}function T_(e){zr.D(e),f0("dns-prefetch",e,null)}function __(e,t){zr.C(e,t),f0("preconnect",e,t)}function A_(e,t,a){zr.L(e,t,a);var o=Di;if(o&&e&&t){var s='link[rel="preload"][as="'+Mn(t)+'"]';t==="image"&&a&&a.imageSrcSet?(s+='[imagesrcset="'+Mn(a.imageSrcSet)+'"]',typeof a.imageSizes=="string"&&(s+='[imagesizes="'+Mn(a.imageSizes)+'"]')):s+='[href="'+Mn(e)+'"]';var f=s;switch(t){case"style":f=ji(e);break;case"script":f=Bi(e)}kn.has(f)||(e=m({rel:"preload",href:t==="image"&&a&&a.imageSrcSet?void 0:e,as:t},a),kn.set(f,e),o.querySelector(s)!==null||t==="style"&&o.querySelector(Vl(f))||t==="script"&&o.querySelector(Pl(f))||(t=o.createElement("link"),Zt(t,"link",e),ct(t),o.head.appendChild(t)))}}function R_(e,t){zr.m(e,t);var a=Di;if(a&&e){var o=t&&typeof t.as=="string"?t.as:"script",s='link[rel="modulepreload"][as="'+Mn(o)+'"][href="'+Mn(e)+'"]',f=s;switch(o){case"audioworklet":case"paintworklet":case"serviceworker":case"sharedworker":case"worker":case"script":f=Bi(e)}if(!kn.has(f)&&(e=m({rel:"modulepreload",href:e},t),kn.set(f,e),a.querySelector(s)===null)){switch(o){case"audioworklet":case"paintworklet":case"serviceworker":case"sharedworker":case"worker":case"script":if(a.querySelector(Pl(f)))return}o=a.createElement("link"),Zt(o,"link",e),ct(o),a.head.appendChild(o)}}}function w_(e,t,a){zr.S(e,t,a);var o=Di;if(o&&e){var s=Cn(o).hoistableStyles,f=ji(e);t=t||"default";var v=s.get(f);if(!v){var b={loading:0,preload:null};if(v=o.querySelector(Vl(f)))b.loading=5;else{e=m({rel:"stylesheet",href:e,"data-precedence":t},a),(a=kn.get(f))&&Wf(e,a);var w=v=o.createElement("link");ct(w),Zt(w,"link",e),w._p=new Promise(function(P,J){w.onload=P,w.onerror=J}),w.addEventListener("load",function(){b.loading|=1}),w.addEventListener("error",function(){b.loading|=2}),b.loading|=4,ku(v,t,o)}v={type:"stylesheet",instance:v,count:1,state:b},s.set(f,v)}}}function C_(e,t){zr.X(e,t);var a=Di;if(a&&e){var o=Cn(a).hoistableScripts,s=Bi(e),f=o.get(s);f||(f=a.querySelector(Pl(s)),f||(e=m({src:e,async:!0},t),(t=kn.get(s))&&Jf(e,t),f=a.createElement("script"),ct(f),Zt(f,"link",e),a.head.appendChild(f)),f={type:"script",instance:f,count:1,state:null},o.set(s,f))}}function N_(e,t){zr.M(e,t);var a=Di;if(a&&e){var o=Cn(a).hoistableScripts,s=Bi(e),f=o.get(s);f||(f=a.querySelector(Pl(s)),f||(e=m({src:e,async:!0,type:"module"},t),(t=kn.get(s))&&Jf(e,t),f=a.createElement("script"),ct(f),Zt(f,"link",e),a.head.appendChild(f)),f={type:"script",instance:f,count:1,state:null},o.set(s,f))}}function d0(e,t,a,o){var s=(s=te.current)?zu(s):null;if(!s)throw Error(l(446));switch(e){case"meta":case"title":return null;case"style":return typeof a.precedence=="string"&&typeof a.href=="string"?(t=ji(a.href),a=Cn(s).hoistableStyles,o=a.get(t),o||(o={type:"style",instance:null,count:0,state:null},a.set(t,o)),o):{type:"void",instance:null,count:0,state:null};case"link":if(a.rel==="stylesheet"&&typeof a.href=="string"&&typeof a.precedence=="string"){e=ji(a.href);var f=Cn(s).hoistableStyles,v=f.get(e);if(v||(s=s.ownerDocument||s,v={type:"stylesheet",instance:null,count:0,state:{loading:0,preload:null}},f.set(e,v),(f=s.querySelector(Vl(e)))&&!f._p&&(v.instance=f,v.state.loading=5),kn.has(e)||(a={rel:"preload",as:"style",href:a.href,crossOrigin:a.crossOrigin,integrity:a.integrity,media:a.media,hrefLang:a.hrefLang,referrerPolicy:a.referrerPolicy},kn.set(e,a),f||M_(s,e,a,v.state))),t&&o===null)throw Error(l(528,""));return v}if(t&&o!==null)throw Error(l(529,""));return null;case"script":return t=a.async,a=a.src,typeof a=="string"&&t&&typeof t!="function"&&typeof t!="symbol"?(t=Bi(a),a=Cn(s).hoistableScripts,o=a.get(t),o||(o={type:"script",instance:null,count:0,state:null},a.set(t,o)),o):{type:"void",instance:null,count:0,state:null};default:throw Error(l(444,e))}}function ji(e){return'href="'+Mn(e)+'"'}function Vl(e){return'link[rel="stylesheet"]['+e+"]"}function p0(e){return m({},e,{"data-precedence":e.precedence,precedence:null})}function M_(e,t,a,o){e.querySelector('link[rel="preload"][as="style"]['+t+"]")?o.loading=1:(t=e.createElement("link"),o.preload=t,t.addEventListener("load",function(){return o.loading|=1}),t.addEventListener("error",function(){return o.loading|=2}),Zt(t,"link",a),ct(t),e.head.appendChild(t))}function Bi(e){return'[src="'+Mn(e)+'"]'}function Pl(e){return"script[async]"+e}function h0(e,t,a){if(t.count++,t.instance===null)switch(t.type){case"style":var o=e.querySelector('style[data-href~="'+Mn(a.href)+'"]');if(o)return t.instance=o,ct(o),o;var s=m({},a,{"data-href":a.href,"data-precedence":a.precedence,href:null,precedence:null});return o=(e.ownerDocument||e).createElement("style"),ct(o),Zt(o,"style",s),ku(o,a.precedence,e),t.instance=o;case"stylesheet":s=ji(a.href);var f=e.querySelector(Vl(s));if(f)return t.state.loading|=4,t.instance=f,ct(f),f;o=p0(a),(s=kn.get(s))&&Wf(o,s),f=(e.ownerDocument||e).createElement("link"),ct(f);var v=f;return v._p=new Promise(function(b,w){v.onload=b,v.onerror=w}),Zt(f,"link",o),t.state.loading|=4,ku(f,a.precedence,e),t.instance=f;case"script":return f=Bi(a.src),(s=e.querySelector(Pl(f)))?(t.instance=s,ct(s),s):(o=a,(s=kn.get(f))&&(o=m({},a),Jf(o,s)),e=e.ownerDocument||e,s=e.createElement("script"),ct(s),Zt(s,"link",o),e.head.appendChild(s),t.instance=s);case"void":return null;default:throw Error(l(443,t.type))}else t.type==="stylesheet"&&(t.state.loading&4)===0&&(o=t.instance,t.state.loading|=4,ku(o,a.precedence,e));return t.instance}function ku(e,t,a){for(var o=a.querySelectorAll('link[rel="stylesheet"][data-precedence],style[data-precedence]'),s=o.length?o[o.length-1]:null,f=s,v=0;v<o.length;v++){var b=o[v];if(b.dataset.precedence===t)f=b;else if(f!==s)break}f?f.parentNode.insertBefore(e,f.nextSibling):(t=a.nodeType===9?a.head:a,t.insertBefore(e,t.firstChild))}function Wf(e,t){e.crossOrigin==null&&(e.crossOrigin=t.crossOrigin),e.referrerPolicy==null&&(e.referrerPolicy=t.referrerPolicy),e.title==null&&(e.title=t.title)}function Jf(e,t){e.crossOrigin==null&&(e.crossOrigin=t.crossOrigin),e.referrerPolicy==null&&(e.referrerPolicy=t.referrerPolicy),e.integrity==null&&(e.integrity=t.integrity)}var Lu=null;function y0(e,t,a){if(Lu===null){var o=new Map,s=Lu=new Map;s.set(a,o)}else s=Lu,o=s.get(a),o||(o=new Map,s.set(a,o));if(o.has(e))return o;for(o.set(e,null),a=a.getElementsByTagName(e),s=0;s<a.length;s++){var f=a[s];if(!(f[wn]||f[At]||e==="link"&&f.getAttribute("rel")==="stylesheet")&&f.namespaceURI!=="http://www.w3.org/2000/svg"){var v=f.getAttribute(t)||"";v=e+v;var b=o.get(v);b?b.push(f):o.set(v,[f])}}return o}function v0(e,t,a){e=e.ownerDocument||e,e.head.insertBefore(a,t==="title"?e.querySelector("head > title"):null)}function D_(e,t,a){if(a===1||t.itemProp!=null)return!1;switch(e){case"meta":case"title":return!0;case"style":if(typeof t.precedence!="string"||typeof t.href!="string"||t.href==="")break;return!0;case"link":if(typeof t.rel!="string"||typeof t.href!="string"||t.href===""||t.onLoad||t.onError)break;switch(t.rel){case"stylesheet":return e=t.disabled,typeof t.precedence=="string"&&e==null;default:return!0}case"script":if(t.async&&typeof t.async!="function"&&typeof t.async!="symbol"&&!t.onLoad&&!t.onError&&t.src&&typeof t.src=="string")return!0}return!1}function m0(e){return!(e.type==="stylesheet"&&(e.state.loading&3)===0)}var Xl=null;function j_(){}function B_(e,t,a){if(Xl===null)throw Error(l(475));var o=Xl;if(t.type==="stylesheet"&&(typeof a.media!="string"||matchMedia(a.media).matches!==!1)&&(t.state.loading&4)===0){if(t.instance===null){var s=ji(a.href),f=e.querySelector(Vl(s));if(f){e=f._p,e!==null&&typeof e=="object"&&typeof e.then=="function"&&(o.count++,o=Uu.bind(o),e.then(o,o)),t.state.loading|=4,t.instance=f,ct(f);return}f=e.ownerDocument||e,a=p0(a),(s=kn.get(s))&&Wf(a,s),f=f.createElement("link"),ct(f);var v=f;v._p=new Promise(function(b,w){v.onload=b,v.onerror=w}),Zt(f,"link",a),t.instance=f}o.stylesheets===null&&(o.stylesheets=new Map),o.stylesheets.set(t,e),(e=t.state.preload)&&(t.state.loading&3)===0&&(o.count++,t=Uu.bind(o),e.addEventListener("load",t),e.addEventListener("error",t))}}function $_(){if(Xl===null)throw Error(l(475));var e=Xl;return e.stylesheets&&e.count===0&&ed(e,e.stylesheets),0<e.count?function(t){var a=setTimeout(function(){if(e.stylesheets&&ed(e,e.stylesheets),e.unsuspend){var o=e.unsuspend;e.unsuspend=null,o()}},6e4);return e.unsuspend=t,function(){e.unsuspend=null,clearTimeout(a)}}:null}function Uu(){if(this.count--,this.count===0){if(this.stylesheets)ed(this,this.stylesheets);else if(this.unsuspend){var e=this.unsuspend;this.unsuspend=null,e()}}}var Hu=null;function ed(e,t){e.stylesheets=null,e.unsuspend!==null&&(e.count++,Hu=new Map,t.forEach(q_,e),Hu=null,Uu.call(e))}function q_(e,t){if(!(t.state.loading&4)){var a=Hu.get(e);if(a)var o=a.get(null);else{a=new Map,Hu.set(e,a);for(var s=e.querySelectorAll("link[data-precedence],style[data-precedence]"),f=0;f<s.length;f++){var v=s[f];(v.nodeName==="LINK"||v.getAttribute("media")!=="not all")&&(a.set(v.dataset.precedence,v),o=v)}o&&a.set(null,o)}s=t.instance,v=s.getAttribute("data-precedence"),f=a.get(v)||o,f===o&&a.set(null,s),a.set(v,s),this.count++,o=Uu.bind(this),s.addEventListener("load",o),s.addEventListener("error",o),f?f.parentNode.insertBefore(s,f.nextSibling):(e=e.nodeType===9?e.head:e,e.insertBefore(s,e.firstChild)),t.state.loading|=4}}var Ql={$$typeof:B,Provider:null,Consumer:null,_currentValue:ae,_currentValue2:ae,_threadCount:0};function z_(e,t,a,o,s,f,v,b){this.tag=1,this.containerInfo=e,this.pingCache=this.current=this.pendingChildren=null,this.timeoutHandle=-1,this.callbackNode=this.next=this.pendingContext=this.context=this.cancelPendingCommit=null,this.callbackPriority=0,this.expirationTimes=De(-1),this.entangledLanes=this.shellSuspendCounter=this.errorRecoveryDisabledLanes=this.expiredLanes=this.warmLanes=this.pingedLanes=this.suspendedLanes=this.pendingLanes=0,this.entanglements=De(0),this.hiddenUpdates=De(null),this.identifierPrefix=o,this.onUncaughtError=s,this.onCaughtError=f,this.onRecoverableError=v,this.pooledCache=null,this.pooledCacheLanes=0,this.formState=b,this.incompleteTransitions=new Map}function g0(e,t,a,o,s,f,v,b,w,P,J,ne){return e=new z_(e,t,a,v,b,w,P,ne),t=1,f===!0&&(t|=24),f=mn(3,null,null,t),e.current=f,f.stateNode=e,t=Bc(),t.refCount++,e.pooledCache=t,t.refCount++,f.memoizedState={element:o,isDehydrated:a,cache:t},kc(f),e}function b0(e){return e?(e=fi,e):fi}function S0(e,t,a,o,s,f){s=b0(s),o.context===null?o.context=s:o.pendingContext=s,o=ea(t),o.payload={element:a},f=f===void 0?null:f,f!==null&&(o.callback=f),a=ta(e,o,t),a!==null&&(En(a,e,t),Ol(a,e,t))}function x0(e,t){if(e=e.memoizedState,e!==null&&e.dehydrated!==null){var a=e.retryLane;e.retryLane=a!==0&&a<t?a:t}}function td(e,t){x0(e,t),(e=e.alternate)&&x0(e,t)}function E0(e){if(e.tag===13){var t=ci(e,67108864);t!==null&&En(t,e,67108864),td(e,67108864)}}var Gu=!0;function k_(e,t,a,o){var s=H.T;H.T=null;var f=I.p;try{I.p=2,nd(e,t,a,o)}finally{I.p=f,H.T=s}}function L_(e,t,a,o){var s=H.T;H.T=null;var f=I.p;try{I.p=8,nd(e,t,a,o)}finally{I.p=f,H.T=s}}function nd(e,t,a,o){if(Gu){var s=rd(o);if(s===null)Yf(e,t,o,Yu,a),T0(e,o);else if(H_(s,e,t,a,o))o.stopPropagation();else if(T0(e,o),t&4&&-1<U_.indexOf(e)){for(;s!==null;){var f=We(s);if(f!==null)switch(f.tag){case 3:if(f=f.stateNode,f.current.memoizedState.isDehydrated){var v=mt(f.pendingLanes);if(v!==0){var b=f;for(b.pendingLanes|=2,b.entangledLanes|=2;v;){var w=1<<31-se(v);b.entanglements[1]|=w,v&=~w}or(f),(at&6)===0&&(Au=Me()+500,Ul(0))}}break;case 13:b=ci(f,2),b!==null&&En(b,f,2),wu(),td(f,2)}if(f=rd(o),f===null&&Yf(e,t,o,Yu,a),f===s)break;s=f}s!==null&&o.stopPropagation()}else Yf(e,t,o,null,a)}}function rd(e){return e=oc(e),ad(e)}var Yu=null;function ad(e){if(Yu=null,e=Kn(e),e!==null){var t=c(e);if(t===null)e=null;else{var a=t.tag;if(a===13){if(e=d(t),e!==null)return e;e=null}else if(a===3){if(t.stateNode.current.memoizedState.isDehydrated)return t.tag===3?t.stateNode.containerInfo:null;e=null}else t!==e&&(e=null)}}return Yu=e,null}function O0(e){switch(e){case"beforetoggle":case"cancel":case"click":case"close":case"contextmenu":case"copy":case"cut":case"auxclick":case"dblclick":case"dragend":case"dragstart":case"drop":case"focusin":case"focusout":case"input":case"invalid":case"keydown":case"keypress":case"keyup":case"mousedown":case"mouseup":case"paste":case"pause":case"play":case"pointercancel":case"pointerdown":case"pointerup":case"ratechange":case"reset":case"resize":case"seeked":case"submit":case"toggle":case"touchcancel":case"touchend":case"touchstart":case"volumechange":case"change":case"selectionchange":case"textInput":case"compositionstart":case"compositionend":case"compositionupdate":case"beforeblur":case"afterblur":case"beforeinput":case"blur":case"fullscreenchange":case"focus":case"hashchange":case"popstate":case"select":case"selectstart":return 2;case"drag":case"dragenter":case"dragexit":case"dragleave":case"dragover":case"mousemove":case"mouseout":case"mouseover":case"pointermove":case"pointerout":case"pointerover":case"scroll":case"touchmove":case"wheel":case"mouseenter":case"mouseleave":case"pointerenter":case"pointerleave":return 8;case"message":switch(Fe()){case Ht:return 2;case ze:return 8;case Ze:case Gt:return 32;case $t:return 268435456;default:return 32}default:return 32}}var id=!1,ha=null,ya=null,va=null,Kl=new Map,Fl=new Map,ma=[],U_="mousedown mouseup touchcancel touchend touchstart auxclick dblclick pointercancel pointerdown pointerup dragend dragstart drop compositionend compositionstart keydown keypress keyup input textInput copy cut paste click change contextmenu reset".split(" ");function T0(e,t){switch(e){case"focusin":case"focusout":ha=null;break;case"dragenter":case"dragleave":ya=null;break;case"mouseover":case"mouseout":va=null;break;case"pointerover":case"pointerout":Kl.delete(t.pointerId);break;case"gotpointercapture":case"lostpointercapture":Fl.delete(t.pointerId)}}function Zl(e,t,a,o,s,f){return e===null||e.nativeEvent!==f?(e={blockedOn:t,domEventName:a,eventSystemFlags:o,nativeEvent:f,targetContainers:[s]},t!==null&&(t=We(t),t!==null&&E0(t)),e):(e.eventSystemFlags|=o,t=e.targetContainers,s!==null&&t.indexOf(s)===-1&&t.push(s),e)}function H_(e,t,a,o,s){switch(t){case"focusin":return ha=Zl(ha,e,t,a,o,s),!0;case"dragenter":return ya=Zl(ya,e,t,a,o,s),!0;case"mouseover":return va=Zl(va,e,t,a,o,s),!0;case"pointerover":var f=s.pointerId;return Kl.set(f,Zl(Kl.get(f)||null,e,t,a,o,s)),!0;case"gotpointercapture":return f=s.pointerId,Fl.set(f,Zl(Fl.get(f)||null,e,t,a,o,s)),!0}return!1}function _0(e){var t=Kn(e.target);if(t!==null){var a=c(t);if(a!==null){if(t=a.tag,t===13){if(t=d(a),t!==null){e.blockedOn=t,Zr(e.priority,function(){if(a.tag===13){var o=xn();o=br(o);var s=ci(a,o);s!==null&&En(s,a,o),td(a,o)}});return}}else if(t===3&&a.stateNode.current.memoizedState.isDehydrated){e.blockedOn=a.tag===3?a.stateNode.containerInfo:null;return}}}e.blockedOn=null}function Vu(e){if(e.blockedOn!==null)return!1;for(var t=e.targetContainers;0<t.length;){var a=rd(e.nativeEvent);if(a===null){a=e.nativeEvent;var o=new a.constructor(a.type,a);lc=o,a.target.dispatchEvent(o),lc=null}else return t=We(a),t!==null&&E0(t),e.blockedOn=a,!1;t.shift()}return!0}function A0(e,t,a){Vu(e)&&a.delete(t)}function G_(){id=!1,ha!==null&&Vu(ha)&&(ha=null),ya!==null&&Vu(ya)&&(ya=null),va!==null&&Vu(va)&&(va=null),Kl.forEach(A0),Fl.forEach(A0)}function Pu(e,t){e.blockedOn===t&&(e.blockedOn=null,id||(id=!0,n.unstable_scheduleCallback(n.unstable_NormalPriority,G_)))}var Xu=null;function R0(e){Xu!==e&&(Xu=e,n.unstable_scheduleCallback(n.unstable_NormalPriority,function(){Xu===e&&(Xu=null);for(var t=0;t<e.length;t+=3){var a=e[t],o=e[t+1],s=e[t+2];if(typeof o!="function"){if(ad(o||a)===null)continue;break}var f=We(a);f!==null&&(e.splice(t,3),t-=3,rf(f,{pending:!0,data:s,method:a.method,action:o},o,s))}}))}function Il(e){function t(w){return Pu(w,e)}ha!==null&&Pu(ha,e),ya!==null&&Pu(ya,e),va!==null&&Pu(va,e),Kl.forEach(t),Fl.forEach(t);for(var a=0;a<ma.length;a++){var o=ma[a];o.blockedOn===e&&(o.blockedOn=null)}for(;0<ma.length&&(a=ma[0],a.blockedOn===null);)_0(a),a.blockedOn===null&&ma.shift();if(a=(e.ownerDocument||e).$$reactFormReplay,a!=null)for(o=0;o<a.length;o+=3){var s=a[o],f=a[o+1],v=s[St]||null;if(typeof f=="function")v||R0(a);else if(v){var b=null;if(f&&f.hasAttribute("formAction")){if(s=f,v=f[St]||null)b=v.formAction;else if(ad(s)!==null)continue}else b=v.action;typeof b=="function"?a[o+1]=b:(a.splice(o,3),o-=3),R0(a)}}}function ld(e){this._internalRoot=e}Qu.prototype.render=ld.prototype.render=function(e){var t=this._internalRoot;if(t===null)throw Error(l(409));var a=t.current,o=xn();S0(a,o,e,t,null,null)},Qu.prototype.unmount=ld.prototype.unmount=function(){var e=this._internalRoot;if(e!==null){this._internalRoot=null;var t=e.containerInfo;S0(e.current,2,null,e,null,null),wu(),t[Rn]=null}};function Qu(e){this._internalRoot=e}Qu.prototype.unstable_scheduleHydration=function(e){if(e){var t=Vt();e={blockedOn:null,target:e,priority:t};for(var a=0;a<ma.length&&t!==0&&t<ma[a].priority;a++);ma.splice(a,0,e),a===0&&_0(e)}};var w0=r.version;if(w0!=="19.1.0")throw Error(l(527,w0,"19.1.0"));I.findDOMNode=function(e){var t=e._reactInternals;if(t===void 0)throw typeof e.render=="function"?Error(l(188)):(e=Object.keys(e).join(","),Error(l(268,e)));return e=h(t),e=e!==null?y(e):null,e=e===null?null:e.stateNode,e};var Y_={bundleType:0,version:"19.1.0",rendererPackageName:"react-dom",currentDispatcherRef:H,reconcilerVersion:"19.1.0"};if(typeof __REACT_DEVTOOLS_GLOBAL_HOOK__<"u"){var Ku=__REACT_DEVTOOLS_GLOBAL_HOOK__;if(!Ku.isDisabled&&Ku.supportsFiber)try{_t=Ku.inject(Y_),rt=Ku}catch{}}return io.createRoot=function(e,t){if(!u(e))throw Error(l(299));var a=!1,o="",s=Vm,f=Pm,v=Xm,b=null;return t!=null&&(t.unstable_strictMode===!0&&(a=!0),t.identifierPrefix!==void 0&&(o=t.identifierPrefix),t.onUncaughtError!==void 0&&(s=t.onUncaughtError),t.onCaughtError!==void 0&&(f=t.onCaughtError),t.onRecoverableError!==void 0&&(v=t.onRecoverableError),t.unstable_transitionCallbacks!==void 0&&(b=t.unstable_transitionCallbacks)),t=g0(e,1,!1,null,null,a,o,s,f,v,b,null),e[Rn]=t.current,Gf(e),new ld(t)},io.hydrateRoot=function(e,t,a){if(!u(e))throw Error(l(299));var o=!1,s="",f=Vm,v=Pm,b=Xm,w=null,P=null;return a!=null&&(a.unstable_strictMode===!0&&(o=!0),a.identifierPrefix!==void 0&&(s=a.identifierPrefix),a.onUncaughtError!==void 0&&(f=a.onUncaughtError),a.onCaughtError!==void 0&&(v=a.onCaughtError),a.onRecoverableError!==void 0&&(b=a.onRecoverableError),a.unstable_transitionCallbacks!==void 0&&(w=a.unstable_transitionCallbacks),a.formState!==void 0&&(P=a.formState)),t=g0(e,1,!0,t,a??null,o,s,f,v,b,w,P),t.context=b0(null),a=t.current,o=xn(),o=br(o),s=ea(o),s.callback=null,ta(a,s,o),a=o,t.current.lanes=a,Yt(t,a),or(t),e[Rn]=t.current,Gf(e),new Qu(t)},io.version="19.1.0",io}var YS;function S5(){if(YS)return vh.exports;YS=1;function n(){if(!(typeof __REACT_DEVTOOLS_GLOBAL_HOOK__>"u"||typeof __REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE!="function"))try{__REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE(n)}catch{}}return n(),vh.exports=b5(),vh.exports}var x5=S5();const E5=_a(x5);E5.createRoot(document.getElementById("root")).render(T.jsx(Xe.StrictMode,{children:T.jsx(v5,{})}));
